@@ -1,20 +1,19 @@
 /* EEG.cpp
  *
- * Copyright (C) 2011-2012,2013,2014,2015 Paul Boersma
+ * Copyright (C) 2011-2012,2013,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "EEG.h"
@@ -61,8 +60,8 @@ void structEEG :: v_info () {
 
 void structEEG :: v_shiftX (double xfrom, double xto) {
 	EEG_Parent :: v_shiftX (xfrom, xto);
-	if (our sound   )  Function_shiftXTo (our sound,    xfrom, xto);
-	if (our textgrid)  Function_shiftXTo (our textgrid, xfrom, xto);
+	if (our sound   )  Function_shiftXTo (our sound.get(),    xfrom, xto);
+	if (our textgrid)  Function_shiftXTo (our textgrid.get(), xfrom, xto);
 }
 
 void structEEG :: v_scaleX (double xminfrom, double xmaxfrom, double xminto, double xmaxto) {
@@ -76,11 +75,11 @@ void EEG_init (EEG me, double tmin, double tmax) {
 	my xmax = tmax;
 }
 
-EEG EEG_create (double tmin, double tmax) {
+autoEEG EEG_create (double tmin, double tmax) {
 	try {
 		autoEEG me = Thing_new (EEG);
-		EEG_init (me.peek(), tmin, tmax);
-		return me.transfer();
+		EEG_init (me.get(), tmin, tmax);
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"EEG object not created.");
 	}
@@ -95,7 +94,7 @@ long EEG_getChannelNumber (EEG me, const char32 *channelName) {
 	return 0;
 }
 
-EEG EEG_readFromBdfFile (MelderFile file) {
+autoEEG EEG_readFromBdfFile (MelderFile file) {
 	try {
 		autofile f = Melder_fopen (file, "rb");
 		char buffer [81];
@@ -198,7 +197,7 @@ EEG EEG_readFromBdfFile (MelderFile file) {
 		for (long record = 1; record <= numberOfDataRecords; record ++) {
 			for (long channel = 1; channel <= numberOfChannels; channel ++) {
 				double factor = channel == numberOfChannels ? 1.0 : physicalMinimum [channel] / digitalMinimum [channel];
-				if (channel < numberOfChannels - EEG_getNumberOfExtraSensors (him.peek())) factor /= 1000000.0;
+				if (channel < numberOfChannels - EEG_getNumberOfExtraSensors (him.get())) factor /= 1000000.0;
 				if (is24bit) {
 					fread (& dataBuffer [0], 3, numberOfSamplesPerDataRecord, f);
 					unsigned char *p = & dataBuffer [0];
@@ -247,7 +246,7 @@ EEG EEG_readFromBdfFile (MelderFile file) {
 						if (letters. string [0] == U'+') {
 							if (NUMdefined (time)) {
 								try {
-									TextGrid_insertPoint (thee.peek(), 1, time, U"");
+									TextGrid_insertPoint (thee.get(), 1, time, U"");
 								} catch (MelderError) {
 									Melder_throw (U"Did not insert empty mark (", letters. string, U") on Mark tier.");
 								}
@@ -262,13 +261,13 @@ EEG EEG_readFromBdfFile (MelderFile file) {
 							try {
 								if (Melder_nequ (letters. string, U"Trigger-", 8)) {
 									try {
-										TextGrid_insertPoint (thee.peek(), 2, time, & letters. string [8]);
+										TextGrid_insertPoint (thee.get(), 2, time, & letters. string [8]);
 									} catch (MelderError) {
 										Melder_clearError ();
 										trace (U"Duplicate trigger at ", time, U" seconds: ", & letters. string [8]);
 									}
 								} else {
-									TextGrid_insertPoint (thee.peek(), 1, time, & letters. string [0]);
+									TextGrid_insertPoint (thee.get(), 1, time, & letters. string [0]);
 								}
 							} catch (MelderError) {
 								Melder_throw (U"Did not insert mark (", letters. string, U") on Trigger tier.");
@@ -280,7 +279,7 @@ EEG EEG_readFromBdfFile (MelderFile file) {
 				}
 			}
 			if (NUMdefined (time)) {
-				TextGrid_insertPoint (thee.peek(), 1, time, U"");
+				TextGrid_insertPoint (thee.get(), 1, time, U"");
 				time = NUMundefined;   // defensive
 			}
 		} else {
@@ -288,124 +287,124 @@ EEG EEG_readFromBdfFile (MelderFile file) {
 				numberOfStatusBits == 8 ? U"S1 S2 S3 S4 S5 S6 S7 S8" : U"S1 S2 S3 S4 S5 S6 S7 S8 S9 S10 S11 S12 S13 S14 S15 S16", U"");
 			for (int bit = 1; bit <= numberOfStatusBits; bit ++) {
 				unsigned long bitValue = 1 << (bit - 1);
-				IntervalTier tier = (IntervalTier) thy tiers -> item [bit];
+				IntervalTier tier = (IntervalTier) thy tiers->at [bit];
 				for (long i = 1; i <= my nx; i ++) {
 					unsigned long previousValue = i == 1 ? 0 : (long) my z [numberOfChannels] [i - 1];
 					unsigned long thisValue = (long) my z [numberOfChannels] [i];
 					if ((thisValue & bitValue) != (previousValue & bitValue)) {
 						double time = i == 1 ? 0.0 : my x1 + (i - 1.5) * my dx;
 						if (time != 0.0)
-							TextGrid_insertBoundary (thee.peek(), bit, time);
+							TextGrid_insertBoundary (thee.get(), bit, time);
 						if ((thisValue & bitValue) != 0)
-							TextGrid_setIntervalText (thee.peek(), bit, tier -> intervals -> size, U"1");
+							TextGrid_setIntervalText (thee.get(), bit, tier -> intervals.size, U"1");
 					}
 				}
 			}
 		}
 		f.close (file);
 		his channelNames = channelNames.transfer();
-		his sound = me.transfer();
-		his textgrid = thee.transfer();
-		if (EEG_getNumberOfCapElectrodes (him.peek()) == 32) {
-			EEG_setChannelName (him.peek(), 1, U"Fp1");
-			EEG_setChannelName (him.peek(), 2, U"AF3");
-			EEG_setChannelName (him.peek(), 3, U"F7");
-			EEG_setChannelName (him.peek(), 4, U"F3");
-			EEG_setChannelName (him.peek(), 5, U"FC1");
-			EEG_setChannelName (him.peek(), 6, U"FC5");
-			EEG_setChannelName (him.peek(), 7, U"T7");
-			EEG_setChannelName (him.peek(), 8, U"C3");
-			EEG_setChannelName (him.peek(), 9, U"CP1");
-			EEG_setChannelName (him.peek(), 10, U"CP5");
-			EEG_setChannelName (him.peek(), 11, U"P7");
-			EEG_setChannelName (him.peek(), 12, U"P3");
-			EEG_setChannelName (him.peek(), 13, U"Pz");
-			EEG_setChannelName (him.peek(), 14, U"PO3");
-			EEG_setChannelName (him.peek(), 15, U"O1");
-			EEG_setChannelName (him.peek(), 16, U"Oz");
-			EEG_setChannelName (him.peek(), 17, U"O2");
-			EEG_setChannelName (him.peek(), 18, U"PO4");
-			EEG_setChannelName (him.peek(), 19, U"P4");
-			EEG_setChannelName (him.peek(), 20, U"P8");
-			EEG_setChannelName (him.peek(), 21, U"CP6");
-			EEG_setChannelName (him.peek(), 22, U"CP2");
-			EEG_setChannelName (him.peek(), 23, U"C4");
-			EEG_setChannelName (him.peek(), 24, U"T8");
-			EEG_setChannelName (him.peek(), 25, U"FC6");
-			EEG_setChannelName (him.peek(), 26, U"FC2");
-			EEG_setChannelName (him.peek(), 27, U"F4");
-			EEG_setChannelName (him.peek(), 28, U"F8");
-			EEG_setChannelName (him.peek(), 29, U"AF4");
-			EEG_setChannelName (him.peek(), 30, U"Fp2");
-			EEG_setChannelName (him.peek(), 31, U"Fz");
-			EEG_setChannelName (him.peek(), 32, U"Cz");
-		} else if (EEG_getNumberOfCapElectrodes (him.peek()) == 64) {
-			EEG_setChannelName (him.peek(), 1, U"Fp1");
-			EEG_setChannelName (him.peek(), 2, U"AF7");
-			EEG_setChannelName (him.peek(), 3, U"AF3");
-			EEG_setChannelName (him.peek(), 4, U"F1");
-			EEG_setChannelName (him.peek(), 5, U"F3");
-			EEG_setChannelName (him.peek(), 6, U"F5");
-			EEG_setChannelName (him.peek(), 7, U"F7");
-			EEG_setChannelName (him.peek(), 8, U"FT7");
-			EEG_setChannelName (him.peek(), 9, U"FC5");
-			EEG_setChannelName (him.peek(), 10, U"FC3");
-			EEG_setChannelName (him.peek(), 11, U"FC1");
-			EEG_setChannelName (him.peek(), 12, U"C1");
-			EEG_setChannelName (him.peek(), 13, U"C3");
-			EEG_setChannelName (him.peek(), 14, U"C5");
-			EEG_setChannelName (him.peek(), 15, U"T7");
-			EEG_setChannelName (him.peek(), 16, U"TP7");
-			EEG_setChannelName (him.peek(), 17, U"CP5");
-			EEG_setChannelName (him.peek(), 18, U"CP3");
-			EEG_setChannelName (him.peek(), 19, U"CP1");
-			EEG_setChannelName (him.peek(), 20, U"P1");
-			EEG_setChannelName (him.peek(), 21, U"P3");
-			EEG_setChannelName (him.peek(), 22, U"P5");
-			EEG_setChannelName (him.peek(), 23, U"P7");
-			EEG_setChannelName (him.peek(), 24, U"P9");
-			EEG_setChannelName (him.peek(), 25, U"PO7");
-			EEG_setChannelName (him.peek(), 26, U"PO3");
-			EEG_setChannelName (him.peek(), 27, U"O1");
-			EEG_setChannelName (him.peek(), 28, U"Iz");
-			EEG_setChannelName (him.peek(), 29, U"Oz");
-			EEG_setChannelName (him.peek(), 30, U"POz");
-			EEG_setChannelName (him.peek(), 31, U"Pz");
-			EEG_setChannelName (him.peek(), 32, U"CPz");
-			EEG_setChannelName (him.peek(), 33, U"Fpz");
-			EEG_setChannelName (him.peek(), 34, U"Fp2");
-			EEG_setChannelName (him.peek(), 35, U"AF8");
-			EEG_setChannelName (him.peek(), 36, U"AF4");
-			EEG_setChannelName (him.peek(), 37, U"AFz");
-			EEG_setChannelName (him.peek(), 38, U"Fz");
-			EEG_setChannelName (him.peek(), 39, U"F2");
-			EEG_setChannelName (him.peek(), 40, U"F4");
-			EEG_setChannelName (him.peek(), 41, U"F6");
-			EEG_setChannelName (him.peek(), 42, U"F8");
-			EEG_setChannelName (him.peek(), 43, U"FT8");
-			EEG_setChannelName (him.peek(), 44, U"FC6");
-			EEG_setChannelName (him.peek(), 45, U"FC4");
-			EEG_setChannelName (him.peek(), 46, U"FC2");
-			EEG_setChannelName (him.peek(), 47, U"FCz");
-			EEG_setChannelName (him.peek(), 48, U"Cz");
-			EEG_setChannelName (him.peek(), 49, U"C2");
-			EEG_setChannelName (him.peek(), 50, U"C4");
-			EEG_setChannelName (him.peek(), 51, U"C6");
-			EEG_setChannelName (him.peek(), 52, U"T8");
-			EEG_setChannelName (him.peek(), 53, U"TP8");
-			EEG_setChannelName (him.peek(), 54, U"CP6");
-			EEG_setChannelName (him.peek(), 55, U"CP4");
-			EEG_setChannelName (him.peek(), 56, U"CP2");
-			EEG_setChannelName (him.peek(), 57, U"P2");
-			EEG_setChannelName (him.peek(), 58, U"P4");
-			EEG_setChannelName (him.peek(), 59, U"P6");
-			EEG_setChannelName (him.peek(), 60, U"P8");
-			EEG_setChannelName (him.peek(), 61, U"P10");
-			EEG_setChannelName (him.peek(), 62, U"PO8");
-			EEG_setChannelName (him.peek(), 63, U"PO4");
-			EEG_setChannelName (him.peek(), 64, U"O2");
+		his sound = me.move();
+		his textgrid = thee.move();
+		if (EEG_getNumberOfCapElectrodes (him.get()) == 32) {
+			EEG_setChannelName (him.get(), 1, U"Fp1");
+			EEG_setChannelName (him.get(), 2, U"AF3");
+			EEG_setChannelName (him.get(), 3, U"F7");
+			EEG_setChannelName (him.get(), 4, U"F3");
+			EEG_setChannelName (him.get(), 5, U"FC1");
+			EEG_setChannelName (him.get(), 6, U"FC5");
+			EEG_setChannelName (him.get(), 7, U"T7");
+			EEG_setChannelName (him.get(), 8, U"C3");
+			EEG_setChannelName (him.get(), 9, U"CP1");
+			EEG_setChannelName (him.get(), 10, U"CP5");
+			EEG_setChannelName (him.get(), 11, U"P7");
+			EEG_setChannelName (him.get(), 12, U"P3");
+			EEG_setChannelName (him.get(), 13, U"Pz");
+			EEG_setChannelName (him.get(), 14, U"PO3");
+			EEG_setChannelName (him.get(), 15, U"O1");
+			EEG_setChannelName (him.get(), 16, U"Oz");
+			EEG_setChannelName (him.get(), 17, U"O2");
+			EEG_setChannelName (him.get(), 18, U"PO4");
+			EEG_setChannelName (him.get(), 19, U"P4");
+			EEG_setChannelName (him.get(), 20, U"P8");
+			EEG_setChannelName (him.get(), 21, U"CP6");
+			EEG_setChannelName (him.get(), 22, U"CP2");
+			EEG_setChannelName (him.get(), 23, U"C4");
+			EEG_setChannelName (him.get(), 24, U"T8");
+			EEG_setChannelName (him.get(), 25, U"FC6");
+			EEG_setChannelName (him.get(), 26, U"FC2");
+			EEG_setChannelName (him.get(), 27, U"F4");
+			EEG_setChannelName (him.get(), 28, U"F8");
+			EEG_setChannelName (him.get(), 29, U"AF4");
+			EEG_setChannelName (him.get(), 30, U"Fp2");
+			EEG_setChannelName (him.get(), 31, U"Fz");
+			EEG_setChannelName (him.get(), 32, U"Cz");
+		} else if (EEG_getNumberOfCapElectrodes (him.get()) == 64) {
+			EEG_setChannelName (him.get(), 1, U"Fp1");
+			EEG_setChannelName (him.get(), 2, U"AF7");
+			EEG_setChannelName (him.get(), 3, U"AF3");
+			EEG_setChannelName (him.get(), 4, U"F1");
+			EEG_setChannelName (him.get(), 5, U"F3");
+			EEG_setChannelName (him.get(), 6, U"F5");
+			EEG_setChannelName (him.get(), 7, U"F7");
+			EEG_setChannelName (him.get(), 8, U"FT7");
+			EEG_setChannelName (him.get(), 9, U"FC5");
+			EEG_setChannelName (him.get(), 10, U"FC3");
+			EEG_setChannelName (him.get(), 11, U"FC1");
+			EEG_setChannelName (him.get(), 12, U"C1");
+			EEG_setChannelName (him.get(), 13, U"C3");
+			EEG_setChannelName (him.get(), 14, U"C5");
+			EEG_setChannelName (him.get(), 15, U"T7");
+			EEG_setChannelName (him.get(), 16, U"TP7");
+			EEG_setChannelName (him.get(), 17, U"CP5");
+			EEG_setChannelName (him.get(), 18, U"CP3");
+			EEG_setChannelName (him.get(), 19, U"CP1");
+			EEG_setChannelName (him.get(), 20, U"P1");
+			EEG_setChannelName (him.get(), 21, U"P3");
+			EEG_setChannelName (him.get(), 22, U"P5");
+			EEG_setChannelName (him.get(), 23, U"P7");
+			EEG_setChannelName (him.get(), 24, U"P9");
+			EEG_setChannelName (him.get(), 25, U"PO7");
+			EEG_setChannelName (him.get(), 26, U"PO3");
+			EEG_setChannelName (him.get(), 27, U"O1");
+			EEG_setChannelName (him.get(), 28, U"Iz");
+			EEG_setChannelName (him.get(), 29, U"Oz");
+			EEG_setChannelName (him.get(), 30, U"POz");
+			EEG_setChannelName (him.get(), 31, U"Pz");
+			EEG_setChannelName (him.get(), 32, U"CPz");
+			EEG_setChannelName (him.get(), 33, U"Fpz");
+			EEG_setChannelName (him.get(), 34, U"Fp2");
+			EEG_setChannelName (him.get(), 35, U"AF8");
+			EEG_setChannelName (him.get(), 36, U"AF4");
+			EEG_setChannelName (him.get(), 37, U"AFz");
+			EEG_setChannelName (him.get(), 38, U"Fz");
+			EEG_setChannelName (him.get(), 39, U"F2");
+			EEG_setChannelName (him.get(), 40, U"F4");
+			EEG_setChannelName (him.get(), 41, U"F6");
+			EEG_setChannelName (him.get(), 42, U"F8");
+			EEG_setChannelName (him.get(), 43, U"FT8");
+			EEG_setChannelName (him.get(), 44, U"FC6");
+			EEG_setChannelName (him.get(), 45, U"FC4");
+			EEG_setChannelName (him.get(), 46, U"FC2");
+			EEG_setChannelName (him.get(), 47, U"FCz");
+			EEG_setChannelName (him.get(), 48, U"Cz");
+			EEG_setChannelName (him.get(), 49, U"C2");
+			EEG_setChannelName (him.get(), 50, U"C4");
+			EEG_setChannelName (him.get(), 51, U"C6");
+			EEG_setChannelName (him.get(), 52, U"T8");
+			EEG_setChannelName (him.get(), 53, U"TP8");
+			EEG_setChannelName (him.get(), 54, U"CP6");
+			EEG_setChannelName (him.get(), 55, U"CP4");
+			EEG_setChannelName (him.get(), 56, U"CP2");
+			EEG_setChannelName (him.get(), 57, U"P2");
+			EEG_setChannelName (him.get(), 58, U"P4");
+			EEG_setChannelName (him.get(), 59, U"P6");
+			EEG_setChannelName (him.get(), 60, U"P8");
+			EEG_setChannelName (him.get(), 61, U"P10");
+			EEG_setChannelName (him.get(), 62, U"PO8");
+			EEG_setChannelName (him.get(), 63, U"PO4");
+			EEG_setChannelName (him.get(), 64, U"O2");
 		}
-		return him.transfer();
+		return him;
 	} catch (MelderError) {
 		Melder_throw (U"BDF file not read.");
 	}
@@ -435,14 +434,14 @@ void EEG_filter (EEG me, double lowFrequency, double lowWidth, double highFreque
 	NUMfft_Table_init (& fftTable, nsampFFT);
 */
 		for (long ichan = 1; ichan <= my numberOfChannels - EEG_getNumberOfExtraSensors (me); ichan ++) {
-			autoSound channel = Sound_extractChannel (my sound, ichan);
-			autoSpectrum spec = Sound_to_Spectrum (channel.peek(), true);
-			Spectrum_passHannBand (spec.peek(), lowFrequency, 0.0, lowWidth);
-			Spectrum_passHannBand (spec.peek(), 0.0, highFrequency, highWidth);
+			autoSound channel = Sound_extractChannel (my sound.get(), ichan);
+			autoSpectrum spec = Sound_to_Spectrum (channel.get(), true);
+			Spectrum_passHannBand (spec.get(), lowFrequency, 0.0, lowWidth);
+			Spectrum_passHannBand (spec.get(), 0.0, highFrequency, highWidth);
 			if (doNotch50Hz) {
-				Spectrum_stopHannBand (spec.peek(), 48.0, 52.0, 1.0);
+				Spectrum_stopHannBand (spec.get(), 48.0, 52.0, 1.0);
 			}
-			autoSound him = Spectrum_to_Sound (spec.peek());
+			autoSound him = Spectrum_to_Sound (spec.get());
 			NUMvector_copyElements (his z [1], my sound -> z [ichan], 1, my sound -> nx);
 		}
 	} catch (MelderError) {
@@ -537,15 +536,15 @@ void EEG_setChannelToZero (EEG me, const char32 *channelName) {
 
 void EEG_removeTriggers (EEG me, int which_Melder_STRING, const char32 *criterion) {
 	try {
-		if (my textgrid -> numberOfTiers () < 2 || ! Melder_equ (my textgrid -> tier (2) -> name, U"Trigger"))
+		if (my textgrid -> tiers->size < 2 || ! Melder_equ (my textgrid -> tiers->at [2] -> name, U"Trigger"))
 			Melder_throw (me, U" does not have a Trigger channel.");
-		TextGrid_removePoints (my textgrid, 2, which_Melder_STRING, criterion);
+		TextGrid_removePoints (my textgrid.get(), 2, which_Melder_STRING, criterion);
 	} catch (MelderError) {
 		Melder_throw (me, U": triggers not removed.");
 	}
 }
 
-EEG EEG_extractChannel (EEG me, long channelNumber) {
+autoEEG EEG_extractChannel (EEG me, long channelNumber) {
 	try {
 		if (channelNumber < 1 || channelNumber > my numberOfChannels)
 			Melder_throw (U"No channel ", channelNumber, U".");
@@ -553,15 +552,15 @@ EEG EEG_extractChannel (EEG me, long channelNumber) {
 		thy numberOfChannels = 1;
 		thy channelNames = NUMvector <char32 *> (1, 1);
 		thy channelNames [1] = Melder_dup (my channelNames [1]);
-		thy sound = Sound_extractChannel (my sound, channelNumber).transfer();
-		thy textgrid = Data_copy (my textgrid);
-		return thee.transfer();
+		thy sound = Sound_extractChannel (my sound.get(), channelNumber);
+		thy textgrid = Data_copy (my textgrid.get());
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": channel ", channelNumber, U" not extracted.");
 	}
 }
 
-EEG EEG_extractChannel (EEG me, const char32 *channelName) {
+autoEEG EEG_extractChannel (EEG me, const char32 *channelName) {
 	try {
 		long channelNumber = EEG_getChannelNumber (me, channelName);
 		if (channelNumber == 0)
@@ -572,15 +571,15 @@ EEG EEG_extractChannel (EEG me, const char32 *channelName) {
 	}
 }
 
-EEG EEGs_concatenate (Collection me) {
+autoEEG EEGs_concatenate (OrderedOf<structEEG>* me) {
 	try {
 		if (my size < 1)
 			Melder_throw (U"Cannot concatenate zero EEG objects.");
-		EEG first = (EEG) my item [1];
+		EEG first = my at [1];
 		long numberOfChannels = first -> numberOfChannels;
 		char32 **channelNames = first -> channelNames;
 		for (long ieeg = 2; ieeg <= my size; ieeg ++) {
-			EEG other = (EEG) my item [ieeg];
+			EEG other = my at [ieeg];
 			if (other -> numberOfChannels != numberOfChannels)
 				Melder_throw (U"The number of channels of ", other, U" does not match the number of channels of ", first, U".");
 			for (long ichan = 1; ichan <= numberOfChannels; ichan ++) {
@@ -588,14 +587,12 @@ EEG EEGs_concatenate (Collection me) {
 					Melder_throw (U"Channel ", ichan, U" has a different name in ", other, U" (", other -> channelNames [ichan], U") than in ", first, U" (", channelNames [ichan], U").");
 			}
 		}
-		autoOrdered soundCollection = Ordered_create ();
-		Collection_dontOwnItems (soundCollection.peek());
-		autoOrdered textgridCollection = Ordered_create ();
-		Collection_dontOwnItems (textgridCollection.peek());
+		OrderedOf<structSound> soundList;
+		OrderedOf<structTextGrid> textgridList;
 		for (long ieeg = 1; ieeg <= my size; ieeg ++) {
-			EEG eeg = (EEG) my item [ieeg];
-			Collection_addItem (soundCollection.peek(), eeg -> sound);
-			Collection_addItem (textgridCollection.peek(), eeg -> textgrid);
+			EEG eeg = my at [ieeg];
+			soundList. addItem_ref (eeg -> sound.get());
+			textgridList. addItem_ref (eeg -> textgrid.get());
 		}
 		autoEEG thee = Thing_new (EEG);
 		thy numberOfChannels = numberOfChannels;
@@ -603,17 +600,17 @@ EEG EEGs_concatenate (Collection me) {
 		for (long ichan = 1; ichan <= numberOfChannels; ichan ++) {
 			thy channelNames [ichan] = Melder_dup (channelNames [ichan]);
 		}
-		thy sound = Sounds_concatenate_e (soundCollection.peek(), 0.0).transfer();
-		thy textgrid = TextGrids_concatenate (textgridCollection.peek()).transfer();
+		thy sound = Sounds_concatenate (soundList, 0.0);
+		thy textgrid = TextGrids_concatenate (& textgridList);
 		thy xmin = thy textgrid -> xmin;
 		thy xmax = thy textgrid -> xmax;
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (U"TextGrids not concatenated.");
 	}
 }
 
-EEG EEG_extractPart (EEG me, double tmin, double tmax, bool preserveTimes) {
+autoEEG EEG_extractPart (EEG me, double tmin, double tmax, bool preserveTimes) {
 	try {
 		autoEEG thee = Thing_new (EEG);
 		thy numberOfChannels = my numberOfChannels;
@@ -621,11 +618,11 @@ EEG EEG_extractPart (EEG me, double tmin, double tmax, bool preserveTimes) {
 		for (long ichan = 1; ichan <= my numberOfChannels; ichan ++) {
 			thy channelNames [ichan] = Melder_dup (my channelNames [ichan]);
 		}
-		thy sound = Sound_extractPart (my sound, tmin, tmax, kSound_windowShape_RECTANGULAR, 1.0, preserveTimes).transfer();
-		thy textgrid = TextGrid_extractPart (my textgrid, tmin, tmax, preserveTimes).transfer();
+		thy sound = Sound_extractPart (my sound.get(), tmin, tmax, kSound_windowShape_RECTANGULAR, 1.0, preserveTimes);
+		thy textgrid = TextGrid_extractPart (my textgrid.get(), tmin, tmax, preserveTimes);
 		thy xmin = thy textgrid -> xmin;
 		thy xmax = thy textgrid -> xmax;
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": part not extracted.");
 	}
@@ -633,24 +630,22 @@ EEG EEG_extractPart (EEG me, double tmin, double tmax, bool preserveTimes) {
 
 void EEG_replaceTextGrid (EEG me, TextGrid textgrid) {
 	try {
-		autoTextGrid textgrid2 = Data_copy (textgrid);
-		forget (my textgrid);
-		my textgrid = textgrid2.transfer();
+		my textgrid = Data_copy (textgrid);
 	} catch (MelderError) {
 		Melder_throw (me, U": TextGrid not replaced with ", textgrid, U".");
 	}
 }
 
-MixingMatrix EEG_to_MixingMatrix (EEG me, long maxNumberOfIterations, double tol, int method) {
+autoMixingMatrix EEG_to_MixingMatrix (EEG me, long maxNumberOfIterations, double tol, int method) {
 	try {
-		autoCrossCorrelationTables tables = Sound_to_CrossCorrelationTables (my sound, 0.0, 0.0, 0.002, 1);
+		autoCrossCorrelationTableList tables = Sound_to_CrossCorrelationTableList (my sound.get(), 0.0, 0.0, 0.002, 1);
 		autoMixingMatrix thee = MixingMatrix_create (my sound -> ny, my sound -> ny);
 		for (long ichan = 1; ichan <= my numberOfChannels; ichan ++) {
-			TableOfReal_setRowLabel (thee.peek(), ichan, my channelNames [ichan]);
-			TableOfReal_setColumnLabel (thee.peek(), ichan, Melder_cat (U"ic", ichan));
+			TableOfReal_setRowLabel (thee.get(), ichan, my channelNames [ichan]);
+			TableOfReal_setColumnLabel (thee.get(), ichan, Melder_cat (U"ic", ichan));
 		}
-		MixingMatrix_and_CrossCorrelationTables_improveUnmixing (thee.peek(), tables.peek(), maxNumberOfIterations, tol, method);
-		return thee.transfer();
+		MixingMatrix_and_CrossCorrelationTableList_improveUnmixing (thee.get(), tables.get(), maxNumberOfIterations, tol, method);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": no MixingMatrix created.");
 	}
