@@ -2,19 +2,18 @@
  *
  * Copyright (C) 2011,2014,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -23,8 +22,8 @@ oo_DEFINE_CLASS (EEG, Function)
 
 	oo_LONG (numberOfChannels)
 	oo_STRING_VECTOR (channelNames, numberOfChannels)
-	oo_OBJECT (Sound, 2, sound)
-	oo_OBJECT (TextGrid, 0, textgrid)
+	oo_AUTO_OBJECT (Sound, 2, sound)
+	oo_AUTO_OBJECT (TextGrid, 0, textgrid)
 
 	#if oo_DECLARING
 		void v_info ()
@@ -40,4 +39,5 @@ oo_DEFINE_CLASS (EEG, Function)
 oo_END_CLASS (EEG)
 #undef ooSTRUCT
 
+
 /* End of file EEG_def.h */
