@@ -1,20 +1,19 @@
 /* ERPTier.cpp
  *
- * Copyright (C) 2011-2012,2014,2015 Paul Boersma
+ * Copyright (C) 2011-2012,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "ERPTier.h"
@@ -44,19 +43,7 @@ Thing_implement (ERPPoint, AnyPoint, 0);
 
 /***** ERPTier *****/
 
-Thing_implement (ERPTier, Function, 0);
-
-void structERPTier :: v_shiftX (double xfrom, double xto) {
-	ERPTier_Parent :: v_shiftX (xfrom, xto);
-	//if (our sound   )  Function_shiftXTo (our sound,    xfrom, xto);
-	//if (our textgrid)  Function_shiftXTo (our textgrid, xfrom, xto);
-}
-
-void structERPTier :: v_scaleX (double xminfrom, double xmaxfrom, double xminto, double xmaxto) {
-	ERPTier_Parent :: v_scaleX (xminfrom, xmaxfrom, xminto, xmaxto);
-	//if (our sound   )  our sound    -> v_scaleX (xminfrom, xmaxfrom, xminto, xmaxto);
-	//if (our textgrid)  our textgrid -> v_scaleX (xminfrom, xmaxfrom, xminto, xmaxto);
-}
+Thing_implement (ERPTier, AnyTier, 0);
 
 long ERPTier_getChannelNumber (ERPTier me, const char32 *channelName) {
 	for (long ichan = 1; ichan <= my numberOfChannels; ichan ++) {
@@ -68,9 +55,9 @@ long ERPTier_getChannelNumber (ERPTier me, const char32 *channelName) {
 }
 
 double ERPTier_getMean (ERPTier me, long pointNumber, long channelNumber, double tmin, double tmax) {
-	if (pointNumber < 1 || pointNumber > my events -> size) return NUMundefined;
+	if (pointNumber < 1 || pointNumber > my points.size) return NUMundefined;
 	if (channelNumber < 1 || channelNumber > my numberOfChannels) return NUMundefined;
-	ERPPoint point = my event (pointNumber);
+	ERPPoint point = my points.at [pointNumber];
 	return Vector_getMean (point -> erp.get(), tmin, tmax, channelNumber);
 }
 
@@ -78,10 +65,10 @@ double ERPTier_getMean (ERPTier me, long pointNumber, const char32 *channelName,
 	return ERPTier_getMean (me, pointNumber, ERPTier_getChannelNumber (me, channelName), tmin, tmax);
 }
 
-static ERPTier EEG_PointProcess_to_ERPTier (EEG me, PointProcess events, double fromTime, double toTime) {
+static autoERPTier EEG_PointProcess_to_ERPTier (EEG me, PointProcess events, double fromTime, double toTime) {
 	try {
 		autoERPTier thee = Thing_new (ERPTier);
-		Function_init (thee.peek(), fromTime, toTime);
+		Function_init (thee.get(), fromTime, toTime);
 		thy numberOfChannels = my numberOfChannels - EEG_getNumberOfExtraSensors (me);
 		Melder_assert (thy numberOfChannels > 0);
 		thy channelNames = NUMvector <char32 *> (1, thy numberOfChannels);
@@ -89,7 +76,6 @@ static ERPTier EEG_PointProcess_to_ERPTier (EEG me, PointProcess events, double
 			thy channelNames [ichan] = Melder_dup (my channelNames [ichan]);
 		}
 		long numberOfEvents = events -> nt;
-		thy events = SortedSetOfDouble_create ();
 		double soundDuration = toTime - fromTime;
 		double samplingPeriod = my sound -> dx;
 		long numberOfSamples = (long) floor (soundDuration / samplingPeriod) + 1;
@@ -113,19 +99,19 @@ static ERPTier EEG_PointProcess_to_ERPTier (EEG me, PointProcess events, double
 					event -> erp -> z [ichannel] [isample] = jsample < 1 || jsample > my sound -> nx ? 0.0 : my sound -> z [ichannel] [jsample];
 				}
 			}
-			Collection_addItem (thy events, event.transfer());
+			thy points. addItem_move (event.move());
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": ERP analysis not performed.");
 	}
 }
 
-ERPTier EEG_to_ERPTier_bit (EEG me, double fromTime, double toTime, int markerBit) {
+autoERPTier EEG_to_ERPTier_bit (EEG me, double fromTime, double toTime, int markerBit) {
 	try {
-		autoPointProcess events = TextGrid_getStartingPoints (my textgrid, markerBit, kMelder_string_EQUAL_TO, U"1");
-		autoERPTier thee = EEG_PointProcess_to_ERPTier (me, events.peek(), fromTime, toTime);
-		return thee.transfer();
+		autoPointProcess events = TextGrid_getStartingPoints (my textgrid.get(), markerBit, kMelder_string_EQUAL_TO, U"1");
+		autoERPTier thee = EEG_PointProcess_to_ERPTier (me, events.get(), fromTime, toTime);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": ERPTier not created.");
 	}
@@ -134,13 +120,13 @@ ERPTier EEG_to_ERPTier_bit (EEG me, double fromTime, double toTime, int markerBi
 static autoPointProcess TextGrid_getStartingPoints_multiNumeric (TextGrid me, uint16_t number) {
 	try {
 		autoPointProcess thee;
-		int numberOfBits = my numberOfTiers();
+		int numberOfBits = my tiers->size;
 		for (int ibit = 0; ibit < numberOfBits; ibit ++) {
 			(void) TextGrid_checkSpecifiedTierIsIntervalTier (me, ibit + 1);
 			if (number & (1 << ibit)) {
 				autoPointProcess bitEvents = TextGrid_getStartingPoints (me, ibit + 1, kMelder_string_EQUAL_TO, U"1");
 				if (thee) {
-					thee = PointProcesses_intersection (thee.peek(), bitEvents.peek());
+					thee = PointProcesses_intersection (thee.get(), bitEvents.get());
 				} else {
 					thee = bitEvents.move();
 				}
@@ -150,7 +136,7 @@ static autoPointProcess TextGrid_getStartingPoints_multiNumeric (TextGrid me, ui
 			autoPointProcess bitEvents = TextGrid_getStartingPoints (me, ibit + 1, kMelder_string_EQUAL_TO, U"1");
 			if (! (number & (1 << ibit))) {
 				if (thee) {
-					thee = PointProcesses_difference (thee.peek(), bitEvents.peek());
+					thee = PointProcesses_difference (thee.get(), bitEvents.get());
 				} else {
 					thee = PointProcess_create (my xmin, my xmax, 10);
 				}
@@ -162,52 +148,52 @@ static autoPointProcess TextGrid_getStartingPoints_multiNumeric (TextGrid me, ui
 	}
 }
 
-ERPTier EEG_to_ERPTier_marker (EEG me, double fromTime, double toTime, uint16_t marker) {
+autoERPTier EEG_to_ERPTier_marker (EEG me, double fromTime, double toTime, uint16_t marker) {
 	try {
-		autoPointProcess events = TextGrid_getStartingPoints_multiNumeric (my textgrid, marker);
-		autoERPTier thee = EEG_PointProcess_to_ERPTier (me, events.peek(), fromTime, toTime);
-		return thee.transfer();
+		autoPointProcess events = TextGrid_getStartingPoints_multiNumeric (my textgrid.get(), marker);
+		autoERPTier thee = EEG_PointProcess_to_ERPTier (me, events.get(), fromTime, toTime);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": ERPTier not created.");
 	}
 }
 
-ERPTier EEG_to_ERPTier_triggers (EEG me, double fromTime, double toTime,
+autoERPTier EEG_to_ERPTier_triggers (EEG me, double fromTime, double toTime,
 	int which_Melder_STRING, const char32 *criterion)
 {
 	try {
-		autoPointProcess events = TextGrid_getPoints (my textgrid, 2, which_Melder_STRING, criterion);
-		autoERPTier thee = EEG_PointProcess_to_ERPTier (me, events.peek(), fromTime, toTime);
-		return thee.transfer();
+		autoPointProcess events = TextGrid_getPoints (my textgrid.get(), 2, which_Melder_STRING, criterion);
+		autoERPTier thee = EEG_PointProcess_to_ERPTier (me, events.get(), fromTime, toTime);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": ERPTier not created.");
 	}
 }
 
-ERPTier EEG_to_ERPTier_triggers_preceded (EEG me, double fromTime, double toTime,
+autoERPTier EEG_to_ERPTier_triggers_preceded (EEG me, double fromTime, double toTime,
 	int which_Melder_STRING, const char32 *criterion,
 	int which_Melder_STRING_precededBy, const char32 *criterion_precededBy)
 {
 	try {
-		autoPointProcess events = TextGrid_getPoints_preceded (my textgrid, 2,
+		autoPointProcess events = TextGrid_getPoints_preceded (my textgrid.get(), 2,
 			which_Melder_STRING, criterion,
 			which_Melder_STRING_precededBy, criterion_precededBy);
-		autoERPTier thee = EEG_PointProcess_to_ERPTier (me, events.peek(), fromTime, toTime);
-		return thee.transfer();
+		autoERPTier thee = EEG_PointProcess_to_ERPTier (me, events.get(), fromTime, toTime);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": ERPTier not created.");
 	}
 }
 
 void ERPTier_subtractBaseline (ERPTier me, double tmin, double tmax) {
-	long numberOfEvents = my events -> size;
+	long numberOfEvents = my points.size;
 	if (numberOfEvents < 1)
 		return;   // nothing to do
-	ERPPoint firstEvent = my event (1);
+	ERPPoint firstEvent = my points.at [1];
 	long numberOfChannels = firstEvent -> erp -> ny;
 	long numberOfSamples = firstEvent -> erp -> nx;
 	for (long ievent = 1; ievent <= numberOfEvents; ievent ++) {
-		ERPPoint event = my event (ievent);
+		ERPPoint event = my points.at [ievent];
 		for (long ichannel = 1; ichannel <= numberOfChannels; ichannel ++) {
 			double mean = Vector_getMean (event -> erp.get(), tmin, tmax, ichannel);
 			double *channel = event -> erp -> z [ichannel];
@@ -219,16 +205,16 @@ void ERPTier_subtractBaseline (ERPTier me, double tmin, double tmax) {
 }
 
 void ERPTier_rejectArtefacts (ERPTier me, double threshold) {
-	long numberOfEvents = my events -> size;
+	long numberOfEvents = my points.size;
 	if (numberOfEvents < 1)
 		return;   // nothing to do
-	ERPPoint firstEvent = my event (1);
+	ERPPoint firstEvent = my points.at [1];
 	long numberOfChannels = firstEvent -> erp -> ny;
 	long numberOfSamples = firstEvent -> erp -> nx;
 	if (numberOfSamples < 1)
 		return;   // nothing to do
 	for (long ievent = numberOfEvents; ievent >= 1; ievent --) {   // cycle down because of removal
-		ERPPoint event = my event (ievent);
+		ERPPoint event = my points.at [ievent];
 		double minimum = event -> erp -> z [1] [1];
 		double maximum = minimum;
 		for (long ichannel = 1; ichannel <= (numberOfChannels & ~ 15); ichannel ++) {
@@ -240,22 +226,22 @@ void ERPTier_rejectArtefacts (ERPTier me, double threshold) {
 			}
 		}
 		if (minimum < - threshold || maximum > threshold) {
-			Collection_removeItem (my events, ievent);
+			my points. removeItem (ievent);
 		}
 	}
 }
 
-ERP ERPTier_extractERP (ERPTier me, long eventNumber) {
+autoERP ERPTier_extractERP (ERPTier me, long eventNumber) {
 	try {
-		long numberOfEvents = my events -> size;
+		long numberOfEvents = my points.size;
 		if (numberOfEvents < 1)
 			Melder_throw (U"No events.");
 		ERPTier_checkEventNumber (me, eventNumber);
-		ERPPoint event = my event (eventNumber);
+		ERPPoint event = my points.at [eventNumber];
 		long numberOfChannels = event -> erp -> ny;
 		long numberOfSamples = event -> erp -> nx;
 		autoERP thee = Thing_new (ERP);
-		event -> erp -> structSound :: v_copy (thee.peek());
+		event -> erp -> structSound :: v_copy (thee.get());
 		for (long ichannel = 1; ichannel <= numberOfChannels; ichannel ++) {
 			double *oldChannel = event -> erp -> z [ichannel];
 			double *newChannel = thy z [ichannel];
@@ -267,24 +253,24 @@ ERP ERPTier_extractERP (ERPTier me, long eventNumber) {
 		for (long ichan = 1; ichan <= thy ny; ichan ++) {
 			thy channelNames [ichan] = Melder_dup (my channelNames [ichan]);
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": ERP not extracted.");
 	}
 }
 
-ERP ERPTier_to_ERP_mean (ERPTier me) {
+autoERP ERPTier_to_ERP_mean (ERPTier me) {
 	try {
-		long numberOfEvents = my events -> size;
+		long numberOfEvents = my points.size;
 		if (numberOfEvents < 1)
 			Melder_throw (U"No events.");
-		ERPPoint firstEvent = my event (1);
+		ERPPoint firstEvent = my points.at [1];
 		long numberOfChannels = firstEvent -> erp -> ny;
 		long numberOfSamples = firstEvent -> erp -> nx;
 		autoERP mean = Thing_new (ERP);
-		firstEvent -> erp -> structSound :: v_copy (mean.peek());
+		firstEvent -> erp -> structSound :: v_copy (mean.get());
 		for (long ievent = 2; ievent <= numberOfEvents; ievent ++) {
-			ERPPoint event = my event (ievent);
+			ERPPoint event = my points.at [ievent];
 			for (long ichannel = 1; ichannel <= numberOfChannels; ichannel ++) {
 				double *erpChannel = event -> erp -> z [ichannel];
 				double *meanChannel = mean -> z [ichannel];
@@ -304,72 +290,70 @@ ERP ERPTier_to_ERP_mean (ERPTier me) {
 		for (long ichan = 1; ichan <= mean -> ny; ichan ++) {
 			mean -> channelNames [ichan] = Melder_dup (my channelNames [ichan]);
 		}
-		return mean.transfer();
+		return mean;
 	} catch (MelderError) {
 		Melder_throw (me, U": mean not computed.");
 	}
 }
 
-ERPTier ERPTier_extractEventsWhereColumn_number (ERPTier me, Table table, long columnNumber, int which_Melder_NUMBER, double criterion) {
+autoERPTier ERPTier_extractEventsWhereColumn_number (ERPTier me, Table table, long columnNumber, int which_Melder_NUMBER, double criterion) {
 	try {
 		Table_checkSpecifiedColumnNumberWithinRange (table, columnNumber);
 		Table_numericize_Assert (table, columnNumber);   // extraction should work even if cells are not defined
-		if (my events -> size != table -> rows -> size)
-			Melder_throw (me, U" & ", table, U": the number of rows in the table (", table -> rows -> size,
-				U") doesn't match the number of events (", my events -> size, U").");
+		if (my points.size != table -> rows.size)
+			Melder_throw (me, U" & ", table, U": the number of rows in the table (", table -> rows.size,
+				U") doesn't match the number of events (", my points.size, U").");
 		autoERPTier thee = Thing_new (ERPTier);
-		Function_init (thee.peek(), my xmin, my xmax);
+		Function_init (thee.get(), my xmin, my xmax);
 		thy numberOfChannels = my numberOfChannels;
 		thy channelNames = NUMvector <char32 *> (1, thy numberOfChannels);
 		for (long ichan = 1; ichan <= thy numberOfChannels; ichan ++) {
 			thy channelNames [ichan] = Melder_dup (my channelNames [ichan]);
 		}
-		thy events = SortedSetOfDouble_create ();
-		for (long ievent = 1; ievent <= my events -> size; ievent ++) {
-			ERPPoint oldEvent = my event (ievent);
-			TableRow row = table -> row (ievent);
+		for (long ievent = 1; ievent <= my points.size; ievent ++) {
+			ERPPoint oldEvent = my points.at [ievent];
+			TableRow row = table -> rows.at [ievent];
 			if (Melder_numberMatchesCriterion (row -> cells [columnNumber]. number, which_Melder_NUMBER, criterion)) {
 				autoERPPoint newEvent = Data_copy (oldEvent);
-				Collection_addItem (thy events, newEvent.transfer());
+				thy points. addItem_move (newEvent.move());
 			}
 		}
-		if (thy events -> size == 0) {
+		if (thy points.size == 0) {
 			Melder_warning (U"No event matches criterion.");
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": events not extracted.");
 	}
 }
 
-ERPTier ERPTier_extractEventsWhereColumn_string (ERPTier me, Table table,
+autoERPTier ERPTier_extractEventsWhereColumn_string (ERPTier me, Table table,
 	long columnNumber, int which_Melder_STRING, const char32 *criterion)
 {
 	try {
 		Table_checkSpecifiedColumnNumberWithinRange (table, columnNumber);
-		if (my events -> size != table -> rows -> size)
-			Melder_throw (me, U" & ", table, U": the number of rows in the table (", table -> rows -> size,
-				U") doesn't match the number of events (", my events -> size, U").");
+		if (my points.size != table -> rows.size)
+			Melder_throw (me, U" & ", table, U": the number of rows in the table (", table -> rows.size,
+				U") doesn't match the number of events (", my points.size, U").");
 		autoERPTier thee = Thing_new (ERPTier);
-		Function_init (thee.peek(), my xmin, my xmax);
+		Function_init (thee.get(), my xmin, my xmax);
 		thy numberOfChannels = my numberOfChannels;
 		thy channelNames = NUMvector <char32 *> (1, thy numberOfChannels);
 		for (long ichan = 1; ichan <= thy numberOfChannels; ichan ++) {
 			thy channelNames [ichan] = Melder_dup (my channelNames [ichan]);
 		}
-		thy events = SortedSetOfDouble_create ();
-		for (long ievent = 1; ievent <= my events -> size; ievent ++) {
-			ERPPoint oldEvent = my event (ievent);
-			TableRow row = table -> row (ievent);
+		for (long ievent = 1; ievent <= my points.size; ievent ++) {
+			ERPPoint oldEvent = my points.at [ievent];
+			TableRow row = table -> rows.at [ievent];
 			if (Melder_stringMatchesCriterion (row -> cells [columnNumber]. string, which_Melder_STRING, criterion)) {
 				autoERPPoint newEvent = Data_copy (oldEvent);
-				Collection_addItem (thy events, newEvent.transfer());
+				thy points. addItem_move (newEvent.move());
 			}
 		}
-		if (thy events -> size == 0) {
+		if (thy points.size == 0) {
 			Melder_warning (U"No event matches criterion.");
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": events not extracted.");
 	}
