@@ -1,20 +1,19 @@
 /* ERPWindow.cpp
  *
- * Copyright (C) 2012,2013,2014,2015 Paul Boersma
+ * Copyright (C) 2012,2013,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "ERPWindow.h"
@@ -272,10 +271,10 @@ void ERP_drawScalp (ERP me, Graphics graphics, double tmin, double tmax, double
 
 void structERPWindow :: v_drawSelectionViewer () {
 	ERP erp = (ERP) data;
-	Graphics_setWindow (d_graphics, -1.1, 1.1, -1.01, 1.19);
-	Graphics_setColour (d_graphics, Graphics_WINDOW_BACKGROUND_COLOUR);
-	Graphics_fillRectangle (d_graphics, -1.1, 1.1, -1.01, 1.19);
-	Graphics_setColour (d_graphics, Graphics_BLACK);
+	Graphics_setWindow (d_graphics.get(), -1.1, 1.1, -1.01, 1.19);
+	Graphics_setColour (d_graphics.get(), Graphics_WINDOW_BACKGROUND_COLOUR);
+	Graphics_fillRectangle (d_graphics.get(), -1.1, 1.1, -1.01, 1.19);
+	Graphics_setColour (d_graphics.get(), Graphics_BLACK);
 	long numberOfDrawableChannels =
 			erp -> ny >= 64 && Melder_equ (erp -> channelNames [64], U"O2") ? 64 :
 			erp -> ny >= 32 && Melder_equ (erp -> channelNames [32], U"Cz") ? 32 :
@@ -355,43 +354,43 @@ void structERPWindow :: v_drawSelectionViewer () {
 			}
 		}
 	}
-	Graphics_setColourScale (d_graphics, our p_scalp_colourScale);
-	Graphics_image (d_graphics, image.peek(), 1, n, -1.0-0.5/n, 1.0+0.5/n, 1, n, -1.0-0.5/n, 1.0+0.5/n, minimum, maximum);
-	Graphics_setColourScale (d_graphics, kGraphics_colourScale_GREY);
-	Graphics_setLineWidth (d_graphics, 2.0);
+	Graphics_setColourScale (our d_graphics.get(), our p_scalp_colourScale);
+	Graphics_image (our d_graphics.get(), image.peek(), 1, n, -1.0-0.5/n, 1.0+0.5/n, 1, n, -1.0-0.5/n, 1.0+0.5/n, minimum, maximum);
+	Graphics_setColourScale (our d_graphics.get(), kGraphics_colourScale_GREY);
+	Graphics_setLineWidth (our d_graphics.get(), 2.0);
 	/*
 	 * Nose.
 	 */
-	Graphics_setGrey (d_graphics, our p_scalp_colourScale == kGraphics_colourScale_BLUE_TO_RED ? 1.0 : 0.5);
+	Graphics_setGrey (our d_graphics.get(), our p_scalp_colourScale == kGraphics_colourScale_BLUE_TO_RED ? 1.0 : 0.5);
 	{// scope
 		double x [3] = { -0.08, 0.0, 0.08 }, y [3] = { 0.99, 1.18, 0.99 };
-		Graphics_fillArea (d_graphics, 3, x, y);
+		Graphics_fillArea (our d_graphics.get(), 3, x, y);
 	}
-	Graphics_setColour (d_graphics, Graphics_BLACK);
-	Graphics_line (d_graphics, -0.08, 0.99, 0.0, 1.18);
-	Graphics_line (d_graphics, 0.08, 0.99, 0.0, 1.18);
+	Graphics_setColour (our d_graphics.get(), Graphics_BLACK);
+	Graphics_line (our d_graphics.get(), -0.08, 0.99, 0.0, 1.18);
+	Graphics_line (our d_graphics.get(), 0.08, 0.99, 0.0, 1.18);
 	/*
 	 * Ears.
 	 */
-	Graphics_setGrey (d_graphics, our p_scalp_colourScale == kGraphics_colourScale_BLUE_TO_RED ? 1.0 : 0.5);
-	Graphics_fillRectangle (d_graphics, -1.09, -1.00, -0.08, 0.08);
-	Graphics_fillRectangle (d_graphics, 1.09, 1.00, -0.08, 0.08);
-	Graphics_setColour (d_graphics, Graphics_BLACK);
-	Graphics_line (d_graphics, -0.99, 0.08, -1.09, 0.08);
-	Graphics_line (d_graphics, -1.09, 0.08, -1.09, -0.08);
-	Graphics_line (d_graphics, -1.09, -0.08, -0.99, -0.08);
-	Graphics_line (d_graphics, 0.99, 0.08, 1.09, 0.08);
-	Graphics_line (d_graphics, 1.09, 0.08, 1.09, -0.08);
-	Graphics_line (d_graphics, 1.09, -0.08, 0.99, -0.08);
+	Graphics_setGrey (our d_graphics.get(), our p_scalp_colourScale == kGraphics_colourScale_BLUE_TO_RED ? 1.0 : 0.5);
+	Graphics_fillRectangle (our d_graphics.get(), -1.09, -1.00, -0.08, 0.08);
+	Graphics_fillRectangle (our d_graphics.get(), 1.09, 1.00, -0.08, 0.08);
+	Graphics_setColour (our d_graphics.get(), Graphics_BLACK);
+	Graphics_line (our d_graphics.get(), -0.99, 0.08, -1.09, 0.08);
+	Graphics_line (our d_graphics.get(), -1.09, 0.08, -1.09, -0.08);
+	Graphics_line (our d_graphics.get(), -1.09, -0.08, -0.99, -0.08);
+	Graphics_line (our d_graphics.get(), 0.99, 0.08, 1.09, 0.08);
+	Graphics_line (our d_graphics.get(), 1.09, 0.08, 1.09, -0.08);
+	Graphics_line (our d_graphics.get(), 1.09, -0.08, 0.99, -0.08);
 	/*
 	 * Scalp.
 	 */
-	Graphics_ellipse (d_graphics, -1.0, 1.0, -1.0, 1.0);
-	Graphics_setLineWidth (d_graphics, 1.0);
+	Graphics_ellipse (our d_graphics.get(), -1.0, 1.0, -1.0, 1.0);
+	Graphics_setLineWidth (our d_graphics.get(), 1.0);
 }
 
 void structERPWindow :: v_prefs_addFields (EditorCommand cmd) {
-	Any radio;
+	UiField radio;
 	OPTIONMENU_ENUM (U"Scalp colour space", kGraphics_colourScale, kGraphics_colourScale_BLUE_TO_RED)
 }
 void structERPWindow :: v_prefs_setValues (EditorCommand cmd) {
@@ -406,7 +405,7 @@ autoERPWindow ERPWindow_create (const char32 *title, ERP data) {
 	Melder_assert (data);
 	try {
 		autoERPWindow me = Thing_new (ERPWindow);
-		SoundEditor_init (me.peek(), title, data);
+		SoundEditor_init (me.get(), title, data);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"ERP window not created.");
