@@ -2,19 +2,18 @@
  *
  * Copyright (C) 1994-2011, 2015 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -34,8 +33,7 @@
 	LPC-spectrum is approximately 20 dB too high (w.r.t. 25 ms spectrum from Sound)
 */
 
-void LPC_Frame_into_Spectrum (LPC_Frame me, Spectrum thee, double bandwidthReduction,
-                              double deEmphasisFrequency) {
+void LPC_Frame_into_Spectrum (LPC_Frame me, Spectrum thee, double bandwidthReduction, double deEmphasisFrequency) {
 	if (my nCoefficients == 0) {
 		for (long i = 1; i <= thy nx; i++) {
 			thy z[1][i] = thy z[2][i] = 0.0;
@@ -87,11 +85,11 @@ void LPC_Frame_into_Spectrum (LPC_Frame me, Spectrum thee, double bandwidthReduc
 	*/
 
 	NUMforwardRealFastFourierTransform (fftbuffer.peek(), nfft);
-	if (my gain > 0) {
+	if (my gain > 0.0) {
 		scale *= sqrt (my gain);
 	}
 	thy z[1][1] = scale / fftbuffer[1];
-	thy z[2][1] = 0;
+	thy z[2][1] = 0.0;
 	for (long i = 2; i <= nfft / 2; i++) {
 		// We use: 1 / (a + ib) = (a - ib) / (a^2 + b^2)
 
@@ -101,7 +99,7 @@ void LPC_Frame_into_Spectrum (LPC_Frame me, Spectrum thee, double bandwidthReduc
 		thy z[2][i] = -im * invSquared;
 	}
 	thy z[1][thy nx] = scale / fftbuffer[2];
-	thy z[2][thy nx] = 0;
+	thy z[2][thy nx] = 0.0;
 }
 
 autoSpectrum LPC_to_Spectrum (LPC me, double t, double dfMin, double bandwidthReduction, double deEmphasisFrequency) {
@@ -122,7 +120,7 @@ autoSpectrum LPC_to_Spectrum (LPC me, double t, double dfMin, double bandwidthRe
 			nfft *= 2;
 		}
 		autoSpectrum thee = Spectrum_create (samplingFrequency / 2.0, nfft / 2 + 1);
-		LPC_Frame_into_Spectrum (& my d_frames[index], thee.peek(), bandwidthReduction, deEmphasisFrequency);
+		LPC_Frame_into_Spectrum (& my d_frames[index], thee.get(), bandwidthReduction, deEmphasisFrequency);
 		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": no Spectrum created.");
