@@ -2,21 +2,20 @@
 #define _Sound_and_LPC_h_
 /* Sound_and_LPC.h
  *
- * Copyright (C) 1994-2011, 2015 David Weenink
+ * Copyright (C) 1994-2011, 2015-2016 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -29,17 +28,13 @@
 #include "LPC.h"
 #include "Sound.h"
 
-autoLPC Sound_to_LPC_auto (Sound me, int predictionOrder, double analysisWidth, double dt,
-	double preEmphasisFrequency);
+autoLPC Sound_to_LPC_auto (Sound me, int predictionOrder, double analysisWidth, double dt, double preEmphasisFrequency);
 
-autoLPC Sound_to_LPC_covar (Sound me, int predictionOrder, double analysisWidth, double dt,
-	double preEmphasisFrequency);
+autoLPC Sound_to_LPC_covar (Sound me, int predictionOrder, double analysisWidth, double dt, double preEmphasisFrequency);
 
-autoLPC Sound_to_LPC_burg (Sound me, int predictionOrder, double analysisWidth, double dt,
-	double preEmphasisFrequency);
+autoLPC Sound_to_LPC_burg (Sound me, int predictionOrder, double analysisWidth, double dt, double preEmphasisFrequency);
 
-autoLPC Sound_to_LPC_marple (Sound me, int predictionOrder, double analysisWidth, double dt,
-	double preEmphasisFrequency, double tol1, double tol2);
+autoLPC Sound_to_LPC_marple (Sound me, int predictionOrder, double analysisWidth, double dt, double preEmphasisFrequency, double tol1, double tol2);
 
 /*
  * Function:
@@ -71,6 +66,7 @@ autoLPC Sound_to_LPC_marple (Sound me, int predictionOrder, double analysisWidth
  */
 
 void LPC_Frame_and_Sound_filterInverse (LPC_Frame me, Sound thee, int channel);
+
 autoSound LPC_and_Sound_filter (LPC me, Sound thee, int useGain);
 /*
 	E(z) = X(z)A(z),
@@ -83,6 +79,7 @@ autoSound LPC_and_Sound_filter (LPC me, Sound thee, int useGain);
 */
 
 void LPC_and_Sound_filterWithFilterAtTime_inline (LPC me, Sound thee, int channel, double time);
+
 autoSound LPC_and_Sound_filterWithFilterAtTime (LPC me, Sound thee, int channel, double time);
 
 autoSound LPC_and_Sound_filterInverse (LPC me, Sound thee);
@@ -96,6 +93,7 @@ autoSound LPC_and_Sound_filterInverse (LPC me, Sound thee);
 */
 
 autoSound LPC_and_Sound_filterInverseWithFilterAtTime (LPC me, Sound thee, int channel, double time);
+
 void LPC_and_Sound_filterInverseWithFilterAtTime_inline (LPC me, Sound thee, int channel, double time);
 
 #endif /* _Sound_and_LPC_h_ */
