@@ -2,19 +2,18 @@
  *
  * Copyright (C) 1992-2011,2013,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "ArtwordEditor.h"
@@ -22,8 +21,7 @@
 
 Thing_implement (ArtwordEditor, Editor, 0);
 
-void structArtwordEditor :: v_destroy () {
-	forget (graphics);
+void structArtwordEditor :: v_destroy () noexcept {
 	ArtwordEditor_Parent :: v_destroy ();
 }
 
@@ -36,12 +34,10 @@ static void updateList (ArtwordEditor me) {
 			Melder_cat (Melder_single (a -> times [i]), U"  ", Melder_single (a -> targets [i])),
 			i);
 	}
-	Graphics_updateWs (my graphics);
+	Graphics_updateWs (my graphics.get());
 }
 
-static void gui_button_cb_removeTarget (I, GuiButtonEvent event) {
-	(void) event;
-	iam (ArtwordEditor);
+static void gui_button_cb_removeTarget (ArtwordEditor me, GuiButtonEvent /* event */) {
 	Artword artword = (Artword) my data;
 	long numberOfSelectedPositions;
 	long *selectedPositions = GuiList_getSelectedPositions (my list, & numberOfSelectedPositions);   // BUG memory
@@ -54,9 +50,7 @@ static void gui_button_cb_removeTarget (I, GuiButtonEvent event) {
 	Editor_broadcastDataChanged (me);
 }
 
-static void gui_button_cb_addTarget (I, GuiButtonEvent event) {
-	(void) event;
-	iam (ArtwordEditor);
+static void gui_button_cb_addTarget (ArtwordEditor me, GuiButtonEvent /* event */) {
 	Artword artword = (Artword) my data;
 	char32 *timeText = GuiText_getString (my time);
 	double tim = Melder_atof (timeText);
@@ -82,42 +76,39 @@ static void gui_button_cb_addTarget (I, GuiButtonEvent event) {
 	} else {
 		GuiList_insertItem (my list, itemText, i);
 	}
-	Graphics_updateWs (my graphics);
+	Graphics_updateWs (my graphics.get());
 	Editor_broadcastDataChanged (me);
 }
 
-static void gui_radiobutton_cb_toggle (I, GuiRadioButtonEvent event) {
-	iam (ArtwordEditor);
+static void gui_radiobutton_cb_toggle (ArtwordEditor me, GuiRadioButtonEvent event) {
 	my feature = event -> position;
 	Melder_assert (my feature > 0);
 	Melder_assert (my feature <= kArt_muscle_MAX);
 	updateList (me);
 }
 
-static void gui_drawingarea_cb_expose (I, GuiDrawingAreaExposeEvent /* event */) {
-	iam (ArtwordEditor);
+static void gui_drawingarea_cb_expose (ArtwordEditor me, GuiDrawingArea_ExposeEvent /* event */) {
 	if (! my graphics) return;
 	Artword artword = (Artword) my data;
-	Graphics_clearWs (my graphics);
-	Artword_draw (artword, my graphics, my feature, true);
+	Graphics_clearWs (my graphics.get());
+	Artword_draw (artword, my graphics.get(), my feature, true);
 }
 
-static void gui_drawingarea_cb_click (I, GuiDrawingAreaClickEvent event) {
-	iam (ArtwordEditor);
+static void gui_drawingarea_cb_click (ArtwordEditor me, GuiDrawingArea_ClickEvent event) {
 	if (! my graphics) return;
 	Artword artword = (Artword) my data;
-	Graphics_setWindow (my graphics, 0, artword -> totalTime, -1.0, 1.0);
-	Graphics_setInner (my graphics);
+	Graphics_setWindow (my graphics.get(), 0, artword -> totalTime, -1.0, 1.0);
+	Graphics_setInner (my graphics.get());
 	double xWC, yWC;
-	Graphics_DCtoWC (my graphics, event -> x, event -> y, & xWC, & yWC);
-	Graphics_unsetInner (my graphics);
+	Graphics_DCtoWC (my graphics.get(), event -> x, event -> y, & xWC, & yWC);
+	Graphics_unsetInner (my graphics.get());
 	GuiText_setString (my time,  Melder_fixed (xWC, 6));
 	GuiText_setString (my value, Melder_fixed (yWC, 6));
 }
 
 void structArtwordEditor :: v_dataChanged () {
 	updateList (this);
-	Graphics_updateWs (graphics);
+	Graphics_updateWs (graphics.get());
 }
 
 void structArtwordEditor :: v_createChildren () {
@@ -156,10 +147,10 @@ void structArtwordEditor :: v_createChildren () {
 autoArtwordEditor ArtwordEditor_create (const char32 *title, Artword data) {
 	try {
 		autoArtwordEditor me = Thing_new (ArtwordEditor);
-		Editor_init (me.peek(), 20, 40, 650, 600, title, data);
+		Editor_init (me.get(), 20, 40, 650, 600, title, data);
 		//XtUnmanageChild (my menuBar);
 		my graphics = Graphics_create_xmdrawingarea (my drawingArea);
-		updateList (me.peek());
+		updateList (me.get());
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Artword window not created.");
