@@ -1,20 +1,19 @@
 /* Artword_Speaker.cpp
  *
- * Copyright (C) 1992-2011 Paul Boersma
+ * Copyright (C) 1992-2011,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Art_Speaker.h"
@@ -31,16 +30,15 @@ void Artword_Speaker_draw (Artword artword, Speaker speaker, Graphics g, int num
 	Graphics_setLineWidth (g, oldLineWidth);
 }
 
-void Artword_Speaker_movie (Artword artword, Speaker speaker, Graphics g) {
-	double timeStep = 0.00001;
+void Artword_Speaker_movie (Artword artword, Speaker speaker, Graphics graphics) {
+	constexpr double timeStep = 0.03;
 	autoArt art = Art_create ();
 	for (double tim = 0.0; tim < artword -> totalTime; tim += timeStep) {
 		Artword_intoArt (artword, art.get(), tim);
-		Graphics_setViewport (g, 0, 1, 0, 1);
-		Graphics_clearWs (g);
-		Art_Speaker_draw (art.get(), speaker, g);
-		Graphics_flushWs (g);
-		// TODO: we should pause here a bit
+		Graphics_beginMovieFrame (graphics, & Graphics_WHITE);
+		Graphics_setWindow (graphics, 0.0, 1.0, 0.0, 1.0);
+		Art_Speaker_draw (art.get(), speaker, graphics);
+		Graphics_endMovieFrame (graphics, timeStep);
 	}
 }
 
