@@ -1,20 +1,19 @@
 /* Artword_to_Art.cpp
  *
- * Copyright (C) 1992-2011,2015 Paul Boersma
+ * Copyright (C) 1992-2011,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Artword_to_Art.h"
@@ -22,7 +21,7 @@
 autoArt Artword_to_Art (Artword me, double tim) {
 	try {
 		autoArt thee = Art_create ();
-		Artword_intoArt (me, thee.peek(), tim);
+		Artword_intoArt (me, thee.get(), tim);
 		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": not converted to Articulation.");
