@@ -1,20 +1,19 @@
 /* FeatureWeights.cpp
  *
- * Copyright (C) 2007-2008 Ola So"der, 2010-2012 Paul Boersma
+ * Copyright (C) 2007-2008 Ola So"der, 2010-2012,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -48,8 +47,8 @@
 
 void structFeatureWeights :: v_info ()
 {
-    this -> structDaata :: v_info ();
-    MelderInfo_writeLine (U"Number of weights: ", fweights -> numberOfColumns);
+    our structDaata :: v_info ();
+    MelderInfo_writeLine (U"Number of weights: ", our fweights -> numberOfColumns);
 }
 
 Thing_implement (FeatureWeights, Daata, 0);
@@ -58,7 +57,7 @@ Thing_implement (FeatureWeights, Daata, 0);
 // Creation...    //
 /////////////////////////////////////////////////////////////////////////////////////////////
 
-FeatureWeights FeatureWeights_create
+autoFeatureWeights FeatureWeights_create
 (
     ///////////////////////////////
     // Parameters                //
@@ -74,7 +73,7 @@ FeatureWeights FeatureWeights_create
 		for (long i = 1; i <= nweights; i ++) {
 			my fweights -> data [1] [i] = 1;
 		}
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"FeatureWeights not created.");
 	}
@@ -100,38 +99,38 @@ long FeatureWeights_computePriors
 
 {
     long nc = 0;
-    for (long y = 1; y <= c->size; y++)
+    for (long y = 1; y <= c->size; y ++)
     {
         long ifriend = -1;
-        for (long sc = 0; sc < nc; sc++)
-            if (FeatureWeights_areFriends ((SimpleString) c->item[y], (SimpleString) c->item[indices[sc]])) ifriend = sc;
+        for (long sc = 0; sc < nc; sc ++)
+            if (FeatureWeights_areFriends (c->at [y], c->at [indices [sc]])) ifriend = sc;
 
         if (ifriend < 0)
         {
-            indices[nc] = y;
-            priors[nc] = 1;
-            nc++;
+            indices [nc] = y;
+            priors [nc] = 1;
+            nc ++;
         }
         else
         {
-            priors[ifriend]++;
+            priors [ifriend] ++;
         }
     }
-    for (long q = 0; q < nc; q++) priors[q] /= c->size;
-    return(nc);
+    for (long q = 0; q < nc; q++) priors [q] /= c->size;
+    return nc;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////
 // Compute feature weights                                                                 //
 /////////////////////////////////////////////////////////////////////////////////////////////
 
-FeatureWeights FeatureWeights_compute           // Obsolete
+autoFeatureWeights FeatureWeights_compute           // Obsolete
 (
     ///////////////////////////////
     // Parameters                //
     ///////////////////////////////
 
-    Pattern pp,     // Source pattern
+    PatternList pp,     // Source pattern
                     //
     Categories c,   // Source categories
                     //
@@ -139,7 +138,7 @@ FeatureWeights FeatureWeights_compute           // Obsolete
 )
 
 {
-    return(FeatureWeights_computeRELIEF(pp, c, k));
+    return FeatureWeights_computeRELIEF (pp, c, k);
 }
 
 
@@ -147,7 +146,7 @@ FeatureWeights FeatureWeights_compute           // Obsolete
 // Compute feature weights (wrapper), evaluate using folding                               //
 /////////////////////////////////////////////////////////////////////////////////////////////
 
-FeatureWeights FeatureWeights_computeWrapperInt
+autoFeatureWeights FeatureWeights_computeWrapperInt
 (
     ///////////////////////////////
     // Parameters                //
@@ -172,14 +171,14 @@ FeatureWeights FeatureWeights_computeWrapperInt
 )
 
 {
-	if (! me) return nullptr;
+	if (! me) return autoFeatureWeights();
 
 	try {
 		double pivot = 0.5;
 		double range = 0.5;
 		autoNUMvector <double> results (0L, nseeds);
 
-		autoThingVector <FeatureWeights> cs (0L, nseeds);
+		autoThingVector <structFeatureWeights> cs (0L, nseeds);
 		for (long y = 0; y <= nseeds; y++) {
 			cs [y] = FeatureWeights_create (my input -> nx);
 		}
@@ -187,7 +186,7 @@ FeatureWeights FeatureWeights_computeWrapperInt
 		for (long x = 1; x <= my input -> nx; x ++)
 			cs [nseeds] -> fweights -> data [1] [x] = pivot;
 
-		results [nseeds] = KNN_evaluate (me, cs [nseeds], k, d, emode);
+		results [nseeds] = KNN_evaluate (me, cs [nseeds].get(), k, d, emode);
 
 		while (range > 0 && results [nseeds] < stop)
 		{
@@ -195,20 +194,20 @@ FeatureWeights FeatureWeights_computeWrapperInt
 
 			if (mode == 2)
 			{
-				for (long x = 1; x <= (my input)->nx; x++)
+				for (long x = 1; x <= (my input)->nx; x ++)
 				{
-					for (long y = 0; y < nseeds; y++)
+					for (long y = 0; y < nseeds; y ++)
 					{
 						cs[y]->fweights->data[1][x] = NUMrandomUniform(OlaMAX(0, cs[nseeds]->fweights->data[1][x] - range),
 													  OlaMIN(1, cs[nseeds]->fweights->data[1][x] + range));
-						results[y] = KNN_evaluate(me, cs[y], k, d, emode);
+						results[y] = KNN_evaluate (me, cs [y].get(), k, d, emode);
 					}
 					for (long q = 0; q < nseeds; q++)
 						if (results[q] > results[best]) best = q;
 
 					if (results[best] > results[nseeds])
 					{
-						for (long x = 1; x <= (my input)->nx; x++)
+						for (long x = 1; x <= (my input)->nx; x++)   // HELP FIXME the same index for an inner and an outer loop!!!
 							cs[nseeds]->fweights->data[1][x] = cs[best]->fweights->data[1][x];
 						results[nseeds] = results[best];
 					}
@@ -223,7 +222,7 @@ FeatureWeights FeatureWeights_computeWrapperInt
 						cs[y]->fweights->data[1][x] = NUMrandomUniform(OlaMAX(0, cs[nseeds]->fweights->data[1][x] - range),
 													  OlaMIN(1, cs[nseeds]->fweights->data[1][x] + range));
 					}
-					results[y] = KNN_evaluate (me, cs [y], k, d, emode);
+					results[y] = KNN_evaluate (me, cs [y].get(), k, d, emode);
 				}
 
 				for (long q = 0; q < nseeds; q++)
@@ -239,8 +238,7 @@ FeatureWeights FeatureWeights_computeWrapperInt
 			range -= alfa;
 		}
 
-		FeatureWeights result = cs [nseeds];
-		cs [nseeds] = nullptr;   // prevent destruction
+		autoFeatureWeights result = cs [nseeds].move();
 		return result;
 	} catch (MelderError) {
 		Melder_throw (U"FeatureWeights: wrapper not computed.");
@@ -251,7 +249,7 @@ FeatureWeights FeatureWeights_computeWrapperInt
 // Compute feature weights (wrapper), evaluate using separate test set                     //
 /////////////////////////////////////////////////////////////////////////////////////////////
 
-FeatureWeights FeatureWeights_computeWrapperExt
+autoFeatureWeights FeatureWeights_computeWrapperExt
 (
     ///////////////////////////////
     // Parameters                //
@@ -259,7 +257,7 @@ FeatureWeights FeatureWeights_computeWrapperExt
 
     KNN nn,         // Classifier
                     //
-    Pattern pp,     // test pattern
+    PatternList pp,     // test pattern
                     //
     Categories c,   // test categories
                     //
@@ -278,14 +276,14 @@ FeatureWeights FeatureWeights_computeWrapperExt
 )
 
 {
-	if (! nn) return nullptr;
+	if (! nn) return autoFeatureWeights();
 
 	try {
 		double pivot = 0.5;
 		double range = 0.5;
 		autoNUMvector <double> results (0L, nseeds);
 
-		autoThingVector <FeatureWeights> cs (0L, nseeds);
+		autoThingVector <structFeatureWeights> cs (0L, nseeds);
 		for (long y = 0; y <= nseeds; y++) {
 			cs [y] = FeatureWeights_create (pp -> nx);
 		}
@@ -293,7 +291,7 @@ FeatureWeights FeatureWeights_computeWrapperExt
 		for (long x = 1; x <= pp -> nx; x ++)
 			cs [nseeds] -> fweights -> data [1] [x] = pivot;
 
-		results [nseeds] = FeatureWeights_evaluate (cs [nseeds], nn, pp, c, k, d);
+		results [nseeds] = FeatureWeights_evaluate (cs [nseeds].get(), nn, pp, c, k, d);
 
 		while (range > 0 && results [nseeds] < stop)
 		{
@@ -305,16 +303,16 @@ FeatureWeights FeatureWeights_computeWrapperExt
 				{
 					for (long y = 0; y < nseeds; y++)
 					{
-						cs[y]->fweights->data[1][x] = NUMrandomUniform(OlaMAX(0, cs[nseeds]->fweights->data[1][x] - range),
+						cs[y]->fweights->data[1][x] = NUMrandomUniform(OlaMAX(0, (cs[nseeds]->fweights)->data[1][x] - range),
 													  OlaMIN(1, cs[nseeds]->fweights->data[1][x] + range));
-						results[y] = FeatureWeights_evaluate(cs[y], nn, pp, c, k, d);
+						results[y] = FeatureWeights_evaluate (cs[y].get(), nn, pp, c, k, d);
 					}
 					for (long q = 0; q < nseeds; q++)
 						if (results[q] > results[best]) best = q;
 
 					if (results[best] > results[nseeds])
 					{
-						for (long x = 1; x <= pp->nx; x++)
+						for (long x = 1; x <= pp->nx; x++)   // BUG: a loop over x inside a loop over x; just hope mode is never 2
 							cs[nseeds]->fweights->data[1][x] = cs[best]->fweights->data[1][x];
 						results[nseeds] = results[best];
 					}
@@ -329,7 +327,7 @@ FeatureWeights FeatureWeights_computeWrapperExt
 						cs[y]->fweights->data[1][x] = NUMrandomUniform(OlaMAX(0, cs[nseeds]->fweights->data[1][x] - range),
 													  OlaMIN(1, cs[nseeds]->fweights->data[1][x] + range));
 					}
-					results[y] = FeatureWeights_evaluate (cs [y], nn, pp, c, k, d);
+					results[y] = FeatureWeights_evaluate (cs [y].get(), nn, pp, c, k, d);
 				}
 
 				for (long q = 0; q < nseeds; q++)
@@ -345,8 +343,7 @@ FeatureWeights FeatureWeights_computeWrapperExt
 			range -= alfa;
 		}
 
-		FeatureWeights result = cs [nseeds];
-		cs [nseeds] = nullptr;   // prevent destruction
+		autoFeatureWeights result = cs [nseeds].move();
 		return result;
 	} catch (MelderError) {
 		Melder_throw (U"FeatureWeights: wrapper not computed.");
@@ -369,7 +366,7 @@ double FeatureWeights_evaluate      // Obsolete - use *_EvaluateWithTestSet
                                     //
     KNN nn,                         // Classifier
                                     //
-    Pattern pp,                     // test pattern
+    PatternList pp,                     // test pattern
                                     //
     Categories c,                   // test categories
                                     //
@@ -382,14 +379,13 @@ double FeatureWeights_evaluate      // Obsolete - use *_EvaluateWithTestSet
 {
 	try {
 		autoCategories o = KNN_classifyToCategories (nn, pp, fws, k, d);
-		double hits = 0;
-		for (long y = 1; y <= o->size; y++)
-			if (FeatureWeights_areFriends ((SimpleString) o -> item [y], (SimpleString) c -> item [y])) hits ++;
-		hits /= o -> size;
+		double hits = 0.0;
+		for (long y = 1; y <= o->size; y ++)
+			if (FeatureWeights_areFriends (o->at [y], c->at [y])) hits ++;
+		hits /= o->size;
 		return hits;
 	} catch (MelderError) {
 		throw;
-		return 0;
 	}
 }
 
@@ -397,13 +393,13 @@ double FeatureWeights_evaluate      // Obsolete - use *_EvaluateWithTestSet
 // Compute feature weights according to the RELIEF-F algorithm                             //
 /////////////////////////////////////////////////////////////////////////////////////////////
 
-FeatureWeights FeatureWeights_computeRELIEF
+autoFeatureWeights FeatureWeights_computeRELIEF
 (
     ///////////////////////////////
     // Parameters                //
     ///////////////////////////////
 
-    Pattern pp,         // source pattern
+    PatternList pp,         // source pattern
                         //
     Categories c,       // source categories
                         //
@@ -412,7 +408,7 @@ FeatureWeights FeatureWeights_computeRELIEF
 )
 
 {
-	autoPattern p = (Pattern) Data_copy (pp);
+	autoPatternList p = Data_copy (pp);
 	autoFeatureWeights me = FeatureWeights_create (p -> nx);
 
 	/////////////////////////////////
@@ -448,10 +444,10 @@ FeatureWeights FeatureWeights_computeRELIEF
 
 	for (long y = 1; y <= p->ny; y++) {
 		for (long x = 1; x <= p->nx; x++) {
-			if (alfa [x]) {
+			if (alfa [x] != 0.0) {
 				p->z[y][x] = (p->z[y][x] - min[x]) / alfa[x];
 			} else {
-				p->z[y][x] = 0;
+				p->z[y][x] = 0.0;
 			}
 		}
 	}
@@ -473,33 +469,33 @@ FeatureWeights FeatureWeights_computeRELIEF
 
 	for (long y = 1; y <= p -> ny; y ++) {
 
-		long nfriends = KNN_kFriends (p.peek(), p.peek(), c, y, k, friends.peek());
-		long nenemies = KNN_kUniqueEnemies (p.peek(), p.peek(), c, y, nclasses - 1, enemies.peek());
+		long nfriends = KNN_kFriends (p.get(), p.get(), c, y, k, friends.peek());
+		long nenemies = KNN_kUniqueEnemies (p.get(), p.get(), c, y, nclasses - 1, enemies.peek());
 
 		if (nfriends && nenemies) {
 			autoNUMvector <double> classps (0L, nenemies - 1);
-			for (long eq = 0; eq < nenemies; eq++) {
-				for (long iq = 0; iq < nclasses; iq++) {
-					if (FeatureWeights_areFriends ((SimpleString) c->item[enemies[eq]], (SimpleString) c->item[classes[iq]])) {
-						classps[eq] = priors[iq];
+			for (long eq = 0; eq < nenemies; eq ++) {
+				for (long iq = 0; iq < nclasses; iq ++) {
+					if (FeatureWeights_areFriends (c->at [enemies [eq]], c->at [classes [iq]])) {
+						classps [eq] = priors [iq];
 						break;
 					}
 				}
 			}
-			for (long x = 1; x <= p->nx; x++) {
+			for (long x = 1; x <= p -> nx; x ++) {
 				double p1 = 0.0;
 				double p2 = 0.0;
-				for (long ec = 0; ec < nfriends; ec++) {
-					p1 += fabs(p->z[y][x] - p->z[friends[ec]][x]) / (p->ny * nfriends);
+				for (long ec = 0; ec < nfriends; ec ++) {
+					p1 += fabs (p -> z [y] [x] - p -> z [friends [ec]] [x]) / (p -> ny * nfriends);
 				}
 				for (long ec = 0; ec < nenemies; ec++) {
-					p2 += (fabs(p->z[y][x] - p->z[enemies[ec]][x]) * classps[ec]) / p->ny;
+					p2 += (fabs (p->z[y][x] - p->z[enemies[ec]][x]) * classps[ec]) / p->ny;
 				}
 				my fweights -> data [1] [x] = my fweights -> data [1] [x] - p1 + p2;
 			}
 		}
 	}
-	return me.transfer();
+	return me;
 }
 
 /* End of file FeatureWeights.cpp */
