@@ -1,20 +1,19 @@
-/* Collection_extensions.c
+/* Collection_extensions.cpp
  *
- * Copyright (C) 1994-2011, 2015 David Weenink
+ * Copyright (C) 1994-2011, 2015-2016 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -30,46 +29,46 @@
 #include "Simple_extensions.h"
 #include "NUM2.h"
 
-Collection Collection_and_Permutation_permuteItems (Collection me, Permutation him) {
+autoCollection Collection_and_Permutation_permuteItems (Collection me, Permutation him) {
 	try {
 		if (my size != his numberOfElements) {
 			Melder_throw (me, U"The number of elements are not equal.");
 		}
 		autoNUMvector<long> pos (1, my size);
-		autoCollection thee = static_cast<Collection> (Data_copy (me));
+		autoCollection thee = Data_copy (me);
 
-		for (long i = 1; i <= my size; i++) {
-			pos[i] = i;
+		for (long i = 1; i <= my size; i ++) {
+			pos [i] = i;
 		}
 		/* Dual meaning of array pos: */
 		/* k <  i : position of item 'k' */
 		/* k >= i : the item at position 'k' */
 		for (long i = 1; i <= my size; i++) {
-			long ti = pos[i], which = Permutation_getValueAtIndex (him, i);
-			long where = pos[which]; /* where >= i */
-			Daata tmp =  static_cast<Daata> (thy item[i]);
+			long ti = pos [i], which = Permutation_getValueAtIndex (him, i);
+			long where = pos [which];   // where >= i
+			Daata tmp = static_cast<Daata> (thy at [i]);
 			if (i == where) {
 				continue;
 			}
-			thy item[i] = thy item[ where ];
-			thy item[where] = tmp;
+			thy at [i] = thy at [where];
+			thy at [where] = tmp;
 			/* order is important !! */
-			pos[ti] = where;
-			pos[where] = ti;
-			pos[which] = which <= i ? i : ti;
+			pos [ti] = where;
+			pos [where] = ti;
+			pos [which] = ( which <= i ? i : ti );
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": not permuted.");
 	}
 }
 
-Collection Collection_permuteItems (Collection me) {
+autoCollection Collection_permuteItems (Collection me) {
 	try {
 		autoPermutation p = Permutation_create (my size);
-		Permutation_permuteRandomly_inline (p.peek(), 0, 0);
-		autoCollection thee = Collection_and_Permutation_permuteItems (me, p.peek());
-		return thee.transfer();
+		Permutation_permuteRandomly_inline (p.get(), 0, 0);
+		autoCollection thee = Collection_and_Permutation_permuteItems (me, p.get());
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": items not permuted.");
 	}
@@ -79,95 +78,66 @@ Collection Collection_permuteItems (Collection me) {
 
 void structOrderedOfString :: v_info () {
 	structDaata :: v_info ();
-	MelderInfo_writeLine (U"Number of strings: ", size);
-	autoOrderedOfString uStrings = OrderedOfString_selectUniqueItems (this, 1);
-	MelderInfo_writeLine (U"Number of unique categories: ", uStrings -> size);
+	MelderInfo_writeLine (U"Number of strings: ", our size);
+	autoOrderedOfString uStrings = OrderedOfString_selectUniqueItems (this);
+	MelderInfo_writeLine (U"Number of unique categories: ", uStrings->size);   // FIXME: "categories"?, and why mention a Set property?
 }
 
 Thing_implement (OrderedOfString, Ordered, 0);
 
-int OrderedOfString_init (OrderedOfString me, long initialCapacity) {
-	Ordered_init (me, classSimpleString, initialCapacity);
-	return 1;
-}
-
-OrderedOfString OrderedOfString_create () {
+int OrderedOfString_append (OrderedOfString me, const char32 *append) {
 	try {
-		autoOrderedOfString me = Thing_new (OrderedOfString);
-		OrderedOfString_init (me.peek(), 10);
-		return me.transfer();
-	} catch (MelderError) {
-		Melder_throw (U"OrderedOfString not created.");
-	}
-}
-
-int OrderedOfString_append (OrderedOfString me, char32 *append) {
-	try {
-		if (append == nullptr) {
+		if (! append) {
 			return 1;    // BUG: lege string appenden??
 		}
 		autoSimpleString item = SimpleString_create (append);
-		Collection_addItem (me, item.transfer());
+		my addItem_move (item.move());
 		return 1;
 	} catch (MelderError) {
 		Melder_throw (me, U": text not appended.");
 	}
 }
 
-OrderedOfString OrderedOfString_joinItems (OrderedOfString me, OrderedOfString thee) {
+autoOrderedOfString OrderedOfString_joinItems (OrderedOfString me, OrderedOfString thee) {
 	try {
 		if (my size != thy size) {
 			Melder_throw (U"sizes must be equal.");
 		}
 		autoOrderedOfString him = Data_copy (me);
 
-		for (long i = 1; i <= my size; i++) {
-			SimpleString_append ( (SimpleString) his item[i], (SimpleString) thy item[i]);
+		for (long i = 1; i <= my size; i ++) {
+			SimpleString_append (his at [i], thy at [i]);
 		}
-		return him.transfer();
+		return him;
 	} catch (MelderError) {
 		Melder_throw (U"Items not joinmed.");
 	}
 }
 
-
-OrderedOfString OrderedOfString_selectUniqueItems (OrderedOfString me, int sort) {
+autoOrderedOfString OrderedOfString_selectUniqueItems (OrderedOfString me) {
 	try {
-		if (! sort) {
-			autoOrderedOfString him = OrderedOfString_create ();
-			for (long i = 1; i <= my size; i++) {
-				SimpleString ss = (SimpleString) my item[i];
-				if (! OrderedOfString_indexOfItem_c (him.peek(), ss -> string)) {
-					autoSimpleString item = Data_copy (ss);
-					Collection_addItem (him.peek(), item.transfer());
-				}
-			}
-			Collection_shrinkToFit (him.peek());
-			return him.transfer();
-		}
-		autoSortedSetOfString thee = SortedSetOfString_create ();
-		/* Collection_to_SortedSet (I, int (*compare)(I, thou)) */
-		for (long i = 1; i <= my size; i++) {
-			if (! SortedSet_hasItem (thee.peek(), my item[i])) {
-				autoSimpleString item = Data_copy ( (SimpleString) my item[i]);
-				Collection_addItem (thee.peek(), item.transfer());
+		autoStringSet thee = StringSet_create ();
+		for (long i = 1; i <= my size; i ++) {
+			if (! thy hasItem (my at [i])) {   // FIXME: first sort, then unicize
+				autoSimpleString item = Data_copy (my at [i]);
+				thy addItem_move (item.move());
 			}
 		}
 		autoOrderedOfString him = OrderedOfString_create ();
-		for (long i = 1; i <= thy size; i++) {
-			autoSimpleString item = Data_copy ( (SimpleString) thy item[i]);
-			Collection_addItem (him.peek(), item.transfer());
+		for (long i = 1; i <= thy size; i ++) {
+			autoSimpleString item = Data_copy (thy at [i]);
+			his addItem_move (item.move());
 		}
-		return him.transfer();
+		return him;
 	} catch (MelderError) {
 		Melder_throw (me, U": unique items not selected.");
 	}
 }
 
 void OrderedOfString_frequency (OrderedOfString me, OrderedOfString thee, long *count) {
-	for (long i = 1; i <= my size; i++) {
-		for (long j = 1; j <= thy size; j++) {
-			if (Data_equal ( (Daata) my item[i], (Daata) thy item[j])) {
+	for (long i = 1; i <= my size; i ++) {
+		for (long j = 1; j <= thy size; j ++) {
+			if (Data_equal (my at [i], thy at [j])) {
 				count[j]++;
 				break;
 			}
@@ -181,8 +151,8 @@ long OrderedOfString_getNumberOfDifferences (OrderedOfString me, OrderedOfString
 	if (my size != thy size) {
 		return -1;
 	}
-	for (long i = 1; i <= my size; i++) {
-		if (! Data_equal ( (SimpleString) my item[i], (SimpleString) thy item[i])) {
+	for (long i = 1; i <= my size; i ++) {
+		if (! Data_equal (my at [i], thy at [i])) {
 			numberOfDifferences++;
 		}
 	}
@@ -199,13 +169,14 @@ double OrderedOfString_getFractionDifferent (OrderedOfString me, OrderedOfString
 }
 
 int OrderedOfString_difference (OrderedOfString me, OrderedOfString thee, long *ndif, double *fraction) {
-	*ndif = 0; *fraction = 1;
+	*ndif = 0;
+	*fraction = 1.0;
 	if (my size != thy size) {
-		Melder_flushError (U"OrderedOfString_difference: the number of items differ");
+		Melder_flushError (U"OrderedOfString_difference: the numbers of items differ");
 		return 0;
 	}
-	for (long i = 1; i <= my size; i++) {
-		if (! Data_equal ( (SimpleString) my item[i], (SimpleString) thy item[i])) {
+	for (long i = 1; i <= my size; i ++) {
+		if (! Data_equal (my at [i], thy at [i])) {
 			(*ndif) ++;
 		}
 	}
@@ -218,8 +189,8 @@ long OrderedOfString_indexOfItem_c (OrderedOfString me, const char32 *str) {
 	long index = 0;
 	autoSimpleString s = SimpleString_create (str);
 
-	for (long i = 1; i <= my size; i++) {
-		if (Data_equal ( (Daata) my item[i], s.peek())) {
+	for (long i = 1; i <= my size; i ++) {
+		if (Data_equal (my at [i], s.get())) {
 			index = i;
 			break;
 		}
@@ -228,18 +199,15 @@ long OrderedOfString_indexOfItem_c (OrderedOfString me, const char32 *str) {
 }
 
 const char32 *OrderedOfString_itemAtIndex_c (OrderedOfString me, long index) {
-	return index > 0 && index <= my size ? SimpleString_c ( (SimpleString) my item[index]) : nullptr;
+	return index > 0 && index <= my size ? SimpleString_c (my at [index]) : nullptr;
 }
 
-void OrderedOfString_sequentialNumbers (OrderedOfString me, long n) {
-	Collection_removeAllItems (me);
-	for (long i = 1; i <= n; i++) {
-		char32 s[40];
-		Melder_sprint (s,40, i);
-		autoSimpleString str = SimpleString_create (s);
-		Collection_addItem (me, str.transfer());
+void OrderedOfString_initWithSequentialNumbers (OrderedOfString me, long n) {
+	for (long i = 1; i <= n; i ++) {
+		my addItem_move (SimpleString_create (Melder_integer (i)));
 	}
 }
+
 void OrderedOfString_changeStrings (OrderedOfString me, char32 *search, char32 *replace, int maximumNumberOfReplaces, long *nmatches, long *nstringmatches, int use_regexp) {
 	regexp *compiled_search = nullptr;
 	try {
@@ -253,8 +221,8 @@ void OrderedOfString_changeStrings (OrderedOfString me, char32 *search, char32 *
 		if (use_regexp) {
 			compiled_search = CompileRE_throwable (search, 0);
 		}
-		for (long i = 1; i <= my size; i++) {
-			SimpleString ss = (SimpleString) my item[i];
+		for (long i = 1; i <= my size; i ++) {
+			SimpleString ss = my at [i];
 			long nmatches_sub;
 			char32 *r = use_regexp ? str_replace_regexp (ss -> string, compiled_search, replace, maximumNumberOfReplaces, &nmatches_sub) : str_replace_literal (ss -> string, search, replace, maximumNumberOfReplaces, &nmatches_sub);
 
@@ -280,12 +248,12 @@ void OrderedOfString_changeStrings (OrderedOfString me, char32 *search, char32 *
 long OrderedOfString_isSubsetOf (OrderedOfString me, OrderedOfString thee, long *translation) { // ?? test and give number
 	long nStrings = 0;
 
-	for (long i = 1; i <= my size; i++) {
+	for (long i = 1; i <= my size; i ++) {
 		if (translation) {
-			translation[i] = 0;
+			translation [i] = 0;
 		}
-		for (long j = 1; j <= thy size; j++)
-			if (Data_equal ( (SimpleString) my item[i], (SimpleString) thy item[j])) {
+		for (long j = 1; j <= thy size; j ++)
+			if (Data_equal (my at [i], thy at [j])) {
 				if (translation) {
 					translation[i] = j;
 				}
@@ -297,7 +265,7 @@ long OrderedOfString_isSubsetOf (OrderedOfString me, OrderedOfString thee, long
 
 void OrderedOfString_drawItem (OrderedOfString me, Graphics g, long index, double xWC, double yWC) {
 	if (index > 0 && index <= my size) {
-		SimpleString_draw ((SimpleString) my item[index], g, xWC, yWC);
+		SimpleString_draw (my at [index], g, xWC, yWC);
 	}
 }
 
@@ -309,13 +277,13 @@ void OrderedOfString_removeOccurrences (OrderedOfString me, const char32 *search
 	if (! search) {
 		return;
 	}
-	for (long i = my size; i >= 1; i--) {
-		SimpleString ss = (SimpleString) my item[i];
+	for (long i = my size; i >= 1; i --) {
+		SimpleString ss = my at [i];
 		if ( (use_regexp && strstr_regexp (ss -> string, search)) ||
 		        (!use_regexp && str32str (ss -> string, search))) {
-			Collection_removeItem (me, i);
+			my removeItem (i);
 		}
 	}
 }
 
-/* End of file Collection_extensions.c */
+/* End of file Collection_extensions.cpp */
