@@ -2,33 +2,32 @@
 #define _SimpleVector_h_
 /* SimpleVector.h
  *
- * Copyright (C) 1994-2011 David Weenink
+ * Copyright (C) 1994-2011, 2015 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Data.h"
 
 #include "SimpleVector_def.h"
-oo_CLASS_CREATE (DoubleVector, Daata);
-oo_CLASS_CREATE (ComplexVector, Daata);
 
-void DoubleVector_init (I, long min, long max);
-DoubleVector DoubleVector_create (long min, long max);
+void DoubleVector_init (DoubleVector me, long min, long max);
 
-void ComplexVector_init (I, long min, long max);
-ComplexVector ComplexVector_create (long min, long max);
+autoDoubleVector DoubleVector_create (long min, long max);
+
+void ComplexVector_init (ComplexVector me, long min, long max);
+
+autoComplexVector ComplexVector_create (long min, long max);
 
 #endif /* _SimpleVector_h_ */
