@@ -2,19 +2,18 @@
  *
  * Copyright (C) 1993-2013, 2015 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -61,18 +60,18 @@ void structAffineTransform :: v_transform (double **in, long nrows, double **out
 	}
 }
 
-Any structAffineTransform :: v_invert () {
+autoAffineTransform structAffineTransform :: v_invert () {
 	autoAffineTransform thee = Data_copy (this);
 	double tolerance = 0.000001;
 
 	NUMpseudoInverse (r, n, n, thy r, tolerance);
-	for (long i = 1; i <= n; i++) {
+	for (long i = 1; i <= n; i ++) {
 		thy t[i] = 0.0;
-		for (long j = 1; j <= thy n; j++) {
+		for (long j = 1; j <= thy n; j ++) {
 			thy t[i] -= thy r[i][j] * t[j];
 		}
 	}
-	return thee.transfer();
+	return thee;
 }
 
 Thing_implement (AffineTransform, Daata, 0);
@@ -89,27 +88,26 @@ void AffineTransform_init (AffineTransform me, long n) {
 autoAffineTransform AffineTransform_create (long n) {
 	try {
 		autoAffineTransform me = Thing_new (AffineTransform);
-		AffineTransform_init (me.peek(), n);
+		AffineTransform_init (me.get(), n);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"AffineTransform not created.");
 	}
 }
 
-Any AffineTransform_invert (AffineTransform me) {
-	AffineTransform thee = (AffineTransform) my v_invert ();
-	return thee;
+autoAffineTransform AffineTransform_invert (AffineTransform me) {
+	return my v_invert ();
 }
 
 autoTableOfReal AffineTransform_extractMatrix (AffineTransform me) {
 	try {
 		autoTableOfReal thee = TableOfReal_create (my n, my n);
 		NUMmatrix_copyElements (my r, thy data, 1, my n, 1, my n);
-		for (long i = 1; i <= my n; i++) {
-			char32 label[40];
+		for (long i = 1; i <= my n; i ++) {
+			char32 label [40];
 			Melder_sprint (label,40, i);
-			TableOfReal_setRowLabel (thee.peek(), i, label);
-			TableOfReal_setColumnLabel (thee.peek(), i, label);
+			TableOfReal_setRowLabel (thee.get(), i, label);
+			TableOfReal_setColumnLabel (thee.get(), i, label);
 		}
 		return thee;
 	} catch (MelderError) {
