@@ -1,27 +1,26 @@
 /* CC.cpp
  *
- * Copyright (C) 1993-2012, 2014 David Weenink
+ * Copyright (C) 1993-2012, 2014-2015 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  djmw 20011016 removed some causes for compiler warnings
  djmw 20020315 GPL header
  djmw 20061212 Changed info to Melder_writeLine<x> format.
- djmw 20071012 Added: o_CAN_WRITE_AS_ENCODING.h
+ djmw 20071012 Added: oo_CAN_WRITE_AS_ENCODING.h
  djmw 20080122 float -> double
  djmw 20080513 CC_getValue
  */
@@ -66,8 +65,7 @@ void CC_Frame_init (CC_Frame me, long numberOfCoefficients) {
 	my numberOfCoefficients = numberOfCoefficients;
 }
 
-void CC_init (I, double tmin, double tmax, long nt, double dt, double t1, long maximumNumberOfCoefficients, double fmin, double fmax) {
-	iam (CC);
+void CC_init (CC me, double tmin, double tmax, long nt, double dt, double t1, long maximumNumberOfCoefficients, double fmin, double fmax) {
 	my fmin = fmin;
 	my fmax = fmax;
 	my maximumNumberOfCoefficients = maximumNumberOfCoefficients;
@@ -75,29 +73,35 @@ void CC_init (I, double tmin, double tmax, long nt, double dt, double t1, long m
 	my frame = NUMvector<structCC_Frame> (1, nt);
 }
 
-Matrix CC_to_Matrix (I) {
-	iam (CC);
+autoMatrix CC_to_Matrix (CC me) {
 	try {
-		autoMatrix thee = Matrix_create (my xmin, my xmax, my nx, my dx, my x1, 1, my maximumNumberOfCoefficients, my maximumNumberOfCoefficients, 1.0, 1.0);
-
+		// find number of coefficients by quering all frames.
+		// We cannot use maximumNumberOfCoefficiennts because this number is only used to calculate the inverse
+		long numberOfCoefficients = 0;
+		for (long i = 1; i <= my nx; i++) {
+			CC_Frame cf = & my frame[i];
+			if (cf -> numberOfCoefficients > numberOfCoefficients) {
+				numberOfCoefficients = cf -> numberOfCoefficients;
+			}
+		}
+		autoMatrix thee = Matrix_create (my xmin, my xmax, my nx, my dx, my x1, 1.0, numberOfCoefficients, numberOfCoefficients, 1.0, 1.0);
+		
 		for (long i = 1; i <= my nx; i++) {
 			CC_Frame cf = & my frame[i];
 			for (long j = 1; j <= cf -> numberOfCoefficients; j++) {
 				thy z[j][i] = cf -> c[j];
 			}
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": not converted to Matrix.");
 	}
 }
 
-void CC_paint (I, Graphics g, double xmin, double xmax, long cmin,
-               long cmax, double minimum, double maximum, int garnish) {
-	iam (CC);
+void CC_paint (CC me, Graphics g, double xmin, double xmax, long cmin, long cmax, double minimum, double maximum, int garnish) {
 	autoMatrix thee = CC_to_Matrix (me);
 
-	Matrix_paintCells (thee.peek(), g, xmin, xmax, cmin, cmax, minimum, maximum);
+	Matrix_paintCells (thee.get(), g, xmin, xmax, cmin, cmax, minimum, maximum);
 
 	if (garnish) {
 		Graphics_marksBottom (g, 2, true, true, false);
@@ -107,9 +111,7 @@ void CC_paint (I, Graphics g, double xmin, double xmax, long cmin,
 	}
 }
 
-void CC_drawC0 (I, Graphics g, double xmin, double xmax, double ymin,
-                double ymax, int garnish) {
-	iam (CC);
+void CC_drawC0 (CC me, Graphics g, double xmin, double xmax, double ymin, double ymax, int garnish) {
 	(void) garnish;
 
 	if (xmin >= xmax) {
@@ -138,8 +140,7 @@ void CC_drawC0 (I, Graphics g, double xmin, double xmax, double ymin,
 	Graphics_unsetInner (g);
 }
 
-void CC_getNumberOfCoefficients_extrema (I, long startframe, long endframe, long *min, long *max) {
-	iam (CC);
+void CC_getNumberOfCoefficients_extrema (CC me, long startframe, long endframe, long *p_min, long *p_max) {
 
 	Melder_assert (startframe <= endframe);
 
@@ -153,23 +154,28 @@ void CC_getNumberOfCoefficients_extrema (I, long startframe, long endframe, long
 		endframe = my nx;
 	}
 
-	*min = my maximumNumberOfCoefficients;
-	*max = 0;
+	long min = my maximumNumberOfCoefficients;
+	long max = 0;
 
 	for (long i = startframe; i <= endframe; i++) {
 		CC_Frame f = & my frame[i];
 		long nc = f -> numberOfCoefficients;
 
-		if (nc < *min) {
-			*min = nc;
-		} else if (nc > *max) {
-			*max = nc;
+		if (nc < min) {
+			min = nc;
+		} else if (nc > max) {
+			max = nc;
 		}
 	}
+	if (p_min) {
+		*p_min = min;
+	}
+	if (p_max) {
+		*p_max = max;
+	}
 }
 
-long CC_getMinimumNumberOfCoefficients (I, long startframe, long endframe) {
-	iam (CC);
+long CC_getMinimumNumberOfCoefficients (CC me, long startframe, long endframe) {
 	long min, max;
 
 	CC_getNumberOfCoefficients_extrema (me, startframe, endframe, &min, &max);
@@ -177,8 +183,7 @@ long CC_getMinimumNumberOfCoefficients (I, long startframe, long endframe) {
 	return min;
 }
 
-long CC_getMaximumNumberOfCoefficients (I, long startframe, long endframe) {
-	iam (CC);
+long CC_getMaximumNumberOfCoefficients (CC me, long startframe, long endframe) {
 	long min, max;
 
 	CC_getNumberOfCoefficients_extrema (me, startframe, endframe, &min, &max);
@@ -186,8 +191,7 @@ long CC_getMaximumNumberOfCoefficients (I, long startframe, long endframe) {
 	return max;
 }
 
-long CC_getNumberOfCoefficients (I, long iframe) {
-	iam (CC);
+long CC_getNumberOfCoefficients (CC me, long iframe) {
 	if (iframe < 1 || iframe > my nx) {
 		return 0;
 	}
@@ -196,8 +200,7 @@ long CC_getNumberOfCoefficients (I, long iframe) {
 }
 
 
-double CC_getValueInFrame (I, long iframe, long index) {
-	iam (CC);
+double CC_getValueInFrame (CC me, long iframe, long index) {
 	if (iframe < 1 || iframe > my nx) {
 		return NUMundefined;
 	}
@@ -205,14 +208,7 @@ double CC_getValueInFrame (I, long iframe, long index) {
 	return index > cf -> numberOfCoefficients ? NUMundefined : cf -> c[index];
 }
 
-double CC_getValueAtTime (I, double t, long index) {
-	iam (CC);
-	long iframe = Sampled_xToNearestIndex (me, t);
-	return CC_getValueInFrame (me, iframe, index);
-}
-
-double CC_getValue (I, double t, long index) {
-	iam (CC);
+double CC_getValue (CC me, double t, long index) {
 	long iframe = Sampled_xToNearestIndex (me, t);
 	if (iframe < 1 || iframe > my nx) {
 		return NUMundefined;
@@ -221,8 +217,7 @@ double CC_getValue (I, double t, long index) {
 	return index > cf -> numberOfCoefficients ? NUMundefined : cf -> c[index];
 }
 
-double CC_getC0ValueInFrame (I, long iframe) {
-	iam (CC);
+double CC_getC0ValueInFrame (CC me, long iframe) {
 	if (iframe < 1 || iframe > my nx) {
 		return NUMundefined;
 	}
@@ -230,10 +225,11 @@ double CC_getC0ValueInFrame (I, long iframe) {
 	return cf -> c0;
 }
 
-double CC_getC0ValueAtTime (I, double t) {
-	iam (CC);
+#if 0
+double CC_getC0ValueAtTime (CC me, double t) {
 	long iframe = Sampled_xToNearestIndex (me, t);
 	return CC_getC0ValueInFrame (me, iframe);
 }
+#endif
 
 /* End of file CC.cpp */
