@@ -2,19 +2,18 @@
  *
  * Copyright (C) 1993-2012, 2015 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -72,14 +71,14 @@ void structConfiguration :: v_info () {
 autoConfiguration Configuration_create (long numberOfPoints, long numberOfDimensions) {
 	try {
 		autoConfiguration me = Thing_new (Configuration);
-		TableOfReal_init (me.peek(), numberOfPoints, numberOfDimensions);
+		TableOfReal_init (me.get(), numberOfPoints, numberOfDimensions);
 		my w = NUMvector<double> (1, numberOfDimensions);
-		TableOfReal_setSequentialRowLabels (me.peek(), 0, 0, nullptr, 1, 1);
-		TableOfReal_setSequentialColumnLabels (me.peek(), 0, 0, U"dimension ", 1, 1);
+		TableOfReal_setSequentialRowLabels (me.get(), 0, 0, nullptr, 1, 1);
+		TableOfReal_setSequentialColumnLabels (me.get(), 0, 0, U"dimension ", 1, 1);
 
 		my metric = 2;
-		Configuration_setDefaultWeights (me.peek());
-		Configuration_randomize (me.peek());
+		Configuration_setDefaultWeights (me.get());
+		Configuration_randomize (me.get());
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Configuration not created.");
@@ -102,7 +101,7 @@ void Configuration_setSqWeights (Configuration me, const double weight[]) {
 	}
 }
 
-void Configuration_normalize (Configuration me, double sumsq, int columns) {
+void Configuration_normalize (Configuration me, double sumsq, bool columns) {
 	TableOfReal_centreColumns (me);
 	if (columns) {
 		sumsq = sumsq <= 0.0 ? 1.0 : sqrt (sumsq);
@@ -312,7 +311,7 @@ autoConfiguration Configuration_varimax (Configuration me, int normalizeRows,
 autoConfiguration Configuration_congruenceRotation (Configuration me, Configuration thee, long maximumNumberOfIterations, double tolerance) {
 	try {
 		autoAffineTransform at = Configurations_to_AffineTransform_congruence (me, thee, maximumNumberOfIterations, tolerance);
-		autoConfiguration him = Configuration_and_AffineTransform_to_Configuration (me, at.peek());
+		autoConfiguration him = Configuration_and_AffineTransform_to_Configuration (me, at.get());
 		return him;
 	} catch (MelderError) {
 		Melder_throw (me, U": congruence rotation not performed.");
@@ -333,7 +332,9 @@ void Configuration_rotateToPrincipalDirections (Configuration me) {
 	}
 }
 
-void Configuration_draw (Configuration me, Graphics g, int xCoordinate, int yCoordinate, double xmin, double xmax, double ymin, double ymax, int labelSize, int useRowLabels, const char32 *label, int garnish) {
+void Configuration_draw (Configuration me, Graphics g, int xCoordinate, int yCoordinate, double xmin, double xmax, double ymin, double ymax,
+	int labelSize, bool useRowLabels, const char32 *label, bool garnish)
+{
 	long nPoints = my numberOfRows, numberOfDimensions = my numberOfColumns;
 
 	if (numberOfDimensions > 1 && (xCoordinate > numberOfDimensions || yCoordinate > numberOfDimensions)) {
@@ -349,9 +350,9 @@ void Configuration_draw (Configuration me, Graphics g, int xCoordinate, int yCoo
 	autoNUMvector<double> x (1, nPoints);
 	autoNUMvector<double> y (1, nPoints);
 
-	for (long i = 1; i <= nPoints; i++) {
-		x[i] = my data[i][xCoordinate] * my w[xCoordinate];
-		y[i] = numberOfDimensions > 1 ? my data[i][yCoordinate] * my w[yCoordinate] : 0.0;
+	for (long i = 1; i <= nPoints; i ++) {
+		x[i] = my data [i] [xCoordinate] * my w [xCoordinate];
+		y[i] = ( numberOfDimensions > 1 ? my data [i] [yCoordinate] * my w [yCoordinate] : 0.0 );
 	}
 	if (xmax <= xmin) {
 		NUMvector_extrema (x.peek(), 1, nPoints, &xmin, &xmax);
@@ -371,13 +372,13 @@ void Configuration_draw (Configuration me, Graphics g, int xCoordinate, int yCoo
 	Graphics_setInner (g);
 	Graphics_setTextAlignment (g, Graphics_CENTRE, Graphics_HALF);
 	Graphics_setFontSize (g, labelSize);
-	for (long i = 1; i <= my numberOfRows; i++) {
-		if (x[i] >= xmin && x[i] <= xmax && y[i] >= ymin && y[i] <= ymax) {
-			const char32 *plotLabel = useRowLabels ? my rowLabels[i] : label;
+	for (long i = 1; i <= my numberOfRows; i ++) {
+		if (x [i] >= xmin && x [i] <= xmax && y [i] >= ymin && y [i] <= ymax) {
+			const char32 *plotLabel = ( useRowLabels ? my rowLabels [i] : label );
 			if (NUMstring_containsPrintableCharacter (plotLabel)) {
-				Graphics_text (g, x[i], y[i], plotLabel);
+				Graphics_text (g, x [i], y [i], plotLabel);
 			} else {
-				noLabel++;
+				noLabel ++;
 			}
 		}
 	}
@@ -403,9 +404,9 @@ void Configuration_draw (Configuration me, Graphics g, int xCoordinate, int yCoo
 	}
 }
 
-void Configuration_drawConcentrationEllipses (Configuration me, Graphics g, double scale, int confidence, const char32 *label, long d1, long d2, double xmin, double xmax, double ymin, double ymax, int fontSize, int garnish) {
-	autoSSCPs sscps = TableOfReal_to_SSCPs_byLabel (me);
-	SSCPs_drawConcentrationEllipses (sscps.peek(), g, scale, confidence, label, d1, d2, xmin, xmax, ymin, ymax, fontSize, garnish);
+void Configuration_drawConcentrationEllipses (Configuration me, Graphics g, double scale, bool confidence, const char32 *label, long d1, long d2, double xmin, double xmax, double ymin, double ymax, int fontSize, bool garnish) {
+	autoSSCPList sscps = TableOfReal_to_SSCPList_byLabel (me);
+	SSCPList_drawConcentrationEllipses (sscps.get(), g, scale, confidence, label, d1, d2, xmin, xmax, ymin, ymax, fontSize, garnish);
 }
 
 autoConfiguration TableOfReal_to_Configuration (TableOfReal me) {
@@ -413,7 +414,7 @@ autoConfiguration TableOfReal_to_Configuration (TableOfReal me) {
 		autoConfiguration thee = Configuration_create (my numberOfRows, my numberOfColumns);
 
 		NUMmatrix_copyElements (my data, thy data, 1, my numberOfRows, 1, my numberOfColumns);
-		TableOfReal_copyLabels (me, thee.peek(), 1, 1);
+		TableOfReal_copyLabels (me, thee.get(), 1, 1);
 		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": not converted.");
@@ -426,8 +427,8 @@ autoConfiguration TableOfReal_to_Configuration_pca (TableOfReal me, long numberO
 			numberOfDimensions = my numberOfColumns;
 		}
 
-		autoPCA pca = TableOfReal_to_PCA (me);
-		autoConfiguration thee = PCA_and_TableOfReal_to_Configuration (pca.peek(), me, numberOfDimensions);
+		autoPCA pca = TableOfReal_to_PCA_byRows (me);
+		autoConfiguration thee = PCA_and_TableOfReal_to_Configuration (pca.get(), me, numberOfDimensions);
 		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": pca not performed.");
@@ -473,16 +474,16 @@ autoConfiguration Configuration_createLetterRExample (int choice) {
 
 		if (choice == 2) {
 			x = x2; y = y2;
-			Thing_setName (me.peek(), U"R_fit");
+			Thing_setName (me.get(), U"R_fit");
 		} else {
 			x = x1; y = y1;
-			Thing_setName (me.peek(), U"R");
+			Thing_setName (me.get(), U"R");
 		}
 
 		for (long i = 1; i <= 32; i++) {
 			char32 s[20];
 			Melder_sprint (s,20, i);
-			TableOfReal_setRowLabel (me.peek(), i, s);
+			TableOfReal_setRowLabel (me.get(), i, s);
 			my data [i][1] = x[i];
 			my data [i][2] = y[i];
 		}
@@ -502,7 +503,7 @@ autoConfiguration Configuration_createCarrollWishExample () {
 		for (long i = 1; i <= nObjects; i++) {
 			my data[i][1] = x[i];
 			my data[i][2] = y[i];
-			TableOfReal_setRowLabel (me.peek(), i, label[i]);
+			TableOfReal_setRowLabel (me.get(), i, label[i]);
 		}
 		return me;
 	} catch (MelderError) {
@@ -512,16 +513,6 @@ autoConfiguration Configuration_createCarrollWishExample () {
 
 /************ CONFIGURATIONS **************************************/
 
-Thing_implement (Configurations, Ordered, 0);
-
-autoConfigurations Configurations_create () {
-	try {
-		autoConfigurations me = Thing_new (Configurations);
-		Ordered_init (me.peek(), classConfiguration, 10);
-		return me;
-	} catch (MelderError) {
-		Melder_throw (U"Configurations not created.");
-	}
-}
+Thing_implement (ConfigurationList, TableOfRealList, 0);
 
 /* End of file Configuration.cpp */
