@@ -2,19 +2,18 @@
  *
  * Copyright (C) 1993-2012, 2015 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -155,7 +154,7 @@ static void NUMmaximizeCongruence (double **b, double **a, long nr, long nc, dou
 
 		// Step 8
 
-		SVD_svd_d (svd.peek(), u.peek());
+		SVD_svd_d (svd.get(), u.peek());
 
 		// Step 9
 
@@ -198,7 +197,7 @@ autoConfiguration Configuration_and_AffineTransform_to_Configuration (Configurat
 		if (my numberOfColumns != thy n) {
 			Melder_throw (U"Dimensions do not agree.");
 		}
-		autoConfiguration him = (Configuration) Data_copy (me);
+		autoConfiguration him = Data_copy (me);
 
 		// Apply transformation YT
 
