@@ -2,7 +2,7 @@
 #define _DataModeler_h_
 /* DataModeler.h
  *
- * Copyright (C) 2014-2015 David Weenink
+ * Copyright (C) 2014-2016 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -123,17 +123,20 @@ double DataModeler_getWeightedMean (DataModeler me);
 
 long DataModeler_getNumberOfInvalidDataPoints (DataModeler me);
 
-double DataModeler_getDataPointValue (DataModeler me, long index);
+double DataModeler_getDataPointXValue (DataModeler me, long index);
+double DataModeler_getDataPointYValue (DataModeler me, long index);
 
-void DataModeler_setDataPointValue (DataModeler me, long index, double value);
+void DataModeler_setDataPointXValue (DataModeler me, long index, double value);
+void DataModeler_setDataPointYValue (DataModeler me, long index, double value);
+void DataModeler_setDataPointValues (DataModeler me, long index, double xvalue, double yvalue);
 
 int DataModeler_getDataPointStatus (DataModeler me, long index);
 
 void DataModeler_setDataPointStatus (DataModeler me, long index, int status);
 
-void DataModeler_setDataPointSigma (DataModeler me, long index, double sigma);
+void DataModeler_setDataPointYSigma (DataModeler me, long index, double sigma);
 
-double DataModeler_getDataPointSigma (DataModeler me, long index);
+double DataModeler_getDataPointYSigma (DataModeler me, long index);
 double DataModeler_getResidualSumOfSquares (DataModeler me, long *numberOfDataPoints);
 
 void DataModeler_getZScores (DataModeler me, int useSigmaY, double zscores[]);
@@ -144,6 +147,8 @@ double DataModeler_getChiSquaredQ (DataModeler me, int useSigmaY, double *probab
 
 double DataModeler_getCoefficientOfDetermination (DataModeler me, double *ssreg, double *sstot);
 
+void DataModeler_reportChiSquared (DataModeler me, int weighDataType);
+
 autoFormant Formant_extractPart (Formant me, double tmin, double tmax);
 
 autoCovariance DataModeler_to_Covariance_parameters (DataModeler me);
@@ -243,6 +248,8 @@ double FormantModeler_getSmoothnessValue (FormantModeler me, long fromFormant, l
 
 double FormantModeler_getAverageDistanceBetweenTracks (FormantModeler me, long track1, long track2, int type);
 
+void FormantModeler_reportChiSquared (FormantModeler me, int weighDataType);
+
 long Formants_getSmoothestInInterval (CollectionOf<structFormant>* me, double tmin, double tmax, long numberOfFormantTracks, long numberOfParametersPerTrack, int useBandWidthsForTrackEstimation, int useConstraints, double numberOfSigmas, double power, double minF1, double maxF1, double minF2, double maxF2, double minF3);
 
 double FormantModeler_getFormantsConstraintsFactor (FormantModeler me, double minF1, double maxF1, double minF2, double maxF2, double minF3);
