@@ -2,19 +2,18 @@
  *
  * Copyright (C) 1993-2011, 2015 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -29,7 +28,7 @@ Thing_implement (Distance, Proximity, 0);
 autoDistance Distance_create (long numberOfPoints) {
 	try {
 		autoDistance me = Thing_new (Distance);
-		Proximity_init (me.peek(), numberOfPoints);
+		Proximity_init (me.get(), numberOfPoints);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Distance not created.");
