@@ -1,20 +1,19 @@
 /* EditDistanceTable.c
  *
- * Copyright (C) 2012, 2014, 2015 David Weenink
+ * Copyright (C) 2012, 2014-2016 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -106,40 +105,59 @@ static void WarpingPath_shiftPathByOne (WarpingPath me) {
 	}
 }
 
-long WarpingPath_getColumnsFromRowIndex (WarpingPath me, long iy, long *ix1, long *ix2) {
-	if (iy <= 0) {
-		return 0;
-	}
-	*ix1 = 0; *ix2 = 0;
-	for (long i = 1; i <= my pathLength; i++) {
-		if (my path[i].y < iy) {
-			continue;
-		} else if (my path[i].y == iy) {
-			if (*ix1 == 0) *ix1 = my path[i].x;
-			*ix2 = my path[i].x;
-		} else {
-			break;
+long WarpingPath_getColumnsFromRowIndex (WarpingPath me, long iy, long *p_ix1, long *p_ix2) {
+	long ix1 = 0, ix2 = 0, numberOfColumns = 0;
+	if (iy > 0) {
+		for (long i = 1; i <= my pathLength; i++) {
+			if (my path[i].y < iy) {
+				continue;
+			} else if (my path[i].y == iy) {
+				if (ix1 == 0) {
+					ix1 = my path[i].x;
+				}
+				ix2 = my path[i].x;
+			} else {
+				break;
+			}
 		}
+		numberOfColumns = ix2 - ix1 + 1;
 	}
-	return *ix2 - *ix1 + 1;
+	if (p_ix1) {
+		*p_ix1 = ix1;
+	}
+	if (p_ix2) {
+		*p_ix2 = ix2;
+	}
+	return numberOfColumns;
 }
 
-long WarpingPath_getRowsFromColumnIndex (WarpingPath me, long ix, long *iy1, long *iy2) {
+long WarpingPath_getRowsFromColumnIndex (WarpingPath me, long ix, long *p_iy1, long *p_iy2) {
 	if (ix <= 0) {
 		return 0;
 	}
-	*iy1 = 0; *iy2 = 0;
-	for (long i = 1; i <= my pathLength; i++) {
-		if (my path[i].x < ix) {
-			continue;
-		} else if (my path[i].x == ix) {
-			if (*iy1 == 0) *iy1 = my path[i].y;
-			*iy2 = my path[i].y;
-		} else {
-			break;
+	long iy1 = 0, iy2 = 0, numberOfRows = 0;
+	if (ix > 0) {
+		for (long i = 1; i <= my pathLength; i++) {
+			if (my path[i].x < ix) {
+				continue;
+			} else if (my path[i].x == ix) {
+				if (iy1 == 0) {
+					iy1 = my path[i].y;
+				}
+				iy2 = my path[i].y;
+			} else {
+				break;
+			}
 		}
+		numberOfRows = iy2 - iy1 + 1;
 	}
-	return *iy2 - *iy1 + 1;
+	if (p_iy1) {
+		*p_iy1 = iy1;
+	}
+	if (p_iy2) {
+		*p_iy2 = iy2;
+	}
+	return numberOfRows;
 }
 
 Thing_implement (EditCostsTable, TableOfReal, 0);
@@ -165,7 +183,7 @@ bool structEditCostsTable :: v_matchTargetWithSourceSymbol (const char32 *target
 autoEditCostsTable EditCostsTable_create (long targetAlphabetSize, long sourceAlphabetSize) {
 	try{
 		autoEditCostsTable me = Thing_new (EditCostsTable);
-		TableOfReal_init (me.peek(), targetAlphabetSize + 2, sourceAlphabetSize + 2);
+		TableOfReal_init (me.get(), targetAlphabetSize + 2, sourceAlphabetSize + 2);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"EditCostsTable not created.");
@@ -333,18 +351,18 @@ autoEditDistanceTable EditDistanceTable_create (Strings target, Strings source)
 	try {
 		autoEditDistanceTable me = Thing_new (EditDistanceTable);
 		long numberOfSourceSymbols = source -> numberOfStrings, numberOfTargetSymbols = target -> numberOfStrings;
-		TableOfReal_init (me.peek(), numberOfTargetSymbols + 1, numberOfSourceSymbols + 1);
-		TableOfReal_setColumnLabel (me.peek(), 1, U"");
+		TableOfReal_init (me.get(), numberOfTargetSymbols + 1, numberOfSourceSymbols + 1);
+		TableOfReal_setColumnLabel (me.get(), 1, U"");
 		for (long j = 1; j <= numberOfSourceSymbols; j++) {
 			my columnLabels[j + 1] = Melder_dup (source -> strings[j]);
 		}
-		TableOfReal_setRowLabel (me.peek(), 1, U"");
+		TableOfReal_setRowLabel (me.get(), 1, U"");
 		for (long i = 1; i <= numberOfTargetSymbols; i++) {
 			my rowLabels[i + 1] = Melder_dup (target -> strings[i]);
 		}
 		my warpingPath = WarpingPath_create (numberOfTargetSymbols + numberOfSourceSymbols + 1);
 		my editCostsTable = EditCostsTable_createDefault ();
-		EditDistanceTable_findPath (me.peek(), 0);
+		EditDistanceTable_findPath (me.get(), 0);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"EditDistanceTable not created.");
@@ -363,7 +381,7 @@ autoEditDistanceTable EditDistanceTable_createFromCharacterStrings (const char32
 	try {
 		autoStrings s1 = Strings_createAsCharacters (chars1);
 		autoStrings s2 = Strings_createAsCharacters (chars2);
-		autoEditDistanceTable me = EditDistanceTable_create (s1.peek(), s2.peek());
+		autoEditDistanceTable me = EditDistanceTable_create (s1.get(), s2.get());
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"EditDistanceTable not created from character strings.");
@@ -508,7 +526,7 @@ void EditDistanceTable_drawEditOperations (EditDistanceTable me, Graphics graphi
 }
 
 void EditDistanceTable_setDefaultCosts (EditDistanceTable me, double insertionCosts, double deletionCosts, double substitutionCosts) {
-	EditCostsTable_setDefaultCosts (my editCostsTable.peek(), insertionCosts, deletionCosts, substitutionCosts);
+	EditCostsTable_setDefaultCosts (my editCostsTable.get(), insertionCosts, deletionCosts, substitutionCosts);
 	EditDistanceTable_findPath (me, 0);
 }
 
@@ -530,19 +548,19 @@ void EditDistanceTable_findPath (EditDistanceTable me, autoTableOfReal *directio
 		autoNUMmatrix<double> delta (0, numberOfTargets, 0, numberOfSources);
 
 		for (long j = 1; j <= numberOfSources; j++) {
-			delta[0][j] = delta[0][j - 1] + EditCostsTable_getDeletionCost (my editCostsTable.peek(), my columnLabels[j+1]);
+			delta[0][j] = delta[0][j - 1] + EditCostsTable_getDeletionCost (my editCostsTable.get(), my columnLabels[j+1]);
 			psi[0][j] = WARPING_fromLeft;
 		}
 		for (long i = 1; i <= numberOfTargets; i++) {
-			delta[i][0] = delta[i - 1][0] + EditCostsTable_getInsertionCost (my editCostsTable.peek(), my rowLabels[i+1]);
+			delta[i][0] = delta[i - 1][0] + EditCostsTable_getInsertionCost (my editCostsTable.get(), my rowLabels[i+1]);
 			psi[i][0] = WARPING_fromBelow;
 		}
 		for (long j = 1; j <= numberOfSources; j++) {
 			for (long i = 1; i <= numberOfTargets; i++) {
 				// the substitution, deletion and insertion costs.
-				double left = delta[i][j - 1] + EditCostsTable_getInsertionCost (my editCostsTable.peek(), my rowLabels[i+1]);
-				double bottom = delta[i - 1][j] + EditCostsTable_getDeletionCost (my editCostsTable.peek(), my columnLabels[j+1]);
-				double mindist = delta[i - 1][j - 1] + EditCostsTable_getSubstitutionCost (my editCostsTable.peek(), my rowLabels[i+1], my columnLabels[j+1]); // diag
+				double left = delta[i][j - 1] + EditCostsTable_getInsertionCost (my editCostsTable.get(), my rowLabels[i+1]);
+				double bottom = delta[i - 1][j] + EditCostsTable_getDeletionCost (my editCostsTable.get(), my columnLabels[j+1]);
+				double mindist = delta[i - 1][j - 1] + EditCostsTable_getSubstitutionCost (my editCostsTable.get(), my rowLabels[i+1], my columnLabels[j+1]); // diag
 				psi[i][j] = WARPING_fromDiag;
 				if (bottom < mindist) {
 					mindist = bottom;
@@ -558,11 +576,11 @@ void EditDistanceTable_findPath (EditDistanceTable me, autoTableOfReal *directio
 		// find minimum distance in last column
 		long iy = numberOfTargets, ix = numberOfSources;
 
-		WarpingPath_reset (my warpingPath.peek());
+		WarpingPath_reset (my warpingPath.get());
 
-		WarpingPath_getPath (my warpingPath.peek(), psi.peek(), iy, ix);
+		WarpingPath_getPath (my warpingPath.get(), psi.peek(), iy, ix);
 
-		WarpingPath_shiftPathByOne (my warpingPath.peek());
+		WarpingPath_shiftPathByOne (my warpingPath.get());
 
 		for (long i = 0; i <= numberOfTargets; i++) {
 			for (long j = 0; j <= numberOfSources; j++) {
