@@ -1,20 +1,19 @@
 /* GaussianMixture_def.h
  *
- * Copyright (C) 2010 David Weenink
+ * Copyright (C) 2010 David Weenink, 2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define ooSTRUCT GaussianMixture
@@ -23,7 +22,7 @@ oo_DEFINE_CLASS (GaussianMixture, Daata)
 	oo_LONG (numberOfComponents)
 	oo_LONG (dimension)
 	oo_DOUBLE_VECTOR (mixingProbabilities, numberOfComponents)
-	oo_COLLECTION (Ordered, covariances, Covariance, 0)
+	oo_AUTO_OBJECT (CovarianceList, 0, covariances)
 
 	#if oo_DECLARING
 		void v_info ()
