@@ -1,20 +1,19 @@
 /* Intensity_extensions.cpp
  *
- * Copyright (C) 2007-2011 David Weenink
+ * Copyright (C) 2007-2011 David Weenink, 2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -38,12 +37,12 @@ static void IntervalTier_addBoundaryUnsorted (IntervalTier me, long iinterval, d
 	}
 
 	// Modify end time of left label
-	TextInterval ti = (TextInterval) my intervals -> item[iinterval];
+	TextInterval ti = my intervals.at [iinterval];
 	ti -> xmax = time;
 	TextInterval_setText (ti, leftLabel);
 
 	autoTextInterval ti_new = TextInterval_create (time, my xmax, U"");
-	Sorted_addItem_unsorted (my intervals, ti_new.transfer());
+	my intervals. addItem_unsorted_move (ti_new.move());
 }
 
 autoTextGrid Intensity_to_TextGrid_detectSilences (Intensity me, double silenceThreshold_dB, double minSilenceDuration, double minSoundingDuration, const char32 *silenceLabel, const char32 *soundingLabel) {
@@ -55,8 +54,8 @@ autoTextGrid Intensity_to_TextGrid_detectSilences (Intensity me, double silenceT
 		}
 
 		autoTextGrid thee = TextGrid_create (my xmin, my xmax, U"silences", U"");
-		IntervalTier it = (IntervalTier) thy tiers -> item[1];
-		TextInterval_setText ( (TextInterval) it -> intervals -> item[1], soundingLabel);
+		IntervalTier it = (IntervalTier) thy tiers->at [1];
+		TextInterval_setText (it -> intervals.at [1], soundingLabel);
 		if (minSilenceDuration > duration) {
 			return thee;
 		}
@@ -104,8 +103,8 @@ autoTextGrid Intensity_to_TextGrid_detectSilences (Intensity me, double silenceT
 		// (re)label last interval */
 
 		label = inSilenceInterval ? silenceLabel : soundingLabel;
-		TextInterval_setText ( (TextInterval) it -> intervals -> item[iinterval], label);
-		Sorted_sort (it -> intervals);
+		TextInterval_setText (it -> intervals.at [iinterval], label);
+		it -> intervals. sort ();
 
 		// First remove short non-silence intervals in-between silence intervals and
 		// then remove the remaining short silence intervals.
@@ -142,7 +141,7 @@ autoTextGrid IntensityTier_to_TextGrid_detectSilences (IntensityTier me, double
 	double minSoundingDuration, const char32 *silenceLabel, const char32 *soundingLabel) {
 	try {
 		autoIntensity intensity = IntensityTier_to_Intensity (me, dt);
-		autoTextGrid thee = Intensity_to_TextGrid_detectSilences (intensity.peek(), silenceThreshold_dB, minSilenceDuration, minSoundingDuration, silenceLabel, soundingLabel);
+		autoTextGrid thee = Intensity_to_TextGrid_detectSilences (intensity.get(), silenceThreshold_dB, minSilenceDuration, minSoundingDuration, silenceLabel, soundingLabel);
 		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U" no TextGrid created.");
