@@ -1,20 +1,19 @@
 /* Minimizers.cpp
  *
- * Copyright (C) 2001-2013, 2015 David Weenink
+ * Copyright (C) 2001-2013, 2015-2016 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 /*
  David Weenink, 20011016
@@ -47,13 +46,13 @@
 
 Thing_implement (Minimizer, Thing, 0);
 
-void structMinimizer :: v_destroy () {
+void structMinimizer :: v_destroy () noexcept {
 	NUMvector_free<double> (p, 1);
 	NUMvector_free<double> (history, 1);
 	Minimizer_Parent :: v_destroy ();
 }
 
-static void classMinimizer_after (Minimizer me, Any /* aclosure */) {
+static void classMinimizer_afterHook (Minimizer me, Thing /* boss */) {
 
 	if (my success || ! my gmonitor) {
 		return;
@@ -63,9 +62,11 @@ static void classMinimizer_after (Minimizer me, Any /* aclosure */) {
 		Minimizer_drawHistory (me, my gmonitor, 0, my maxNumOfIterations, 0.0, 1.1 * my history[1], 1);
 		Graphics_textTop (my gmonitor, false, Melder_cat (U"Dimension of search space: ", my nParameters));
 	}
+	Graphics_beginMovieFrame (my gmonitor, nullptr);
 	Graphics_setInner (my gmonitor);
 	Graphics_line (my gmonitor, my iteration, my history[my iteration], my iteration, my history[my iteration]);
 	Graphics_unsetInner (my gmonitor);
+	Graphics_endMovieFrame (my gmonitor, 0.0);
 	Melder_monitor ((double) (my iteration) / my maxNumOfIterations, U"Iterations: ", my iteration, 
 		U", Function calls: ", my funcCalls, U", Cost: ", my minimum);
 }
@@ -75,14 +76,10 @@ void Minimizer_init (Minimizer me, long nParameters, Daata object) {
 	my p = NUMvector<double> (1, nParameters);
 	my object = object;
 	my minimum = 1.0e30;
-	my after = classMinimizer_after;
+	my afterHook = classMinimizer_afterHook;
 	Minimizer_reset (me, nullptr); /* added 27/11/97 */
 }
 
-void Minimizer_setParameters (Minimizer me, Any parameters) {
-	my v_setParameters (parameters);
-}
-
 static void monitor_off (Minimizer me) {
 	Melder_monitor (1.1);
 	if (my gmonitor) {
@@ -158,10 +155,14 @@ void Minimizer_minimizeManyTimes (Minimizer me, long numberOfTimes, long maxIter
 	Minimizer_reset (me, popt.peek());
 }
 
-void Minimizer_setAfterEachIteration (Minimizer me, void (*after) (Minimizer me, Any aclosure), Any aclosure) {
-	my after = after;
-	my aclosure = aclosure;
+#if 0
+void Minimizer_setAfterEachIteration (Minimizer me, int (*afterHook) (Minimizer me, Thing afterBoss), Thing afterBoss);
+/* set the procedure that is executed after each iteration. */
+void Minimizer_setAfterEachIteration (Minimizer me, void (*afterHook) (Minimizer me, Thing afterBoss), Thing afterBoss) {
+	my afterHook = afterHook;
+	my afterBoss = afterBoss;
 }
+#endif
 
 void Minimizer_reset (Minimizer me, const double guess[]) {
 	if (guess) {
@@ -234,9 +235,9 @@ void structSteepestDescentMinimizer :: v_minimize () {
 		}
 		history[++iteration] = minimum = func (object, p);
 		success = 2.0 * fabs (fret - minimum) < tolerance * (fabs (fret) + fabs (minimum));
-		if (after) {
+		if (our afterHook) {
 			try {
-				after (this, aclosure);
+				our afterHook (this, our afterBoss);
 			} catch (MelderError) {
 				Melder_casual (U"Interrupted after ", iteration, U" iterations.");
 				Melder_clearError ();
@@ -250,23 +251,13 @@ void structSteepestDescentMinimizer :: v_minimize () {
 	}
 }
 
-void structSteepestDescentMinimizer :: v_setParameters (Any parameters) {
-	if (p) {
-		SteepestDescentMinimizer_parameters thee = (SteepestDescentMinimizer_parameters) parameters;
-		eta = thy eta;
-		momentum = thy momentum;
-	} else {
-		eta = 0.1; momentum = 0.9;
-	}
-}
-
-SteepestDescentMinimizer SteepestDescentMinimizer_create (long nParameters, Daata object, double (*func) (Daata object, const double p[]), void (*dfunc) (Daata object, const double p[], double dp[])) {
+autoSteepestDescentMinimizer SteepestDescentMinimizer_create (long nParameters, Daata object, double (*func) (Daata object, const double p[]), void (*dfunc) (Daata object, const double p[], double dp[])) {
 	try {
 		autoSteepestDescentMinimizer me = Thing_new (SteepestDescentMinimizer);
-		Minimizer_init (me.peek(), nParameters, object);
+		Minimizer_init (me.get(), nParameters, object);
 		my func = func;
 		my dfunc = dfunc;
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"SteepestDescentMinimizer not created.");
 	}
@@ -421,9 +412,9 @@ void structVDSmagtMinimizer :: v_minimize () {
 					gropt = grc;
 					dalpha = - dalpha;
 					success = gsq < tolerance;
-					if (after) {
+					if (our afterHook) {
 						try {
-							after (this, aclosure);
+							our afterHook (this, our afterBoss);
 						} catch (MelderError) {
 							Melder_casual (U"Interrupted after ", this -> iteration, U" iterations.");
 							Melder_clearError ();
@@ -474,7 +465,7 @@ void structVDSmagtMinimizer :: v_minimize () {
 	}
 }
 
-void structVDSmagtMinimizer :: v_destroy () {
+void structVDSmagtMinimizer :: v_destroy () noexcept {
 	NUMvector_free<double> (dp, 1);
 	NUMvector_free<double> (pc, 1);
 	NUMvector_free<double> (gc, 1);
@@ -489,18 +480,10 @@ void structVDSmagtMinimizer :: v_reset () {
 	restart_flag = 1;
 }
 
-void structVDSmagtMinimizer :: v_setParameters (Any parameters) {
-	if (parameters) {
-		VDSmagtMinimizer_parameters  vdspars = (VDSmagtMinimizer_parameters) parameters;
-		lineSearchGradient = vdspars -> lineSearchGradient;
-		lineSearchMaxNumOfIterations = vdspars -> lineSearchMaxNumOfIterations;
-	}
-}
-
-VDSmagtMinimizer VDSmagtMinimizer_create (long nParameters, Daata object, double (*func) (Daata object, const double x[]), void (*dfunc) (Daata object, const double x[], double dx[])) {
+autoVDSmagtMinimizer VDSmagtMinimizer_create (long nParameters, Daata object, double (*func) (Daata object, const double x[]), void (*dfunc) (Daata object, const double x[], double dx[])) {
 	try {
 		autoVDSmagtMinimizer me = Thing_new (VDSmagtMinimizer);
-		Minimizer_init (me.peek(), nParameters, object);
+		Minimizer_init (me.get(), nParameters, object);
 		my dp = NUMvector<double> (1, nParameters);
 		my pc = NUMvector<double> (1, nParameters);
 		my gc = NUMvector<double> (1, nParameters);
@@ -512,7 +495,7 @@ VDSmagtMinimizer VDSmagtMinimizer_create (long nParameters, Daata object, double
 		my dfunc = dfunc;
 		my lineSearchGradient = 0.9;
 		my lineSearchMaxNumOfIterations = 5;
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"VDSmagtMinimizer not created.");
 	}
@@ -520,7 +503,7 @@ VDSmagtMinimizer VDSmagtMinimizer_create (long nParameters, Daata object, double
 
 /************ class LineMinimizer *******************************/
 
-void structLineMinimizer :: v_destroy () {
+void structLineMinimizer :: v_destroy () noexcept {
 	NUMvector_free (ptry, 1);
 	NUMvector_free (direction, 1);
 	LineMinimizer_Parent :: v_destroy ();
@@ -528,8 +511,7 @@ void structLineMinimizer :: v_destroy () {
 
 Thing_implement (LineMinimizer, Minimizer, 0);
 
-void LineMinimizer_init (I, long nParameters, Daata object, double (*func) (Daata, const double [])) {
-	iam (LineMinimizer);
+void LineMinimizer_init (LineMinimizer me, long nParameters, Daata object, double (*func) (Daata, const double [])) {
 	Minimizer_init (me, nParameters, object);
 	my direction = NUMvector<double> (1, nParameters);
 	my ptry = NUMvector<double> (1, nParameters);
