@@ -2,21 +2,20 @@
 #define _Minimizers_h_
 /* Minimizers.h
  *
- * Copyright (C) 1993-2011 David Weenink
+ * Copyright (C) 1993-2011,2015-2016 David Weenink, 2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -42,18 +41,17 @@ Thing_define (Minimizer, Thing) {
 	long start;			/* start iteration series */
 	long maxNumOfIterations; /* the current maximum number of iterations */
 	long iteration;     /* the total number of iterations */
-	void (*after) (Minimizer me, Any aclosure); /* to be called after each iteration */
-	Any aclosure;
+	void (*afterHook) (Minimizer me, Thing boss); /* to be called after each iteration */
+	Thing afterBoss;
 	Graphics gmonitor;		/* graphics to monitor the minimization process */
 
-	void v_destroy ()
+	void v_destroy () noexcept
 		override;
 	void v_info ()
 		override { }
 
 	virtual void v_minimize () { }  /* does the work */
 	virtual void v_reset () { } /* reset the minimizer */
-	virtual void v_setParameters (Any parameters) { (void) parameters; }
 };
 
 void Minimizer_init (Minimizer me, long nParameters, Daata object);
@@ -75,11 +73,6 @@ void Minimizer_reset (Minimizer me, const double guess[]);
  *    reset (me);
  */
 
-void Minimizer_setAfterEachIteration (Minimizer me, int (*after) (Minimizer me, Any aclosure), Any aclosure);
-/* set the procedure that is executed after each iteration. */
-
-void Minimizer_setParameters (Minimizer me, Any parameters); /* for inheritors */
-
 void Minimizer_minimize (Minimizer me, long maxNumOfIterations, double tolerance, int monitor);
 /* Minimizes during maximally maxNumOfIterations. The gmonitor is initialized
  * before minimization and cleared afterwards.
@@ -101,20 +94,19 @@ double Minimizer_getMinimum (Minimizer me);
 /********** deferred class LineMinimizer ************************************/
 
 Thing_define (LineMinimizer, Minimizer) {
-	// new data:
-	public:
-		/* the function to be minimized */
-		double (*func) (Daata object, const double p[]);
-		double maxLineStep;	/*maximum step in line search direction */
-		double *direction;	/* search direction vector */
-		double *ptry;		/* point in search direction */
-	// overridden methods:
-		virtual void v_destroy ();
-	// new methods:
-		//virtual void v_linmin (double p[], double fp, double direction[], double *fret);	 // David, is dit correct? ja
+	/* the function to be minimized */
+	double (*func) (Daata object, const double p[]);
+	double maxLineStep;	/*maximum step in line search direction */
+	double *direction;	/* search direction vector */
+	double *ptry;		/* point in search direction */
+
+	void v_destroy () noexcept
+		override;
+
+	//virtual void v_linmin (double p[], double fp, double direction[], double *fret);	 // David, is dit correct? ja
 };
 
-void LineMinimizer_init (I, long nParameters, Daata object, double (*func) (Daata object, const double p[]));
+void LineMinimizer_init (LineMinimizer me, long nParameters, Daata object, double (*func) (Daata object, const double p[]));
 
 /******************  class SteepestDescentMinimizer**************************/
 
@@ -123,18 +115,16 @@ typedef struct structSteepestDescentMinimizer_parameters {
 } *SteepestDescentMinimizer_parameters;
 
 Thing_define (SteepestDescentMinimizer, Minimizer) {
-	// new data:
-	public:
-		double eta, momentum;
-		double (*func) (Daata object, const double p[]);
-		void  (*dfunc) (Daata object, const double p[], double dp[]);
-		/* calculates gradient at position p */
-	// overridden methods:
-		virtual void v_minimize ();
-		virtual void v_setParameters (Any parameters);
+	double eta, momentum;
+	double (*func) (Daata object, const double p[]);
+	void  (*dfunc) (Daata object, const double p[], double dp[]);
+	/* calculates gradient at position p */
+
+	void v_minimize ()
+		override;
 };
 
-SteepestDescentMinimizer SteepestDescentMinimizer_create (long nParameters, Daata object, double (*func) (Daata object, const double p[]), void (*dfunc) (Daata object, const double p[], double dp[]));
+autoSteepestDescentMinimizer SteepestDescentMinimizer_create (long nParameters, Daata object, double (*func) (Daata object, const double p[]), void (*dfunc) (Daata object, const double p[], double dp[]));
 
 
 /**********  class VDSmagtMinimizer ********************************/
@@ -145,31 +135,31 @@ typedef struct structVDSmagtMinimizer_parameters {
 } *VDSmagtMinimizer_parameters;
 
 Thing_define (VDSmagtMinimizer, Minimizer) {
-	// new data:
-	public:
-		double (*func) (Daata object, const double p[]);
-		void  (*dfunc) (Daata object, const double p[], double dp[]);
-		double *dp;
-		double lineSearchGradient;
-		long lineSearchMaxNumOfIterations;
-		double gr0, gropt, df, alplim, alpha, dalpha, alphamin;
-		double *pc;	/* position of current point */
-		double *gc;	/* gradient of current point */
-		double *g0;	/* gradient at beginning of line search */
-		double *s;	/* search direction for line search */
-		double *srst;/* search direction for first iteration after restart */
-		double *grst; /* gradient for first iteration after restart */
-		double fc, grc, fch, gr2s, temp, grs, beta, gcg0;
-		double gamma, gamma_in, f0, gsq, gopt_sq;
-		long lineSearch_iteration, flag, again, one_up, restart;
-		long restart_flag;
-	// overridden methods:
-		virtual void v_destroy ();
-		virtual void v_minimize ();
-		virtual void v_reset ();
-		virtual void v_setParameters (Any parameters);
+	double (*func) (Daata object, const double p[]);
+	void  (*dfunc) (Daata object, const double p[], double dp[]);
+	double *dp;
+	double lineSearchGradient;
+	long lineSearchMaxNumOfIterations;
+	double gr0, gropt, df, alplim, alpha, dalpha, alphamin;
+	double *pc;	/* position of current point */
+	double *gc;	/* gradient of current point */
+	double *g0;	/* gradient at beginning of line search */
+	double *s;	/* search direction for line search */
+	double *srst;/* search direction for first iteration after restart */
+	double *grst; /* gradient for first iteration after restart */
+	double fc, grc, fch, gr2s, temp, grs, beta, gcg0;
+	double gamma, gamma_in, f0, gsq, gopt_sq;
+	long lineSearch_iteration, flag, again, one_up, restart;
+	long restart_flag;
+
+	void v_destroy () noexcept
+		override;
+	void v_minimize ()
+		override;
+	void v_reset ()
+		override;
 };
 
-VDSmagtMinimizer VDSmagtMinimizer_create (long dimension, Daata object, double (*func) (Daata object, const double p[]), void (*dfunc) (Daata object, const double p[], double dp[]));
+autoVDSmagtMinimizer VDSmagtMinimizer_create (long dimension, Daata object, double (*func) (Daata object, const double p[]), void (*dfunc) (Daata object, const double p[], double dp[]));
 
 #endif /* _Minimizer_h_ */
