@@ -137,6 +137,17 @@ void PCA_getEqualityOfEigenvalues (PCA me, long from, long to, int conservative,
  * 
  */
 
+autoEigen PCA_to_Eigen (PCA me) {
+	try {
+		autoEigen thee = Eigen_create (my numberOfEigenvalues, my dimension);
+		NUMmatrix_copyElements <double>(my eigenvectors, thy eigenvectors, 1, my numberOfEigenvalues, 1, my dimension);
+		NUMvector_copyElements<double>(my eigenvalues, thy eigenvalues, 1, my numberOfEigenvalues);
+		return thee;
+	} catch (MelderError) {
+		Melder_throw (me, U": no Eigen created.");
+	}
+}
+
 static autoPCA NUMdmatrix_to_PCA (double **m, long numberOfRows, long numberOfColumns, bool byColumns) {
 	try {
 		if (! NUMdmatrix_hasFiniteElements(m, 1, numberOfRows, 1, numberOfColumns)) {
