@@ -2,21 +2,20 @@
 #define _SSCP_h_
 /* SSCP.h
  *
- * Copyright (C) 1993-2014 David Weenink
+ * Copyright (C) 1993-2014, 2015 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "TableOfReal_extensions.h"
@@ -24,7 +23,6 @@
 #include "CCA.h"
 
 #include "SSCP_def.h"
-oo_CLASS_CREATE (SSCP, TableOfReal);
 
 Thing_define (Covariance, SSCP) {
 };
@@ -36,57 +34,73 @@ Thing_define (Correlation, SSCP) {
 	Ordered collection of SSCP's
 	All SSCP's must have the same dimensions and labels.
 */
-Thing_define (SSCPs, Ordered) {
+Collection_define (SSCPList, OrderedOf, SSCP) {
+};
+
+Collection_define (CovarianceList, OrderedOf, Covariance) {
+	SSCPList asSSCPList () {
+		return reinterpret_cast<SSCPList> (this);
+	}
 };
 
 void SSCP_init (SSCP me, long dimension, long storage);
 
-SSCP SSCP_create (long dimension);
+autoSSCP SSCP_create (long dimension);
 
 void SSCP_drawTwoDimensionalEllipse_inside  (SSCP me, Graphics g, double scale, char32 * label, int fontSize);
+
 double SSCP_getEllipseScalefactor (SSCP me, double scale, bool confidence);
+
 void SSCP_drawConcentrationEllipse (SSCP me, Graphics g, double scale, int confidence,
 	long d1, long d2, double xmin, double xmax, double ymin, double ymax, int garnish);
 
 void SSCP_setNumberOfObservations (SSCP me, double numberOfObservations);
+
 void SSCP_setCentroid (SSCP me, long component, double value); // only SSCP & Covariance
+
 void SSCP_setValue (SSCP me, long row, long col, double value); // only SSCP & Covariance
 
 double SSCP_getNumberOfObservations (SSCP me);
+
 double SSCP_getDegreesOfFreedom (SSCP me);
+
 double SSCP_getTotalVariance (SSCP me);
+
 double SSCP_getCumulativeContributionOfComponents (SSCP me, long from, long to);
+
 double SSCP_getLnDeterminant (SSCP me);
+
 double SSCP_getConcentrationEllipseArea(SSCP me, double scale, bool confidence, long d1, long d2);
+
 double SSCP_getFractionVariation (SSCP me, long from, long to);
 
-SSCP TableOfReal_to_SSCP (TableOfReal me, long rowb, long rowe, long colb, long cole);
+autoSSCP TableOfReal_to_SSCP (TableOfReal me, long rowb, long rowe, long colb, long cole);
 
-TableOfReal SSCP_and_TableOfReal_extractDistanceQuantileRange (SSCP me, TableOfReal thee,
-	double qlow, double qhigh);
-TableOfReal Covariance_and_TableOfReal_extractDistanceQuantileRange (Covariance me, TableOfReal thee,
-	double qlow, double qhigh);
+autoTableOfReal SSCP_and_TableOfReal_extractDistanceQuantileRange (SSCP me, TableOfReal thee, double qlow, double qhigh);
+
+autoTableOfReal Covariance_and_TableOfReal_extractDistanceQuantileRange (Covariance me, TableOfReal thee, double qlow, double qhigh);
 /*
 	Select from a TableOfReal the rows whose Mahalanobis distance to the centroid
 	(from the SSCP) is in the quantile [qlow, qhigh].
 */
 
-TableOfReal Covariance_and_TableOfReal_mahalanobis (Covariance me, thou, bool useTableCentroid);
+autoTableOfReal Covariance_and_TableOfReal_mahalanobis (Covariance me, TableOfReal thee, bool useTableCentroid);
 /*
 	Calculate the Mahalanobis distance: sqrt ((x-m)'S**-1 (x-m))
 	use the m-vector (centroid) from the covariance unless useTableColumnMeans is true.
 */
 
+autoCovariance TableOfReal_to_Covariance (TableOfReal me);
 
-Covariance TableOfReal_to_Covariance (TableOfReal me);
+autoCorrelation TableOfReal_to_Correlation (TableOfReal me);
 
-Correlation TableOfReal_to_Correlation (TableOfReal me);
-Correlation TableOfReal_to_Correlation_rank (TableOfReal me);
+autoCorrelation TableOfReal_to_Correlation_rank (TableOfReal me);
 
-TableOfReal SSCP_to_TableOfReal (SSCP me);
-TableOfReal SSCP_extractCentroid (SSCP me);
+autoTableOfReal SSCP_to_TableOfReal (SSCP me);
 
-TableOfReal Covariance_to_TableOfReal_randomSampling (Covariance me, long numberOfData);
+autoTableOfReal SSCP_extractCentroid (SSCP me);
+
+autoTableOfReal Covariance_to_TableOfReal_randomSampling (Covariance me, long numberOfData);
 /* Generate a table with data based on the covariance matrix */
 
 void Covariance_and_PCA_generateOneVector (Covariance me, PCA thee, double *vec, double *buf);
@@ -102,18 +116,21 @@ void Covariance_and_PCA_generateOneVector (Covariance me, PCA thee, double *vec,
 		4. buf, a vector of length my numberOfColumns, is needed so the routine cannot fail
 */
 
-SSCPs TableOfReal_to_SSCPs_byLabel (TableOfReal me);
+autoSSCPList TableOfReal_to_SSCPList_byLabel (TableOfReal me);
 
-PCA SSCP_to_PCA (SSCP me);
+autoPCA SSCP_to_PCA (SSCP me);
 
 void SSCP_expandPCA (SSCP me);
+
 void SSCP_unExpandPCA (SSCP me);
 
 autoCCA SSCP_to_CCA (SSCP me, long ny);
 
-Covariance Covariance_create (long dimension);
-Covariance Covariance_createSimple (char32 *covars, char32 *centroid, long numberOfObservations);
-Covariance Covariance_create_reduceStorage (long dimension, long storage);
+autoCovariance Covariance_create (long dimension);
+
+autoCovariance Covariance_createSimple (char32 *covars, char32 *centroid, long numberOfObservations);
+
+autoCovariance Covariance_create_reduceStorage (long dimension, long storage);
 /*
 	storage 0 or >= dimension: complete matrix
 	storage 1: only diagonal
@@ -124,10 +141,11 @@ Covariance Covariance_create_reduceStorage (long dimension, long storage);
     See also SSCP_expand () for usage.
 */
 
-Correlation Correlation_create (long dimension);
+autoCorrelation Correlation_create (long dimension);
 
-TableOfReal Correlation_confidenceIntervals (Correlation me,
-	double confidenceLevel, long numberOfTests, int method);
+autoCorrelation Correlation_createSimple (char32 *s_correlations, char32 *s_centroid, long numberOfObservations);
+
+autoTableOfReal Correlation_confidenceIntervals (Correlation me, double confidenceLevel, long numberOfTests, int method);
 /*
 	if (method == 1)
 		Confidence intervals by Ruben's approximation
@@ -142,45 +160,36 @@ TableOfReal Correlation_confidenceIntervals (Correlation me,
 
 /* Precondition ||vector|| = 1 */
 void Covariance_getMarginalDensityParameters (Covariance me, double *vector, double *mu, double *stdev);
-double Covariance_getMarginalProbabilityAtPosition (Covariance me, double *vector, double x);
+
+double Covariance_getMarginalProbabilityAtPosition (Covariance me, double vector[], double x);
 
 double Covariance_getProbabilityAtPosition_string (Covariance me, char32 *xpos);
-double Covariance_getProbabilityAtPosition (Covariance me, double *x);
+
+double Covariance_getProbabilityAtPosition (Covariance me, double x[]);
 /* evaluate the pdf(x,mu,Sigma) at x */
 
-Covariance SSCP_to_Covariance (SSCP me, long numberOfConstraints);
+autoCovariance SSCP_to_Covariance (SSCP me, long numberOfConstraints);
 
-SSCP Covariance_to_SSCP (Covariance me);
+autoSSCP Covariance_to_SSCP (Covariance me);
 
-void SSCP_testDiagonality_bartlett (SSCP me, long numberOfContraints,
-	double *chisq, double *probability);
-void Correlation_testDiagonality_bartlett (Correlation me,
-	long numberOfContraints, double *chisq, double *probability);
-/* Test whether matrices are diagonal matrices, Morrison, page 118 */
+void SSCP_testDiagonality_bartlett (SSCP me, long numberOfContraints, double *chisq, double *prob, double *df);
 
-Correlation SSCP_to_Correlation (SSCP me);
+void Correlation_testDiagonality_bartlett (Correlation me, long numberOfContraints, double *chisq, double *prob, double *df);
+/* Test if a Correlation matrix is diagonal, Morrison pp. 116-118 */
 
-Configuration SSCP_to_Configuration (SSCP me, long numberOfDimensions);
+autoCorrelation SSCP_to_Correlation (SSCP me);
 
-Configuration Covariance_to_Configuration (Covariance me, long numberOfDimensions);
+void Covariance_difference (Covariance me, Covariance thee, double *prob, double *chisq, double *df);
 
-Configuration Correlation_to_Configuration (Correlation me, long numberOfDimensions);
+void Covariance_getSignificanceOfOneMean (Covariance me, long index, double mu,	double *probability, double *t, double *df);
 
-void Covariance_difference (Covariance me, Covariance thee, double *prob, double *chisq, long *ndf);
-
-void Covariance_getSignificanceOfOneMean (Covariance me, long index, double mu,
+void Covariance_getSignificanceOfMeansDifference (Covariance me, long index1, long index2, double mu, int paired, int equalVariances,
 	double *probability, double *t, double *ndf);
 
-void Covariance_getSignificanceOfMeansDifference (Covariance me,
-	long index1, long index2, double mu, int paired, int equalVariances,
-	double *probability, double *t, double *ndf);
+void Covariance_getSignificanceOfOneVariance (Covariance me, long index, double sigmasq, double *probability, double *chisq, long *ndf);
 
-void Covariance_getSignificanceOfOneVariance (Covariance me, long index,
-	double sigmasq, double *probability, double *chisq, long *ndf);
-
-void Covariance_getSignificanceOfVariancesRatio (Covariance me,
-	long index1, long index2, double ratio, double *probability,
-	double *f, long *ndf);
+void Covariance_getSignificanceOfVariancesRatio (Covariance me, long index1, long index2, double ratio, double *probability,
+	double *f, double *df);
 
 double Covariances_getMultivariateCentroidDifference (Covariance me, Covariance thee, int equalCovariances, double *prob, double *fisher, double *df1, double *df2);
 /* Are the centroids of me and thee different?
@@ -191,36 +200,37 @@ double Covariances_getMultivariateCentroidDifference (Covariance me, Covariance
 	f has Fisher distribution with p and n1+n2-p-1 degrees of freedom.
 */
 
-void Covariances_equality (Collection me, int method, double *prob, double *chisq, double *df);
+void Covariances_equality (CovarianceList me, int method, double *prob, double *chisq, double *df);
 /*
 	Equality of covariance.
 	method = 1 : Bartlett (Morrison, 1990)
 	method = 2 : Wald (Schott, 2001)
 */
 
-SSCPs SSCPs_create ();
+autoCovariance CovarianceList_to_Covariance_pool (CovarianceList me);
 
-SSCPs TableOfReal_to_SSCPs_byLabel (TableOfReal me);
+autoSSCPList TableOfReal_to_SSCPList_byLabel (TableOfReal me);
 
-SSCP SSCPs_to_SSCP_sum (SSCPs me);
+autoSSCP SSCPList_to_SSCP_sum (SSCPList me);
 /* Sum the sscp's and weigh each means with it's numberOfObservations. */
 
-SSCP SSCPs_to_SSCP_pool (SSCPs me);
+autoSSCP SSCPList_to_SSCP_pool (SSCPList me);
 
-void SSCPs_getHomegeneityOfCovariances_box (SSCPs me, double *probability,
-	double *chisq, long *ndf);
+void SSCPList_getHomegeneityOfCovariances_box (SSCPList me, double *probability, double *chisq, double *df);
 
-SSCP SSCP_toTwoDimensions (SSCP me, double *v1, double *v2);
-SSCPs SSCPs_toTwoDimensions (SSCPs me, double *v1, double *v2);
-SSCPs SSCPs_extractTwoDimensions (SSCPs me, long d1, long d2);
+autoSSCP SSCP_toTwoDimensions (SSCP me, double *v1, double *v2);
+
+autoSSCPList SSCPList_toTwoDimensions (SSCPList me, double *v1, double *v2);
+
+autoSSCPList SSCPList_extractTwoDimensions (SSCPList me, long d1, long d2);
 
 /* For inheritors */
 
-void SSCPs_drawConcentrationEllipses (SSCPs me, Graphics g, double scale,
-	int confidence, const char32 *label, long d1, long d2, double xmin, double xmax,
-	double ymin, double ymax, int fontSize, int garnish);
+void SSCPList_drawConcentrationEllipses (SSCPList me, Graphics g, double scale,
+	bool confidence, const char32 *label, long d1, long d2, double xmin, double xmax,
+	double ymin, double ymax, int fontSize, bool garnish);
 
-void SSCPs_getEllipsesBoundingBoxCoordinates (SSCPs me, double scale, int confidence,
+void SSCPList_getEllipsesBoundingBoxCoordinates (SSCPList me, double scale, bool confidence,
 	double *xmin, double *xmax, double *ymin, double *ymax);
 
 void SSCP_expand (SSCP me);
@@ -240,6 +250,8 @@ void SSCP_unExpand (SSCP me);
 /* Use only if the memory is really needed! */
 
 void SSCP_expandLowerCholesky (SSCP me); // create lower square root of covariance matrix
+
 void SSCP_unExpandLowerCholesky (SSCP me);
 
-#endif /* _SSCP_h_ */
+/* End of file SSCP.h */
+#endif
