@@ -1,20 +1,19 @@
 /* Sound_extensions.cpp
  *
- * Copyright (C) 1993-2011, 2015 David Weenink
+ * Copyright (C) 1993-2011, 2015-2016 David Weenink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -79,8 +78,8 @@ static void PitchTier_modifyExcursionRange (PitchTier me, double tmin, double tm
 
 	double fref_st = 12.0 * log (fref_Hz / 100.0) / NUMln2;
 
-	for (long i = 1; i <= my points -> size; i++) {
-		RealPoint point = (RealPoint) my points -> item [i];
+	for (long i = 1; i <= my points.size; i++) {
+		RealPoint point = my points.at [i];
 		double f = point -> value;
 		if (point -> number < tmin || point -> number > tmax) {
 			continue;
@@ -273,19 +272,8 @@ static void r4read (Sound me, FILE *f) {
 	}
 }
 
-static long fileLengthBytes (FILE *f) {
-	long begin, end, current;
-	if ( (current = ftell (f)) < 0 ||
-	        fseek (f, 0L, SEEK_SET) || (begin = ftell (f)) < 0 ||
-	        fseek (f, 0L, SEEK_END) || (end = ftell (f)) < 0 ||
-	        fseek (f, current, SEEK_SET)) {
-		end = begin = 0;
-	}
-	return end - begin;
-}
-
 /* Old TIMIT sound-file format */
-Sound Sound_readFromCmuAudioFile (MelderFile file) {
+autoSound Sound_readFromCmuAudioFile (MelderFile file) {
 	try {
 		int littleEndian = 1;
 		autofile f = Melder_fopen (file, "rb");
@@ -308,15 +296,15 @@ Sound Sound_readFromCmuAudioFile (MelderFile file) {
 			Melder_throw (U"Incorrect number of samples.");
 		}
 		autoSound me = Sound_createSimple (1, nSamples / 16000., 16000);
-		i2read (me.peek(), f, littleEndian);
+		i2read (me.get(), f, littleEndian);
 		f.close (file);
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Sound not read from CMU audio file ", MelderFile_messageName (file), U".");
 	}
 }
 
-Sound Sound_readFromRawFile (MelderFile file, const char *format, int nBitsCoding, int littleEndian, int unSigned, long skipNBytes, double samplingFrequency) {
+autoSound Sound_readFromRawFile (MelderFile file, const char *format, int nBitsCoding, int littleEndian, int unSigned, long skipNBytes, double samplingFrequency) {
 	try {
 		autofile f = Melder_fopen (file, "rb");
 		if (! format) {
@@ -335,29 +323,29 @@ Sound Sound_readFromRawFile (MelderFile file, const char *format, int nBitsCodin
 		if (skipNBytes <= 0) {
 			skipNBytes = 0;
 		}
-		long nSamples = (fileLengthBytes (f) - skipNBytes) / nBytesPerSample;
+		long nSamples = (MelderFile_length (file) - skipNBytes) / nBytesPerSample;
 		if (nSamples < 1) {
 			Melder_throw (U"No samples left to read");
 		}
 		autoSound me = Sound_createSimple (1, nSamples / samplingFrequency, samplingFrequency);
 		fseek (f, skipNBytes, SEEK_SET);
 		if (nBytesPerSample == 1 && unSigned) {
-			u1read (me.peek(), f);
+			u1read (me.get(), f);
 		} else if (nBytesPerSample == 1 && ! unSigned) {
-			i1read (me.peek(), f);
+			i1read (me.get(), f);
 		} else if (nBytesPerSample == 2 && unSigned) {
-			u2read (me.peek(), f, littleEndian);
+			u2read (me.get(), f, littleEndian);
 		} else if (nBytesPerSample == 2 && ! unSigned) {
-			i2read (me.peek(), f, littleEndian);
+			i2read (me.get(), f, littleEndian);
 		} else if (nBytesPerSample == 4 && unSigned) {
-			u4read (me.peek(), f, littleEndian);
+			u4read (me.get(), f, littleEndian);
 		} else if (nBytesPerSample == 4 && ! unSigned) {
-			i4read (me.peek(), f, littleEndian);
+			i4read (me.get(), f, littleEndian);
 		} else if (nBytesPerSample == 4 && strequ (format, "float")) {
-			r4read (me.peek(), f);
+			r4read (me.get(), f);
 		}
 		f.close (file);
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Sound not read from raw audio file ", MelderFile_messageName (file), U".");
 	}
@@ -614,7 +602,7 @@ static autoSound Sound_createToneComplex (double minimumTime, double maximumTime
 			}
 		}
 		if (scaleAmplitudes) {
-			Vector_scale (me.peek(), 0.99996948);
+			Vector_scale (me.get(), 0.99996948);
 		}
 		return me;
 	} catch (MelderError) {
@@ -661,7 +649,7 @@ autoSound Sound_createGammaTone (double minimumTime, double maximumTime, double
 				        exp (- NUM2pi * bandwidth * t) * cos (NUM2pi * frequency * t + addition * log (t) + initialPhase);
 		}
 		if (scaleAmplitudes) {
-			Vector_scale (me.peek(), 0.99996948);
+			Vector_scale (me.get(), 0.99996948);
 		}
 		return me;
 	} catch (MelderError) {
@@ -916,7 +904,7 @@ autoSound Sound_createShepardToneComplex (double minimumTime, double maximumTime
 				tswitch = b1 * octaveTime;
 			}
 			for (long j = 1; j <= my nx; j++) {
-				double t = Sampled_indexToX (me.peek(), j);
+				double t = Sampled_indexToX (me.get(), j);
 				double tmod = fmod (t, sweeptime);
 				double tone = tmod <= tswitch ? b1 + a * tmod : b2 + a * (tmod - tswitch);
 				double f = lowestFrequency * pow (2, tone);
@@ -932,7 +920,7 @@ autoSound Sound_createShepardToneComplex (double minimumTime, double maximumTime
 				phasejm1 = phasej;
 			}
 		}
-		Vector_scale (me.peek(), 0.99996948);
+		Vector_scale (me.get(), 0.99996948);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Sound not created from Shepard tone complex.");
@@ -978,7 +966,7 @@ autoSound Sound_createShepardTone (double minimumTime, double maximumTime, doubl
 				ft *= 2; argt *= 2;
 			}
 		}
-		Vector_scale (me.peek(), 0.99996948);
+		Vector_scale (me.get(), 0.99996948);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Sound not created from Shepard tone.");
@@ -999,7 +987,7 @@ autoSound Sound_createPattersonWightmanTone (double minimumTime, double maximumT
 			}
 			my z[1][i] = a;
 		}
-		Vector_scale (me.peek(), 0.99996948);
+		Vector_scale (me.get(), 0.99996948);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Sound not created from Patterson Wightman tone.");
@@ -1024,7 +1012,7 @@ autoSound Sound_createPlompTone (double minimumTime, double maximumTime, double
 			}
 			my z[1][i] = a;
 		}
-		Vector_scale (me.peek(), 0.99996948);
+		Vector_scale (me.get(), 0.99996948);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Sound not created from Plomp tone.");
@@ -1088,45 +1076,47 @@ double Sound_correlateParts (Sound me, double tx, double ty, double duration) {
 	return rxy;
 }
 
-void Sound_localMean (Sound me, double fromTime, double toTime, double *mean) {
+void Sound_localMean (Sound me, double fromTime, double toTime, double *p_mean) {
 	long n1 = Sampled_xToNearestIndex (me, fromTime);
 	long n2 = Sampled_xToNearestIndex (me, toTime);
-	double *s = my z[1];
-	*mean = 0;
-	if (fromTime > toTime) {
-		return;
+	double *s = my z[1], mean = 0.0;
+	if (fromTime  <= toTime) {
+		if (n1 < 1) {
+			n1 = 1;
+		}
+		if (n2 > my nx) {
+			n2 = my nx;
+		}
+		for (long i = n1; i <= n2; i++) {
+			mean += s[i];
+		}
+		mean /= n2 - n1 + 1;
 	}
-	if (n1 < 1) {
-		n1 = 1;
+	if (p_mean) {
+		*p_mean = mean;
 	}
-	if (n2 > my nx) {
-		n2 = my nx;
-	}
-	for (long i = n1; i <= n2; i++) {
-		*mean += s[i];
-	}
-	*mean /= n2 - n1 + 1;
 }
 
-void Sound_localPeak (Sound me, double fromTime, double toTime, double ref, double *peak) {
+void Sound_localPeak (Sound me, double fromTime, double toTime, double ref, double *p_peak) {
 	long n1 = Sampled_xToNearestIndex (me, fromTime);
 	long n2 = Sampled_xToNearestIndex (me, toTime);
-	double *s = my z[1];
-	*peak = -1e308;
-	if (fromTime > toTime) {
-		return;
-	}
-	if (n1 < 1) {
-		n1 = 1;
-	}
-	if (n2 > my nx) {
-		n2 = my nx;
-	}
-	for (long i = n1; i <= n2; i++) {
-		double ds = fabs (s[i] - ref);
-		if (ds > *peak) {
-			*peak = ds;
+	double *s = my z[1], peak = -1e308;
+	if (fromTime <= toTime) {
+		if (n1 < 1) {
+			n1 = 1;
 		}
+		if (n2 > my nx) {
+			n2 = my nx;
+		}
+		for (long i = n1; i <= n2; i++) {
+			double ds = fabs (s[i] - ref);
+			if (ds > peak) {
+				peak = ds;
+			}
+		}
+	}
+	if (p_peak) {
+		*p_peak = peak;
 	}
 }
 
@@ -1142,29 +1132,23 @@ void Sound_into_Sound (Sound me, Sound to, double startTime) {
 IntervalTier Sound_PointProcess_to_IntervalTier (Sound me, PointProcess thee, double window);
 IntervalTier Sound_PointProcess_to_IntervalTier (Sound me, PointProcess thee, double window)
 {
-	IntervalTier him;
-	TextInterval interval;
-	double t1, t2, t, window2 = window / 2;
-	long i;
-
-	him = IntervalTier_create (my xmin, my xmax);
-	if (!him) return nullptr;
-
-	t1 = thy t[1] - window2;
+	double window2 = window / 2;
+	double t1 = thy t[1] - window2;
 	if (t1 < my xmin) t1 = my xmin;
-	t2 = t1 + window2;
+	double t2 = t1 + window2;
 	if (t2 > my xmax) t2 = my xmax;
-	interval = TextInterval_create (t1, t2, "yes");
-	if (!interval || ! Collection_addItem (his intervals, interval)) goto end;
+	autoIntervalTier him = IntervalTier_create (my xmin, my xmax);
+	autoTextInterval interval = TextInterval_create (t1, t2, "yes");
+	Collection_addItem_move (his intervals, interval.move());
 
-	for (i = 2; i <= thy nt; i++)
+	for (long i = 2; i <= thy nt; i++)
 	{
-		t =  thy t[i];
+		double t =  thy t[i];
 
-		if (t  <= t2)
+		if (t <= t2)
 		{
-			long index = his points -> size;
-			RealPoint point = his points -> item[index];
+			long index = his points.size;
+			RealPoint point = his points->at [index];
 			t2 = t + window2;
 			if (t2 > my xmax) t2 = my xmax;
 			point -> value = t2;
@@ -1173,12 +1157,9 @@ IntervalTier Sound_PointProcess_to_IntervalTier (Sound me, PointProcess thee, do
 		{
 			t2 = t + window2;
 			if (t2 > my xmax) t2 = my xmax;
-			if (! RealTier_addPoint (him, t, t2)) goto end;
+			RealTier_addPoint (him, t, t2);
 		}
 	}
-
-end:
-	if (Melder_hasError()) forget (him);
 	return him;
 }
 */
@@ -1220,13 +1201,13 @@ void Sound_overwritePart (Sound me, double t1, double t2, Sound thee, double t3)
 void Sound_filter_part_formula (Sound me, double t1, double t2, const char32 *formula, Interpreter interpreter) {
 	try {
 		autoSound part = Sound_extractPart (me, t1, t2, kSound_windowShape_RECTANGULAR, 1, 1);
-		autoSpectrum spec = Sound_to_Spectrum (part.peek(), true);
-		Matrix_formula ( (Matrix) spec.peek(), formula, interpreter, 0);
-		autoSound filtered = Spectrum_to_Sound (spec.peek());
+		autoSpectrum spec = Sound_to_Spectrum (part.get(), true);
+		Matrix_formula ( (Matrix) spec.get(), formula, interpreter, 0);
+		autoSound filtered = Spectrum_to_Sound (spec.get());
 
 		// Overwrite part between t1 and t2 of original with the filtered signal */
 
-		Sound_overwritePart (me, t1, t2, filtered.peek(), 0);
+		Sound_overwritePart (me, t1, t2, filtered.get(), 0);
 	} catch (MelderError) {
 		Melder_throw (me, U": part not filtered by formula.");
 	}
@@ -1250,7 +1231,7 @@ autoPointProcess Sound_to_PointProcess_getJumps (Sound me, double minimumJump, d
 			while (j <= i + dtn && j <= my nx) {
 				if (fabs (s[i] - s[j]) > minimumJump) {
 					double t = Sampled_indexToX (me, i);
-					PointProcess_addPoint (thee.peek(), t);
+					PointProcess_addPoint (thee.get(), t);
 					step = j - i + 1; break;
 				}
 				j++;
@@ -1272,37 +1253,37 @@ autoSound Sound_and_Pitch_changeSpeaker (Sound me, Pitch him, double formantMult
 			Melder_throw (U"The Pitch and the Sound object must have the same start and end times.");
 		}
 		autoSound sound = Data_copy (me);
-		Vector_subtractMean (sound.peek());
+		Vector_subtractMean (sound.get());
 
 		if (formantMultiplier != 1) {
 			// Shift all frequencies (inclusive pitch!) */
-			Sound_overrideSamplingFrequency (sound.peek(), samplingFrequency_old * formantMultiplier);
+			Sound_overrideSamplingFrequency (sound.get(), samplingFrequency_old * formantMultiplier);
 		}
 
 		autoPitch pitch = Data_copy (him);
-		Pitch_scaleDuration (pitch.peek(), 1 / formantMultiplier); //
-		Pitch_scalePitch (pitch.peek(), formantMultiplier);
+		Pitch_scaleDuration (pitch.get(), 1 / formantMultiplier); //
+		Pitch_scalePitch (pitch.get(), formantMultiplier);
 
-		autoPointProcess pulses = Sound_Pitch_to_PointProcess_cc (sound.peek(), pitch.peek());
-		autoPitchTier pitchTier = Pitch_to_PitchTier (pitch.peek());
+		autoPointProcess pulses = Sound_Pitch_to_PointProcess_cc (sound.get(), pitch.get());
+		autoPitchTier pitchTier = Pitch_to_PitchTier (pitch.get());
 
-		double median = Pitch_getQuantile (pitch.peek(), 0, 0, 0.5, kPitch_unit_HERTZ);
+		double median = Pitch_getQuantile (pitch.get(), 0, 0, 0.5, kPitch_unit_HERTZ);
 		if (median != 0 && median != NUMundefined) {
 			/* Incorporate pitch shift from overriding the sampling frequency */
-			PitchTier_multiplyFrequencies (pitchTier.peek(), sound -> xmin, sound -> xmax, pitchMultiplier / formantMultiplier);
-			PitchTier_modifyExcursionRange (pitchTier.peek(), sound -> xmin, sound -> xmax, pitchRangeMultiplier, median);
+			PitchTier_multiplyFrequencies (pitchTier.get(), sound -> xmin, sound -> xmax, pitchMultiplier / formantMultiplier);
+			PitchTier_modifyExcursionRange (pitchTier.get(), sound -> xmin, sound -> xmax, pitchRangeMultiplier, median);
 		} else if (pitchMultiplier != 1) {
 			Melder_warning (U"Pitch has not been changed because the sound was entirely voiceless.");
 		}
 		autoDurationTier duration = DurationTier_create (my xmin, my xmax);
-		RealTier_addPoint (duration.peek(), (my xmin + my xmax) / 2, formantMultiplier * durationMultiplier);
+		RealTier_addPoint (duration.get(), (my xmin + my xmax) / 2, formantMultiplier * durationMultiplier);
 
-		autoSound thee = Sound_Point_Pitch_Duration_to_Sound (sound.peek(), pulses.peek(), pitchTier.peek(), duration.peek(), MAX_T);
+		autoSound thee = Sound_Point_Pitch_Duration_to_Sound (sound.get(), pulses.get(), pitchTier.get(), duration.get(), MAX_T);
 
 		// Resample to the original sampling frequency
 
 		if (formantMultiplier != 1) {
-			thee = Sound_resample (thee.peek(), samplingFrequency_old, 10);
+			thee = Sound_resample (thee.get(), samplingFrequency_old, 10);
 		}
 		return thee;
 	} catch (MelderError) {
@@ -1313,7 +1294,7 @@ autoSound Sound_and_Pitch_changeSpeaker (Sound me, Pitch him, double formantMult
 autoSound Sound_changeSpeaker (Sound me, double pitchMin, double pitchMax, double formantMultiplier, double pitchMultiplier,  double pitchRangeMultiplier, double durationMultiplier) { // > 0
 	try {
 		autoPitch pitch = Sound_to_Pitch (me, 0.8 / pitchMin, pitchMin, pitchMax);
-		autoSound thee = Sound_and_Pitch_changeSpeaker (me, pitch.peek(), formantMultiplier, pitchMultiplier, pitchRangeMultiplier, durationMultiplier);
+		autoSound thee = Sound_and_Pitch_changeSpeaker (me, pitch.get(), formantMultiplier, pitchMultiplier, pitchRangeMultiplier, durationMultiplier);
 		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": speaker not changed.");
@@ -1325,8 +1306,9 @@ autoTextGrid Sound_to_TextGrid_detectSilences (Sound me, double minPitch, double
 	const char32 *silentLabel, const char32 *soundingLabel) {
 	try {
 		int subtractMeanPressure = 1;
-		autoIntensity thee = Sound_to_Intensity (me, minPitch, timeStep, subtractMeanPressure);
-		autoTextGrid him = Intensity_to_TextGrid_detectSilences (thee.peek(), silenceThreshold, minSilenceDuration, minSoundingDuration, silentLabel, soundingLabel);
+		autoSound filtered = Sound_filter_passHannBand (me, 80.0, 8000.0, 80.0);
+		autoIntensity thee = Sound_to_Intensity (filtered.get(), minPitch, timeStep, subtractMeanPressure);
+		autoTextGrid him = Intensity_to_TextGrid_detectSilences (thee.get(), silenceThreshold, minSilenceDuration, minSoundingDuration, silentLabel, soundingLabel);
 		return him;
 	} catch (MelderError) {
 		Melder_throw (me, U": no TextGrid with silences created.");
@@ -1338,16 +1320,21 @@ void Sound_getStartAndEndTimesOfSounding (Sound me, double minPitch, double time
 		const char32 *silentLabel = U"-", *soundingLabel = U"+";
 		autoTextGrid dbs = Sound_to_TextGrid_detectSilences (me, minPitch, timeStep, silenceThreshold,
 			minSilenceDuration, minSoundingDuration, silentLabel, soundingLabel);
-		IntervalTier itier = (IntervalTier) dbs -> tiers -> item[1];
-		TextInterval ti = (TextInterval) itier -> intervals -> item[1];
-		*t1 = my xmin;
-		if (Melder_equ (ti -> text, silentLabel)) {
-			*t1 = ti -> xmax;
+		IntervalTier tier = (IntervalTier) dbs -> tiers->at [1];
+		Melder_assert (tier -> intervals.size > 0);
+		TextInterval interval = tier -> intervals.at [1];
+		if (t1) {
+			*t1 = my xmin;
+			if (Melder_equ (interval -> text, silentLabel)) {
+				*t1 = interval -> xmax;
+			}
 		}
-		*t2 = my xmax;
-		ti = (TextInterval) itier -> intervals -> item[itier -> intervals -> size];
-		if (Melder_equ (ti -> text, silentLabel)) {
-			*t2 = ti -> xmin;
+		if (t2) {
+			*t2 = my xmax;
+			interval = tier -> intervals.at [tier -> intervals.size];
+			if (Melder_equ (interval -> text, silentLabel)) {
+				*t2 = interval -> xmin;
+			}
 		}
 	} catch (MelderError) {
 		Melder_throw (U"Sounding times not found.");
@@ -1359,10 +1346,10 @@ autoSound Sound_and_IntervalTier_cutPartsMatchingLabel (Sound me, IntervalTier t
         // count samples of the trimmed sound
         long ixmin, ixmax, numberOfSamples = 0, previous_ixmax = 0;
 		double xmin = my xmin; // start time of output sound is start time of input sound
-        for (long iint = 1; iint <= thy intervals -> size; iint++) {
-            TextInterval ti = (TextInterval) thy intervals -> item[iint];
-            if (! Melder_equ (ti -> text, match)) {
-                numberOfSamples += Sampled_getWindowSamples (me, ti -> xmin, ti -> xmax, &ixmin, &ixmax);
+        for (long iint = 1; iint <= thy intervals.size; iint ++) {
+            TextInterval interval = thy intervals.at [iint];
+            if (! Melder_equ (interval -> text, match)) {
+                numberOfSamples += Sampled_getWindowSamples (me, interval -> xmin, interval -> xmax, &ixmin, &ixmax);
                 // if two contiguous intervals have to be copied then the last sample of previous interval
                 // and first sample of current interval might sometimes be equal
 				if (ixmin == previous_ixmax) {
@@ -1371,29 +1358,30 @@ autoSound Sound_and_IntervalTier_cutPartsMatchingLabel (Sound me, IntervalTier t
 				previous_ixmax = ixmax;
 			} else { // matches label
 				if (iint == 1) { // Start time of output sound is end time of first interval
-					xmin = ti -> xmax;
+					xmin = interval -> xmax;
 				}
             }
         }
         // Now copy the parts. The output sound starts at xmin
         autoSound him = Sound_create (my ny, xmin, xmin + numberOfSamples * my dx, numberOfSamples, my dx, xmin + 0.5 * my dx);
-        numberOfSamples = 0; previous_ixmax = 0;
-        for (long iint = 1; iint <= thy intervals -> size; iint++) {
-            TextInterval ti = (TextInterval) thy intervals -> item[iint];
-            if (! Melder_equ (ti -> text, match)) {
+        numberOfSamples = 0;
+		previous_ixmax = 0;
+        for (long iint = 1; iint <= thy intervals.size; iint ++) {
+            TextInterval interval = thy intervals.at [iint];
+            if (! Melder_equ (interval -> text, match)) {
 				long ipos;
-                Sampled_getWindowSamples (me, ti -> xmin, ti -> xmax, &ixmin, &ixmax);
+                Sampled_getWindowSamples (me, interval -> xmin, interval -> xmax, &ixmin, &ixmax);
 				if (ixmin == previous_ixmax) {
 					ixmin++;
 				}
 				previous_ixmax = ixmax;
-                for (long ichan = 1; ichan <= my ny; ichan++) {
+                for (long ichan = 1; ichan <= my ny; ichan ++) {
                     ipos = numberOfSamples + 1;
-                    for (long i = ixmin; i <= ixmax; i++, ipos++) {
-                        his z[ichan][ipos] = my z[ichan][i];
+                    for (long i = ixmin; i <= ixmax; i ++, ipos ++) {
+                        his z [ichan] [ipos] = my z [ichan] [i];
                     }
                 }
-                numberOfSamples = --ipos;
+                numberOfSamples = -- ipos;
             }
         }
         Melder_assert (numberOfSamples == his nx);
@@ -1403,7 +1391,6 @@ autoSound Sound_and_IntervalTier_cutPartsMatchingLabel (Sound me, IntervalTier t
     }
 }
 
-
 autoSound Sound_trimSilences (Sound me, double trimDuration, bool onlyAtStartAndEnd, double minPitch, double timeStep, double silenceThreshold, double minSilenceDuration, double minSoundingDuration, autoTextGrid *p_tg, const char32 *trimLabel) {
     try {
         if (my ny > 1) {
@@ -1411,41 +1398,40 @@ autoSound Sound_trimSilences (Sound me, double trimDuration, bool onlyAtStartAnd
         }
         const char32 *silentLabel = U"silent", *soundingLabel = U"sounding";
         const char32 *copyLabel = U"";
-        autoTextGrid dbs = Sound_to_TextGrid_detectSilences (me, minPitch, timeStep, silenceThreshold,
-            minSilenceDuration, minSoundingDuration, silentLabel, soundingLabel);
-        autoIntervalTier itg = (IntervalTier) Data_copy ((IntervalTier) dbs -> tiers -> item[1]);
-        IntervalTier itier = (IntervalTier) dbs -> tiers -> item[1];
-        for (long iint = 1; iint <= itier -> intervals -> size; iint++) {
-            TextInterval ti = (TextInterval) itier -> intervals -> item[iint];
-            TextInterval ati = (TextInterval) itg -> intervals -> item[iint];
+        autoTextGrid tg = Sound_to_TextGrid_detectSilences (me, minPitch, timeStep, silenceThreshold, minSilenceDuration, minSoundingDuration, silentLabel, soundingLabel);
+        autoIntervalTier itg = Data_copy ((IntervalTier) tg -> tiers->at [1]);
+        IntervalTier tier = (IntervalTier) tg -> tiers->at [1];
+        for (long iint = 1; iint <= tier -> intervals.size; iint ++) {
+            TextInterval ti = tier -> intervals.at [iint];
+            TextInterval ati = itg -> intervals.at [iint];
             double duration = ti -> xmax - ti -> xmin;
-            if (duration > trimDuration && Melder_equ (ti -> text, silentLabel)) { // silent
+            if (duration > trimDuration && Melder_equ (ti -> text, silentLabel)) {   // silent
 				const char32 * label = trimLabel;
                 if (iint == 1) { // first is special
                     double trim_t = ti -> xmax - trimDuration;
-                    IntervalTier_moveBoundary (itg.peek(), iint, false, trim_t);
-                } else if (iint == itier -> intervals -> size) { // last is special
+                    IntervalTier_moveBoundary (itg.get(), iint, false, trim_t);
+                } else if (iint == tier -> intervals.size) {   // last is special
                     double trim_t = ti -> xmin + trimDuration;
-                    IntervalTier_moveBoundary (itg.peek(), iint, true, trim_t);
+                    IntervalTier_moveBoundary (itg.get(), iint, true, trim_t);
                 } else {
 					if (onlyAtStartAndEnd) {
 						label = ati -> text;
 					} else {
                     	double trim_t = ti -> xmin + 0.5 * trimDuration;
-						IntervalTier_moveBoundary (itg.peek(), iint, true, trim_t);
+						IntervalTier_moveBoundary (itg.get(), iint, true, trim_t);
                     	trim_t = ti -> xmax - 0.5 * trimDuration;
-                    	IntervalTier_moveBoundary (itg.peek(), iint, false, trim_t);
+                    	IntervalTier_moveBoundary (itg.get(), iint, false, trim_t);
 					}
                 }
                 TextInterval_setText (ati, label);
-            } else { // sounding
+            } else {   // sounding
                 TextInterval_setText (ati, copyLabel);
             }
         }
-        autoSound thee = Sound_and_IntervalTier_cutPartsMatchingLabel (me, itg.peek(), trimLabel);
+        autoSound thee = Sound_and_IntervalTier_cutPartsMatchingLabel (me, itg.get(), trimLabel);
         if (p_tg) {
-			TextGrid_addTier_copy (dbs.peek(), itg.peek());
-            *p_tg = dbs.move();
+			TextGrid_addTier_copy (tg.get(), itg.get());
+            *p_tg = tg.move();
         }
         return thee;
     } catch (MelderError) {
@@ -1457,17 +1443,21 @@ autoSound Sound_trimSilencesAtStartAndEnd (Sound me, double trimDuration, double
 	double silenceThreshold, double minSilenceDuration, double minSoundingDuration, double *t1, double *t2) {
 	try {
 		autoTextGrid tg;
-		autoSound thee = Sound_trimSilences (me, trimDuration, true, minPitch, timeStep, silenceThreshold, minSilenceDuration, minSoundingDuration, &tg, U"trimmed");
-		IntervalTier trim = (IntervalTier) tg -> tiers -> item[2];
-		TextInterval ti1 = (TextInterval) trim -> intervals -> item[1];
-		*t1 = my xmin;
-		if (Melder_equ (ti1 -> text, U"trimmed")) {
-			*t1 = ti1 -> xmax;
+		autoSound thee = Sound_trimSilences (me, trimDuration, true, minPitch, timeStep, silenceThreshold, minSilenceDuration, minSoundingDuration, & tg, U"trimmed");
+		IntervalTier trim = (IntervalTier) tg -> tiers->at [2];
+		TextInterval ti1 = trim -> intervals.at [1];
+		if (t1) {
+			*t1 = my xmin;
+			if (Melder_equ (ti1 -> text, U"trimmed")) {
+				*t1 = ti1 -> xmax;
+			}
 		}
-		TextInterval ti2 = (TextInterval) trim -> intervals -> item[trim -> intervals -> size];
-		*t2 = my xmax;
-		if (Melder_equ (ti2 -> text, U"trimmed")) {
-			*t2 = ti2 -> xmin;
+		TextInterval ti2 = trim -> intervals.at [trim -> intervals.size];
+		if (t2) {
+			*t2 = my xmax;
+			if (Melder_equ (ti2 -> text, U"trimmed")) {
+				*t2 = ti2 -> xmin;
+			}
 		}
 		return thee;
 	} catch (MelderError) {
@@ -1478,8 +1468,8 @@ autoSound Sound_trimSilencesAtStartAndEnd (Sound me, double trimDuration, double
 /*  Compatibility with old Sound(&pitch)_changeGender  ***********************************/
 
 static void PitchTier_modifyRange_old (PitchTier me, double tmin, double tmax, double factor, double fmid) {
-	for (long i = 1; i <= my points -> size; i ++) {
-		RealPoint point = (RealPoint) my points -> item [i];
+	for (long i = 1; i <= my points.size; i ++) {
+		RealPoint point = my points.at [i];
 		double f = point -> value;
 		if (point -> number < tmin || point -> number > tmax) {
 			continue;
@@ -1489,7 +1479,7 @@ static void PitchTier_modifyRange_old (PitchTier me, double tmin, double tmax, d
 	}
 }
 
-static Pitch Pitch_scaleTime_old (Pitch me, double scaleFactor) {
+static autoPitch Pitch_scaleTime_old (Pitch me, double scaleFactor) {
 	try {
 		double dx = my dx, x1 = my x1, xmax = my xmax;
 		if (scaleFactor != 1) {
@@ -1507,7 +1497,7 @@ static Pitch Pitch_scaleTime_old (Pitch me, double scaleFactor) {
 				thy frame[i].candidate[1].frequency = f;
 			}
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (U"Pitch not scaled.");
 	}
@@ -1528,39 +1518,39 @@ autoSound Sound_and_Pitch_changeGender_old (Sound me, Pitch him, double formantR
 		}
 
 		autoSound sound = Data_copy (me);
-		Vector_subtractMean (sound.peek());
+		Vector_subtractMean (sound.get());
 
 		if (formantRatio != 1) {
 			// Shift all frequencies (inclusive pitch!)
-			Sound_overrideSamplingFrequency (sound.peek(), samplingFrequency_old * formantRatio);
+			Sound_overrideSamplingFrequency (sound.get(), samplingFrequency_old * formantRatio);
 		}
 
 		autoPitch pitch = Pitch_scaleTime_old (him, 1 / formantRatio);
-		autoPointProcess pulses = Sound_Pitch_to_PointProcess_cc (sound.peek(), pitch.peek());
-		autoPitchTier pitchTier = Pitch_to_PitchTier (pitch.peek());
+		autoPointProcess pulses = Sound_Pitch_to_PointProcess_cc (sound.get(), pitch.get());
+		autoPitchTier pitchTier = Pitch_to_PitchTier (pitch.get());
 
-		double median = Pitch_getQuantile (pitch.peek(), 0, 0, 0.5, kPitch_unit_HERTZ);
+		double median = Pitch_getQuantile (pitch.get(), 0, 0, 0.5, kPitch_unit_HERTZ);
 		if (median != 0 && median != NUMundefined) {
 			// Incorporate pitch shift from overriding the sampling frequency
 			if (new_pitch == 0) {
 				new_pitch = median / formantRatio;
 			}
 			double factor = new_pitch / median;
-			PitchTier_multiplyFrequencies (pitchTier.peek(), sound -> xmin, sound -> xmax, factor);
-			PitchTier_modifyRange_old (pitchTier.peek(), sound -> xmin, sound -> xmax, pitchRangeFactor, new_pitch);
+			PitchTier_multiplyFrequencies (pitchTier.get(), sound -> xmin, sound -> xmax, factor);
+			PitchTier_modifyRange_old (pitchTier.get(), sound -> xmin, sound -> xmax, pitchRangeFactor, new_pitch);
 		} else {
 			Melder_warning (U"There were no voiced segments found.");
 		}
 		autoDurationTier duration = DurationTier_create (my xmin, my xmax);
-		RealTier_addPoint (duration.peek(), (my xmin + my xmax) / 2, formantRatio * durationFactor);
+		RealTier_addPoint (duration.get(), (my xmin + my xmax) / 2, formantRatio * durationFactor);
 
-		autoSound thee = Sound_Point_Pitch_Duration_to_Sound (sound.peek(), pulses.peek(), pitchTier.peek(),
-		                 duration.peek(), 1.25 / Pitch_getMinimum (pitch.peek(), 0.0, 0.0, kPitch_unit_HERTZ, false));
+		autoSound thee = Sound_Point_Pitch_Duration_to_Sound (sound.get(), pulses.get(), pitchTier.get(),
+		                 duration.get(), 1.25 / Pitch_getMinimum (pitch.get(), 0.0, 0.0, kPitch_unit_HERTZ, false));
 
 		// Resample to the original sampling frequency
 
 		if (formantRatio != 1) {
-			thee = Sound_resample (thee.peek(), samplingFrequency_old, 10);
+			thee = Sound_resample (thee.get(), samplingFrequency_old, 10);
 		}
 		return thee;
 	} catch (MelderError) {
@@ -1571,7 +1561,7 @@ autoSound Sound_and_Pitch_changeGender_old (Sound me, Pitch him, double formantR
 autoSound Sound_changeGender_old (Sound me, double fmin, double fmax, double formantRatio, double new_pitch, double pitchRangeFactor, double durationFactor) {
 	try {
 		autoPitch pitch = Sound_to_Pitch (me, 0.8 / fmin, fmin, fmax);
-		autoSound thee = Sound_and_Pitch_changeGender_old (me, pitch.peek(), formantRatio,
+		autoSound thee = Sound_and_Pitch_changeGender_old (me, pitch.get(), formantRatio,
 		                 new_pitch, pitchRangeFactor, durationFactor);
 		return thee;
 	} catch (MelderError) {
@@ -1776,7 +1766,7 @@ autoSound Sound_localAverage (Sound me, double averagingInterval, int windowType
 		long nswindow2 = window -> nx / 2;
 		long nswindow2p = (window -> nx - 1) / 2; // nx is odd: one sample less in the forward direction
 		if (nswindow2 < 1) {
-			return thee.transfer();
+			return thee;
 		}
 		double *w = window -> z[1];
 
@@ -1870,7 +1860,7 @@ static void Sound_findIntermediatePoint_bs (Sound me, long ichannel, long isampl
 		thy z[channel][1] = my z[channel][isample]; thy z[channel][3] = my z[channel][isample + 1];
 	}
 
-	Formula_compile (interpreter, thee.peek(), formula, kFormula_EXPRESSION_TYPE_NUMERIC, true);
+	Formula_compile (interpreter, thee.get(), formula, kFormula_EXPRESSION_TYPE_NUMERIC, true);
 
 	// bisection to find optimal x and y
 	long istep = 1;
@@ -2151,10 +2141,10 @@ static autoSound Sound_removeNoiseBySpectralSubtraction_mono (Sound me, Sound no
 		autoSound denoised = Sound_create (1, my xmin, my xmax, my nx, my dx, my x1);
 		autoSound analysisWindow = Sound_createSimple (1, windowLength, samplingFrequency);
 		long windowSamples = analysisWindow -> nx;
-		autoSound noise_copy = (Sound) Data_copy (noise);
-		Sound_multiplyByWindow (noise_copy.peek(), kSound_windowShape_HANNING);
+		autoSound noise_copy = Data_copy (noise);
+		Sound_multiplyByWindow (noise_copy.get(), kSound_windowShape_HANNING);
 		double bandwidth = samplingFrequency / windowSamples;
-		autoLtas noiseLtas = Sound_to_Ltas (noise_copy.peek(), bandwidth);
+		autoLtas noiseLtas = Sound_to_Ltas (noise_copy.get(), bandwidth);
 		autoNUMvector<double> noiseAmplitudes (1, noiseLtas -> nx);
 		for (long i = 1; i <= noiseLtas -> nx; i++) {
 			noiseAmplitudes[i] = pow (10.0, (noiseLtas -> z[1][i] - 94) / 20);
@@ -2174,7 +2164,7 @@ static autoSound Sound_removeNoiseBySpectralSubtraction_mono (Sound me, Sound no
 			for (long j = nsamples + 1; j <= windowSamples; j++) {
 				analysisWindow -> z[1][j] = 0;
 			}
-			autoSpectrum analysisSpectrum = Sound_to_Spectrum (analysisWindow.peek(), 0);
+			autoSpectrum analysisSpectrum = Sound_to_Spectrum (analysisWindow.get(), 0);
 
 			// Suppress noise in the analysisSpectrum by subtracting the noise spectrum
 
@@ -2185,8 +2175,8 @@ static autoSound Sound_removeNoiseBySpectralSubtraction_mono (Sound me, Sound no
 				factor = factor < 1e-6 ? 1e-6 : factor;
 				x[i] *= factor; y[i] *= factor;
 			}
-			autoSound suppressed = Spectrum_to_Sound (analysisSpectrum.peek());
-			Sound_multiplyByWindow (suppressed.peek(), kSound_windowShape_HANNING);
+			autoSound suppressed = Spectrum_to_Sound (analysisSpectrum.get());
+			Sound_multiplyByWindow (suppressed.get(), kSound_windowShape_HANNING);
 			for (long j = 1; j <= nsamples; j++) {
 				denoised -> z[1][istart - 1 + j] += 0.5 * suppressed -> z[1][j]; // 0.5 because of 2-fold oversampling
 			}
@@ -2201,7 +2191,7 @@ static void Sound_findNoise (Sound me, double minimumNoiseDuration, double *nois
 	try {
 		*noiseStart = NUMundefined; *noiseEnd = NUMundefined;
 		autoIntensity intensity = Sound_to_Intensity (me, 20, 0.005, 1);
-		double tmin = Vector_getXOfMinimum (intensity.peek(), intensity -> xmin, intensity ->  xmax, 1) - minimumNoiseDuration / 2;
+		double tmin = Vector_getXOfMinimum (intensity.get(), intensity -> xmin, intensity ->  xmax, 1) - minimumNoiseDuration / 2;
 		double tmax = tmin + minimumNoiseDuration;
 		if (tmin < my xmin) {
 			tmin = my xmin; tmax = tmin + minimumNoiseDuration;
@@ -2225,13 +2215,13 @@ autoSound Sound_removeNoise (Sound me, double noiseStart, double noiseEnd, doubl
 		bool findNoise = noiseEnd <= noiseStart;
 		double minimumNoiseDuration = 2 * windowLength;
 		for (long ichannel = 1; ichannel <= my ny; ichannel++) {
-			autoSound denoisedi, channeli = Sound_extractChannel (filtered.peek(), ichannel);
+			autoSound denoisedi, channeli = Sound_extractChannel (filtered.get(), ichannel);
 			if (findNoise) {
-				Sound_findNoise (channeli.peek(), minimumNoiseDuration, &noiseStart, &noiseEnd);
+				Sound_findNoise (channeli.get(), minimumNoiseDuration, &noiseStart, &noiseEnd);
 			}
-			autoSound noise = Sound_extractPart (channeli.peek(), noiseStart, noiseEnd, kSound_windowShape_RECTANGULAR, 1.0, false);
+			autoSound noise = Sound_extractPart (channeli.get(), noiseStart, noiseEnd, kSound_windowShape_RECTANGULAR, 1.0, false);
 			if (method == 1) { // spectral subtraction
-				denoisedi = Sound_removeNoiseBySpectralSubtraction_mono (filtered.peek(), noise.peek(), windowLength);
+				denoisedi = Sound_removeNoiseBySpectralSubtraction_mono (filtered.get(), noise.get(), windowLength);
 			}
 			NUMvector_copyElements<double> (denoisedi -> z[1], denoised -> z[ichannel], 1, my nx);
 		}
@@ -2244,9 +2234,9 @@ autoSound Sound_removeNoise (Sound me, double noiseStart, double noiseEnd, doubl
 void Sound_playAsFrequencyShifted (Sound me, double shiftBy, double newSamplingFrequency, long precision) {
 	try {
 		autoSpectrum spectrum = Sound_to_Spectrum (me, 1);
-		autoSpectrum shifted = Spectrum_shiftFrequencies (spectrum.peek(), shiftBy, newSamplingFrequency / 2, precision);
-		autoSound thee = Spectrum_to_Sound (shifted.peek());
-		Sound_playPart (thee.peek(), my xmin, my xmax, nullptr, nullptr);
+		autoSpectrum shifted = Spectrum_shiftFrequencies (spectrum.get(), shiftBy, newSamplingFrequency / 2, precision);
+		autoSound thee = Spectrum_to_Sound (shifted.get());
+		Sound_playPart (thee.get(), my xmin, my xmax, nullptr, nullptr);
 	} catch (MelderError) {
 		Melder_throw (me, U" not played with frequencies shifted.");
 	}
