@@ -1,6 +1,6 @@
 /* SpeechSynthesizer_def.h
  *
- * Copyright (C) 2011-2012 David Weenink
+ * Copyright (C) 2011-2012, 2015-2016 David Weenink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,7 +64,6 @@ oo_END_CLASS (SpeechSynthesizerVoice)
 
 #define ooSTRUCT SpeechSynthesizer
 oo_DEFINE_CLASS (SpeechSynthesizer, Daata)
-
 	// sythesizers language /voice
 	oo_STRING (d_voiceLanguageName)
 	oo_STRING (d_voiceVariantName)
@@ -84,19 +83,19 @@ oo_DEFINE_CLASS (SpeechSynthesizer, Daata)
 
 	#if !oo_READING && !oo_WRITING
 		// Filled by the call back
-		oo_OBJECT(Table, 0, d_events)
+		oo_AUTO_OBJECT (Table, 0, d_events)
 		oo_DOUBLE (d_internalSamplingFrequency)
 		oo_LONG (d_numberOfSamples)
 		oo_LONG (d_wavCapacity)
 		oo_INT_VECTOR (d_wav, d_wavCapacity)
 	#endif
 	#if oo_READING
-		SpeechSynthesizer_initSoundBuffer (this);
+		SpeechSynthesizer_initEspeak ();
+		SpeechSynthesizer_changeLanguageNameToCurrent (this);
 	#endif
 	#if oo_DECLARING
-		protected:
-		// overridden methods:
-			virtual void v_info ();
+		void v_info ()
+			override;
 	#endif
 
 oo_END_CLASS (SpeechSynthesizer)
