@@ -1,36 +1,28 @@
 /* Distributions_and_Transition.cpp
  *
- * Copyright (C) 1997-2011,2015 Paul Boersma
+ * Copyright (C) 1997-2011,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-/*
- * pb 1997/03/02 created
- * pb 2002/07/16 GPL
- * pb 2007/08/12 wchar
- * pb 2011/05/09 C++
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Distributions_and_Transition.h"
 
 autoTransition Distributions_to_Transition (Distributions underlying, Distributions surface, long environment,
-	Transition adjacency, int greedy)
+	Transition adjacency, bool greedy)
 {
 	try {
-		if (! underlying) return nullptr;
+		if (! underlying) return autoTransition();
 
 		/*
 		 * Preconditions: range check and matrix matching.
@@ -59,7 +51,7 @@ autoTransition Distributions_to_Transition (Distributions underlying, Distributi
 		for (long i = 1; i <= thy numberOfStates; i ++) {
 			thy stateLabels [i] = Melder_dup (underlying -> columnLabels [i]);
 		}
-		Thing_setName (thee.peek(), underlying -> columnLabels [environment]);
+		Thing_setName (thee.get(), underlying -> columnLabels [environment]);
 
 		/*
 		 * Compute the off-diagonal elements of the transition matrix in environment 'environment'.
