@@ -1,27 +1,25 @@
 /* FormantTier_def.h
  *
- * Copyright (C) 1992-2002 Paul Boersma
+ * Copyright (C) 1992-2002,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 
 #define ooSTRUCT FormantPoint
-oo_DEFINE_CLASS (FormantPoint, Daata)
+oo_DEFINE_CLASS (FormantPoint, AnyPoint)
 
-	oo_DOUBLE (time)   /* AnyPoint */
 	oo_INT (numberOfFormants)
 	oo_DOUBLE_ARRAY (formant, 10, numberOfFormants)
 	oo_DOUBLE_ARRAY (bandwidth, 10, numberOfFormants)
@@ -31,9 +29,13 @@ oo_END_CLASS (FormantPoint)
 
 
 #define ooSTRUCT FormantTier
-oo_DEFINE_CLASS (FormantTier, Function)
+oo_DEFINE_CLASS (FormantTier, Function)   // a kind of AnyTier though
 
-	oo_COLLECTION (SortedSetOfDouble, points, FormantPoint, 0)
+	oo_COLLECTION_OF (SortedSetOfDoubleOf, points, FormantPoint, 0)
+
+	#if oo_DECLARING
+		AnyTier_METHODS
+	#endif
 
 oo_END_CLASS (FormantTier)
 #undef ooSTRUCT
