@@ -4,19 +4,18 @@
  *
  * Copyright (C) 1992-2011,2012,2013,2014,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Editor.h"
@@ -39,7 +38,7 @@ Thing_define (FunctionEditor, Editor) {
 		/*    tmin <= startWindow < endWindow <= tmax; */
 		/*    tmin <= (startSelection, endSelection) <= tmax; */
 
-	Graphics d_graphics;   // used in the 'draw' method
+	autoGraphics d_graphics;   // used in the 'draw' method
 	short functionViewerLeft, functionViewerRight;   // size of drawing areas in pixels
 	short selectionViewerLeft, selectionViewerRight;   // size of drawing areas in pixels
 	short height;   // size of drawing areas in pixels
@@ -59,7 +58,7 @@ Thing_define (FunctionEditor, Editor) {
 	double marker [1 + 3], playCursor, startZoomHistory, endZoomHistory;
 	int numberOfMarkers;
 
-	void v_destroy ()
+	void v_destroy () noexcept
 		override;
 	void v_info ()
 		override;
@@ -95,7 +94,7 @@ Thing_define (FunctionEditor, Editor) {
 		/*
 		 * Message: "the user clicked in one of the rectangles above or below the data window."
 		 */
-	virtual int v_click (double xWC, double yWC, bool shiftKeyPressed);
+	virtual bool v_click (double xWC, double yWC, bool shiftKeyPressed);
 		/*
 		 * Message: "the user clicked in data window with the left mouse button."
 		 * 'xWC' is the time;
@@ -111,8 +110,8 @@ Thing_define (FunctionEditor, Editor) {
 		 * Behaviour of FunctionEditor::click ():
 		 *    moves the cursor to 'xWC', drags to create a selection, or extends the selection.
 		 */
-	virtual int v_clickB (double xWC, double yWC);
-	virtual int v_clickE (double xWC, double yWC);
+	virtual bool v_clickB (double xWC, double yWC);
+	virtual bool v_clickE (double xWC, double yWC);
 	virtual int v_playCallback (int phase, double tmin, double tmax, double t);
 	virtual void v_updateText () { }
 	virtual void v_prefs_addFields (EditorCommand) { }
@@ -135,7 +134,7 @@ Thing_define (FunctionEditor, Editor) {
     #include "FunctionEditor_prefs.h"
 };
 
-int theFunctionEditor_playCallback (void *void_me, int phase, double tmin, double tmax, double t);
+int theFunctionEditor_playCallback (FunctionEditor me, int phase, double tmin, double tmax, double t);
 
 /*
 	Attributes:
@@ -161,8 +160,8 @@ int theFunctionEditor_playCallback (void *void_me, int phase, double tmin, doubl
 */
 
 
-#define FunctionEditor_UPDATE_NEEDED  1
-#define FunctionEditor_NO_UPDATE_NEEDED  0
+#define FunctionEditor_UPDATE_NEEDED  true
+#define FunctionEditor_NO_UPDATE_NEEDED  false
 
 void FunctionEditor_init (FunctionEditor me, const char32 *title, Function data);
 /*
