@@ -29,7 +29,7 @@ double Harmonicity_getMean (Harmonicity me, double tmin, double tmax) {
 	double sum = 0.0;
 	long nSounding = 0;
 	for (long i = imin; i <= imax; i ++) {
-		if (my z [1] [i] != -200) {
+		if (my z [1] [i] != -200.0) {
 			nSounding ++;
 			sum += my z [1] [i];
 		}
@@ -46,7 +46,7 @@ double Harmonicity_getStandardDeviation (Harmonicity me, double tmin, double tma
 	double sum = 0.0;
 	long nSounding = 0;
 	for (long i = imin; i <= imax; i ++) {
-		if (my z [1] [i] != -200) {
+		if (my z [1] [i] != -200.0) {
 			nSounding ++;
 			sum += my z [1] [i];
 		}
@@ -55,7 +55,7 @@ double Harmonicity_getStandardDeviation (Harmonicity me, double tmin, double tma
 	double mean = sum / nSounding;
 	double sumOfSquares = 0.0;
 	for (long i = imin; i <= imax; i ++) {
-		if (my z [1] [i] != -200) {
+		if (my z [1] [i] != -200.0) {
 			double d = my z [1] [i] - mean;
 			sumOfSquares += d * d;
 		}
@@ -67,7 +67,7 @@ double Harmonicity_getQuantile (Harmonicity me, double quantile) {
 	autoNUMvector <double> strengths (1, my nx);
 	long nSounding = 0;
 	for (long ix = 1; ix <= my nx; ix ++)
-		if (my z [1] [ix] != -200)
+		if (my z [1] [ix] != -200.0)
 			strengths [++ nSounding] = my z [1] [ix];
 	double result = -200.0;
 	if (nSounding >= 1) {
@@ -86,14 +86,13 @@ void structHarmonicity :: v_info () {
 	autoNUMvector <double> strengths (1, nx);
 	long nSounding = 0;
 	for (long ix = 1; ix <= nx; ix ++)
-		if (z [1] [ix] != -200)
+		if (z [1] [ix] != -200.0)
 			strengths [++ nSounding] = z [1] [ix];
 	MelderInfo_writeLine (U"Time sampling:");
 	MelderInfo_writeLine (U"   Number of frames: ", nx, U" (", nSounding, U" sounding)");
 	MelderInfo_writeLine (U"   Time step: ", dx, U" seconds");
 	MelderInfo_writeLine (U"   First frame centred at: ", x1, U" seconds");
 	if (nSounding) {
-		double sum = 0, sumOfSquares = 0;
 		MelderInfo_writeLine (U"Periodicity-to-noise ratios of sounding frames:");
 		NUMsort_d (nSounding, strengths.peek());
 		MelderInfo_writeLine (U"   Median ", Melder_single (NUMquantile (nSounding, strengths.peek(), 0.50)), U" dB");
@@ -105,6 +104,7 @@ void structHarmonicity :: v_info () {
 			Melder_single (NUMquantile (nSounding, strengths.peek(), 0.75)), U" dB");
 		MelderInfo_writeLine (U"Minimum: ", Melder_single (strengths [1]), U" dB");
 		MelderInfo_writeLine (U"Maximum: ", Melder_single (strengths [nSounding]), U" dB");
+		double sum = 0.0, sumOfSquares = 0.0;
 		for (long i = 1; i <= nSounding; i ++) {
 			double f = strengths [i];
 			sum += f;
@@ -121,7 +121,7 @@ void structHarmonicity :: v_info () {
 autoHarmonicity Harmonicity_create (double tmin, double tmax, long nt, double dt, double t1) {
 	try {
 		autoHarmonicity me = Thing_new (Harmonicity);
-		Matrix_init (me.get(), tmin, tmax, nt, dt, t1, 1, 1, 1, 1, 1);
+		Matrix_init (me.get(), tmin, tmax, nt, dt, t1, 1.0, 1.0, 1, 1.0, 1.0);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Harmonicity not created.");
