@@ -1,20 +1,19 @@
 /* Movie.cpp
  *
- * Copyright (C) 2011-2012,2015 Paul Boersma
+ * Copyright (C) 2011-2012,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Movie.h"
@@ -53,12 +52,12 @@ void structMovie :: v_info ()
 	MelderInfo_writeLine (U"   First frame centred at: ", x1, U" seconds");
 }
 
-void Movie_init (Movie me, Sound sound, const char32 *folderName, Strings fileNames)
+void Movie_init (Movie me, autoSound sound, const char32 *folderName, autoStrings fileNames)
 {
 	Sampled_init (me, sound -> xmin, sound -> xmax, fileNames ? fileNames -> numberOfStrings : 0, 0.04, 0.0);
-	my d_sound = sound;
+	my d_sound = sound.move();
 	my d_folderName = Melder_dup (folderName);
-	my d_fileNames = fileNames;
+	my d_fileNames = fileNames.move();
 }
 
 autoMovie Movie_openFromSoundFile (MelderFile file)
@@ -76,7 +75,7 @@ autoMovie Movie_openFromSoundFile (MelderFile file)
 		autoStrings strings = Strings_createAsFileList (Melder_cat (fileNameHead.string, U"*.png"));
 		struct structMelderDir folder;
 		MelderFile_getParentDir (file, & folder);
-		Movie_init (me.peek(), sound.transfer(), Melder_dirToPath (& folder), strings.transfer());
+		Movie_init (me.get(), sound.move(), Melder_dirToPath (& folder), strings.move());
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Movie object not read from file ", file, U".");
@@ -88,7 +87,7 @@ void Movie_paintOneImageInside (Movie me, Graphics graphics, long frameNumber, d
 	try {
 		if (frameNumber < 1) Melder_throw (U"Specified frame number is ", frameNumber, U" but should be at least 1.");
 		if (frameNumber > my nx) Melder_throw (U"Specified frame number is ", frameNumber, U" but there are only ", my nx, U"frames.");
-		Melder_assert (my d_fileNames != 0);
+		Melder_assert (my d_fileNames);
 		Melder_assert (my d_fileNames -> numberOfStrings == my nx);
 		struct structMelderDir folder;
 		Melder_pathToDir (my d_folderName, & folder);
@@ -112,10 +111,9 @@ void Movie_paintOneImage (Movie me, Graphics graphics, long frameNumber, double
 	}
 }
 
-void Movie_play (Movie me, Graphics g, double tmin, double tmax, int (*callback) (void *closure, int phase, double tmin, double tmax, double t), void *closure)
+void Movie_play (Movie me, Graphics /* g */, double tmin, double tmax, Sound_PlayCallback callback, Thing boss)
 {
-	(void) g;
-	Sound_playPart (my d_sound, tmin, tmax, callback, closure);
+	Sound_playPart (my d_sound.get(), tmin, tmax, callback, boss);
 }
 
 /* End of file Movie.cpp */
