@@ -2,31 +2,29 @@
 #define _Pitch_h_
 /* Pitch.h
  *
- * Copyright (C) 1992-2011,2014,2015 Paul Boersma
+ * Copyright (C) 1992-2011,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Sampled.h"
 #include "Graphics.h"
-#include "Interpreter_decl.h"
+Thing_declare (Interpreter);
 
 #include "Pitch_enums.h"
 
 #include "Pitch_def.h"
-oo_CLASS_CREATE (Pitch, Sampled);
 
 autoPitch Pitch_create (double tmin, double tmax, long nt, double dt, double t1,
 	double ceiling, int maxnCandidates);
@@ -92,8 +90,8 @@ bool Pitch_isVoiced_t (Pitch me, double t);
 #define Pitch_NEAREST  0
 #define Pitch_LINEAR  1
 
-double Pitch_getValueAtTime (Pitch me, double time, int unit, int interpolate);
-double Pitch_getStrengthAtTime (Pitch me, double time, int unit, int interpolate);
+double Pitch_getValueAtTime (Pitch me, double time, int unit, bool interpolate);
+double Pitch_getStrengthAtTime (Pitch me, double time, int unit, bool interpolate);
 
 long Pitch_countVoicedFrames (Pitch me);
 
@@ -101,14 +99,14 @@ double Pitch_getMean (Pitch me, double tmin, double tmax, int unit);
 double Pitch_getMeanStrength (Pitch me, double tmin, double tmax, int unit);
 double Pitch_getQuantile (Pitch me, double tmin, double tmax, double quantile, int unit);
 double Pitch_getStandardDeviation (Pitch me, double tmin, double tmax, int unit);
-void Pitch_getMaximumAndTime (Pitch me, double tmin, double tmax, int unit, int interpolate,
+void Pitch_getMaximumAndTime (Pitch me, double tmin, double tmax, int unit, bool interpolate,
 	double *return_maximum, double *return_timeOfMaximum);
-double Pitch_getMaximum (Pitch me, double tmin, double tmax, int unit, int interpolate);
-double Pitch_getTimeOfMaximum (Pitch me, double tmin, double tmax, int unit, int interpolate);
-void Pitch_getMinimumAndTime (Pitch me, double tmin, double tmax, int unit, int interpolate,
+double Pitch_getMaximum (Pitch me, double tmin, double tmax, int unit, bool interpolate);
+double Pitch_getTimeOfMaximum (Pitch me, double tmin, double tmax, int unit, bool interpolate);
+void Pitch_getMinimumAndTime (Pitch me, double tmin, double tmax, int unit, bool interpolate,
 	double *return_minimum, double *return_timeOfMinimum);
-double Pitch_getMinimum (Pitch me, double tmin, double tmax, int unit, int interpolate);
-double Pitch_getTimeOfMinimum (Pitch me, double tmin, double tmax, int unit, int interpolate);
+double Pitch_getMinimum (Pitch me, double tmin, double tmax, int unit, bool interpolate);
+double Pitch_getTimeOfMinimum (Pitch me, double tmin, double tmax, int unit, bool interpolate);
 
 int Pitch_getMaxnCandidates (Pitch me);
 /*
@@ -151,7 +149,7 @@ long Pitch_getMeanAbsSlope_noOctave (Pitch me, double *slope);
    'value', 'minimum', 'maximum', and 'mean' are valid if nVoiced >= 1;
    'variance' and 'slope' are valid if nVoiced >= 2.
    Invalid variables are always set to 0.0.
-   'minimum', 'maximum', 'mean', and 'variance' may be NULL.
+   'minimum', 'maximum', 'mean', and 'variance' may be null.
 */
 
 autoPitch Pitch_killOctaveJumps (Pitch me);
