@@ -1,20 +1,19 @@
 /* Pitch_to_PointProcess.cpp
  *
- * Copyright (C) 1992-2011,2014,2015 Paul Boersma
+ * Copyright (C) 1992-2011,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -41,7 +40,7 @@
 autoPointProcess Pitch_to_PointProcess (Pitch pitch) {
 	try {
 		autoPitchTier pitchTier = Pitch_to_PitchTier (pitch);
-		autoPointProcess point = PitchTier_Pitch_to_PointProcess (pitchTier.peek(), pitch);
+		autoPointProcess point = PitchTier_Pitch_to_PointProcess (pitchTier.get(), pitch);
 		return point;
 	} catch (MelderError) {
 		Melder_throw (pitch, U": not converted to PointProcess.");
@@ -73,7 +72,7 @@ static int Pitch_getVoicedIntervalAfter (Pitch me, double after, double *tleft,
 }
 
 static double findExtremum_3 (double *channel1_base, double *channel2_base, long d, long n, int includeMaxima, int includeMinima) {
-	double *channel1 = channel1_base + d, *channel2 = channel2_base ? channel2_base + d : NULL;
+	double *channel1 = channel1_base + d, *channel2 = channel2_base ? channel2_base + d : nullptr;
 	int includeAll = includeMaxima == includeMinima;
 	long imin = 1, imax = 1, i, iextr;
 	double minimum, maximum;
@@ -116,7 +115,7 @@ static double Sound_findExtremum (Sound me, double tmin, double tmax, int includ
 	Melder_assert (NUMdefined (tmax));
 	if (imin < 1) imin = 1;
 	if (imax > my nx) imax = my nx;
-	double iextremum = findExtremum_3 (my z [1], my ny > 1 ? my z [2] : NULL, imin - 1, imax - imin + 1, includeMaxima, includeMinima);
+	double iextremum = findExtremum_3 (my z [1], my ny > 1 ? my z [2] : nullptr, imin - 1, imax - imin + 1, includeMaxima, includeMinima);
 	if (iextremum != 0.0)
 		return my x1 + (imin - 1 + iextremum - 1) * my dx;
 	else
@@ -210,7 +209,7 @@ autoPointProcess Sound_Pitch_to_PointProcess_cc (Sound sound, Pitch pitch) {
 			}
 			double tmax = Sound_findExtremum (sound, tmiddle - 0.5 / f0middle, tmiddle + 0.5 / f0middle, true, true);
 			Melder_assert (NUMdefined (tmax));
-			PointProcess_addPoint (point.peek(), tmax);
+			PointProcess_addPoint (point.get(), tmax);
 
 			double tsave = tmax;
 			for (;;) {
@@ -220,13 +219,13 @@ autoPointProcess Sound_Pitch_to_PointProcess_cc (Sound sound, Pitch pitch) {
 				if (correlation == -1) /*break*/ tmax -= 1.0 / f0;   // this one period will drop out
 				if (tmax < tleft) {
 					if (correlation > 0.7 && peak > 0.023333 * globalPeak && tmax - addedRight > 0.8 / f0) {
-						PointProcess_addPoint (point.peek(), tmax);
+						PointProcess_addPoint (point.get(), tmax);
 					}
 					break;
 				}
 				if (correlation > 0.3 && (peak == 0.0 || peak > 0.01 * globalPeak)) {
 					if (tmax - addedRight > 0.8 / f0) {   // do not fill in a short originally unvoiced interval twice
-						PointProcess_addPoint (point.peek(), tmax);
+						PointProcess_addPoint (point.get(), tmax);
 					}
 				}
 			}
@@ -238,13 +237,13 @@ autoPointProcess Sound_Pitch_to_PointProcess_cc (Sound sound, Pitch pitch) {
 				if (correlation == -1) /*break*/ tmax += 1.0 / f0;
 				if (tmax > tright) {
 					if (correlation > 0.7 && peak > 0.023333 * globalPeak) {
-						PointProcess_addPoint (point.peek(), tmax);
+						PointProcess_addPoint (point.get(), tmax);
 						addedRight = tmax;
 					}
 					break;
 				}
 				if (correlation > 0.3 && (peak == 0.0 || peak > 0.01 * globalPeak)) {
-					PointProcess_addPoint (point.peek(), tmax);
+					PointProcess_addPoint (point.get(), tmax);
 					addedRight = tmax;
 				}
 			}
@@ -283,7 +282,7 @@ autoPointProcess Sound_Pitch_to_PointProcess_peaks (Sound sound, Pitch pitch, in
 			Melder_assert (NUMdefined (f0middle));
 			double tmax = Sound_findExtremum (sound, tmiddle - 0.5 / f0middle, tmiddle + 0.5 / f0middle, includeMaxima, includeMinima);
 			Melder_assert (NUMdefined (tmax));
-			PointProcess_addPoint (point.peek(), tmax);
+			PointProcess_addPoint (point.get(), tmax);
 
 			double tsave = tmax;
 			for (;;) {
@@ -292,12 +291,12 @@ autoPointProcess Sound_Pitch_to_PointProcess_peaks (Sound sound, Pitch pitch, in
 				tmax = Sound_findExtremum (sound, tmax - 1.25 / f0, tmax - 0.8 / f0, includeMaxima, includeMinima);
 				if (tmax < tleft) {
 					if (tmax - addedRight > 0.8 / f0) {
-						PointProcess_addPoint (point.peek(), tmax);
+						PointProcess_addPoint (point.get(), tmax);
 					}
 					break;
 				}
 				if (tmax - addedRight > 0.8 / f0) {   // do not fill in a short originally unvoiced interval twice
-					PointProcess_addPoint (point.peek(), tmax);
+					PointProcess_addPoint (point.get(), tmax);
 				}
 			}
 			tmax = tsave;
@@ -306,11 +305,11 @@ autoPointProcess Sound_Pitch_to_PointProcess_peaks (Sound sound, Pitch pitch, in
 				if (f0 == NUMundefined) break;
 				tmax = Sound_findExtremum (sound, tmax + 0.8 / f0, tmax + 1.25 / f0, includeMaxima, includeMinima);
 				if (tmax > tright) {
-					PointProcess_addPoint (point.peek(), tmax);
+					PointProcess_addPoint (point.get(), tmax);
 					addedRight = tmax;
 					break;
 				}
-				PointProcess_addPoint (point.peek(), tmax);
+				PointProcess_addPoint (point.get(), tmax);
 				addedRight = tmax;
 			}
 			t = tright;
