@@ -4,19 +4,18 @@
  *
  * Copyright (C) 1992-2011,2012,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "TimeSoundEditor.h"
@@ -31,7 +30,7 @@ Thing_define (RealTierEditor, TimeSoundEditor) {
 		override;
 	void v_draw ()
 		override;
-	int v_click (double xWC, double yWC, bool shiftKeyPressed)
+	bool v_click (double xWC, double yWC, bool shiftKeyPressed)
 		override;
 	void v_play (double tmin, double tmax)
 		override;
@@ -62,7 +61,7 @@ void RealTierEditor_updateScaling (RealTierEditor me);
 
 void RealTierEditor_init (RealTierEditor me, const char32 *title, RealTier data, Sound sound, bool ownSound);
 /*
-	`Sound` may be NULL;
+	`sound` may be null;
 	if `ownSound` is `true`, the editor will contain a deep copy of the Sound,
 	which the editor will destroy when the editor is destroyed.
 */
