@@ -4,19 +4,18 @@
  *
  * Copyright (C) 2001-2011,2012,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Editor.h"
@@ -24,12 +23,12 @@
 
 Thing_define (RunnerMFC, Editor) {
 	GuiDrawingArea d_drawingArea;
-	Ordered experiments;
+	autoExperimentMFCList experiments;
 	long iexperiment;
-	Graphics graphics;
+	autoGraphics graphics;
 	long numberOfReplays;
 
-	void v_destroy ()
+	void v_destroy () noexcept
 		override;
 	bool v_editable ()
 		override { return false; }
@@ -41,7 +40,7 @@ Thing_define (RunnerMFC, Editor) {
 		override;
 };
 
-autoRunnerMFC RunnerMFC_create (const char32 *title, Ordered experiments);
+autoRunnerMFC RunnerMFC_create (const char32 *title, autoExperimentMFCList experiments);
 
 /* End of file RunnerMFC.h */
 #endif
