@@ -1,20 +1,19 @@
 /* SoundEditor.cpp
  *
- * Copyright (C) 1992-2012,2013,2014,2015 Paul Boersma, 2007 Erez Volk (FLAC support)
+ * Copyright (C) 1992-2012,2013,2014,2015,2016 Paul Boersma, 2007 Erez Volk (FLAC support)
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "SoundEditor.h"
@@ -29,7 +28,7 @@ Thing_implement (SoundEditor, TimeSoundAnalysisEditor, 0);
 
 void structSoundEditor :: v_dataChanged () {
 	Sound sound = (Sound) data;
-	Melder_assert (sound != NULL);   // LongSound objects should not get v_dataChanged messages
+	Melder_assert (sound);   // LongSound objects should not get v_dataChanged messages
 	Matrix_getWindowExtrema (sound, 1, sound -> nx, 1, sound -> ny, & d_sound.minimum, & d_sound.maximum);   // BUG unreadable
 	v_reset_analysis ();
 	SoundEditor_Parent :: v_dataChanged ();
@@ -37,26 +36,16 @@ void structSoundEditor :: v_dataChanged () {
 
 /***** EDIT MENU *****/
 
-static void menu_cb_Copy (EDITOR_ARGS) {
-	EDITOR_IAM (SoundEditor);
+static void menu_cb_Copy (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	try {
-		/*
-		 * Create without change.
-		 */
-		autoSound publish = my d_longSound.data ? LongSound_extractPart ((LongSound) my data, my d_startSelection, my d_endSelection, false) :
+		Sound_clipboard = my d_longSound.data ? LongSound_extractPart ((LongSound) my data, my d_startSelection, my d_endSelection, false) :
 			Sound_extractPart ((Sound) my data, my d_startSelection, my d_endSelection, kSound_windowShape_RECTANGULAR, 1.0, false);
-		/*
-		 * Change without error.
-		 */
-		forget (Sound_clipboard);
-		Sound_clipboard = publish.transfer();
 	} catch (MelderError) {
 		Melder_throw (U"Sound selection not copied to clipboard.");
 	}
 }
 
-static void menu_cb_Cut (EDITOR_ARGS) {
-	EDITOR_IAM (SoundEditor);
+static void menu_cb_Cut (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	try {
 		Sound sound = (Sound) my data;
 		long first, last, selectionNumberOfSamples = Sampled_getWindowSamples (sound,
@@ -100,8 +89,7 @@ static void menu_cb_Cut (EDITOR_ARGS) {
 			sound -> nx = newNumberOfSamples;
 			sound -> x1 = 0.5 * sound -> dx;
 			sound -> z = newData.transfer();
-			forget (Sound_clipboard);
-			Sound_clipboard = publish.transfer();
+			Sound_clipboard = publish.move();
 
 			/* Start updating the markers of the FunctionEditor, respecting the invariants. */
 
@@ -157,8 +145,7 @@ static void menu_cb_Cut (EDITOR_ARGS) {
 	}
 }
 
-static void menu_cb_Paste (EDITOR_ARGS) {
-	EDITOR_IAM (SoundEditor);
+static void menu_cb_Paste (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	Sound sound = (Sound) my data;
 	long leftSample = Sampled_xToLowIndex (sound, my d_endSelection);
 	long oldNumberOfSamples = sound -> nx, newNumberOfSamples;
@@ -221,8 +208,7 @@ static void menu_cb_Paste (EDITOR_ARGS) {
 	Editor_broadcastDataChanged (me);
 }
 
-static void menu_cb_SetSelectionToZero (EDITOR_ARGS) {
-	EDITOR_IAM (SoundEditor);
+static void menu_cb_SetSelectionToZero (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	Sound sound = (Sound) my data;
 	long first, last;
 	Sampled_getWindowSamples (sound, my d_startSelection, my d_endSelection, & first, & last);
@@ -237,8 +223,7 @@ static void menu_cb_SetSelectionToZero (EDITOR_ARGS) {
 	Editor_broadcastDataChanged (me);
 }
 
-static void menu_cb_ReverseSelection (EDITOR_ARGS) {
-	EDITOR_IAM (SoundEditor);
+static void menu_cb_ReverseSelection (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	Editor_save (me, U"Reverse selection");
 	Sound_reverse ((Sound) my data, my d_startSelection, my d_endSelection);
 	my v_reset_analysis ();
@@ -248,8 +233,7 @@ static void menu_cb_ReverseSelection (EDITOR_ARGS) {
 
 /***** SELECT MENU *****/
 
-static void menu_cb_MoveCursorToZero (EDITOR_ARGS) {
-	EDITOR_IAM (SoundEditor);
+static void menu_cb_MoveCursorToZero (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	double zero = Sound_getNearestZeroCrossing ((Sound) my data, 0.5 * (my d_startSelection + my d_endSelection), 1);   // STEREO BUG
 	if (NUMdefined (zero)) {
 		my d_startSelection = my d_endSelection = zero;
@@ -257,8 +241,7 @@ static void menu_cb_MoveCursorToZero (EDITOR_ARGS) {
 	}
 }
 
-static void menu_cb_MoveBtoZero (EDITOR_ARGS) {
-	EDITOR_IAM (SoundEditor);
+static void menu_cb_MoveBtoZero (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	double zero = Sound_getNearestZeroCrossing ((Sound) my data, my d_startSelection, 1);   // STEREO BUG
 	if (NUMdefined (zero)) {
 		my d_startSelection = zero;
@@ -271,8 +254,7 @@ static void menu_cb_MoveBtoZero (EDITOR_ARGS) {
 	}
 }
 
-static void menu_cb_MoveEtoZero (EDITOR_ARGS) {
-	EDITOR_IAM (SoundEditor);
+static void menu_cb_MoveEtoZero (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	double zero = Sound_getNearestZeroCrossing ((Sound) my data, my d_endSelection, 1);   // STEREO BUG
 	if (NUMdefined (zero)) {
 		my d_endSelection = zero;
@@ -287,20 +269,20 @@ static void menu_cb_MoveEtoZero (EDITOR_ARGS) {
 
 /***** HELP MENU *****/
 
-static void menu_cb_SoundEditorHelp (EDITOR_ARGS) { EDITOR_IAM (SoundEditor); Melder_help (U"SoundEditor"); }
-static void menu_cb_LongSoundEditorHelp (EDITOR_ARGS) { EDITOR_IAM (SoundEditor); Melder_help (U"LongSoundEditor"); }
+static void menu_cb_SoundEditorHelp (SoundEditor, EDITOR_ARGS_DIRECT) { Melder_help (U"SoundEditor"); }
+static void menu_cb_LongSoundEditorHelp (SoundEditor, EDITOR_ARGS_DIRECT) { Melder_help (U"LongSoundEditor"); }
 
 void structSoundEditor :: v_createMenus () {
 	SoundEditor_Parent :: v_createMenus ();
-	Melder_assert (data != NULL);
-	Melder_assert (d_sound.data != NULL || d_longSound.data != NULL);
+	Melder_assert (data);
+	Melder_assert (d_sound.data || d_longSound.data);
 
-	Editor_addCommand (this, U"Edit", U"-- cut copy paste --", 0, NULL);
+	Editor_addCommand (this, U"Edit", U"-- cut copy paste --", 0, nullptr);
 	if (d_sound.data) cutButton = Editor_addCommand (this, U"Edit", U"Cut", 'X', menu_cb_Cut);
 	copyButton = Editor_addCommand (this, U"Edit", U"Copy selection to Sound clipboard", 'C', menu_cb_Copy);
 	if (d_sound.data) pasteButton = Editor_addCommand (this, U"Edit", U"Paste after selection", 'V', menu_cb_Paste);
 	if (d_sound.data) {
-		Editor_addCommand (this, U"Edit", U"-- zero --", 0, NULL);
+		Editor_addCommand (this, U"Edit", U"-- zero --", 0, nullptr);
 		zeroButton = Editor_addCommand (this, U"Edit", U"Set selection to zero", 0, menu_cb_SetSelectionToZero);
 		reverseButton = Editor_addCommand (this, U"Edit", U"Reverse selection", 'R', menu_cb_ReverseSelection);
 	}
@@ -338,56 +320,56 @@ void structSoundEditor :: v_draw () {
 	Sampled data = (Sampled) this -> data;
 	Graphics_Viewport viewport;
 	bool showAnalysis = p_spectrogram_show || p_pitch_show || p_intensity_show || p_formant_show;
-	Melder_assert (data != NULL);
-	Melder_assert (d_sound.data != NULL || d_longSound.data != NULL);
+	Melder_assert (data);
+	Melder_assert (d_sound.data || d_longSound.data);
 
 	/*
 	 * We check beforehand whether the window fits the LongSound buffer.
 	 */
 	if (d_longSound.data && d_endWindow - d_startWindow > d_longSound.data -> bufferLength) {
-		Graphics_setColour (d_graphics, Graphics_WHITE);
-		Graphics_setWindow (d_graphics, 0, 1, 0, 1);
-		Graphics_fillRectangle (d_graphics, 0, 1, 0, 1);
-		Graphics_setColour (d_graphics, Graphics_BLACK);
-		Graphics_setTextAlignment (d_graphics, Graphics_CENTRE, Graphics_BOTTOM);
-		Graphics_text (d_graphics, 0.5, 0.5,   U"(window longer than ", Melder_float (Melder_single (d_longSound.data -> bufferLength)), U" seconds)");
-		Graphics_setTextAlignment (d_graphics, Graphics_CENTRE, Graphics_TOP);
-		Graphics_text (d_graphics, 0.5, 0.5, U"(zoom in to see the samples)");
+		Graphics_setColour (d_graphics.get(), Graphics_WHITE);
+		Graphics_setWindow (d_graphics.get(), 0.0, 1.0, 0.0, 1.0);
+		Graphics_fillRectangle (d_graphics.get(), 0.0, 1.0, 0.0, 1.0);
+		Graphics_setColour (d_graphics.get(), Graphics_BLACK);
+		Graphics_setTextAlignment (d_graphics.get(), Graphics_CENTRE, Graphics_BOTTOM);
+		Graphics_text (d_graphics.get(), 0.5, 0.5,   U"(window longer than ", Melder_float (Melder_single (d_longSound.data -> bufferLength)), U" seconds)");
+		Graphics_setTextAlignment (d_graphics.get(), Graphics_CENTRE, Graphics_TOP);
+		Graphics_text (d_graphics.get(), 0.5, 0.5, U"(zoom in to see the samples)");
 		return;
 	}
 
 	/* Draw sound. */
 
 	if (showAnalysis)
-		viewport = Graphics_insetViewport (d_graphics, 0, 1, 0.5, 1);
-	Graphics_setColour (d_graphics, Graphics_WHITE);
-	Graphics_setWindow (d_graphics, 0, 1, 0, 1);
-	Graphics_fillRectangle (d_graphics, 0, 1, 0, 1);
+		viewport = Graphics_insetViewport (d_graphics.get(), 0.0, 1.0, 0.5, 1.0);
+	Graphics_setColour (d_graphics.get(), Graphics_WHITE);
+	Graphics_setWindow (d_graphics.get(), 0.0, 1.0, 0.0, 1.0);
+	Graphics_fillRectangle (d_graphics.get(), 0.0, 1.0, 0.0, 1.0);
 	TimeSoundEditor_drawSound (this, d_sound.minimum, d_sound.maximum);
-	Graphics_flushWs (d_graphics);
+	//Graphics_flushWs (d_graphics.get());
 	if (showAnalysis)
-		Graphics_resetViewport (d_graphics, viewport);
+		Graphics_resetViewport (d_graphics.get(), viewport);
 
 	/* Draw analyses. */
 
 	if (showAnalysis) {
 		/* Draw spectrogram, pitch, formants. */
-		viewport = Graphics_insetViewport (d_graphics, 0, 1, 0, 0.5);
+		viewport = Graphics_insetViewport (d_graphics.get(), 0.0, 1.0, 0.0, 0.5);
 		v_draw_analysis ();
-		Graphics_flushWs (d_graphics);
-		Graphics_resetViewport (d_graphics, viewport);
+		//Graphics_flushWs (d_graphics.get());
+		Graphics_resetViewport (d_graphics.get(), viewport);
 	}
 
 	/* Draw pulses. */
 
 	if (p_pulses_show) {
 		if (showAnalysis)
-			viewport = Graphics_insetViewport (d_graphics, 0, 1, 0.5, 1);
+			viewport = Graphics_insetViewport (d_graphics.get(), 0.0, 1.0, 0.5, 1.0);
 		v_draw_analysis_pulses ();
 		TimeSoundEditor_drawSound (this, d_sound.minimum, d_sound.maximum);   // second time, partially across the pulses
-		Graphics_flushWs (d_graphics);
+		//Graphics_flushWs (d_graphics.get());
 		if (showAnalysis)
-			Graphics_resetViewport (d_graphics, viewport);
+			Graphics_resetViewport (d_graphics.get(), viewport);
 	}
 
 	/* Update buttons. */
@@ -410,32 +392,32 @@ void structSoundEditor :: v_play (double a_tmin, double a_tmax) {
 		Sound_playPart ((Sound) data, a_tmin, a_tmax, theFunctionEditor_playCallback, this);
 }
 
-int structSoundEditor :: v_click (double xWC, double yWC, bool shiftKeyPressed) {
+bool structSoundEditor :: v_click (double xWC, double yWC, bool shiftKeyPressed) {
 	if ((p_spectrogram_show || p_formant_show) && yWC < 0.5 && xWC > d_startWindow && xWC < d_endWindow) {
 		d_spectrogram_cursor = p_spectrogram_viewFrom +
-			2 * yWC * (p_spectrogram_viewTo - p_spectrogram_viewFrom);
+			2.0 * yWC * (p_spectrogram_viewTo - p_spectrogram_viewFrom);
 	}
 	return SoundEditor_Parent :: v_click (xWC, yWC, shiftKeyPressed);   // drag & update
 }
 
 void structSoundEditor :: v_highlightSelection (double left, double right, double bottom, double top) {
 	if (p_spectrogram_show)
-		Graphics_highlight (d_graphics, left, right, 0.5 * (bottom + top), top);
+		Graphics_highlight (d_graphics.get(), left, right, 0.5 * (bottom + top), top);
 	else
-		Graphics_highlight (d_graphics, left, right, bottom, top);
+		Graphics_highlight (d_graphics.get(), left, right, bottom, top);
 }
 
 void structSoundEditor :: v_unhighlightSelection (double left, double right, double bottom, double top) {
 	if (p_spectrogram_show)
-		Graphics_unhighlight (d_graphics, left, right, 0.5 * (bottom + top), top);
+		Graphics_unhighlight (d_graphics.get(), left, right, 0.5 * (bottom + top), top);
 	else
-		Graphics_unhighlight (d_graphics, left, right, bottom, top);
+		Graphics_unhighlight (d_graphics.get(), left, right, bottom, top);
 }
 
 void SoundEditor_init (SoundEditor me, const char32 *title, Sampled data) {
 	/*
 	 * my longSound.data or my sound.data have to be set before we call FunctionEditor_init,
-	 * because createMenus expects that one of them is not NULL.
+	 * because createMenus expects that one of them is not null.
 	 */
 	TimeSoundAnalysisEditor_init (me, title, data, data, false);
 	if (my d_longSound.data && my d_endWindow - my d_startWindow > 30.0) {
@@ -450,7 +432,7 @@ autoSoundEditor SoundEditor_create (const char32 *title, Sampled data) {
 	Melder_assert (data);
 	try {
 		autoSoundEditor me = Thing_new (SoundEditor);
-		SoundEditor_init (me.peek(), title, data);
+		SoundEditor_init (me.get(), title, data);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Sound window not created.");
