@@ -1,20 +1,19 @@
 /* Sound_to_Pitch.cpp
  *
- * Copyright (C) 1992-2011,2014,2015 Paul Boersma
+ * Copyright (C) 1992-2011,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -258,7 +257,7 @@ Thing_define (Sound_into_Pitch_Args, Thing) { public:
 
 Thing_implement (Sound_into_Pitch_Args, Thing, 0);
 
-static Sound_into_Pitch_Args Sound_into_Pitch_Args_create (Sound sound, Pitch pitch,
+static autoSound_into_Pitch_Args Sound_into_Pitch_Args_create (Sound sound, Pitch pitch,
 	long firstFrame, long lastFrame, double minimumPitch, int maxnCandidates, int method,
 	double voicingThreshold, double octaveCost,
 	double dt_window, long nsamp_window, long halfnsamp_window, long maximumLag, long nsampFFT,
@@ -290,7 +289,7 @@ static Sound_into_Pitch_Args Sound_into_Pitch_Args_create (Sound sound, Pitch pi
 	my windowR = windowR;
 	my isMainThread = isMainThread;
 	my cancelled = cancelled;
-	return me.transfer();
+	return me;
 }
 
 MelderThread_MUTEX (mutex);
@@ -535,20 +534,20 @@ autoPitch Sound_to_Pitch_any (Sound me,
 		volatile int cancelled = 0;
 		for (int ithread = 1; ithread <= numberOfThreads; ithread ++) {
 			if (ithread == numberOfThreads) lastFrame = nFrames;
-			args [ithread - 1].reset (Sound_into_Pitch_Args_create (me, thee.peek(),
+			args [ithread - 1] = Sound_into_Pitch_Args_create (me, thee.get(),
 				firstFrame, lastFrame, minimumPitch, maxnCandidates, method,
 				voicingThreshold, octaveCost,
 				dt_window, nsamp_window, halfnsamp_window, maximumLag,
 				nsampFFT, nsamp_period, halfnsamp_period, brent_ixmax, brent_depth,
 				globalPeak, window.peek(), windowR.peek(),
-				ithread == numberOfThreads, & cancelled));
+				ithread == numberOfThreads, & cancelled);
 			firstFrame = lastFrame + 1;
 			lastFrame += numberOfFramesPerThread;
 		}
 		MelderThread_run (Sound_into_Pitch, args, numberOfThreads);
 
 		Melder_progress (0.95, U"Sound to Pitch: path finder");
-		Pitch_pathFinder (thee.peek(), silenceThreshold, voicingThreshold,
+		Pitch_pathFinder (thee.get(), silenceThreshold, voicingThreshold,
 			octaveCost, octaveJumpCost, voicedUnvoicedCost, ceiling, Melder_debug == 31 ? true : false);
 
 		return thee;
