@@ -2,28 +2,18 @@
  *
  * Copyright (C) 1999-2011,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-/*
- * pb 2002/07/16 GPL
- * pb 2007/06/21 tex
- * pb 2007/08/12 wchar
- * pb 2007/10/01 can write as encoding
- * pb 2011/03/03 wide-character WordList
- * pb 2011/06/10 C++
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "SpellingChecker.h"
@@ -56,6 +46,7 @@ autoSpellingChecker WordList_upto_SpellingChecker (WordList me) {
 	try {
 		autoSpellingChecker thee = Thing_new (SpellingChecker);
 		thy wordList = Data_copy (me);
+		thy userDictionary = StringSet_create ();
 		thy separatingCharacters = Melder_dup (U".,;:()\"");
 		return thee;
 	} catch (MelderError) {
@@ -64,46 +55,30 @@ autoSpellingChecker WordList_upto_SpellingChecker (WordList me) {
 }
 
 autoWordList SpellingChecker_extractWordList (SpellingChecker me) {
-	return Data_copy (my wordList);
+	return Data_copy (my wordList.get());
 }
 
 void SpellingChecker_replaceWordList (SpellingChecker me, WordList list) {
 	try {
-		/*
-		 * Create without change.
-		 */
-		autoWordList newList = Data_copy (list);
-		/*
-		 * Change without error.
-		 */
-		forget (my wordList);
-		my wordList = newList.transfer();
+		my wordList = Data_copy (list);
 	} catch (MelderError) {
 		Melder_throw (me, U": word list not replaced.");
 	}
 }
 
-autoSortedSetOfString SpellingChecker_extractUserDictionary (SpellingChecker me) {
+autoStringSet SpellingChecker_extractUserDictionary (SpellingChecker me) {
 	try {
-		if (! my userDictionary)
+		if (my userDictionary->size == 0)
 			Melder_throw (U"This spelling checker does not contain a user dictionary.");
-		return Data_copy (my userDictionary);
+		return Data_copy (my userDictionary.get());
 	} catch (MelderError) {
 		Melder_throw (me, U": user dictionary not extracted.");
 	}
 }
 
-void SpellingChecker_replaceUserDictionary (SpellingChecker me, SortedSetOfString userDictionary) {
+void SpellingChecker_replaceUserDictionary (SpellingChecker me, StringSet userDictionary) {
 	try {
-		/*
-		 * Create without change.
-		 */
-		autoSortedSetOfString newDict = Data_copy (userDictionary);
-		/*
-		 * Change without error.
-		 */
-		forget (my userDictionary);
-		my userDictionary = newDict.transfer();
+		my userDictionary = Data_copy (userDictionary);
 	} catch (MelderError) {
 		Melder_throw (me, U": user dictionary not replaced.");
 	}
@@ -198,13 +173,13 @@ bool SpellingChecker_isWordAllowed (SpellingChecker me, const char32 *word) {
 			}
 		}
 	}
-	if (WordList_hasWord (my wordList, word))
+	if (WordList_hasWord (my wordList.get(), word))
 		return true;
-	if (my userDictionary != NULL) {
+	if (my userDictionary->size > 0) {
 		if (str32len (word) > 3333) return false;   // superfluous, because WordList_hasWord already checked; but safe
 		static char32 buffer [3*3333+1];
 		Longchar_genericize32 (word, buffer);
-		if (SortedSetOfString_lookUp (my userDictionary, buffer) != 0)
+		if (my userDictionary -> lookUp (buffer) != 0)
 			return true;
 	}
 	return false;
@@ -212,11 +187,9 @@ bool SpellingChecker_isWordAllowed (SpellingChecker me, const char32 *word) {
 
 void SpellingChecker_addNewWord (SpellingChecker me, const char32 *word) {
 	try {
-		if (! my userDictionary)
-			my userDictionary = SortedSetOfString_create ();
 		autostring32 generic = Melder_calloc (char32, 3 * str32len (word) + 1);
 		Longchar_genericize32 (word, generic.peek());
-		SortedSetOfString_addString (my userDictionary, generic.transfer());
+		my userDictionary -> addString_copy (generic.transfer());
 	} catch (MelderError) {
 		Melder_throw (me, U": word \"", word, U"\" not added.");
 	}
@@ -226,12 +199,12 @@ char32 * SpellingChecker_nextNotAllowedWord (SpellingChecker me, const char32 *s
 	const char32 *p = sentence + *start;
 	for (;;) {
 		if (*p == U'\0') {
-			return NULL;   // all words allowed
+			return nullptr;   // all words allowed
 		} else if (*p == U'(' && my allowAllParenthesized) {
 			p ++;
 			for (;;) {
 				if (*p == U'\0') {
-					return NULL;   // everything is parenthesized...
+					return nullptr;   // everything is parenthesized...
 				} else if (*p == U')') {
 					p ++;
 					break;
@@ -260,7 +233,7 @@ char32 * SpellingChecker_nextNotAllowedWord (SpellingChecker me, const char32 *s
 			}
 		}
 	}
-	return NULL;   // all words allowed
+	return nullptr;   // all words allowed
 }
 
 /* End of file SpellingChecker.cpp */
