@@ -1,26 +1,19 @@
 /* TextGrid_Sound.cpp
  *
- * Copyright (C) 1992-2011,2013,2014,2015 Paul Boersma
+ * Copyright (C) 1992-2011,2013,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-/*
- * pb 2010/12/06 BDF/EDF files (for EEG)
- * pb 2010/12/08 split off from TextGrid.c and Sound.c
- * pb 2011/06/11 C++
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "TextGrid_Sound.h"
@@ -29,16 +22,23 @@
 #include "LongSound.h"
 
 static bool IntervalTier_check (IntervalTier me) {
-	for (long iinterval = 1; iinterval <= my numberOfIntervals (); iinterval ++) {
-		TextInterval interval = my interval (iinterval);
-		if (interval -> xmin >= interval -> xmax)
+	for (long iinterval = 1; iinterval <= my intervals.size; iinterval ++) {
+		TextInterval interval = my intervals.at [iinterval];
+		if (interval -> xmin >= interval -> xmax) {
+			Melder_casual (U"Interval ", iinterval, U" starts at ", interval -> xmin,
+				U" but ends at ", interval -> xmax, U" seconds.");
 			return false;
+		}
 	}
-	if (my numberOfIntervals () < 2) return true;
-	for (long iinterval = 1; iinterval < my numberOfIntervals (); iinterval ++) {
-		TextInterval interval = my interval (iinterval), nextInterval = my interval (iinterval + 1);
-		if (interval -> xmax != nextInterval -> xmin)
+	if (my intervals.size < 2) return true;
+	for (long iinterval = 1; iinterval < my intervals.size; iinterval ++) {
+		TextInterval thisInterval = my intervals.at [iinterval];
+		TextInterval nextInterval = my intervals.at [iinterval + 1];
+		if (thisInterval -> xmax != nextInterval -> xmin) {
+			Melder_casual (U"Interval ", iinterval, U" ends at ", thisInterval -> xmax,
+				U" but the next interval starts at ", nextInterval -> xmin, U" seconds.");
 			return false;
+		}
 	}
 	return true;
 }
@@ -55,43 +55,43 @@ static void IntervalTier_insertIntervalDestructively (IntervalTier me, double tm
 		long intervalNumber = IntervalTier_timeToIndex (me, tmin);
 		if (intervalNumber == 0)
 			Melder_throw (U"Cannot add a boundary at ", Melder_fixed (tmin, 6), U" seconds, because this is outside the time domain of the intervals.");
-		TextInterval interval = my interval (intervalNumber);
+		TextInterval interval = my intervals.at [intervalNumber];
 		/*
 		 * Move the text to the left of the boundary.
 		 */
 		autoTextInterval newInterval = TextInterval_create (tmin, interval -> xmax, U"");
 		interval -> xmax = tmin;
-		Collection_addItem (my intervals, newInterval.transfer());
+		my intervals. addItem_move (newInterval.move());
 		firstIntervalNumber = IntervalTier_hasTime (me, interval -> xmin);
 	}
-	Melder_assert (firstIntervalNumber >= 1 && firstIntervalNumber <= my intervals -> size);
+	Melder_assert (firstIntervalNumber >= 1 && firstIntervalNumber <= my intervals.size);
 	long lastIntervalNumber = IntervalTier_hasTime (me, tmax);
 	if (! lastIntervalNumber) {
 		long intervalNumber = IntervalTier_timeToIndex (me, tmax);
 		if (intervalNumber == 0)
 			Melder_throw (U"Cannot add a boundary at ", Melder_fixed (tmin, 6), U" seconds, because this is outside the time domain of the intervals.");
-		TextInterval interval = my interval (intervalNumber);
+		TextInterval interval = my intervals.at [intervalNumber];
 		/*
 		 * Move the text to the right of the boundary.
 		 */
 		autoTextInterval newInterval = TextInterval_create (interval -> xmin, tmax, U"");
 		interval -> xmin = tmax;
-		Collection_addItem (my intervals, newInterval.transfer());
+		my intervals. addItem_move (newInterval.move());
 		lastIntervalNumber = IntervalTier_hasTime (me, interval -> xmax);
 	}
-	Melder_assert (lastIntervalNumber >= 1 && lastIntervalNumber <= my intervals -> size);
+	Melder_assert (lastIntervalNumber >= 1 && lastIntervalNumber <= my intervals.size);
 	/*
 	 * Empty the interval in the word tier.
 	 */
 	trace (U"Empty interval %ld down to ", lastIntervalNumber, U".", firstIntervalNumber);
 	for (long iinterval = lastIntervalNumber; iinterval >= firstIntervalNumber; iinterval --) {
-		TextInterval interval = my interval (iinterval);
+		TextInterval interval = my intervals.at [iinterval];
 		if (interval -> xmin > tmin && interval -> xmin < tmax) {
 			Melder_assert (iinterval > 1);
-			TextInterval previous = (TextInterval) my intervals -> item [iinterval - 1];
+			TextInterval previous = my intervals.at [iinterval - 1];
 			previous -> xmax = tmax;   // collapse left and right intervals into left interval
 			TextInterval_setText (previous, U"");
-			Collection_removeItem (my intervals, iinterval);   // remove right interval
+			my intervals. removeItem (iinterval);   // remove right interval
 		}
 		if (interval -> xmax == tmax) {
 			TextInterval_setText (interval, U"");
@@ -102,7 +102,7 @@ static void IntervalTier_insertIntervalDestructively (IntervalTier me, double tm
 static double IntervalTier_boundaryTimeClosestTo (IntervalTier me, double tmin, double tmax) {
 	long intervalNumber = IntervalTier_timeToLowIndex (me, tmax);
 	if (intervalNumber != 0) {
-		TextInterval interval = my interval (intervalNumber);
+		TextInterval interval = my intervals.at [intervalNumber];
 		if (interval -> xmin > tmin && interval -> xmin < tmax) {
 			return interval -> xmin;
 		}
@@ -112,19 +112,19 @@ static double IntervalTier_boundaryTimeClosestTo (IntervalTier me, double tmin,
 
 static void IntervalTier_removeEmptyIntervals (IntervalTier me, IntervalTier boss) {
 	IntervalTier_removeBoundariesBetweenIdenticallyLabeledIntervals (me, U"");
-	if (my intervals -> size < 2) return;
-	TextInterval firstInterval = my interval (1);
+	if (my intervals.size < 2) return;
+	TextInterval firstInterval = my intervals.at [1];
 	if (Melder_equ (firstInterval -> text, U"")) {
 		IntervalTier_removeLeftBoundary (me, 2);
 	}
-	if (my numberOfIntervals () < 2) return;
-	TextInterval lastInterval = my interval (my numberOfIntervals ());
+	if (my intervals.size < 2) return;
+	TextInterval lastInterval = my intervals.at [my intervals.size];
 	if (Melder_equ (lastInterval -> text, U"")) {
-		IntervalTier_removeLeftBoundary (me, my numberOfIntervals ());
+		IntervalTier_removeLeftBoundary (me, my intervals.size);
 	}
-	if (my numberOfIntervals () < 3) return;
-	for (long iinterval = my numberOfIntervals () - 1; iinterval >= 2; iinterval --) {
-		TextInterval interval = my interval (iinterval);
+	if (my intervals.size < 3) return;
+	for (long iinterval = my intervals.size - 1; iinterval >= 2; iinterval --) {
+		TextInterval interval = my intervals.at [iinterval];
 		if (Melder_equ (interval -> text, U"")) {
 			/*
 			 * Distribute the empty interval between its neigbours.
@@ -133,11 +133,11 @@ static void IntervalTier_removeEmptyIntervals (IntervalTier me, IntervalTier bos
 				boss ?
 				IntervalTier_boundaryTimeClosestTo (boss, interval -> xmin, interval -> xmax) :
 				0.5 * (interval -> xmin + interval -> xmax);
-			TextInterval previous = my interval (iinterval - 1);
-			TextInterval next = my interval (iinterval + 1);
+			TextInterval previous = my intervals.at [iinterval - 1];
+			TextInterval next = my intervals.at [iinterval + 1];
 			previous -> xmax = newBoundaryTime;
 			next -> xmin = newBoundaryTime;
-			Collection_removeItem (my intervals, iinterval);
+			my intervals. removeItem (iinterval);
 		}
 	}
 }
@@ -145,9 +145,9 @@ static void IntervalTier_removeEmptyIntervals (IntervalTier me, IntervalTier bos
 void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierNumber, long intervalNumber, const char32 *languageName, bool includeWords, bool includePhonemes) {
 	try {
 		IntervalTier headTier = TextGrid_checkSpecifiedTierIsIntervalTier (me, tierNumber);
-		if (intervalNumber < 1 || intervalNumber > headTier -> numberOfIntervals ())
+		if (intervalNumber < 1 || intervalNumber > headTier -> intervals.size)
 			Melder_throw (U"Interval ", intervalNumber, U" does not exist.");
-		TextInterval interval = headTier -> interval (intervalNumber);
+		TextInterval interval = headTier -> intervals.at [intervalNumber];
 		if (! includeWords && ! includePhonemes)
 			Melder_throw (U"Nothing to be done, because you asked neither for word alignment nor for phoneme alignment.");
 		if (str32str (headTier -> name, U"/") )
@@ -157,45 +157,57 @@ void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierN
 				LongSound_extractPart (static_cast <LongSound> (anySound), interval -> xmin, interval -> xmax, true) :
 				Sound_extractPart (static_cast <Sound> (anySound), interval -> xmin, interval -> xmax, kSound_windowShape_RECTANGULAR, 1.0, true);
 		autoSpeechSynthesizer synthesizer = SpeechSynthesizer_create (languageName, U"default");
-		double silenceThreshold = -35, minSilenceDuration = 0.1, minSoundingDuration = 0.1;
-		autoTextGrid analysis = NULL;
+		synthesizer -> d_samplingFrequency = round (
+			anySound -> classInfo == classLongSound ?
+				static_cast <LongSound> (anySound) -> sampleRate :
+				1.0 / static_cast <Sound> (anySound) -> dx
+		);
+		double silenceThreshold = -30.0, minSilenceDuration = 0.1, minSoundingDuration = 0.1;
+		autoTextGrid analysis;
 		if (! Melder_equ (interval -> text, U"")) {
-			try {
-				analysis = SpeechSynthesizer_and_Sound_and_TextInterval_align
-					(synthesizer.peek(), part.peek(), interval, silenceThreshold, minSilenceDuration, minSoundingDuration);
-			} catch (MelderError) {
-				Melder_clearError ();   // ignore all error messages from DTW and the like
-			}
+			analysis = SpeechSynthesizer_and_Sound_and_TextInterval_align
+				(synthesizer.get(), part.get(), interval, silenceThreshold, minSilenceDuration, minSoundingDuration);
 		}
-		if (analysis.peek()) {
+		if (analysis) {
 			/*
 			 * Clean up the analysis.
 			 */
-			Melder_assert (analysis -> xmin == interval -> xmin);
-			Melder_assert (analysis -> xmax == interval -> xmax);
-			Melder_assert (analysis -> numberOfTiers () == 4);
-			Thing_cast (IntervalTier, analysisWordTier, analysis -> tier (3));
+			Melder_assert (fabs (analysis -> xmin - interval -> xmin) < 1e-12);
+			if (analysis -> xmax != interval -> xmax) {
+				//Melder_fatal (U"Analysis ends at ", analysis -> xmax, U" but interval at ", interval -> xmax, U"seconds.");
+				analysis -> xmax = interval -> xmax;
+				analysis -> intervalTier_cast (1) -> xmax = interval -> xmax;
+				analysis -> intervalTier_cast (2) -> xmax = interval -> xmax;
+				analysis -> intervalTier_cast (3) -> xmax = interval -> xmax;
+				analysis -> intervalTier_cast (4) -> xmax = interval -> xmax;
+				analysis -> intervalTier_cast (1) -> intervals.at [analysis -> intervalTier_cast (1) -> intervals.size] -> xmax = interval -> xmax;
+				analysis -> intervalTier_cast (2) -> intervals.at [analysis -> intervalTier_cast (2) -> intervals.size] -> xmax = interval -> xmax;
+				analysis -> intervalTier_cast (3) -> intervals.at [analysis -> intervalTier_cast (3) -> intervals.size] -> xmax = interval -> xmax;
+				analysis -> intervalTier_cast (4) -> intervals.at [analysis -> intervalTier_cast (4) -> intervals.size] -> xmax = interval -> xmax;
+			}
+			Melder_assert (analysis -> tiers->size == 4);
+			IntervalTier analysisWordTier = analysis -> intervalTier_cast (3);
 			if (! IntervalTier_check (analysisWordTier))
 				Melder_throw (U"Analysis word tier out of order.");
-			IntervalTier_removeEmptyIntervals (analysisWordTier, NULL);
+			IntervalTier_removeEmptyIntervals (analysisWordTier, nullptr);
 			Melder_assert (analysisWordTier -> xmax == analysis -> xmax);
-			Melder_assert (analysisWordTier -> numberOfIntervals () >= 1);
-			TextInterval firstInterval = analysisWordTier -> interval (1);
-			TextInterval lastInterval = analysisWordTier -> interval (analysisWordTier -> numberOfIntervals ());
+			Melder_assert (analysisWordTier -> intervals.size >= 1);
+			TextInterval firstInterval = analysisWordTier -> intervals.at [1];
+			TextInterval lastInterval = analysisWordTier -> intervals.at [analysisWordTier -> intervals.size];
 			firstInterval -> xmin = analysis -> xmin;
 			lastInterval  -> xmax = analysis -> xmax;
 			if (lastInterval -> xmax != analysis -> xmax)
 				Melder_fatal (U"analysis ends at ", analysis -> xmax, U", but last interval at ", lastInterval -> xmax, U" seconds");
 			if (! IntervalTier_check (analysisWordTier))
 				Melder_throw (U"Analysis word tier out of order (2).");
-			Thing_cast (IntervalTier, analysisPhonemeTier, analysis -> tier (4));
+			IntervalTier analysisPhonemeTier = analysis -> intervalTier_cast (4);
 			if (! IntervalTier_check (analysisPhonemeTier))
 				Melder_throw (U"Analysis phoneme tier out of order.");
 			IntervalTier_removeEmptyIntervals (analysisPhonemeTier, analysisWordTier);
 			Melder_assert (analysisPhonemeTier -> xmax == analysis -> xmax);
-			Melder_assert (analysisPhonemeTier -> numberOfIntervals () >= 1);
-			firstInterval = analysisPhonemeTier -> interval (1);
-			lastInterval  = analysisPhonemeTier -> interval (analysisPhonemeTier -> numberOfIntervals ());
+			Melder_assert (analysisPhonemeTier -> intervals.size >= 1);
+			firstInterval = analysisPhonemeTier -> intervals.at [1];
+			lastInterval  = analysisPhonemeTier -> intervals.at [analysisPhonemeTier -> intervals.size];
 			firstInterval -> xmin = analysis -> xmin;
 			lastInterval  -> xmax = analysis -> xmax;
 			Melder_assert (lastInterval -> xmax == analysis -> xmax);
@@ -203,7 +215,7 @@ void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierN
 				Melder_throw (U"Analysis phoneme tier out of order (2).");
 		}
 		long wordTierNumber = 0, phonemeTierNumber = 0;
-		IntervalTier wordTier = NULL, phonemeTier = NULL;
+		IntervalTier wordTier = nullptr, phonemeTier = nullptr;
 		/*
 		 * Include a word tier.
 		 */
@@ -213,8 +225,8 @@ void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierN
 			 */
 			autoMelderString newWordTierName;
 			MelderString_copy (& newWordTierName, headTier -> name, U"/word");
-			for (long itier = 1; itier <= my numberOfTiers (); itier ++) {
-				IntervalTier tier = static_cast <IntervalTier> (my tier (itier));
+			for (long itier = 1; itier <= my tiers->size; itier ++) {
+				Function tier = my tiers->at [itier];
 				if (Melder_equ (newWordTierName.string, tier -> name)) {
 					if (tier -> classInfo != classIntervalTier)
 						Melder_throw (U"A tier with the prospective word tier name (", tier -> name, U") already exists, but it is not an interval tier."
@@ -225,11 +237,11 @@ void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierN
 			}
 			if (! wordTierNumber) {
 				autoIntervalTier newWordTier = IntervalTier_create (my xmin, my xmax);
-				Thing_setName (newWordTier.peek(), newWordTierName.string);
-				Ordered_addItemPos (my tiers, newWordTier.transfer(), wordTierNumber = tierNumber + 1);
+				Thing_setName (newWordTier.get(), newWordTierName.string);
+				my tiers -> addItemAtPosition_move (newWordTier.move(), wordTierNumber = tierNumber + 1);
 			}
-			Melder_assert (wordTierNumber >= 1 && wordTierNumber <= my tiers -> size);
-			wordTier = static_cast <IntervalTier> (my tier (wordTierNumber));
+			Melder_assert (wordTierNumber >= 1 && wordTierNumber <= my tiers->size);
+			wordTier = static_cast <IntervalTier> (my tiers->at [wordTierNumber]);
 			/*
 			 * Make sure that the word tier has boundaries at the edges of the interval.
 			 */
@@ -239,24 +251,24 @@ void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierN
 			 */
 			long wordIntervalNumber = IntervalTier_hasTime (wordTier, interval -> xmin);
 			Melder_assert (wordIntervalNumber != 0);
-			if (analysis.peek()) {
-				Thing_cast (IntervalTier, analysisWordTier, analysis -> tier (3));
+			if (analysis) {
+				IntervalTier analysisWordTier = analysis -> intervalTier_cast (3);
 				if (! IntervalTier_check (analysisWordTier))
 					Melder_throw (U"Analysis word tier out of order (3).");
 				if (! IntervalTier_check (wordTier))
 					Melder_throw (U"Word tier out of order (3).");
-				for (long ianalysisInterval = 1; ianalysisInterval <= analysisWordTier -> numberOfIntervals (); ianalysisInterval ++) {
-					TextInterval analysisInterval = analysisWordTier -> interval (ianalysisInterval);
-					TextInterval wordInterval = NULL;
+				for (long ianalysisInterval = 1; ianalysisInterval <= analysisWordTier -> intervals.size; ianalysisInterval ++) {
+					TextInterval analysisInterval = analysisWordTier -> intervals.at [ianalysisInterval];
+					TextInterval wordInterval = nullptr;
 					double tmin = analysisInterval -> xmin, tmax = analysisInterval -> xmax;
 					if (tmax == analysis -> xmax) {
-						wordInterval = wordTier -> interval (wordIntervalNumber);
+						wordInterval = wordTier -> intervals.at [wordIntervalNumber];
 						TextInterval_setText (wordInterval, analysisInterval -> text);
 					} else {
-						wordInterval = wordTier -> interval (wordIntervalNumber);
+						wordInterval = wordTier -> intervals.at [wordIntervalNumber];
 						autoTextInterval newInterval = TextInterval_create (tmin, tmax, analysisInterval -> text);
 						wordInterval -> xmin = tmax;
-						Collection_addItem (wordTier -> intervals, newInterval.transfer());
+						wordTier -> intervals. addItem_move (newInterval.move());
 						wordIntervalNumber ++;
 					}
 				}
@@ -275,8 +287,8 @@ void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierN
 			 */
 			autoMelderString newPhonemeTierName;
 			MelderString_copy (& newPhonemeTierName, headTier -> name, U"/phon");
-			for (long itier = 1; itier <= my numberOfTiers (); itier ++) {
-				IntervalTier tier = static_cast <IntervalTier> (my tier (itier));
+			for (long itier = 1; itier <= my tiers->size; itier ++) {
+				Function tier = my tiers->at [itier];
 				if (Melder_equ (newPhonemeTierName.string, tier -> name)) {
 					if (tier -> classInfo != classIntervalTier)
 						Melder_throw (U"A tier with the prospective phoneme tier name (", tier -> name, U") already exists, but it is not an interval tier."
@@ -287,11 +299,12 @@ void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierN
 			}
 			if (! phonemeTierNumber) {
 				autoIntervalTier newPhonemeTier = IntervalTier_create (my xmin, my xmax);
-				Thing_setName (newPhonemeTier.peek(), newPhonemeTierName.string);
-				Ordered_addItemPos (my tiers, newPhonemeTier.transfer(), phonemeTierNumber = wordTierNumber ? wordTierNumber + 1 : tierNumber + 1);
+				Thing_setName (newPhonemeTier.get(), newPhonemeTierName.string);
+				my tiers -> addItemAtPosition_move (newPhonemeTier.move(),
+					phonemeTierNumber = wordTierNumber ? wordTierNumber + 1 : tierNumber + 1);
 			}
-			Melder_assert (phonemeTierNumber >= 1 && phonemeTierNumber <= my tiers -> size);
-			phonemeTier = static_cast <IntervalTier> (my tiers -> item [phonemeTierNumber]);
+			Melder_assert (phonemeTierNumber >= 1 && phonemeTierNumber <= my tiers->size);
+			phonemeTier = my intervalTier_cast (phonemeTierNumber);
 			/*
 			 * Make sure that the phoneme tier has boundaries at the edges of the interval.
 			 */
@@ -301,20 +314,20 @@ void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierN
 			 */
 			long phonemeIntervalNumber = IntervalTier_hasTime (phonemeTier, interval -> xmin);
 			Melder_assert (phonemeIntervalNumber != 0);
-			if (analysis.peek()) {
-				Thing_cast (IntervalTier, analysisPhonemeTier, analysis -> tiers -> item [4]);
-				for (long ianalysisInterval = 1; ianalysisInterval <= analysisPhonemeTier -> numberOfIntervals (); ianalysisInterval ++) {
-					TextInterval analysisInterval = analysisPhonemeTier -> interval (ianalysisInterval);
-					TextInterval phonemeInterval = NULL;
+			if (analysis.get()) {
+				IntervalTier analysisPhonemeTier = analysis -> intervalTier_cast (4);
+				for (long ianalysisInterval = 1; ianalysisInterval <= analysisPhonemeTier -> intervals.size; ianalysisInterval ++) {
+					TextInterval analysisInterval = analysisPhonemeTier -> intervals.at [ianalysisInterval];
+					TextInterval phonemeInterval = nullptr;
 					double tmin = analysisInterval -> xmin, tmax = analysisInterval -> xmax;
 					if (tmax == analysis -> xmax) {
-						phonemeInterval = phonemeTier -> interval (phonemeIntervalNumber);
+						phonemeInterval = phonemeTier -> intervals.at [phonemeIntervalNumber];
 						TextInterval_setText (phonemeInterval, analysisInterval -> text);
 					} else {
-						phonemeInterval = phonemeTier -> interval (phonemeIntervalNumber);
+						phonemeInterval = phonemeTier -> intervals.at [phonemeIntervalNumber];
 						autoTextInterval newInterval = TextInterval_create (tmin, tmax, analysisInterval -> text);
 						phonemeInterval -> xmin = tmax;
-						Collection_addItem (phonemeTier -> intervals, newInterval.transfer());
+						phonemeTier -> intervals. addItem_move (newInterval.move());
 						phonemeIntervalNumber ++;
 					}
 				}
@@ -334,7 +347,7 @@ void TextGrid_anySound_alignInterval (TextGrid me, Function anySound, long tierN
 void TextGrid_Sound_draw (TextGrid me, Sound sound, Graphics g, double tmin, double tmax,
 	bool showBoundaries, bool useTextStyles, bool garnish)   // STEREO BUG
 {
-	long numberOfTiers = my numberOfTiers ();
+	long numberOfTiers = my tiers->size;
 
 	/*
 	 * Automatic windowing:
@@ -365,21 +378,21 @@ void TextGrid_Sound_draw (TextGrid me, Sound sound, Graphics g, double tmin, dou
 	Graphics_setCircumflexIsSuperscript (g, useTextStyles);
 	Graphics_setUnderscoreIsSubscript (g, useTextStyles);
 	for (long itier = 1; itier <= numberOfTiers; itier ++) {
-		Function anyTier = my tier (itier);
+		Function anyTier = my tiers->at [itier];
 		double ymin = -1.0 - 0.5 * itier, ymax = ymin + 0.5;
 		Graphics_rectangle (g, tmin, tmax, ymin, ymax);
 		if (anyTier -> classInfo == classIntervalTier) {
 			IntervalTier tier = static_cast <IntervalTier> (anyTier);
-			long ninterval = tier -> numberOfIntervals ();
+			long ninterval = tier -> intervals.size;
 			for (long iinterval = 1; iinterval <= ninterval; iinterval ++) {
-				TextInterval interval = tier -> interval (iinterval);
+				TextInterval interval = tier -> intervals.at [iinterval];
 				double intmin = interval -> xmin, intmax = interval -> xmax;
 				if (intmin < tmin) intmin = tmin;
 				if (intmax > tmax) intmax = tmax;
 				if (intmin >= intmax) continue;
 				if (showBoundaries && intmin > tmin && intmin < tmax) {
 					Graphics_setLineType (g, Graphics_DOTTED);
-					Graphics_line (g, intmin, -1.0, intmin, 1.0);   /* In sound part. */
+					Graphics_line (g, intmin, -1.0, intmin, 1.0);   // in sound part
 					Graphics_setLineType (g, Graphics_DRAWN);
 				}      
 				/* Draw left boundary. */
@@ -393,14 +406,14 @@ void TextGrid_Sound_draw (TextGrid me, Sound sound, Graphics g, double tmin, dou
 			}
 		} else {
 			TextTier tier = static_cast <TextTier> (anyTier);
-			long numberOfPoints = tier -> numberOfPoints ();
+			long numberOfPoints = tier -> points.size;
 			for (long ipoint = 1; ipoint <= numberOfPoints; ipoint ++) {
-				TextPoint point = tier -> point (ipoint);
+				TextPoint point = tier -> points.at [ipoint];
 				double t = point -> number;
 				if (t > tmin && t < tmax) {
 					if (showBoundaries) {
 						Graphics_setLineType (g, Graphics_DOTTED);
-						Graphics_line (g, t, -1.0, t, 1.0);   /* In sound part. */
+						Graphics_line (g, t, -1.0, t, 1.0);   // in sound part
 						Graphics_setLineType (g, Graphics_DRAWN);
 					}
 					Graphics_line (g, t, ymin, t, 0.8 * ymin + 0.2 * ymax);
@@ -423,59 +436,61 @@ void TextGrid_Sound_draw (TextGrid me, Sound sound, Graphics g, double tmin, dou
 	}
 }
 
-autoCollection TextGrid_Sound_extractAllIntervals (TextGrid me, Sound sound, long tierNumber, int preserveTimes) {
+autoSoundList TextGrid_Sound_extractAllIntervals (TextGrid me, Sound sound, long tierNumber, bool preserveTimes) {
 	try {
 		IntervalTier tier = TextGrid_checkSpecifiedTierIsIntervalTier (me, tierNumber);
-		autoCollection collection = Collection_create (NULL, tier -> numberOfIntervals ());
-		for (long iseg = 1; iseg <= tier -> numberOfIntervals (); iseg ++) {
-			TextInterval segment = tier -> interval (iseg);
+		autoSoundList list = SoundList_create ();
+		for (long iseg = 1; iseg <= tier -> intervals.size; iseg ++) {
+			TextInterval segment = tier -> intervals.at [iseg];
 			autoSound interval = Sound_extractPart (sound, segment -> xmin, segment -> xmax, kSound_windowShape_RECTANGULAR, 1.0, preserveTimes);
-			Thing_setName (interval.peek(), segment -> text ? segment -> text : U"untitled");
-			Collection_addItem (collection.peek(), interval.transfer()); 
+			Thing_setName (interval.get(), segment -> text ? segment -> text : U"untitled");
+			list -> addItem_move (interval.move());
 		}
-		return collection;
+		return list;
 	} catch (MelderError) {
 		Melder_throw (me, U" & ", sound, U": intervals not extracted.");
 	}
 }
 
-autoCollection TextGrid_Sound_extractNonemptyIntervals (TextGrid me, Sound sound, long tierNumber, int preserveTimes) {
+Thing_implement (SoundList, Ordered, 0);
+
+autoSoundList TextGrid_Sound_extractNonemptyIntervals (TextGrid me, Sound sound, long tierNumber, bool preserveTimes) {
 	try {
 		IntervalTier tier = TextGrid_checkSpecifiedTierIsIntervalTier (me, tierNumber);
-		autoCollection collection = Collection_create (NULL, tier -> numberOfIntervals ());
-		for (long iseg = 1; iseg <= tier -> numberOfIntervals (); iseg ++) {
-			TextInterval segment = tier -> interval (iseg);
-			if (segment -> text != NULL && segment -> text [0] != '\0') {
+		autoSoundList list = SoundList_create ();
+		for (long iseg = 1; iseg <= tier -> intervals.size; iseg ++) {
+			TextInterval segment = tier -> intervals.at [iseg];
+			if (segment -> text && segment -> text [0] != U'\0') {
 				autoSound interval = Sound_extractPart (sound, segment -> xmin, segment -> xmax, kSound_windowShape_RECTANGULAR, 1.0, preserveTimes);
-				Thing_setName (interval.peek(), segment -> text ? segment -> text : U"untitled");
-				Collection_addItem (collection.peek(), interval.transfer());
+				Thing_setName (interval.get(), segment -> text ? segment -> text : U"untitled");
+				list -> addItem_move (interval.move());
 			}
 		}
-		if (collection -> size == 0) Melder_warning (U"No non-empty intervals were found.");
-		return collection;
+		if (list->size == 0) Melder_warning (U"No non-empty intervals were found.");
+		return list;
 	} catch (MelderError) {
 		Melder_throw (me, U" & ", sound, U": non-empty intervals not extracted.");
 	}
 }
 
-autoCollection TextGrid_Sound_extractIntervalsWhere (TextGrid me, Sound sound, long tierNumber,
-	int comparison_Melder_STRING, const char32 *text, int preserveTimes)
+autoSoundList TextGrid_Sound_extractIntervalsWhere (TextGrid me, Sound sound, long tierNumber,
+	int comparison_Melder_STRING, const char32 *text, bool preserveTimes)
 {
 	try {
 		IntervalTier tier = TextGrid_checkSpecifiedTierIsIntervalTier (me, tierNumber);
-		autoCollection collection = Collection_create (NULL, tier -> numberOfIntervals ());
+		autoSoundList list = SoundList_create ();
 		long count = 0;
-		for (long iseg = 1; iseg <= tier -> numberOfIntervals (); iseg ++) {
-			TextInterval segment = tier -> interval (iseg);
+		for (long iseg = 1; iseg <= tier -> intervals.size; iseg ++) {
+			TextInterval segment = tier -> intervals.at [iseg];
 			if (Melder_stringMatchesCriterion (segment -> text, comparison_Melder_STRING, text)) {
 				autoSound interval = Sound_extractPart (sound, segment -> xmin, segment -> xmax, kSound_windowShape_RECTANGULAR, 1.0, preserveTimes);
-				Thing_setName (interval.peek(), Melder_cat (sound -> name ? sound -> name : U"", U"_", text, U"_", ++ count));
-				Collection_addItem (collection.peek(), interval.transfer());
+				Thing_setName (interval.get(), Melder_cat (sound -> name ? sound -> name : U"", U"_", text, U"_", ++ count));
+				list -> addItem_move (interval.move());
 			}
 		}
-		if (collection -> size == 0)
+		if (list->size == 0)
 			Melder_warning (U"No label that ", kMelder_string_getText (comparison_Melder_STRING), U" the text \"", text, U"\" was found.");
-		return collection;
+		return list;
 	} catch (MelderError) {
 		Melder_throw (me, U" & ", sound, U": intervals not extracted.");
 	}
@@ -563,9 +578,9 @@ static void autoMarks_semitones (Graphics g, double ymin, double ymax, bool have
 }
 
 void TextGrid_Pitch_drawSeparately (TextGrid grid, Pitch pitch, Graphics g, double tmin, double tmax,
-	double fmin, double fmax, int showBoundaries, int useTextStyles, int garnish, int speckle, int unit)
+	double fmin, double fmax, bool showBoundaries, bool useTextStyles, bool garnish, bool speckle, int unit)
 {
-	int ntier = grid -> tiers -> size;
+	int ntier = grid -> tiers->size;
 	if (tmax <= tmin) tmin = grid -> xmin, tmax = grid -> xmax;
 	if (Function_isUnitLogarithmic (pitch, Pitch_LEVEL_FREQUENCY, unit)) {
 		fmin = Function_convertStandardToSpecialUnit (pitch, fmin, Pitch_LEVEL_FREQUENCY, unit);
@@ -575,7 +590,7 @@ void TextGrid_Pitch_drawSeparately (TextGrid grid, Pitch pitch, Graphics g, doub
 		Pitch_draw (pitch, g, tmin, tmax, pow (10.0, fmin - 0.25 * (fmax - fmin) * ntier), pow (10.0, fmax), false, speckle, unit);
 	else
 		Pitch_draw (pitch, g, tmin, tmax, fmin - 0.25 * (fmax - fmin) * ntier, fmax, false, speckle, unit);
-	TextGrid_Sound_draw (grid, NULL, g, tmin, tmax, showBoundaries, useTextStyles, false);
+	TextGrid_Sound_draw (grid, nullptr, g, tmin, tmax, showBoundaries, useTextStyles, false);
 	/*
 	 * Restore window for the sake of margin drawing.
 	 */
@@ -605,7 +620,7 @@ void TextGrid_Pitch_drawSeparately (TextGrid grid, Pitch pitch, Graphics g, doub
 
 void TextGrid_Pitch_draw (TextGrid grid, Pitch pitch, Graphics g,
 	long tierNumber, double tmin, double tmax, double fmin, double fmax,
-	double fontSize, int useTextStyles, int horizontalAlignment, int garnish, int speckle, int unit)
+	double fontSize, bool useTextStyles, int horizontalAlignment, bool garnish, bool speckle, int unit)
 {
 	try {
 		Function anyTier = TextGrid_checkSpecifiedTierNumberWithinRange (grid, tierNumber);
@@ -626,15 +641,15 @@ void TextGrid_Pitch_draw (TextGrid grid, Pitch pitch, Graphics g,
 		Graphics_setUnderscoreIsSubscript (g, useTextStyles);
 		if (anyTier -> classInfo == classIntervalTier) {
 			IntervalTier tier = static_cast <IntervalTier> (anyTier);
-			for (long i = 1; i <= tier -> numberOfIntervals (); i ++) {
-				TextInterval interval = tier -> interval (i);
+			for (long i = 1; i <= tier -> intervals.size; i ++) {
+				TextInterval interval = tier -> intervals.at [i];
 				double tleft = interval -> xmin, tright = interval -> xmax, tmid, f0;
 				if (! interval -> text || ! interval -> text [0]) continue;
 				if (tleft < pitch -> xmin) tleft = pitch -> xmin;
 				if (tright > pitch -> xmax) tright = pitch -> xmax;
 				tmid = (tleft + tright) / 2;
 				if (tmid < tmin || tmid > tmax) continue;
-				f0 = Function_convertStandardToSpecialUnit (pitch, RealTier_getValueAtTime (pitchTier.peek(), tmid), Pitch_LEVEL_FREQUENCY, unit);
+				f0 = Function_convertStandardToSpecialUnit (pitch, RealTier_getValueAtTime (pitchTier.get(), tmid), Pitch_LEVEL_FREQUENCY, unit);
 				if (f0 < fmin || f0 > fmax) continue;
 				Graphics_text (g,
 					horizontalAlignment == Graphics_LEFT ? tleft : horizontalAlignment == Graphics_RIGHT ? tright : tmid,
@@ -642,12 +657,12 @@ void TextGrid_Pitch_draw (TextGrid grid, Pitch pitch, Graphics g,
 			}
 		} else {
 			TextTier tier = static_cast <TextTier> (anyTier);
-			for (long i = 1; i <= tier -> numberOfPoints (); i ++) {
-				TextPoint point = tier -> point (i);
-				double t = point -> number, f0;
+			for (long i = 1; i <= tier -> points.size; i ++) {
+				TextPoint point = tier -> points.at [i];
+				double t = point -> number;
 				if (! point -> mark || ! point -> mark [0]) continue;
 				if (t < tmin || t > tmax) continue;
-				f0 = Function_convertStandardToSpecialUnit (pitch, RealTier_getValueAtTime (pitchTier.peek(), t), Pitch_LEVEL_FREQUENCY, unit);
+				double f0 = Function_convertStandardToSpecialUnit (pitch, RealTier_getValueAtTime (pitchTier.get(), t), Pitch_LEVEL_FREQUENCY, unit);
 				if (f0 < fmin || f0 > fmax) continue;
 				Graphics_text (g, t, f0, point -> mark);
 			}
