@@ -1,20 +1,19 @@
 /* Transition.cpp
  *
- * Copyright (C) 1997-2012,2015 Paul Boersma
+ * Copyright (C) 1997-2012,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Transition.h"
@@ -52,7 +51,7 @@ void structTransition :: v_writeText (MelderFile file) {
 	MelderFile_write (file, U"\n");
 	for (long i = 1; i <= numberOfStates; i ++) {
 		MelderFile_write (file, U"\"");
-		if (stateLabels [i] != NULL) MelderFile_write (file, stateLabels [i]);
+		if (stateLabels [i]) MelderFile_write (file, stateLabels [i]);
 		MelderFile_write (file, U"\"\t");
 	}
 	for (long i = 1; i <= numberOfStates; i ++) {
@@ -74,7 +73,7 @@ void Transition_init (Transition me, long numberOfStates) {
 autoTransition Transition_create (long numberOfStates) {
 	try {
 		autoTransition me = Thing_new (Transition);
-		Transition_init (me.peek(), numberOfStates);
+		Transition_init (me.get(), numberOfStates);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Transition not created.");
@@ -156,14 +155,12 @@ static void Transition_transpose (Transition me) {
 	}
 }
 
-void Transition_eigen (Transition me, Matrix *out_eigenvectors, Matrix *out_eigenvalues) {
-	*out_eigenvectors = NULL;
-	*out_eigenvalues = NULL;
+void Transition_eigen (Transition me, autoMatrix *out_eigenvectors, autoMatrix *out_eigenvalues) {
 	bool transposed = false;
 	try {
 		autoEigen eigen = Thing_new (Eigen);
 		Transition_transpose (me);
-		Eigen_initFromSymmetricMatrix (eigen.peek(), my data, my numberOfStates);
+		Eigen_initFromSymmetricMatrix (eigen.get(), my data, my numberOfStates);
 		Transition_transpose (me);
 		transposed = true;
 		autoMatrix eigenvectors = Matrix_createSimple (my numberOfStates, my numberOfStates);
@@ -173,8 +170,8 @@ void Transition_eigen (Transition me, Matrix *out_eigenvectors, Matrix *out_eige
 			for (long j = 1; j <= my numberOfStates; j ++)
 				eigenvectors -> z [i] [j] = eigen -> eigenvectors [j] [i];
 		}
-		*out_eigenvectors = eigenvectors.transfer();
-		*out_eigenvalues = eigenvalues.transfer();
+		*out_eigenvectors = eigenvectors.move();
+		*out_eigenvalues = eigenvalues.move();
 	} catch (MelderError) {
 		if (transposed)
 			Transition_transpose (me);
