@@ -2,19 +2,18 @@
  *
  * Copyright (C) 2001-2011,2014,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -435,7 +434,7 @@ static void replaceOutput (OTGrammarCandidate me) {
 	my output = Melder_dup (newOutput);
 }
 
-OTGrammar OTGrammar_create_metrics (int equal_footForm_wsp, int trochaicityConstraint, int includeFootBimoraic, int includeFootBisyllabic,
+autoOTGrammar OTGrammar_create_metrics (int equal_footForm_wsp, int trochaicityConstraint, int includeFootBimoraic, int includeFootBisyllabic,
 	int includePeripheral, int nonfinalityConstraint, int overtFormsHaveSecondaryStress,
 	int includeClashAndLapse, int includeCodas)
 {
@@ -487,33 +486,33 @@ OTGrammar OTGrammar_create_metrics (int equal_footForm_wsp, int trochaicityConst
 				computeViolationMarks (& tableau -> candidates [icand]);
 			}
 		}
-		OTGrammar_checkIndex (me.peek());
-		OTGrammar_newDisharmonies (me.peek(), 0.0);
+		OTGrammar_checkIndex (me.get());
+		OTGrammar_newDisharmonies (me.get(), 0.0);
 		if (trochaicityConstraint == 1) {
-			OTGrammar_removeConstraint (me.peek(), U"Trochaic");
+			OTGrammar_removeConstraint (me.get(), U"Trochaic");
 		} else {
-			OTGrammar_removeConstraint (me.peek(), U"FtNonfinal");
+			OTGrammar_removeConstraint (me.get(), U"FtNonfinal");
 		}
-		if (! includeFootBimoraic) OTGrammar_removeConstraint (me.peek(), U"FtBimor");
-		if (! includeFootBisyllabic) OTGrammar_removeConstraint (me.peek(), U"FtBisyl");
-		if (! includePeripheral) OTGrammar_removeConstraint (me.peek(), U"Peripheral");
+		if (! includeFootBimoraic) OTGrammar_removeConstraint (me.get(), U"FtBimor");
+		if (! includeFootBisyllabic) OTGrammar_removeConstraint (me.get(), U"FtBisyl");
+		if (! includePeripheral) OTGrammar_removeConstraint (me.get(), U"Peripheral");
 		if (nonfinalityConstraint == 1) {
-			OTGrammar_removeConstraint (me.peek(), U"MainNonfinal");
-			OTGrammar_removeConstraint (me.peek(), U"HeadNonfinal");
+			OTGrammar_removeConstraint (me.get(), U"MainNonfinal");
+			OTGrammar_removeConstraint (me.get(), U"HeadNonfinal");
 		} else if (nonfinalityConstraint == 2) {
-			OTGrammar_removeConstraint (me.peek(), U"HeadNonfinal");
-			OTGrammar_removeConstraint (me.peek(), U"Nonfinal");
+			OTGrammar_removeConstraint (me.get(), U"HeadNonfinal");
+			OTGrammar_removeConstraint (me.get(), U"Nonfinal");
 		} else {
-			OTGrammar_removeConstraint (me.peek(), U"MainNonfinal");
-			OTGrammar_removeConstraint (me.peek(), U"Nonfinal");
+			OTGrammar_removeConstraint (me.get(), U"MainNonfinal");
+			OTGrammar_removeConstraint (me.get(), U"Nonfinal");
 		}
 		if (! includeClashAndLapse) {
-			OTGrammar_removeConstraint (me.peek(), U"*Clash");
-			OTGrammar_removeConstraint (me.peek(), U"*Lapse");
+			OTGrammar_removeConstraint (me.get(), U"*Clash");
+			OTGrammar_removeConstraint (me.get(), U"*Lapse");
 		}
 		if (! includeCodas) {
-			OTGrammar_removeConstraint (me.peek(), U"WeightByPosition");
-			OTGrammar_removeConstraint (me.peek(), U"*C\\mu");
+			OTGrammar_removeConstraint (me.get(), U"WeightByPosition");
+			OTGrammar_removeConstraint (me.get(), U"*C\\mu");
 		}
 		if (includeCodas) {
 			for (long itab = 1; itab <= my numberOfTableaus; itab ++) {
@@ -523,7 +522,7 @@ OTGrammar OTGrammar_create_metrics (int equal_footForm_wsp, int trochaicityConst
 				}
 			}
 		}
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Metrics grammar not created.");
 	}
