@@ -1,20 +1,19 @@
 /* OTMulti.cpp
  *
- * Copyright (C) 2005-2012,2013,2015 Paul Boersma
+ * Copyright (C) 2005-2012,2013,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -842,24 +841,24 @@ int OTMulti_learnOne (OTMulti me, const char32 *form1, const char32 *form2,
 	return 1;
 }
 
-static Table OTMulti_createHistory (OTMulti me, long storeHistoryEvery, long numberOfData)
+static autoTable OTMulti_createHistory (OTMulti me, long storeHistoryEvery, long numberOfData)
 {
 	try {
 		long numberOfSamplingPoints = numberOfData / storeHistoryEvery;   // e.g. 0, 20, 40, ...
 		autoTable thee = Table_createWithoutColumnNames (1 + numberOfSamplingPoints, 3 + my numberOfConstraints);
-		Table_setColumnLabel (thee.peek(), 1, U"Datum");
-		Table_setColumnLabel (thee.peek(), 2, U"Form1");
-		Table_setColumnLabel (thee.peek(), 3, U"Form2");
+		Table_setColumnLabel (thee.get(), 1, U"Datum");
+		Table_setColumnLabel (thee.get(), 2, U"Form1");
+		Table_setColumnLabel (thee.get(), 3, U"Form2");
 		for (long icons = 1; icons <= my numberOfConstraints; icons ++) {
-			Table_setColumnLabel (thee.peek(), 3 + icons, my constraints [icons]. name);
+			Table_setColumnLabel (thee.get(), 3 + icons, my constraints [icons]. name);
 		}
-		Table_setNumericValue (thee.peek(), 1, 1, 0);
-		Table_setStringValue (thee.peek(), 1, 2, U"(initial)");
-		Table_setStringValue (thee.peek(), 1, 3, U"(initial)");
+		Table_setNumericValue (thee.get(), 1, 1, 0);
+		Table_setStringValue (thee.get(), 1, 2, U"(initial)");
+		Table_setStringValue (thee.get(), 1, 3, U"(initial)");
 		for (long icons = 1; icons <= my numberOfConstraints; icons ++) {
-			Table_setNumericValue (thee.peek(), 1, 3 + icons, my constraints [icons]. ranking);
+			Table_setNumericValue (thee.get(), 1, 3 + icons, my constraints [icons]. ranking);
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": history not created.");
 	}
@@ -886,7 +885,7 @@ static int OTMulti_updateHistory (OTMulti me, Table thee, long storeHistoryEvery
 
 void OTMulti_PairDistribution_learn (OTMulti me, PairDistribution thee, double evaluationNoise, enum kOTGrammar_rerankingStrategy updateRule, int direction,
 	double initialPlasticity, long replicationsPerPlasticity, double plasticityDecrement,
-	long numberOfPlasticities, double relativePlasticityNoise, long storeHistoryEvery, Table *history_out)
+	long numberOfPlasticities, double relativePlasticityNoise, long storeHistoryEvery, autoTable *history_out)
 {
 	long idatum = 0, numberOfData = numberOfPlasticities * replicationsPerPlasticity;
 	try {
@@ -897,7 +896,7 @@ void OTMulti_PairDistribution_learn (OTMulti me, PairDistribution thee, double e
 		}
 		autoTable history;
 		if (storeHistoryEvery) {
-			history.reset (OTMulti_createHistory (me, storeHistoryEvery, numberOfData));
+			history = OTMulti_createHistory (me, storeHistoryEvery, numberOfData);
 		}
 		for (long iplasticity = 1; iplasticity <= numberOfPlasticities; iplasticity ++) {
 			for (long ireplication = 1; ireplication <= replicationsPerPlasticity; ireplication ++) {
@@ -912,13 +911,14 @@ void OTMulti_PairDistribution_learn (OTMulti me, PairDistribution thee, double e
 							sumOfRankings += my constraints [icons]. ranking;
 						}
 						double meanRanking = sumOfRankings / numberOfDrawnConstraints;
+						Graphics_beginMovieFrame (monitor.graphics(), nullptr);
 						Graphics_setWindow (monitor.graphics(), 0, numberOfData, meanRanking - 50, meanRanking + 50);
 						for (long icons = 1; icons <= numberOfDrawnConstraints; icons ++) {
 							Graphics_setGrey (monitor.graphics(), (double) icons / numberOfDrawnConstraints);
 							Graphics_line (monitor.graphics(), idatum, my constraints [icons]. ranking,
 								idatum, my constraints [icons]. ranking+1);
 						}
-						Graphics_flushWs (monitor.graphics());   /* Because drawing is faster than progress loop. */
+						Graphics_endMovieFrame (monitor.graphics(), 0.0);
 					}
 				}
 				try {
@@ -927,26 +927,26 @@ void OTMulti_PairDistribution_learn (OTMulti me, PairDistribution thee, double e
 						U":\n      ", form1, U"     ", form2);
 				} catch (MelderError) {
 					if (history_out)
-						*history_out = history.transfer();   // so that we can inspect
+						*history_out = history.move();   // so that we can inspect
 					throw;
 				}
 				OTMulti_newDisharmonies (me, evaluationNoise);
 				try {
 					OTMulti_learnOne (me, form1, form2, updateRule, direction, plasticity, relativePlasticityNoise);
 				} catch (MelderError) {
-					if (history.peek()) {
-						OTMulti_updateHistory (me, history.peek(), storeHistoryEvery, idatum, form1, form2);
+					if (history) {
+						OTMulti_updateHistory (me, history.get(), storeHistoryEvery, idatum, form1, form2);
 					}
 					throw;
 				}
-				if (history.peek()) {
-					OTMulti_updateHistory (me, history.peek(), storeHistoryEvery, idatum, form1, form2);
+				if (history) {
+					OTMulti_updateHistory (me, history.get(), storeHistoryEvery, idatum, form1, form2);
 				}
 			}
 			plasticity *= plasticityDecrement;
 		}
 		if (history_out)
-			*history_out = history.transfer();
+			*history_out = history.move();
 	} catch (MelderError) {
 		if (idatum > 1)
 			Melder_appendError (U"Only ", idatum - 1, U" input-output pairs out of ", numberOfData, U" were processed.");
@@ -1397,7 +1397,7 @@ void OTMulti_generateOptimalForm (OTMulti me, const char32 *form1, const char32
 	}
 }
 
-Strings OTMulti_Strings_generateOptimalForms (OTMulti me, Strings thee, double evaluationNoise) {
+autoStrings OTMulti_Strings_generateOptimalForms (OTMulti me, Strings thee, double evaluationNoise) {
 	try {
 		autoStrings outputs = Thing_new (Strings);
 		long n = thy numberOfStrings;
@@ -1408,13 +1408,13 @@ Strings OTMulti_Strings_generateOptimalForms (OTMulti me, Strings thee, double e
 			OTMulti_generateOptimalForm (me, thy strings [i], U"", output, evaluationNoise);
 			outputs -> strings [i] = Melder_dup (output);
 		}
-		return outputs.transfer();
+		return outputs;
 	} catch (MelderError) {
 		Melder_throw (me, U" & ", thee, U": optimal forms not generated.");
 	}
 }
 
-Strings OTMulti_generateOptimalForms (OTMulti me, const char32 *form1, const char32 *form2, long numberOfTrials, double evaluationNoise) {
+autoStrings OTMulti_generateOptimalForms (OTMulti me, const char32 *form1, const char32 *form2, long numberOfTrials, double evaluationNoise) {
 	try {
 		autoStrings outputs = Thing_new (Strings);
 		outputs -> numberOfStrings = numberOfTrials;
@@ -1424,13 +1424,13 @@ Strings OTMulti_generateOptimalForms (OTMulti me, const char32 *form1, const cha
 			OTMulti_generateOptimalForm (me, form1, form2, output, evaluationNoise);
 			outputs -> strings [i] = Melder_dup (output);
 		}
-		return outputs.transfer();
+		return outputs;
 	} catch (MelderError) {
 		Melder_throw (me, U": optimal forms not generated.");
 	}
 }
 
-Distributions OTMulti_to_Distribution (OTMulti me, const char32 *form1, const char32 *form2,
+autoDistributions OTMulti_to_Distribution (OTMulti me, const char32 *form1, const char32 *form2,
 	long numberOfTrials, double evaluationNoise)
 {
 	try {
@@ -1466,7 +1466,7 @@ Distributions OTMulti_to_Distribution (OTMulti me, const char32 *form1, const ch
 			long iwinner = OTMulti_getWinner (me, form1, form2);
 			thy data [index [iwinner]] [1] += 1;
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": distribution not computed.");
 	}
