@@ -1,29 +1,19 @@
 /* LogisticRegression.cpp
  *
- * Copyright (C) 2005-2012,2015 Paul Boersma
+ * Copyright (C) 2005-2012,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-/*
- * pb 2005/05/01 created
- * pb 2006/12/10 MelderInfo
- * pb 2007/08/12 wchar
- * pb 2007/10/01 can write as encoding
- * pb 2007/11/18 split off from Regression.c
- * pb 2011/03/20 C++
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "LogisticRegression.h"
@@ -56,39 +46,39 @@ void structLogisticRegression :: v_info () {
 	MelderInfo_writeLine (U"Dependent 2: ", our dependent2);
 	MelderInfo_writeLine (U"Interpretation:");
 	MelderInfo_write (U"   ln (P(", dependent2, U")/P(", dependent1, U")) " UNITEXT_ALMOST_EQUAL_TO U" ", Melder_fixed (intercept, 6));
-	for (long ivar = 1; ivar <= parameters -> size; ivar ++) {
-		RegressionParameter parm = static_cast<RegressionParameter> (parameters -> item [ivar]);
+	for (long ivar = 1; ivar <= parameters.size; ivar ++) {
+		RegressionParameter parm = parameters.at [ivar];
 		MelderInfo_write (parm -> value < 0.0 ? U" - " : U" + ", Melder_fixed (fabs (parm -> value), 6), U" * ", parm -> label);
 	}
 	MelderInfo_writeLine (U"");
 	MelderInfo_writeLine (U"Log odds ratios:");
-	for (long ivar = 1; ivar <= parameters -> size; ivar ++) {
-		RegressionParameter parm = static_cast<RegressionParameter> (parameters -> item [ivar]);
+	for (long ivar = 1; ivar <= parameters.size; ivar ++) {
+		RegressionParameter parm = parameters.at [ivar];
 		MelderInfo_writeLine (U"   Log odds ratio of factor ", parm -> label, U": ", Melder_fixed ((parm -> maximum - parm -> minimum) * parm -> value, 6));
 	}
 	MelderInfo_writeLine (U"Odds ratios:");
-	for (long ivar = 1; ivar <= parameters -> size; ivar ++) {
-		RegressionParameter parm = static_cast<RegressionParameter> (parameters -> item [ivar]);
+	for (long ivar = 1; ivar <= parameters.size; ivar ++) {
+		RegressionParameter parm = parameters.at [ivar];
 		MelderInfo_writeLine (U"   Odds ratio of factor ", parm -> label, U": ", exp ((parm -> maximum - parm -> minimum) * parm -> value));
 	}
 }
 
-LogisticRegression LogisticRegression_create (const char32 *dependent1, const char32 *dependent2) {
+autoLogisticRegression LogisticRegression_create (const char32 *dependent1, const char32 *dependent2) {
 	try {
 		autoLogisticRegression me = Thing_new (LogisticRegression);
-		Regression_init (me.peek());
+		Regression_init (me.get());
 		my dependent1 = Melder_dup (dependent1);
 		my dependent2 = Melder_dup (dependent2);
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"LogisticRegression not created.");
 	}
 }
 
-static LogisticRegression _Table_to_LogisticRegression (Table me, long *factors, long numberOfFactors, long dependent1, long dependent2) {
+static autoLogisticRegression _Table_to_LogisticRegression (Table me, long *factors, long numberOfFactors, long dependent1, long dependent2) {
 	long numberOfParameters = numberOfFactors + 1;
-	long numberOfCells = my rows -> size, numberOfY0 = 0, numberOfY1 = 0, numberOfData = 0;
-	double logLikelihood = 1e308, previousLogLikelihood = 2e308;
+	long numberOfCells = my rows.size, numberOfY0 = 0, numberOfY1 = 0, numberOfData = 0;
+	double logLikelihood = 1e307, previousLogLikelihood = 1e308;
 	if (numberOfParameters < 1)   // includes intercept
 		Melder_throw (U"Not enough columns (has to be more than 1).");
 	/*
@@ -104,7 +94,7 @@ static LogisticRegression _Table_to_LogisticRegression (Table me, long *factors,
 	for (long ivar = 1; ivar <= numberOfFactors; ivar ++) {
 		double minimum = Table_getMinimum (me, factors [ivar]);
 		double maximum = Table_getMaximum (me, factors [ivar]);
-		Regression_addParameter (thee.peek(), my columnHeaders [factors [ivar]]. label, minimum, maximum, 0.0);
+		Regression_addParameter (thee.get(), my columnHeaders [factors [ivar]]. label, minimum, maximum, 0.0);
 	}
 	for (long icell = 1; icell <= numberOfCells; icell ++) {
 		y0 [icell] = Table_getNumericValue_Assert (me, icell, dependent1);
@@ -149,7 +139,7 @@ static LogisticRegression _Table_to_LogisticRegression (Table me, long *factors,
 	 */
 	thy intercept = log ((double) numberOfY1 / (double) numberOfY0);   // initial state of intercept: best guess for average log odds
 	for (long ivar = 1; ivar <= numberOfFactors; ivar ++) {
-		RegressionParameter parm = static_cast<RegressionParameter> (thy parameters -> item [ivar]);
+		RegressionParameter parm = thy parameters.at [ivar];
 		parm -> value = 0.0;   // initial state of dependence: none
 	}
 	long iteration = 1;
@@ -167,7 +157,7 @@ static LogisticRegression _Table_to_LogisticRegression (Table me, long *factors,
 		for (long icell = 1; icell <= numberOfCells; icell ++) {
 			double fittedLogit = thy intercept, fittedP, fittedQ, fittedLogP, fittedLogQ, fittedPQ, fittedVariance;
 			for (long ivar = 1; ivar <= numberOfFactors; ivar ++) {
-				RegressionParameter parm = static_cast<RegressionParameter> (thy parameters -> item [ivar]);
+				RegressionParameter parm = thy parameters.at [ivar];
 				fittedLogit += parm -> value * x [icell] [ivar];
 			}
 			/*
@@ -257,7 +247,7 @@ static LogisticRegression _Table_to_LogisticRegression (Table me, long *factors,
 		 */
 		thy intercept += smallMatrix [0] [numberOfParameters];
 		for (long ivar = 1; ivar <= numberOfFactors; ivar ++) {
-			RegressionParameter parm = static_cast<RegressionParameter> (thy parameters -> item [ivar]);
+			RegressionParameter parm = thy parameters.at [ivar];
 			parm -> value += smallMatrix [ivar] [numberOfParameters];
 		}
 	}
@@ -265,14 +255,14 @@ static LogisticRegression _Table_to_LogisticRegression (Table me, long *factors,
 		Melder_warning (U"Logistic regression has not converged in 100 iterations. The results are unreliable.");
 	}
 	for (long ivar = 1; ivar <= numberOfFactors; ivar ++) {
-		RegressionParameter parm = static_cast<RegressionParameter> (thy parameters -> item [ivar]);
+		RegressionParameter parm = thy parameters.at [ivar];
 		parm -> value /= stdevX [ivar];
 		thy intercept -= parm -> value * meanX [ivar];
 	}
-	return thee.transfer();
+	return thee;
 }
 
-LogisticRegression Table_to_LogisticRegression (Table me, const char32 *factors_columnLabelString,
+autoLogisticRegression Table_to_LogisticRegression (Table me, const char32 *factors_columnLabelString,
 	const char32 *dependent1_columnLabel, const char32 *dependent2_columnLabel)
 {
 	try {
@@ -281,7 +271,7 @@ LogisticRegression Table_to_LogisticRegression (Table me, const char32 *factors_
 		long dependent1_columnIndex = Table_getColumnIndexFromColumnLabel (me, dependent1_columnLabel);
 		long dependent2_columnIndex = Table_getColumnIndexFromColumnLabel (me, dependent2_columnLabel);
 		autoLogisticRegression thee = _Table_to_LogisticRegression (me, factors_columnIndices.peek(), numberOfFactors, dependent1_columnIndex, dependent2_columnIndex);
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": logistic regression not performed.");
 	}
@@ -298,8 +288,8 @@ static inline double NUMmax2 (double a, double b) {
 void LogisticRegression_drawBoundary (LogisticRegression me, Graphics graphics, long colx, double xleft, double xright,
 	long coly, double ybottom, double ytop, bool garnish)
 {
-	RegressionParameter parmx = static_cast<RegressionParameter> (my parameters -> item [colx]);
-	RegressionParameter parmy = static_cast<RegressionParameter> (my parameters -> item [coly]);
+	RegressionParameter parmx = my parameters.at [colx];
+	RegressionParameter parmy = my parameters.at [coly];
 	if (xleft == xright) {
 		xleft = parmx -> minimum;
 		xright = parmx -> maximum;
@@ -309,9 +299,9 @@ void LogisticRegression_drawBoundary (LogisticRegression me, Graphics graphics,
 		ytop = parmy -> maximum;
 	}
 	double intercept = my intercept;
-	for (long iparm = 1; iparm <= my parameters -> size; iparm ++) {
+	for (long iparm = 1; iparm <= my parameters.size; iparm ++) {
 		if (iparm != colx && iparm != coly) {
-			RegressionParameter parm = static_cast<RegressionParameter> (my parameters -> item [iparm]);
+			RegressionParameter parm = my parameters.at [iparm];
 			intercept += parm -> value * (0.5 * (parm -> minimum + parm -> maximum));
 		}
 	}
@@ -352,7 +342,7 @@ void LogisticRegression_drawBoundary (LogisticRegression me, Graphics graphics,
 }
 
 /*
-Table Table_LogisticRegression_addProbabilities (Table me, LogisticRegression thee) {
+autoTable Table_LogisticRegression_addProbabilities (Table me, LogisticRegression thee) {
 	for (icell = 1; icell <= numberOfCells; icell ++) {
 		double fittedLogit = parameters [0], fittedP, fittedQ, fittedLogP, fittedLogQ;
 		for (ivar = 1; ivar <= numberOfIndependentVariables; ivar ++) {
