@@ -1,20 +1,19 @@
 /* TableOfReal.cpp
  *
- * Copyright (C) 1992-2012,2014,2015 Paul Boersma
+ * Copyright (C) 1992-2012,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <ctype.h>
@@ -38,6 +37,9 @@
 #include "oo_DESCRIPTION.h"
 #include "TableOfReal_def.h"
 
+Thing_implement (TableOfReal, Daata, 0);
+Thing_implement (TableOfRealList, Ordered, 0);
+
 static void fprintquotedstring (MelderFile file, const char32 *s) {
 	MelderFile_writeCharacter (file, U'\"');
 	if (s) { char32 c; while ((c = *s ++) != U'\0') { MelderFile_writeCharacter (file, c); if (c == U'\"') MelderFile_writeCharacter (file, c); } }
@@ -92,11 +94,11 @@ void structTableOfReal :: v_info () {
 }
 
 const char32 * structTableOfReal :: v_getRowStr (long irow) {
-	if (irow < 1 || irow > numberOfRows) return NULL;
+	if (irow < 1 || irow > numberOfRows) return nullptr;
 	return rowLabels [irow] ? rowLabels [irow] : U"";
 }
 const char32 * structTableOfReal :: v_getColStr (long icol) {
-	if (icol < 1 || icol > numberOfColumns) return NULL;
+	if (icol < 1 || icol > numberOfColumns) return nullptr;
 	return columnLabels [icol] ? columnLabels [icol] : U"";
 }
 double structTableOfReal :: v_getMatrix (long irow, long icol) {
@@ -111,8 +113,6 @@ double structTableOfReal :: v_getColIndex (const char32 *columnLabel) {
 	return TableOfReal_columnLabelToIndex (this, columnLabel);
 }
 
-Thing_implement (TableOfReal, Daata, 0);
-
 void TableOfReal_init (TableOfReal me, long numberOfRows, long numberOfColumns) {
 	if (numberOfRows < 1 || numberOfColumns < 1)
 		Melder_throw (U"Cannot create cell-less table.");
@@ -123,11 +123,11 @@ void TableOfReal_init (TableOfReal me, long numberOfRows, long numberOfColumns)
 	my data = NUMmatrix <double> (1, my numberOfRows, 1, my numberOfColumns);
 }
 
-TableOfReal TableOfReal_create (long numberOfRows, long numberOfColumns) {
+autoTableOfReal TableOfReal_create (long numberOfRows, long numberOfColumns) {
 	try {
 		autoTableOfReal me = Thing_new (TableOfReal);
-		TableOfReal_init (me.peek(), numberOfRows, numberOfColumns);
-		return me.transfer();
+		TableOfReal_init (me.get(), numberOfRows, numberOfColumns);
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"TableOfReal not created.");
 	}
@@ -310,7 +310,7 @@ void TableOfReal_setColumnLabel (TableOfReal me, long columnNumber, const char32
 void TableOfReal_formula (TableOfReal me, const char32 *expression, Interpreter interpreter, TableOfReal thee) {
 	try {
 		Formula_compile (interpreter, me, expression, kFormula_EXPRESSION_TYPE_NUMERIC, true);
-		if (thee == NULL) thee = me;
+		if (! thee) thee = me;
 		for (long irow = 1; irow <= my numberOfRows; irow ++) {
 			for (long icol = 1; icol <= my numberOfColumns; icol ++) {
 				struct Formula_Result result;
@@ -359,7 +359,7 @@ static void copyColumn (TableOfReal me, long myCol, TableOfReal thee, long thyCo
 	}
 }
 
-TableOfReal TableOfReal_extractRowsWhereColumn (TableOfReal me, long column, int which_Melder_NUMBER, double criterion) {
+autoTableOfReal TableOfReal_extractRowsWhereColumn (TableOfReal me, long column, int which_Melder_NUMBER, double criterion) {
 	try {
 		if (column < 1 || column > my numberOfColumns)
 			Melder_throw (U"No such column: ", column, U".");
@@ -371,18 +371,18 @@ TableOfReal TableOfReal_extractRowsWhereColumn (TableOfReal me, long column, int
 		}
 		if (n == 0) Melder_throw (U"No row matches this criterion.");
 		autoTableOfReal thee = TableOfReal_create (n, my numberOfColumns);
-		copyColumnLabels (me, thee.peek());
+		copyColumnLabels (me, thee.get());
 		n = 0;
 		for (long irow = 1; irow <= my numberOfRows; irow ++)
 			if (Melder_numberMatchesCriterion (my data [irow] [column], which_Melder_NUMBER, criterion))
-				copyRow (me, irow, thee.peek(), ++ n);
-		return thee.transfer();
+				copyRow (me, irow, thee.get(), ++ n);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": rows not extracted.");
 	}
 }
 
-TableOfReal TableOfReal_extractRowsWhereLabel (TableOfReal me, int which_Melder_STRING, const char32 *criterion) {
+autoTableOfReal TableOfReal_extractRowsWhereLabel (TableOfReal me, int which_Melder_STRING, const char32 *criterion) {
 	try {
 		long n = 0;
 		for (long irow = 1; irow <= my numberOfRows; irow ++) {
@@ -393,18 +393,18 @@ TableOfReal TableOfReal_extractRowsWhereLabel (TableOfReal me, int which_Melder_
 		if (n == 0)
 			Melder_throw (U"No row matches this criterion.");
 		autoTableOfReal thee = TableOfReal_create (n, my numberOfColumns);
-		copyColumnLabels (me, thee.peek());
+		copyColumnLabels (me, thee.get());
 		n = 0;
 		for (long irow = 1; irow <= my numberOfRows; irow ++)
 			if (Melder_stringMatchesCriterion (my rowLabels [irow], which_Melder_STRING, criterion))
-				copyRow (me, irow, thee.peek(), ++ n);
-		return thee.transfer();
+				copyRow (me, irow, thee.get(), ++ n);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": rows not extracted.");
 	}
 }
 
-TableOfReal TableOfReal_extractColumnsWhereRow (TableOfReal me, long row, int which_Melder_NUMBER, double criterion) {
+autoTableOfReal TableOfReal_extractColumnsWhereRow (TableOfReal me, long row, int which_Melder_NUMBER, double criterion) {
 	try {
 		if (row < 1 || row > my numberOfRows)
 			Melder_throw (U"No such row: ", row, U".");
@@ -417,18 +417,18 @@ TableOfReal TableOfReal_extractColumnsWhereRow (TableOfReal me, long row, int wh
 		if (n == 0) Melder_throw (U"No column matches this criterion.");
 
 		autoTableOfReal thee = TableOfReal_create (my numberOfRows, n);
-		copyRowLabels (me, thee.peek());
+		copyRowLabels (me, thee.get());
 		n = 0;
 		for (long icol = 1; icol <= my numberOfColumns; icol ++)
 			if (Melder_numberMatchesCriterion (my data [row] [icol], which_Melder_NUMBER, criterion))
-				copyColumn (me, icol, thee.peek(), ++ n);
-		return thee.transfer();
+				copyColumn (me, icol, thee.get(), ++ n);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": columns not extracted.");
 	}
 }
 
-TableOfReal TableOfReal_extractColumnsWhereLabel (TableOfReal me, int which_Melder_STRING, const char32 *criterion) {
+autoTableOfReal TableOfReal_extractColumnsWhereLabel (TableOfReal me, int which_Melder_STRING, const char32 *criterion) {
 	try {
 		long n = 0;
 		for (long icol = 1; icol <= my numberOfColumns; icol ++) {
@@ -439,14 +439,14 @@ TableOfReal TableOfReal_extractColumnsWhereLabel (TableOfReal me, int which_Meld
 		if (n == 0) Melder_throw (U"No column matches this criterion.");
 
 		autoTableOfReal thee = TableOfReal_create (my numberOfRows, n);
-		copyRowLabels (me, thee.peek());
+		copyRowLabels (me, thee.get());
 		n = 0;
 		for (long icol = 1; icol <= my numberOfColumns; icol ++) {
 			if (Melder_stringMatchesCriterion (my columnLabels [icol], which_Melder_STRING, criterion)) {
-				copyColumn (me, icol, thee.peek(), ++ n);
+				copyColumn (me, icol, thee.get(), ++ n);
 			}
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": columns not extracted.");
 	}
@@ -537,35 +537,35 @@ static long *getElementsOfRanges (const char32 *ranges, long maximumElement, lon
 	return elements.transfer();
 }
 
-TableOfReal TableOfReal_extractRowRanges (TableOfReal me, const char32 *ranges) {
+autoTableOfReal TableOfReal_extractRowRanges (TableOfReal me, const char32 *ranges) {
 	try {
 		long numberOfElements;
 		autoNUMvector <long> elements (getElementsOfRanges (ranges, my numberOfRows, & numberOfElements, U"row"), 1);
 		autoTableOfReal thee = TableOfReal_create (numberOfElements, my numberOfColumns);
-		copyColumnLabels (me, thee.peek());
+		copyColumnLabels (me, thee.get());
 		for (long ielement = 1; ielement <= numberOfElements; ielement ++)
-			copyRow (me, elements [ielement], thee.peek(), ielement);
-		return thee.transfer();
+			copyRow (me, elements [ielement], thee.get(), ielement);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": row ranges not extracted.");
 	}
 }
 
-TableOfReal TableOfReal_extractColumnRanges (TableOfReal me, const char32 *ranges) {
+autoTableOfReal TableOfReal_extractColumnRanges (TableOfReal me, const char32 *ranges) {
 	try {
 		long numberOfElements;
 		autoNUMvector <long> elements (getElementsOfRanges (ranges, my numberOfColumns, & numberOfElements, U"column"), 1);
 		autoTableOfReal thee = TableOfReal_create (my numberOfRows, numberOfElements);
-		copyRowLabels (me, thee.peek());
+		copyRowLabels (me, thee.get());
 		for (long ielement = 1; ielement <= numberOfElements; ielement ++)
-			copyColumn (me, elements [ielement], thee.peek(), ielement);
-		return thee.transfer();
+			copyColumn (me, elements [ielement], thee.get(), ielement);
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": column ranges not extracted.");
 	}
 }
 
-TableOfReal TableOfReal_extractRowsWhere (TableOfReal me, const char32 *condition, Interpreter interpreter) {
+autoTableOfReal TableOfReal_extractRowsWhere (TableOfReal me, const char32 *condition, Interpreter interpreter) {
 	try {
 		Formula_compile (interpreter, me, condition, kFormula_EXPRESSION_TYPE_NUMERIC, true);
 		/*
@@ -588,7 +588,7 @@ TableOfReal TableOfReal_extractRowsWhere (TableOfReal me, const char32 *conditio
 		 * Create room for the result.
 		 */	
 		autoTableOfReal thee = TableOfReal_create (numberOfElements, my numberOfColumns);
-		copyColumnLabels (me, thee.peek());
+		copyColumnLabels (me, thee.get());
 		/*
 		 * Store the result.
 		 */
@@ -598,18 +598,18 @@ TableOfReal TableOfReal_extractRowsWhere (TableOfReal me, const char32 *conditio
 				struct Formula_Result result;
 				Formula_run (irow, icol, & result);
 				if (result. result.numericResult != 0.0) {
-					copyRow (me, irow, thee.peek(), ++ numberOfElements);
+					copyRow (me, irow, thee.get(), ++ numberOfElements);
 					break;
 				}
 			}
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": rows not extracted.");
 	}
 }
 
-TableOfReal TableOfReal_extractColumnsWhere (TableOfReal me, const char32 *condition, Interpreter interpreter) {
+autoTableOfReal TableOfReal_extractColumnsWhere (TableOfReal me, const char32 *condition, Interpreter interpreter) {
 	try {
 		Formula_compile (interpreter, me, condition, kFormula_EXPRESSION_TYPE_NUMERIC, true);
 		/*
@@ -632,7 +632,7 @@ TableOfReal TableOfReal_extractColumnsWhere (TableOfReal me, const char32 *condi
 		 * Create room for the result.
 		 */	
 		autoTableOfReal thee = TableOfReal_create (my numberOfRows, numberOfElements);
-		copyRowLabels (me, thee.peek());
+		copyRowLabels (me, thee.get());
 		/*
 		 * Store the result.
 		 */
@@ -642,12 +642,12 @@ TableOfReal TableOfReal_extractColumnsWhere (TableOfReal me, const char32 *condi
 				struct Formula_Result result;
 				Formula_run (irow, icol, & result);
 				if (result. result.numericResult != 0.0) {
-					copyColumn (me, icol, thee.peek(), ++ numberOfElements);
+					copyColumn (me, icol, thee.get(), ++ numberOfElements);
 					break;
 				}
 			}
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": columns not extracted.");
 	}
@@ -655,7 +655,7 @@ TableOfReal TableOfReal_extractColumnsWhere (TableOfReal me, const char32 *condi
 
 /***** EXTRACT *****/
 
-Strings TableOfReal_extractRowLabelsAsStrings (TableOfReal me) {
+autoStrings TableOfReal_extractRowLabelsAsStrings (TableOfReal me) {
 	try {
 		autoStrings thee = Thing_new (Strings);
 		thy strings = NUMvector <char32 *> (1, my numberOfRows);
@@ -663,13 +663,13 @@ Strings TableOfReal_extractRowLabelsAsStrings (TableOfReal me) {
 		for (long irow = 1; irow <= my numberOfRows; irow ++) {
 			thy strings [irow] = Melder_dup (my rowLabels [irow] ? my rowLabels [irow] : U"");
 		}
-		return thee.transfer();	
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": row labels not extracted.");
 	}
 }
 
-Strings TableOfReal_extractColumnLabelsAsStrings (TableOfReal me) {
+autoStrings TableOfReal_extractColumnLabelsAsStrings (TableOfReal me) {
 	try {
 		autoStrings thee = Thing_new (Strings);
 		thy strings = NUMvector <char32 *> (1, my numberOfColumns);
@@ -677,7 +677,7 @@ Strings TableOfReal_extractColumnLabelsAsStrings (TableOfReal me) {
 		for (long icol = 1; icol <= my numberOfColumns; icol ++) {
 			thy strings [icol] = Melder_dup (my columnLabels [icol] ? my columnLabels [icol] : U"");
 		}
-		return thee.transfer();	
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": column labels not extracted.");
 	}
@@ -791,7 +791,7 @@ void TableOfReal_drawAsNumbers_if (TableOfReal me, Graphics graphics, long rowmi
 {
 	try {
 		autoMatrix original = TableOfReal_to_Matrix (me);
-		autoMatrix conditions = original.clone ();
+		autoMatrix conditions = Data_copy (original.get());
 		fixRows (me, & rowmin, & rowmax);
 		Graphics_setInner (graphics);
 		Graphics_setWindow (graphics, 0.5, my numberOfColumns + 0.5, 0.0, 1.0);
@@ -799,7 +799,7 @@ void TableOfReal_drawAsNumbers_if (TableOfReal me, Graphics graphics, long rowmi
 		double lineSpacing = getLineSpacing (graphics);   // not earlier!
 		double maxTextWidth = getMaxRowLabelWidth (me, graphics, rowmin, rowmax);
 		double maxTextHeight = getMaxColumnLabelHeight (me, graphics, 1, my numberOfColumns);
-		Matrix_formula (original.peek(), conditionFormula, interpreter, conditions.peek());
+		Matrix_formula (original.get(), conditionFormula, interpreter, conditions.get());
 
 		Graphics_setTextAlignment (graphics, Graphics_CENTRE, Graphics_BOTTOM);
 		for (long icol = 1; icol <= my numberOfColumns; icol ++) {
@@ -942,62 +942,62 @@ void TableOfReal_drawAsSquares (TableOfReal me, Graphics graphics, long rowmin,
 	}
 }
 
-Any TablesOfReal_append (TableOfReal me, TableOfReal thee) {
+autoTableOfReal TablesOfReal_append (TableOfReal me, TableOfReal thee) {
 	try {
 		if (thy numberOfColumns != my numberOfColumns)
 			Melder_throw (U"Numbers of columns are ", my numberOfColumns, U" and ", thy numberOfColumns, U" but should be equal.");
-		autoTableOfReal him = static_cast <TableOfReal> (Thing_newFromClass (my classInfo));
-		TableOfReal_init (him.peek(), my numberOfRows + thy numberOfRows, my numberOfColumns);
+		autoTableOfReal him = Thing_newFromClass (my classInfo).static_cast_move <structTableOfReal> ();
+		TableOfReal_init (him.get(), my numberOfRows + thy numberOfRows, my numberOfColumns);
 		/* Unsafe: new attributes not initialized. */
 		for (long icol = 1; icol <= my numberOfColumns; icol ++) {
-			TableOfReal_setColumnLabel (him.peek(), icol, my columnLabels [icol]);
+			TableOfReal_setColumnLabel (him.get(), icol, my columnLabels [icol]);
 		}
 		for (long irow = 1; irow <= my numberOfRows; irow ++) {
-			TableOfReal_setRowLabel (him.peek(), irow, my rowLabels [irow]);
+			TableOfReal_setRowLabel (him.get(), irow, my rowLabels [irow]);
 			for (long icol = 1; icol <= my numberOfColumns; icol ++)
 				his data [irow] [icol] = my data [irow] [icol];
 		}
 		for (long irow = 1; irow <= thy numberOfRows; irow ++) {
 			long hisRow = irow + my numberOfRows;
-			TableOfReal_setRowLabel (him.peek(), hisRow, thy rowLabels [irow]);
+			TableOfReal_setRowLabel (him.get(), hisRow, thy rowLabels [irow]);
 			for (long icol = 1; icol <= my numberOfColumns; icol ++)
 				his data [hisRow] [icol] = thy data [irow] [icol];
 		}
-		return him.transfer();
+		return him;
 	} catch (MelderError) {
 		Melder_throw (U"TableOfReal objects not appended.");
 	}
 }
 
-Any TablesOfReal_appendMany (Collection me) {
+autoTableOfReal TablesOfReal_appendMany (OrderedOf<structTableOfReal>* me) {
 	try {
 		if (my size == 0) Melder_throw (U"Cannot add zero tables.");
-		TableOfReal thee = static_cast <TableOfReal> (my item [1]);
+		TableOfReal thee = my at [1];
 		long totalNumberOfRows = thy numberOfRows;
 		long numberOfColumns = thy numberOfColumns;
 		for (long itab = 2; itab <= my size; itab ++) {
-			thee = static_cast <TableOfReal> (my item [itab]);
+			thee = my at [itab];
 			totalNumberOfRows += thy numberOfRows;
 			if (thy numberOfColumns != numberOfColumns) Melder_throw (U"Numbers of columns do not match.");
 		}
-		autoTableOfReal him = static_cast <TableOfReal> (Thing_newFromClass (thy classInfo));
-		TableOfReal_init (him.peek(), totalNumberOfRows, numberOfColumns);
+		autoTableOfReal him = Thing_newFromClass (thy classInfo).static_cast_move <structTableOfReal> ();
+		TableOfReal_init (him.get(), totalNumberOfRows, numberOfColumns);
 		/* Unsafe: new attributes not initialized. */
 		for (long icol = 1; icol <= numberOfColumns; icol ++) {
-			TableOfReal_setColumnLabel (him.peek(), icol, thy columnLabels [icol]);
+			TableOfReal_setColumnLabel (him.get(), icol, thy columnLabels [icol]);
 		}
 		totalNumberOfRows = 0;
 		for (long itab = 1; itab <= my size; itab ++) {
-			thee = static_cast <TableOfReal> (my item [itab]);
+			thee = my at [itab];
 			for (long irow = 1; irow <= thy numberOfRows; irow ++) {
 				totalNumberOfRows ++;
-				TableOfReal_setRowLabel (him.peek(), totalNumberOfRows, thy rowLabels [irow]);
+				TableOfReal_setRowLabel (him.get(), totalNumberOfRows, thy rowLabels [irow]);
 				for (long icol = 1; icol <= numberOfColumns; icol ++)
 					his data [totalNumberOfRows] [icol] = thy data [irow] [icol];
 			}
 		}
 		Melder_assert (totalNumberOfRows == his numberOfRows);
-		return him.transfer();
+		return him;
 	} catch (MelderError) {
 		Melder_throw (U"TableOfReal objects not appended.");
 	}
@@ -1007,16 +1007,16 @@ static void TableOfReal_sort (TableOfReal me, bool useLabels, long column1, long
 	for (long irow = 1; irow < my numberOfRows; irow ++) for (long jrow = irow + 1; jrow <= my numberOfRows; jrow ++) {
 		char32 *tmpString;
 		if (useLabels) {
-			if (my rowLabels [irow] != NULL) {
-				if (my rowLabels [jrow] != NULL) {
+			if (my rowLabels [irow]) {
+				if (my rowLabels [jrow]) {
 					int compare = str32cmp (my rowLabels [irow], my rowLabels [jrow]);
 					if (compare < 0) continue;
 					if (compare > 0) goto swap;
 				} else goto swap;
-			} else if (my rowLabels [jrow] != NULL) continue;
+			} else if (my rowLabels [jrow]) continue;
 		}
 		/*
-		 * If we arrive here, the two labels are equal or both NULL (or useLabels is `false`).
+		 * If we arrive here, the two labels are equal or both null (or useLabels is `false`).
 		 */
 		if (column1 > 0 && column1 <= my numberOfColumns) {
 			if (my data [irow] [column1] < my data [jrow] [column1]) continue;
@@ -1050,24 +1050,24 @@ void TableOfReal_sortByColumn (TableOfReal me, long column1, long column2) {
 	TableOfReal_sort (me, false, column1, column2);
 }
 
-TableOfReal Table_to_TableOfReal (Table me, long labelColumn) {
+autoTableOfReal Table_to_TableOfReal (Table me, long labelColumn) {
 	try {
 		if (labelColumn < 1 || labelColumn > my numberOfColumns) labelColumn = 0;
-		autoTableOfReal thee = TableOfReal_create (my rows -> size, labelColumn ? my numberOfColumns - 1 : my numberOfColumns);
+		autoTableOfReal thee = TableOfReal_create (my rows.size, labelColumn ? my numberOfColumns - 1 : my numberOfColumns);
 		for (long icol = 1; icol <= my numberOfColumns; icol ++) {
 			Table_numericize_Assert (me, icol);
 		}
 		if (labelColumn) {
 			for (long icol = 1; icol < labelColumn; icol ++) {
-				TableOfReal_setColumnLabel (thee.peek(), icol, my columnHeaders [icol]. label);
+				TableOfReal_setColumnLabel (thee.get(), icol, my columnHeaders [icol]. label);
 			}
 			for (long icol = labelColumn + 1; icol <= my numberOfColumns; icol ++) {
-				TableOfReal_setColumnLabel (thee.peek(), icol - 1, my columnHeaders [icol]. label);
+				TableOfReal_setColumnLabel (thee.get(), icol - 1, my columnHeaders [icol]. label);
 			}
-			for (long irow = 1; irow <= my rows -> size; irow ++) {
-				TableRow row = static_cast <TableRow> (my rows -> item [irow]);
+			for (long irow = 1; irow <= my rows.size; irow ++) {
+				TableRow row = my rows.at [irow];
 				char32 *string = row -> cells [labelColumn]. string;
-				TableOfReal_setRowLabel (thee.peek(), irow, string ? string : U"");
+				TableOfReal_setRowLabel (thee.get(), irow, string ? string : U"");
 				for (long icol = 1; icol < labelColumn; icol ++) {
 					thy data [irow] [icol] = row -> cells [icol]. number;   // Optimization.
 					//thy data [irow] [icol] = Table_getNumericValue_Assert (me, irow, icol);
@@ -1079,40 +1079,40 @@ TableOfReal Table_to_TableOfReal (Table me, long labelColumn) {
 			}
 		} else {
 			for (long icol = 1; icol <= my numberOfColumns; icol ++) {
-				TableOfReal_setColumnLabel (thee.peek(), icol, my columnHeaders [icol]. label);
+				TableOfReal_setColumnLabel (thee.get(), icol, my columnHeaders [icol]. label);
 			}
-			for (long irow = 1; irow <= my rows -> size; irow ++) {
-				TableRow row = static_cast <TableRow> (my rows -> item [irow]);
+			for (long irow = 1; irow <= my rows.size; irow ++) {
+				TableRow row = my rows.at [irow];
 				for (long icol = 1; icol <= my numberOfColumns; icol ++) {
 					thy data [irow] [icol] = row -> cells [icol]. number;   // Optimization.
 					//thy data [irow] [icol] = Table_getNumericValue_Assert (me, irow, icol);
 				}
 			}
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": not converted to TableOfReal.");
 	}
 }
 
-Table TableOfReal_to_Table (TableOfReal me, const char32 *labelOfFirstColumn) {
+autoTable TableOfReal_to_Table (TableOfReal me, const char32 *labelOfFirstColumn) {
 	try {
 		autoTable thee = Table_createWithoutColumnNames (my numberOfRows, my numberOfColumns + 1);
-		Table_setColumnLabel (thee.peek(), 1, labelOfFirstColumn);
+		Table_setColumnLabel (thee.get(), 1, labelOfFirstColumn);
 		for (long icol = 1; icol <= my numberOfColumns; icol ++) {
 			char32 *columnLabel = my columnLabels [icol];
 			thy columnHeaders [icol + 1]. label = Melder_dup (columnLabel && columnLabel [0] ? columnLabel : U"?");
 		}
-		for (long irow = 1; irow <= thy rows -> size; irow ++) {
+		for (long irow = 1; irow <= thy rows.size; irow ++) {
 			char32 *stringValue = my rowLabels [irow];
-			TableRow row = static_cast <TableRow> (thy rows -> item [irow]);
+			TableRow row = thy rows.at [irow];
 			row -> cells [1]. string = Melder_dup (stringValue && stringValue [0] ? stringValue : U"?");
 			for (long icol = 1; icol <= my numberOfColumns; icol ++) {
 				double numericValue = my data [irow] [icol];
 				row -> cells [icol + 1]. string = Melder_dup (Melder_double (numericValue));
 			}
 		}
-		return thee.transfer();
+		return thee;
 	} catch (MelderError) {
 		Melder_throw (me, U": not converted to Table.");
 	}
@@ -1125,12 +1125,12 @@ void TableOfReal_writeToHeaderlessSpreadsheetFile (TableOfReal me, MelderFile fi
 		for (long icol = 1; icol <= my numberOfColumns; icol ++) {
 			MelderString_appendCharacter (& buffer, U'\t');
 			char32 *s = my columnLabels [icol];
-			MelderString_append (& buffer, s != NULL && s [0] != U'\0' ? s : U"?");
+			MelderString_append (& buffer, ( s && s [0] != U'\0' ? s : U"?" ));
 		}
 		MelderString_appendCharacter (& buffer, U'\n');
 		for (long irow = 1; irow <= my numberOfRows; irow ++) {
 			char32 *s = my rowLabels [irow];
-			MelderString_append (& buffer, s != NULL && s [0] != U'\0' ? s : U"?");
+			MelderString_append (& buffer, ( s && s [0] != U'\0' ? s : U"?" ));
 			for (long icol = 1; icol <= my numberOfColumns; icol ++) {
 				MelderString_appendCharacter (& buffer, U'\t');
 				double x = my data [irow] [icol];
@@ -1144,7 +1144,7 @@ void TableOfReal_writeToHeaderlessSpreadsheetFile (TableOfReal me, MelderFile fi
 	}
 }
 
-TableOfReal TableOfReal_readFromHeaderlessSpreadsheetFile (MelderFile file) {
+autoTableOfReal TableOfReal_readFromHeaderlessSpreadsheetFile (MelderFile file) {
 	try {
 		autostring32 string = MelderFile_readText (file);
 		long nrow, ncol, nelements;
@@ -1156,11 +1156,11 @@ TableOfReal TableOfReal_readFromHeaderlessSpreadsheetFile (MelderFile file) {
 		char32 *p = & string [0];
 		for (;;) {
 			char32 kar = *p++;
-			if (kar == '\n' || kar == '\0') break;
-			if (kar == ' ' || kar == '\t') continue;
+			if (kar == U'\n' || kar == U'\0') break;
+			if (kar == U' ' || kar == U'\t') continue;
 			ncol ++;
-			do { kar = *p++; } while (kar != ' ' && kar != '\t' && kar != '\n' && kar != '\0');
-			if (kar == '\n' || kar == '\0') break;
+			do { kar = *p++; } while (kar != U' ' && kar != U'\t' && kar != U'\n' && kar != U'\0');
+			if (kar == U'\n' || kar == U'\0') break;
 		}
 		ncol --;
 		if (ncol < 1) Melder_throw (U"No columns.");
@@ -1205,7 +1205,7 @@ TableOfReal TableOfReal_readFromHeaderlessSpreadsheetFile (MelderFile file) {
 				MelderString_appendCharacter (& buffer, *p);
 				p ++;
 			}
-			TableOfReal_setColumnLabel (me.peek(), icol, buffer.string);
+			TableOfReal_setColumnLabel (me.get(), icol, buffer.string);
 		}
 		for (long irow = 1; irow <= nrow; irow ++) {
 			while (*p == U' ' || *p == U'\t' || *p == U'\n') { Melder_assert (*p != U'\0'); p ++; }
@@ -1214,7 +1214,7 @@ TableOfReal TableOfReal_readFromHeaderlessSpreadsheetFile (MelderFile file) {
 				MelderString_appendCharacter (& buffer, *p);
 				p ++;
 			}
-			TableOfReal_setRowLabel (me.peek(), irow, buffer.string);
+			TableOfReal_setRowLabel (me.get(), irow, buffer.string);
 			for (long icol = 1; icol <= ncol; icol ++) {
 				while (*p == U' ' || *p == U'\t' || *p == U'\n') { Melder_assert (*p != U'\0'); p ++; }
 				MelderString_empty (& buffer);
@@ -1225,7 +1225,7 @@ TableOfReal TableOfReal_readFromHeaderlessSpreadsheetFile (MelderFile file) {
 				my data [irow] [icol] = Melder_atof (buffer.string);   // if cell contains a string, this will be 0
 			}
 		}
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"TableOfReal: tab-separated file ", file, U" not read.");
 	}
