@@ -4,19 +4,18 @@
  *
  * Copyright (C) 1992-2012,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* Data inherits from Thing. */
@@ -41,8 +40,8 @@ typedef struct structData_Description {
  */
 
 Thing_define (Daata, Thing) {
-	virtual void v_copy (Any data_to);
-	virtual bool v_equal (Any otherData);
+	virtual void v_copy (Daata data_to);
+	virtual bool v_equal (Daata otherData);
 	virtual Data_Description v_description () { return nullptr; }
 	virtual bool v_writable () { return true; }
 	virtual bool v_canWriteAsEncoding (int outputEncoding);
@@ -52,37 +51,37 @@ Thing_define (Daata, Thing) {
 	virtual void v_readBinary (FILE *f, int formatVersion);
 	virtual void v_repair () { }   // after reading Praat data files created by others
 	// methods for scripting:
-	virtual bool v_hasGetNrow      () { return false; }   virtual double        v_getNrow      ()                      { return NUMundefined; }
-	virtual bool v_hasGetNcol      () { return false; }   virtual double        v_getNcol      ()                      { return NUMundefined; }
-	virtual bool v_hasGetXmin      () { return false; }   virtual double        v_getXmin      ()                      { return NUMundefined; }
-	virtual bool v_hasGetXmax      () { return false; }   virtual double        v_getXmax      ()                      { return NUMundefined; }
-	virtual bool v_hasGetYmin      () { return false; }   virtual double        v_getYmin      ()                      { return NUMundefined; }
-	virtual bool v_hasGetYmax      () { return false; }   virtual double        v_getYmax      ()                      { return NUMundefined; }
-	virtual bool v_hasGetNx        () { return false; }   virtual double        v_getNx        ()                      { return NUMundefined; }
-	virtual bool v_hasGetNy        () { return false; }   virtual double        v_getNy        ()                      { return NUMundefined; }
-	virtual bool v_hasGetDx        () { return false; }   virtual double        v_getDx        ()                      { return NUMundefined; }
-	virtual bool v_hasGetDy        () { return false; }   virtual double        v_getDy        ()                      { return NUMundefined; }
-	virtual bool v_hasGetX         () { return false; }   virtual double        v_getX         (long ix)               { return NUMundefined; (void) ix;   }
-	virtual bool v_hasGetY         () { return false; }   virtual double        v_getY         (long iy)               { return NUMundefined; (void) iy;   }
-	virtual bool v_hasGetRowStr    () { return false; }   virtual const char32 *v_getRowStr    (long irow)             { return nullptr;      (void) irow; }
-	virtual bool v_hasGetColStr    () { return false; }   virtual const char32 *v_getColStr    (long icol)             { return nullptr;      (void) icol; }
-	virtual bool v_hasGetCell      () { return false; }   virtual double        v_getCell      ()                      { return NUMundefined; }
-	virtual bool v_hasGetCellStr   () { return false; }   virtual const char32 *v_getCellStr   ()                      { return nullptr; }
-	virtual bool v_hasGetVector    () { return false; }   virtual double        v_getVector    (long irow, long icol)  { return NUMundefined; (void) irow; (void) icol; }
-	virtual bool v_hasGetVectorStr () { return false; }   virtual const char32 *v_getVectorStr (long icol)             { return nullptr;      (void) icol; }
-	virtual bool v_hasGetMatrix    () { return false; }   virtual double        v_getMatrix    (long irow, long icol)  { return NUMundefined; (void) irow; (void) icol; }
-	virtual bool v_hasGetMatrixStr () { return false; }   virtual const char32 *v_getMatrixStr (long irow, long icol)  { return nullptr;      (void) irow; (void) icol; }
-	virtual bool v_hasGetFunction0 () { return false; }   virtual double        v_getFunction0 ()                      { return NUMundefined; }
-	virtual bool v_hasGetFunction1 () { return false; }   virtual double        v_getFunction1 (long irow, double x)   { return NUMundefined; (void) irow; (void) x; }
-	virtual bool v_hasGetFunction2 () { return false; }   virtual double        v_getFunction2 (double x, double y)    { return NUMundefined; (void) x; (void) y; }
-	virtual bool v_hasGetRowIndex  () { return false; }   virtual double        v_getRowIndex  (const char32 *rowLabel){ return NUMundefined; (void) rowLabel; }
-	virtual bool v_hasGetColIndex  () { return false; }   virtual double        v_getColIndex  (const char32 *colLabel){ return NUMundefined; (void) colLabel; }
+	virtual bool v_hasGetNrow      () { return false; }   virtual double        v_getNrow      ()                                 { return NUMundefined; }
+	virtual bool v_hasGetNcol      () { return false; }   virtual double        v_getNcol      ()                                 { return NUMundefined; }
+	virtual bool v_hasGetXmin      () { return false; }   virtual double        v_getXmin      ()                                 { return NUMundefined; }
+	virtual bool v_hasGetXmax      () { return false; }   virtual double        v_getXmax      ()                                 { return NUMundefined; }
+	virtual bool v_hasGetYmin      () { return false; }   virtual double        v_getYmin      ()                                 { return NUMundefined; }
+	virtual bool v_hasGetYmax      () { return false; }   virtual double        v_getYmax      ()                                 { return NUMundefined; }
+	virtual bool v_hasGetNx        () { return false; }   virtual double        v_getNx        ()                                 { return NUMundefined; }
+	virtual bool v_hasGetNy        () { return false; }   virtual double        v_getNy        ()                                 { return NUMundefined; }
+	virtual bool v_hasGetDx        () { return false; }   virtual double        v_getDx        ()                                 { return NUMundefined; }
+	virtual bool v_hasGetDy        () { return false; }   virtual double        v_getDy        ()                                 { return NUMundefined; }
+	virtual bool v_hasGetX         () { return false; }   virtual double        v_getX         (long /* ix */)                    { return NUMundefined; }
+	virtual bool v_hasGetY         () { return false; }   virtual double        v_getY         (long /* iy */)                    { return NUMundefined; }
+	virtual bool v_hasGetRowStr    () { return false; }   virtual const char32 *v_getRowStr    (long /* irow */)                  { return nullptr;      }
+	virtual bool v_hasGetColStr    () { return false; }   virtual const char32 *v_getColStr    (long /* icol */)                  { return nullptr;      }
+	virtual bool v_hasGetCell      () { return false; }   virtual double        v_getCell      ()                                 { return NUMundefined; }
+	virtual bool v_hasGetCellStr   () { return false; }   virtual const char32 *v_getCellStr   ()                                 { return nullptr; }
+	virtual bool v_hasGetVector    () { return false; }   virtual double        v_getVector    (long /* irow */, long /* icol */) { return NUMundefined; }
+	virtual bool v_hasGetVectorStr () { return false; }   virtual const char32 *v_getVectorStr (long /* icol */)                  { return nullptr;      }
+	virtual bool v_hasGetMatrix    () { return false; }   virtual double        v_getMatrix    (long /* irow */, long /* icol */) { return NUMundefined; }
+	virtual bool v_hasGetMatrixStr () { return false; }   virtual const char32 *v_getMatrixStr (long /* irow */, long /* icol */) { return nullptr;      }
+	virtual bool v_hasGetFunction0 () { return false; }   virtual double        v_getFunction0 ()                                 { return NUMundefined; }
+	virtual bool v_hasGetFunction1 () { return false; }   virtual double        v_getFunction1 (long /* irow */, double /* x */)  { return NUMundefined; }
+	virtual bool v_hasGetFunction2 () { return false; }   virtual double        v_getFunction2 (double /* x */, double /* y */)   { return NUMundefined; }
+	virtual bool v_hasGetRowIndex  () { return false; }   virtual double        v_getRowIndex  (const char32 * /* rowLabel */)    { return NUMundefined; }
+	virtual bool v_hasGetColIndex  () { return false; }   virtual double        v_getColIndex  (const char32 * /* colLabel */)    { return NUMundefined; }
 };
 
-template <class T> T* Data_copy (T* data) {
-	return static_cast <T*> (_Data_copy (data));
+template <class T> _Thing_auto<T> Data_copy (T* data) {
+	return _Data_copy (data).template static_cast_move <T> ();
 }
-Daata _Data_copy (Daata me);
+autoDaata _Data_copy (Daata me);
 /*
 	Message:
 		"return a deep copy of yourself."
@@ -99,7 +98,7 @@ bool Data_equal (Daata data1, Daata data2);
 		Data_equal (data, Data_copy (data)) should always return 1; the names are not compared.
 */
 
-typedef int (*Data_CompareFunction) (Any data1, Any data2);
+typedef MelderCompareHook<structDaata> Data_CompareHook;
 
 bool Data_canWriteAsEncoding (Daata me, int outputEncoding);
 /*
@@ -207,7 +206,7 @@ void Data_readText (Daata me, MelderReadText text, int formatVersion);
 		but is preferably the same as the format produced by the 'writeText' method.
 */
 
-Daata Data_readFromTextFile (MelderFile file);
+autoDaata Data_readFromTextFile (MelderFile file);
 /*
 	Message:
 		"try to read a Data as text from a file".
@@ -244,7 +243,7 @@ void Data_readBinary (Daata me, FILE *f, int formatVersion);
 		but is preferably the same as the format produced by the 'writeBinary' method.
 */
 
-Daata Data_readFromBinaryFile (MelderFile file);
+autoDaata Data_readFromBinaryFile (MelderFile file);
 /*
 	Message:
 		"try to read a Data as binary data from a file".
@@ -260,7 +259,9 @@ Daata Data_readFromBinaryFile (MelderFile file);
 		(plus those from Data_readBinary)
 */
 
-void Data_recognizeFileType (Any (*recognizer) (int nread, const char *header, MelderFile file));
+typedef autoDaata (*Data_FileTypeRecognizer) (int numberOfBytesRead, const char *header, MelderFile file);
+
+void Data_recognizeFileType (Data_FileTypeRecognizer recognizer);
 /*
 Purpose:
 	to make sure that a file can be read by Data_readFromFile.
@@ -286,11 +287,11 @@ Defining a file-type recognizer:
 	You define a file-type recognizer as in the following example,
 	which tries to identify and read a Sun audio file.
 	A Sun audio file should contain at least 24 bytes and start with the string ".snd":
-	Any Sound_sunAudioFileRecognizer (int nread, const char *header, const char *fileName) {
+	autoDaata Sound_sunAudioFileRecognizer (int nread, const char *header, MelderFile file) {
 		if (nread >= 24 && strnequ (& header [0], ".snd", 4))
-			return Sound_readFromSunAudioFile (fileName);
+			return Sound_readFromSunAudioFile (file);
 		else
-			return nullptr;
+			return autoDaata ();
 	}
 	From this example, we see that if the file is recognized, it should be read immediately,
 	and the resulting object (always a descendant of class Data) should be returned.
@@ -302,7 +303,7 @@ Registering a file-type recognizer:
 	After this, Data_readFromFile is able to read Sun audio files.
 */
 
-Daata Data_readFromFile (MelderFile file);
+autoDaata Data_readFromFile (MelderFile file);
 /*
 Purpose:
 	to read a file with data of any kind.
@@ -320,6 +321,10 @@ Behaviour:
 
 extern structMelderDir Data_directoryBeingRead;
 
+int Data_publish (autoDaata me);
+
+void Data_setPublishProc (int (*publish) (autoDaata));
+
 /* The values of 'type' in struct descriptions. */
 
 #define bytewa  1
@@ -344,7 +349,7 @@ extern structMelderDir Data_directoryBeingRead;
 #define widgetwa  19
 #define objectwa  20
 #define autoobjectwa  21
-#define collectionwa  22
+#define collectionofwa  22
 #define autocollectionwa  23
 #define inheritwa  24
 
