@@ -4,33 +4,32 @@
  *
  * Copyright (C) 2009-2011,2012,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Editor.h"
 
 Thing_define (DemoEditor, Editor) {
 	GuiDrawingArea drawingArea;
-	Graphics graphics;
+	autoGraphics graphics;
 	void *praatPicture;
 	bool clicked, keyPressed, shiftKeyPressed, commandKeyPressed, optionKeyPressed, extraControlKeyPressed;
 	long x, y;
 	char32 key;
 	bool waitingForInput, userWantsToClose, fullScreen;
 
-	void v_destroy ()
+	void v_destroy () noexcept
 		override;
 	void v_info ()
 		override;
@@ -49,7 +48,7 @@ Thing_define (DemoEditor, Editor) {
 };
 
 void DemoEditor_init (DemoEditor me);
-DemoEditor DemoEditor_create ();
+autoDemoEditor DemoEditor_create ();
 
 void Demo_open ();
 void Demo_close ();
