@@ -4,19 +4,18 @@
  *
  * Copyright (C) 1992-2012,2013,2014,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Collection.h"
@@ -33,39 +32,55 @@ Thing_define (EditorMenu, Thing) {
 	Editor d_editor;
 	const char32 *menuTitle;
 	GuiMenu menuWidget;
-	Ordered commands;
+	OrderedOf<structEditorCommand> commands;
 
-	void v_destroy ()
+	void v_destroy () noexcept
 		override;
 };
 
+typedef MelderCallback <void, structEditor, EditorCommand, UiForm, int /*narg*/, Stackel /*args*/, const char32 *, Interpreter> EditorCommandCallback;
+
 Thing_define (EditorCommand, Thing) {
 	Editor d_editor;
 	EditorMenu menu;
 	const char32 *itemTitle;
 	GuiMenuItem itemWidget;
-	void (*commandCallback) (Editor editor_me, EditorCommand cmd, UiForm sendingForm, int narg, Stackel args, const char32 *sendingString, Interpreter interpreter);
+	EditorCommandCallback commandCallback;
 	const char32 *script;
-	UiForm d_uiform;
+	autoUiForm d_uiform;
 
-	void v_destroy ()
+	void v_destroy () noexcept
 		override;
 };
 
+typedef MelderCallback <void, structEditor> Editor_DataChangedCallback;
+typedef MelderCallback <void, structEditor> Editor_DestructionCallback;
+
+/*
+	The following doesn't work yet:
+*/
+//typedef MelderCallback <void, structEditor, autoDaata /* publication */> Editor_PublicationCallback;
+/*
+	because the autoDaata argument tends to be called with .move().
+	Therefore we have the stupider version:
+*/
+typedef void (*Editor_PublicationCallback) (Editor, autoDaata /* publication */);
+
 Thing_define (Editor, Thing) {
 	GuiWindow d_windowForm;
 	GuiMenuItem undoButton, searchButton;
-	Ordered menus;
-	Daata data, previousData;   // the data that can be displayed and edited
+	OrderedOf<structEditorMenu> menus;
+	Daata data;   // the data that can be displayed and edited
+	autoDaata previousData;   // the data that can be displayed and edited
 	bool d_ownData;
 	char32 undoText [100];
 	Graphics pictureGraphics;
-	void (*d_dataChangedCallback) (Editor me, void *closure);                    void *d_dataChangedClosure;
-	void (*d_destructionCallback) (Editor me, void *closure);                    void *d_destructionClosure;
-	void (*d_publicationCallback) (Editor me, void *closure, Daata publication); void *d_publicationClosure;
+	Editor_DataChangedCallback d_dataChangedCallback;
+	Editor_DestructionCallback d_destructionCallback;
+	Editor_PublicationCallback d_publicationCallback;
 	const char *callbackSocket;
 
-	void v_destroy ()
+	void v_destroy () noexcept
 		override;
 	void v_info ()
 		override;
@@ -98,16 +113,14 @@ Thing_define (Editor, Thing) {
 	#include "Editor_prefs.h"
 };
 
-GuiMenuItem EditorMenu_addCommand (EditorMenu me, const char32 *itemTitle /* cattable */, long flags,
-	void (*commandCallback) (Editor me, EditorCommand, UiForm, int, Stackel, const char32 *, Interpreter));
+GuiMenuItem EditorMenu_addCommand (EditorMenu me, const char32 *itemTitle /* cattable */, long flags, EditorCommandCallback commandCallback);
 GuiMenuItem EditorCommand_getItemWidget (EditorCommand me);
 
 EditorMenu Editor_addMenu (Editor me, const char32 *menuTitle, long flags);
 GuiObject EditorMenu_getMenuWidget (EditorMenu me);
 
 #define Editor_HIDDEN  (1 << 14)
-GuiMenuItem Editor_addCommand (Editor me, const char32 *menuTitle, const char32 *itemTitle, long flags,
-	void (*commandCallback) (Editor me, EditorCommand cmd, UiForm sendingForm, int narg, Stackel args, const char32 *sendingString, Interpreter interpreter));
+GuiMenuItem Editor_addCommand (Editor me, const char32 *menuTitle, const char32 *itemTitle, long flags, EditorCommandCallback commandCallback);
 GuiMenuItem Editor_addCommandScript (Editor me, const char32 *menuTitle, const char32 *itemTitle, long flags,
 	const char32 *script);
 void Editor_setMenuSensitive (Editor me, const char32 *menu, int sensitive);
@@ -130,7 +143,7 @@ inline static void Editor_dataChanged (Editor me)
 	{
 		my v_dataChanged ();
 	}
-inline static void Editor_setDataChangedCallback (Editor me, void (*dataChangedCallback) (Editor me, void *closure), void *dataChangedClosure)
+inline static void Editor_setDataChangedCallback (Editor me, Editor_DataChangedCallback dataChangedCallback)
 	/*
 	 * Message from boss: "notify me by calling this dataChangedCallback every time your data is changed from *inside* yourself."
 	 *
@@ -141,7 +154,6 @@ inline static void Editor_setDataChangedCallback (Editor me, void (*dataChangedC
 	 */
 	{
 		my d_dataChangedCallback = dataChangedCallback;
-		my d_dataChangedClosure = dataChangedClosure;
 	}
 inline static void Editor_broadcastDataChanged (Editor me)
 	/*
@@ -151,19 +163,18 @@ inline static void Editor_broadcastDataChanged (Editor me)
 	 */
 	{
 		if (my d_dataChangedCallback)
-			my d_dataChangedCallback (me, my d_dataChangedClosure);
+			my d_dataChangedCallback (me);
 	}
-inline static void Editor_setDestructionCallback (Editor me, void (*destructionCallback) (Editor me, void *closure), void *destructionClosure)
+inline static void Editor_setDestructionCallback (Editor me, Editor_DestructionCallback destructionCallback)
 	/*
-	 * Message from boss: "notify me by calling this destructionCallback every time you destroy yourself."
+	 * Message from observer: "notify me by calling this destructionCallback every time you destroy yourself."
 	 *
 	 * In Praat, "destroying yourself" typically happens when the user closes the editor window
 	 * or when an object that is being viewed in an editor window is "Remove"d.
-	 * Typically, the boss will (in the destructionCallback it installed) remove all dangling references to this editor.
+	 * Typically, the observer will (in the destructionCallback it installed) remove all dangling references to this editor.
 	 */
 	{
 		my d_destructionCallback = destructionCallback;
-		my d_destructionClosure = destructionClosure;
 	}
 inline static void Editor_broadcastDestruction (Editor me)
 	/*
@@ -173,9 +184,9 @@ inline static void Editor_broadcastDestruction (Editor me)
 	 */
 	{
 		if (my d_destructionCallback)
-			my d_destructionCallback (me, my d_destructionClosure);
+			my d_destructionCallback (me);
 	}
-inline static void Editor_setPublicationCallback (Editor me, void (*publicationCallback) (Editor me, void *closure, Daata publication), void *publicationClosure)
+inline static void Editor_setPublicationCallback (Editor me, Editor_PublicationCallback publicationCallback)
 	/*
 	 * Message from boss: "notify me by calling this publicationCallback every time you have a piece of data to publish."
 	 *
@@ -186,9 +197,8 @@ inline static void Editor_setPublicationCallback (Editor me, void (*publicationC
 	 */
 	{
 		my d_publicationCallback = publicationCallback;
-		my d_publicationClosure = publicationClosure;
 	}
-inline static void Editor_broadcastPublication (Editor me, Daata publication)
+inline static void Editor_broadcastPublication (Editor me, autoDaata publication)
 	/*
 	 * Message to boss: "I have a piece of data for you to publish."
 	 *
@@ -200,7 +210,7 @@ inline static void Editor_broadcastPublication (Editor me, Daata publication)
 	 */
 	{
 		if (my d_publicationCallback)
-			my d_publicationCallback (me, my d_publicationClosure, publication);
+			my d_publicationCallback (me, publication.move());
 	}
 
 /***** For inheritors. *****/
@@ -229,7 +239,7 @@ void Editor_init (Editor me, int x, int y , int width, int height,
 
 void Editor_save (Editor me, const char32 *text);   // for Undo
 
-UiForm UiForm_createE (EditorCommand cmd, const char32 *title, const char32 *invokingButtonTitle, const char32 *helpTitle);
+autoUiForm UiForm_createE (EditorCommand cmd, const char32 *title, const char32 *invokingButtonTitle, const char32 *helpTitle);
 void UiForm_parseStringE (EditorCommand cmd, int narg, Stackel args, const char32 *arguments, Interpreter interpreter);
 UiForm UiOutfile_createE (EditorCommand cmd, const char32 *title, const char32 *invokingButtonTitle, const char32 *helpTitle);
 UiForm UiInfile_createE (EditorCommand cmd, const char32 *title, const char32 *invokingButtonTitle, const char32 *helpTitle);
