@@ -2,21 +2,20 @@
 #define _GraphicsP_h_
 /* GraphicsP.h
  *
- * Copyright (C) 1992-2011,2012,2013,2014,2015 Paul Boersma, 2013 Tom Naughton
+ * Copyright (C) 1992-2011,2012,2013,2014,2015,2016 Paul Boersma, 2013 Tom Naughton
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Graphics.h"
@@ -25,12 +24,6 @@
 #if defined (_WIN32)
 	#include <windowsx.h>
 	#include <gdiplus.h>
-#elif defined (macintosh)
-	#include "macport_on.h"
-    #if useCarbon
-        #include <Carbon/Carbon.h>
-    #endif
-	#include "macport_off.h"
 #endif
 
 void Graphics_init (Graphics me, int resolution);
@@ -73,11 +66,7 @@ Thing_define (GraphicsScreen, Graphics) {
 		HBITMAP d_gdiBitmap;
 		Gdiplus::Bitmap *d_gdiplusBitmap;
 	#elif defined (macintosh)
-		#if useCarbon
-			GrafPtr d_macPort;
-		#else
-			NSView *d_macView;
-		#endif
+		NSView *d_macView;
 		int d_macFont, d_macStyle;
 		int d_depth;
 		RGBColor d_macColour;
@@ -85,7 +74,7 @@ Thing_define (GraphicsScreen, Graphics) {
 		CGContextRef d_macGraphicsContext;
 	#endif
 
-	void v_destroy ()
+	void v_destroy () noexcept
 		override;
 	void v_polyline (long numberOfPoints, double *xyDC, bool close)
 		override;
@@ -153,7 +142,7 @@ Thing_define (GraphicsPostscript, Graphics) {
 	int pageNumber, lastSize;
 	bool job, eps;
 
-	void v_destroy ()
+	void v_destroy () noexcept
 		override;
 	void v_polyline (long numberOfPoints, double *xyDC, bool close)
 		override;
