@@ -1,20 +1,19 @@
 /* GuiDrawingArea.cpp
  *
- * Copyright (C) 1993-2012,2013,2015 Paul Boersma, 2008 Stefan de Konink, 2010 Franz Brausse, 2013 Tom Naughton
+ * Copyright (C) 1993-2012,2013,2015,2016 Paul Boersma, 2008 Stefan de Konink, 2010 Franz Brausse, 2013 Tom Naughton
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "GuiP.h"
@@ -25,8 +24,6 @@
 
 Thing_implement (GuiDrawingArea, GuiControl, 0);
 
-#undef iam
-#define iam(x)  x me = (x) void_me
 #if win || mac
 	#define iam_drawingarea \
 		Melder_assert (widget -> widgetClass == xmDrawingAreaWidgetClass); \
@@ -51,7 +48,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 		// first place?? Additionally this causes even more flickering
 		//gdk_window_clear_area ((GTK_WIDGET (widget)) -> window, expose->area.x, expose->area.y, expose->area.width, expose->area.height);
 		if (my d_exposeCallback) {
-			struct structGuiDrawingAreaExposeEvent event = { me, 0 };
+			struct structGuiDrawingArea_ExposeEvent event { me, 0 };
 			event. x = expose -> area. x;
 			event. y = expose -> area. y;
 			event. width = expose -> area. width;
@@ -80,7 +77,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 		iam (GuiDrawingArea);
 		if (e -> type != GDK_BUTTON_PRESS) return false;
 		if (my d_clickCallback) {
-			struct structGuiDrawingAreaClickEvent event = { me, 0 };
+			struct structGuiDrawingArea_ClickEvent event { me, 0 };
 			event. button = ((GdkEventButton *) e) -> button;
 			event. x = ((GdkEventButton *) e) -> x;
 			event. y = ((GdkEventButton *) e) -> y;
@@ -98,7 +95,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 		iam (GuiDrawingArea);
 		trace (U"begin");
 		if (my d_keyCallback && gevent -> type == GDK_KEY_PRESS) {
-			struct structGuiDrawingAreaKeyEvent event = { me, 0 };
+			struct structGuiDrawingArea_KeyEvent event { me, 0 };
 			GdkEventKey *gkeyEvent = (GdkEventKey *) gevent;
 			event. key = gkeyEvent -> keyval;
 			/*
@@ -128,7 +125,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 	static gboolean _GuiGtkDrawingArea_resizeCallback (GuiObject widget, GtkAllocation *allocation, gpointer void_me) {
 		iam (GuiDrawingArea);
 		if (my d_resizeCallback) {
-			struct structGuiDrawingAreaResizeEvent event = { me, 0 };
+			struct structGuiDrawingArea_ResizeEvent event { me, 0 };
 			trace (U"drawingArea resized to ", allocation -> width, U" x ", allocation -> height, U".");
 			event. width = allocation -> width;
 			event. height = allocation -> height;
@@ -170,7 +167,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 		trace (U"deleting a drawing area");
 		[super dealloc];
 	}
-	- (GuiThing) userData {
+	- (GuiThing) getUserData {
 		return d_userData;
 	}
 	- (void) setUserData: (GuiThing) userData {
@@ -179,7 +176,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 	- (void) resizeCallback: (NSRect) rect {
 		GuiDrawingArea me = (GuiDrawingArea) d_userData;
 		if (me && my d_resizeCallback) {
-			struct structGuiDrawingAreaResizeEvent event = { me, 0 };
+			struct structGuiDrawingArea_ResizeEvent event { me, 0 };
 			event. width = rect. size. width;
 			event. height = rect. size. height;
 			try {
@@ -198,7 +195,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 			_inited = YES;
 		}
 		if (my d_exposeCallback) {
-			struct structGuiDrawingAreaExposeEvent event = { me };
+			struct structGuiDrawingArea_ExposeEvent event { me };
 			try {
 				my d_exposeCallback (my d_exposeBoss, & event);
 			} catch (MelderError) {
@@ -223,7 +220,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 		 * the key focus from the Search field, a situation that cannot hurt).
 		 */
 		GuiDrawingArea me = (GuiDrawingArea) d_userData;
-		return my d_keyCallback != nullptr;
+		return !! my d_keyCallback;
 	}
 	- (void) mouseEntered: (NSEvent *) nsEvent {
 		(void) nsEvent;
@@ -237,7 +234,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 	 //   [self becomeFirstResponder];
 		GuiDrawingArea me = (GuiDrawingArea) d_userData;
 		if (my d_clickCallback) {
-			struct structGuiDrawingAreaClickEvent event = { me, 0 };
+			struct structGuiDrawingArea_ClickEvent event { me, 0 };
 			NSPoint local_point = [self   convertPoint: [nsEvent locationInWindow]   fromView: nil];
 			event. x = local_point. x;
 			//event. y = [self frame]. size. height - local_point. y;
@@ -289,7 +286,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 	- (void) keyDown: (NSEvent *) nsEvent {
 		GuiDrawingArea me = (GuiDrawingArea) d_userData;
 		if (my d_keyCallback) {
-			struct structGuiDrawingAreaKeyEvent event = { me, 0 };
+			struct structGuiDrawingArea_KeyEvent event { me, 0 };
 			event. key = [[nsEvent charactersIgnoringModifiers]   characterAtIndex: 0];
 			if (event. key == NSLeftArrowFunctionKey)  event. key = 0x2190;
 			if (event. key == NSRightArrowFunctionKey) event. key = 0x2192;
@@ -319,7 +316,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 		PAINTSTRUCT paintStruct;
 		BeginPaint (widget -> window, & paintStruct);
 		if (my d_exposeCallback) {
-			struct structGuiDrawingAreaExposeEvent event = { me };
+			struct structGuiDrawingArea_ExposeEvent event { me };
 			try {
 				my d_exposeCallback (my d_exposeBoss, & event);
 			} catch (MelderError) {
@@ -331,7 +328,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 	void _GuiWinDrawingArea_handleClick (GuiObject widget, int x, int y) {
 		iam_drawingarea;
 		if (my d_clickCallback) {
-			struct structGuiDrawingAreaClickEvent event = { me, 0 };
+			struct structGuiDrawingArea_ClickEvent event { me, 0 };
 			event. x = x;
 			event. y = y;
 			event. shiftKeyPressed = GetKeyState (VK_SHIFT) < 0;
@@ -347,7 +344,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 	void _GuiWinDrawingArea_handleKey (GuiObject widget, TCHAR kar) {   // TODO: event?
 		iam_drawingarea;
 		if (my d_keyCallback) {
-			struct structGuiDrawingAreaKeyEvent event = { me, 0 };
+			struct structGuiDrawingArea_KeyEvent event { me, 0 };
 			event. key = kar;
 			if (event. key == VK_RETURN) event. key = 10;
 			if (event. key == VK_LEFT)  event. key = 0x2190;
@@ -367,80 +364,7 @@ Thing_implement (GuiDrawingArea, GuiControl, 0);
 	void _GuiWinDrawingArea_shellResize (GuiObject widget) {
 		iam_drawingarea;
 		if (my d_resizeCallback) {
-			struct structGuiDrawingAreaResizeEvent event = { me };
-			event. width = widget -> width;
-			event. height = widget -> height;
-			try {
-				my d_resizeCallback (my d_resizeBoss, & event);
-			} catch (MelderError) {
-				Melder_flushError (U"Window resizing not completely handled.");
-			}
-		}
-	}
-#elif mac
-	void _GuiMacDrawingArea_destroy (GuiObject widget) {
-		iam_drawingarea;
-		forget (me);   // NOTE: my widget is not destroyed here
-	}
-	void _GuiMacDrawingArea_update (GuiObject widget) {
-		iam_drawingarea;
-		if (my d_exposeCallback) {
-			struct structGuiDrawingAreaExposeEvent event = { me };
-			_GuiMac_clipOnParent (widget);
-			try {
-				my d_exposeCallback (my d_exposeBoss, & event);
-			} catch (MelderError) {
-				Melder_flushError (U"Redrawing not completed");
-			}
-			GuiMac_clipOff ();
-		}
-	}
-	void _GuiMacDrawingArea_handleClick (GuiObject widget, EventRecord *macEvent) {
-		iam_drawingarea;
-		if (my d_clickCallback) {
-			struct structGuiDrawingAreaClickEvent event = { me, 0 };
-			event. x = macEvent -> where. h;
-			event. y = macEvent -> where. v;
-			event. shiftKeyPressed = (macEvent -> modifiers & shiftKey) != 0;
-			event. commandKeyPressed = (macEvent -> modifiers & cmdKey) != 0;
-			event. optionKeyPressed = (macEvent -> modifiers & optionKey) != 0;
-			event. extraControlKeyPressed = (macEvent -> modifiers & controlKey) != 0;
-			try {
-				my d_clickCallback (my d_clickBoss, & event);
-			} catch (MelderError) {
-				Melder_flushError (U"Mouse click not completely handled.");
-			}
-		}
-	}
-	bool _GuiMacDrawingArea_tryToHandleKey (GuiObject widget, EventRecord *macEvent) {
-		iam_drawingarea;
-		if (my d_keyCallback) {
-			struct structGuiDrawingAreaKeyEvent event = { me, 0 };
-			event. key = macEvent -> message & charCodeMask;
-			//if (event. key == 9) event. key = 0x2324;   // tab
-			if (event. key == 13) event. key = 10;   // return -> newline
-			if (event. key == 27) event. key = 0x238B;
-			if (event. key == 28) event. key = 0x2190;
-			if (event. key == 29) event. key = 0x2192;
-			if (event. key == 30) event. key = 0x2191;
-			if (event. key == 31) event. key = 0x2193;
-			event. shiftKeyPressed = (macEvent -> modifiers & shiftKey) != 0;
-			event. commandKeyPressed = (macEvent -> modifiers & cmdKey) != 0;
-			event. optionKeyPressed = (macEvent -> modifiers & optionKey) != 0;
-			event. extraControlKeyPressed = (macEvent -> modifiers & controlKey) != 0;
-			try {
-				my d_keyCallback (my d_keyBoss, & event);
-			} catch (MelderError) {
-				Melder_flushError (U"Key press not completely handled.");
-			}
-			return true;
-		}
-		return false;
-	}
-	void _GuiMacDrawingArea_shellResize (GuiObject widget) {
-		iam_drawingarea;
-		if (my d_resizeCallback) {
-			struct structGuiDrawingAreaResizeEvent event = { me, 0 };
+			struct structGuiDrawingArea_ResizeEvent event { me };
 			event. width = widget -> width;
 			event. height = widget -> height;
 			try {
@@ -488,13 +412,13 @@ static gboolean _guiGtkDrawingArea_swipeCallback (GuiObject w, GdkEventScroll *e
 #endif
 
 GuiDrawingArea GuiDrawingArea_create (GuiForm parent, int left, int right, int top, int bottom,
-	void (*exposeCallback) (void *boss, GuiDrawingAreaExposeEvent event),
-	void (*clickCallback)  (void *boss, GuiDrawingAreaClickEvent  event),
-	void (*keyCallback)    (void *boss, GuiDrawingAreaKeyEvent    event),
-	void (*resizeCallback) (void *boss, GuiDrawingAreaResizeEvent event), void *boss,
+	GuiDrawingArea_ExposeCallback exposeCallback,
+	GuiDrawingArea_ClickCallback clickCallback,
+	GuiDrawingArea_KeyCallback keyCallback,
+	GuiDrawingArea_ResizeCallback resizeCallback, Thing boss,
 	uint32 /* flags */)
 {
-	GuiDrawingArea me = Thing_new (GuiDrawingArea);
+	autoGuiDrawingArea me = Thing_new (GuiDrawingArea);
 	my d_shell = parent -> d_shell;
 	my d_parent = parent;
 	my d_exposeCallback = exposeCallback;
@@ -513,50 +437,46 @@ GuiDrawingArea GuiDrawingArea_create (GuiForm parent, int left, int right, int t
 			| GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
 			| GDK_POINTER_MOTION_HINT_MASK);                    // receive fewer motion notify events (the cb might take time)
 		gtk_widget_set_events (GTK_WIDGET (my d_widget), mask);
-		g_signal_connect (G_OBJECT (my d_widget), "expose-event",         G_CALLBACK (_GuiGtkDrawingArea_exposeCallback),  me);
-		g_signal_connect (G_OBJECT (my d_widget), "destroy",              G_CALLBACK (_GuiGtkDrawingArea_destroyCallback), me);
-		g_signal_connect (G_OBJECT (my d_widget), "button-press-event",   G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me);
-		g_signal_connect (G_OBJECT (my d_widget), "button-release-event", G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me);
-		g_signal_connect (G_OBJECT (my d_widget), "motion-notify-event",  G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me);
+		g_signal_connect (G_OBJECT (my d_widget), "expose-event",         G_CALLBACK (_GuiGtkDrawingArea_exposeCallback),  me.get());
+		g_signal_connect (G_OBJECT (my d_widget), "destroy",              G_CALLBACK (_GuiGtkDrawingArea_destroyCallback), me.get());
+		g_signal_connect (G_OBJECT (my d_widget), "button-press-event",   G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me.get());
+		g_signal_connect (G_OBJECT (my d_widget), "button-release-event", G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me.get());
+		g_signal_connect (G_OBJECT (my d_widget), "motion-notify-event",  G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me.get());
 		if (parent) {
 			Melder_assert (parent -> d_widget);
 			g_signal_connect (G_OBJECT (gtk_widget_get_toplevel (GTK_WIDGET (parent -> d_widget))), "key-press-event",
-				G_CALLBACK (_GuiGtkDrawingArea_keyCallback), me);
+				G_CALLBACK (_GuiGtkDrawingArea_keyCallback), me.get());
 		}
-		g_signal_connect (G_OBJECT (my d_widget), "size-allocate", G_CALLBACK (_GuiGtkDrawingArea_resizeCallback), me);
+		g_signal_connect (G_OBJECT (my d_widget), "size-allocate", G_CALLBACK (_GuiGtkDrawingArea_resizeCallback), me.get());
 
-		_GuiObject_setUserData (my d_widget, me);
+		_GuiObject_setUserData (my d_widget, me.get());
 		my v_positionInForm (my d_widget, left, right, top, bottom, parent);
 		gtk_widget_set_double_buffered (GTK_WIDGET (my d_widget), false);
 	#elif cocoa
 		GuiCocoaDrawingArea *drawingArea = [[GuiCocoaDrawingArea alloc] init];
 		my d_widget = (GuiObject) drawingArea;
 		my v_positionInForm (my d_widget, left, right, top, bottom, parent);
-		[drawingArea   setUserData: me];
+		[drawingArea   setUserData: me.get()];
 		if (keyCallback) {
 			[[drawingArea window]   makeFirstResponder: drawingArea];   // needed in DemoWindow
 		}
     #elif win
 		my d_widget = _Gui_initializeWidget (xmDrawingAreaWidgetClass, parent -> d_widget, U"drawingArea");
-		_GuiObject_setUserData (my d_widget, me);
+		_GuiObject_setUserData (my d_widget, me.get());
 		my d_widget -> window = CreateWindowEx (0, Melder_peek32toW (_GuiWin_getDrawingAreaClassName ()), L"drawingArea",
 			WS_CHILD | WS_BORDER | WS_CLIPSIBLINGS,
 			my d_widget -> x, my d_widget -> y, my d_widget -> width, my d_widget -> height, my d_widget -> parent -> window, nullptr, theGui.instance, nullptr);
 		SetWindowLongPtr (my d_widget -> window, GWLP_USERDATA, (LONG_PTR) my d_widget);
 		my v_positionInForm (my d_widget, left, right, top, bottom, parent);
-	#elif mac
-		my d_widget = _Gui_initializeWidget (xmDrawingAreaWidgetClass, parent -> d_widget, U"drawingArea");
-		_GuiObject_setUserData (my d_widget, me);
-		my v_positionInForm (my d_widget, left, right, top, bottom, parent);
 	#endif
-	return me;
+	return me.releaseToAmbiguousOwner();
 }
 
 GuiDrawingArea GuiDrawingArea_createShown (GuiForm parent, int left, int right, int top, int bottom,
-	void (*exposeCallback) (void *boss, GuiDrawingAreaExposeEvent event),
-	void (*clickCallback) (void *boss, GuiDrawingAreaClickEvent event),
-	void (*keyCallback) (void *boss, GuiDrawingAreaKeyEvent event),
-	void (*resizeCallback) (void *boss, GuiDrawingAreaResizeEvent event), void *boss,
+	GuiDrawingArea_ExposeCallback exposeCallback,
+	GuiDrawingArea_ClickCallback clickCallback,
+	GuiDrawingArea_KeyCallback keyCallback,
+	GuiDrawingArea_ResizeCallback resizeCallback, Thing boss,
 	uint32 flags)
 {
 	GuiDrawingArea me = GuiDrawingArea_create (parent, left, right, top, bottom, exposeCallback, clickCallback, keyCallback, resizeCallback, boss, flags);
@@ -565,13 +485,13 @@ GuiDrawingArea GuiDrawingArea_createShown (GuiForm parent, int left, int right,
 }
 
 GuiDrawingArea GuiDrawingArea_create (GuiScrolledWindow parent, int width, int height,
-	void (*exposeCallback) (void *boss, GuiDrawingAreaExposeEvent event),
-	void (*clickCallback) (void *boss, GuiDrawingAreaClickEvent event),
-	void (*keyCallback) (void *boss, GuiDrawingAreaKeyEvent event),
-	void (*resizeCallback) (void *boss, GuiDrawingAreaResizeEvent event), void *boss,
+	GuiDrawingArea_ExposeCallback exposeCallback,
+	GuiDrawingArea_ClickCallback clickCallback,
+	GuiDrawingArea_KeyCallback keyCallback,
+	GuiDrawingArea_ResizeCallback resizeCallback, Thing boss,
 	uint32 /* flags */)
 {
-	GuiDrawingArea me = Thing_new (GuiDrawingArea);
+	autoGuiDrawingArea me = Thing_new (GuiDrawingArea);
 	my d_shell = parent -> d_shell;
 	my d_parent = parent;
 	my d_exposeCallback = exposeCallback;
@@ -590,45 +510,41 @@ GuiDrawingArea GuiDrawingArea_create (GuiScrolledWindow parent, int width, int h
 			| GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
 			| GDK_POINTER_MOTION_HINT_MASK);                    // receive fewer motion notify events (the cb might take time)
 		gtk_widget_set_events (GTK_WIDGET (my d_widget), mask);
-		g_signal_connect (G_OBJECT (my d_widget), "expose-event",         G_CALLBACK (_GuiGtkDrawingArea_exposeCallback),  me);
-		g_signal_connect (G_OBJECT (my d_widget), "destroy",              G_CALLBACK (_GuiGtkDrawingArea_destroyCallback), me);
-		g_signal_connect (G_OBJECT (my d_widget), "button-press-event",   G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me);
-		g_signal_connect (G_OBJECT (my d_widget), "button-release-event", G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me);
-		g_signal_connect (G_OBJECT (my d_widget), "motion-notify-event",  G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me);
+		g_signal_connect (G_OBJECT (my d_widget), "expose-event",         G_CALLBACK (_GuiGtkDrawingArea_exposeCallback),  me.get());
+		g_signal_connect (G_OBJECT (my d_widget), "destroy",              G_CALLBACK (_GuiGtkDrawingArea_destroyCallback), me.get());
+		g_signal_connect (G_OBJECT (my d_widget), "button-press-event",   G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me.get());
+		g_signal_connect (G_OBJECT (my d_widget), "button-release-event", G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me.get());
+		g_signal_connect (G_OBJECT (my d_widget), "motion-notify-event",  G_CALLBACK (_GuiGtkDrawingArea_clickCallback),   me.get());
 		if (parent) {
 			g_signal_connect (G_OBJECT (gtk_widget_get_toplevel (GTK_WIDGET (parent -> d_widget))), "key-press-event",
-				G_CALLBACK (_GuiGtkDrawingArea_keyCallback), me);
+				G_CALLBACK (_GuiGtkDrawingArea_keyCallback), me.get());
 		}
-		g_signal_connect (G_OBJECT (my d_widget), "size-allocate", G_CALLBACK (_GuiGtkDrawingArea_resizeCallback), me);
-		_GuiObject_setUserData (my d_widget, me);
+		g_signal_connect (G_OBJECT (my d_widget), "size-allocate", G_CALLBACK (_GuiGtkDrawingArea_resizeCallback), me.get());
+		_GuiObject_setUserData (my d_widget, me.get());
 		my v_positionInScrolledWindow (my d_widget, width, height, parent);
 		gtk_widget_set_double_buffered (GTK_WIDGET (my d_widget), false);
 	#elif cocoa
 		GuiCocoaDrawingArea *drawingArea = [[GuiCocoaDrawingArea alloc] init];
 		my d_widget = (GuiObject) drawingArea;
 		my v_positionInScrolledWindow (my d_widget, width, height, parent);
-		[drawingArea setUserData: me];
+		[drawingArea setUserData: me.get()];
     #elif win
 		my d_widget = _Gui_initializeWidget (xmDrawingAreaWidgetClass, parent -> d_widget, U"drawingArea");
-		_GuiObject_setUserData (my d_widget, me);
+		_GuiObject_setUserData (my d_widget, me.get());
 		my d_widget -> window = CreateWindowEx (0, Melder_peek32toW (_GuiWin_getDrawingAreaClassName ()), L"drawingArea",
 			WS_CHILD | WS_BORDER | WS_CLIPSIBLINGS,
 			0, 0, my d_widget -> width, my d_widget -> height, my d_widget -> parent -> window, nullptr, theGui.instance, nullptr);
 		SetWindowLongPtr (my d_widget -> window, GWLP_USERDATA, (LONG_PTR) my d_widget);
 		my v_positionInScrolledWindow (my d_widget, width, height, parent);
-	#elif mac
-		my d_widget = _Gui_initializeWidget (xmDrawingAreaWidgetClass, parent -> d_widget, U"drawingArea");
-		_GuiObject_setUserData (my d_widget, me);
-		my v_positionInScrolledWindow (my d_widget, width, height, parent);
 	#endif
-	return me;
+	return me.releaseToAmbiguousOwner();
 }
 
 GuiDrawingArea GuiDrawingArea_createShown (GuiScrolledWindow parent, int width, int height,
-	void (*exposeCallback) (void *boss, GuiDrawingAreaExposeEvent event),
-	void (*clickCallback) (void *boss, GuiDrawingAreaClickEvent event),
-	void (*keyCallback) (void *boss, GuiDrawingAreaKeyEvent event),
-	void (*resizeCallback) (void *boss, GuiDrawingAreaResizeEvent event), void *boss,
+	GuiDrawingArea_ExposeCallback exposeCallback,
+	GuiDrawingArea_ClickCallback clickCallback,
+	GuiDrawingArea_KeyCallback keyCallback,
+	GuiDrawingArea_ResizeCallback resizeCallback, Thing boss,
 	uint32 flags)
 {
 	GuiDrawingArea me = GuiDrawingArea_create (parent, width, height, exposeCallback, clickCallback, keyCallback, resizeCallback, boss, flags);
@@ -644,17 +560,17 @@ void GuiDrawingArea_setSwipable (GuiDrawingArea me, GuiScrollBar horizontalScrol
 	#endif
 }
 
-void GuiDrawingArea_setExposeCallback (GuiDrawingArea me, void (*callback) (void *boss, GuiDrawingAreaExposeEvent event), void *boss) {
+void GuiDrawingArea_setExposeCallback (GuiDrawingArea me, GuiDrawingArea_ExposeCallback callback, Thing boss) {
 	my d_exposeCallback = callback;
 	my d_exposeBoss = boss;
 }
 
-void GuiDrawingArea_setClickCallback (GuiDrawingArea me, void (*callback) (void *boss, GuiDrawingAreaClickEvent event), void *boss) {
+void GuiDrawingArea_setClickCallback (GuiDrawingArea me, GuiDrawingArea_ClickCallback callback, Thing boss) {
 	my d_clickCallback = callback;
 	my d_clickBoss = boss;
 }
 
-void GuiDrawingArea_setResizeCallback (GuiDrawingArea me, void (*callback) (void *boss, GuiDrawingAreaResizeEvent event), void *boss) {
+void GuiDrawingArea_setResizeCallback (GuiDrawingArea me, GuiDrawingArea_ResizeCallback callback, Thing boss) {
 	my d_resizeCallback = callback;
 	my d_resizeBoss = boss;
 }
