@@ -1,20 +1,19 @@
 /* GuiMenuItem.cpp
  *
- * Copyright (C) 1992-2012,2013,2015 Paul Boersma, 2013 Tom Naughton
+ * Copyright (C) 1992-2012,2013,2015,2016 Paul Boersma, 2013 Tom Naughton
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "GuiP.h"
@@ -28,12 +27,10 @@
 
 Thing_implement (GuiMenuItem, GuiThing, 0);
 
-#undef iam
-#define iam(x)  x me = (x) void_me
 #if gtk
 	#define iam_menuitem  GuiMenuItem me = (GuiMenuItem) _GuiObject_getUserData (widget)
 #elif cocoa
-	#define iam_menuitem  GuiMenuItem me = (GuiMenuItem) [(GuiCocoaMenuItem *) widget userData];
+	#define iam_menuitem  GuiMenuItem me = (GuiMenuItem) [(GuiCocoaMenuItem *) widget getUserData];
 #elif motif
 	#define iam_menuitem  GuiMenuItem me = (GuiMenuItem) widget -> userData
 #endif
@@ -41,57 +38,34 @@ Thing_implement (GuiMenuItem, GuiThing, 0);
 #if motif
 static void NativeMenuItem_setText (GuiObject me) {
 	int acc = my motiff.pushButton.acceleratorChar, modifiers = my motiff.pushButton.acceleratorModifiers;
-	#if win
-		static MelderString title { 0 };
-		if (acc == 0) {
-			MelderString_copy (& title, _GuiWin_expandAmpersands (my name));
-		} else {
-			static const char32 *keyStrings [256] = {
-				0, U"<-", U"->", U"Up", U"Down", U"PAUSE", U"Del", U"Ins", U"Backspace", U"Tab", U"LineFeed", U"Home", U"End", U"Enter", U"PageUp", U"PageDown",
-				U"Esc", U"F1", U"F2", U"F3", U"F4", U"F5", U"F6", U"F7", U"F8", U"F9", U"F10", U"F11", U"F12", 0, 0, 0,
-				U"Space", U"!", U"\"", U"#", U"$", U"%", U"&", U"\'", U"(", U")", U"*", U"+", U",", U"-", U".", U"/",
-				U"0", U"1", U"2", U"3", U"4", U"5", U"6", U"7", U"8", U"9", U":", U";", U"<", U"=", U">", U"?",
-				U"@", U"A", U"B", U"C", U"D", U"E", U"F", U"G", U"H", U"I", U"J", U"K", U"L", U"M", U"N", U"O",
-				U"P", U"Q", U"R", U"S", U"T", U"U", U"V", U"W", U"X", U"Y", U"Z", U"[", U"\\", U"]", U"^", U"_",
-				U"`", U"a", U"b", U"c", U"d", U"e", U"f", U"g", U"h", U"i", U"j", U"k", U"l", U"m", U"n", U"o",
-				U"p", U"q", U"r", U"s", U"t", U"u", U"v", U"w", U"x", U"y", U"z", U"{", U"|", U"}", U"~", U"Del",
-				0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-				0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-				0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-				0, 0, 0, 0, 0, 0, 0, 0, 0, 0, U"[", U"]", U",", U"?", U".", U"\\",
-				U";", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-				0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, U"-", U"`", U"=", U"\'", 0,
-				0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-				0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
-			const char32 *keyString = keyStrings [acc] ? keyStrings [acc] : U"???";
-			MelderString_copy (& title, _GuiWin_expandAmpersands (my name), U"\t",
-				modifiers & _motif_COMMAND_MASK ? U"Ctrl-" : nullptr,
-				modifiers & _motif_OPTION_MASK ? U"Alt-" : nullptr,
-				modifiers & _motif_SHIFT_MASK ? U"Shift-" : nullptr, keyString);
-		}
-		ModifyMenu (my nat.entry.handle, my nat.entry.id, MF_BYCOMMAND | MF_STRING, my nat.entry.id, Melder_peek32toW (title.string));
-	#elif mac
-		static int theGlyphs [1+31] = { 0,
-			kMenuLeftArrowDashedGlyph, kMenuRightArrowDashedGlyph, kMenuUpArrowDashedGlyph, kMenuDownwardArrowDashedGlyph, 0,
-			kMenuDeleteRightGlyph, 0, kMenuDeleteLeftGlyph, kMenuTabRightGlyph, 0,
-			0, 0, kMenuReturnGlyph, kMenuPageUpGlyph, kMenuPageDownGlyph,
-			kMenuEscapeGlyph, kMenuF1Glyph, kMenuF2Glyph, kMenuF3Glyph, kMenuF4Glyph,
-			kMenuF5Glyph, kMenuF6Glyph, kMenuF7Glyph, kMenuF8Glyph, kMenuF9Glyph,
-			kMenuF10Glyph, kMenuF11Glyph, kMenuF12Glyph, 0, 0,
-			0 };
-		SetMenuItemTextWithCFString (my nat.entry.handle, my nat.entry.item, (CFStringRef) Melder_peek32toCfstring (my name));
-		if (acc > 32) {
-			SetItemCmd (my nat.entry.handle, my nat.entry.item, acc);
-		} else {
-			Melder_assert (acc > 0 && acc < 32);
-			SetItemCmd (my nat.entry.handle, my nat.entry.item, ' ');   /* Funny that this should be needed. */
-			SetMenuItemKeyGlyph (my nat.entry.handle, my nat.entry.item, theGlyphs [acc]);
-		}
-		SetMenuItemModifiers (my nat.entry.handle, my nat.entry.item,
-			( modifiers & _motif_OPTION_MASK ? kMenuOptionModifier : 0 ) +
-			( modifiers & _motif_SHIFT_MASK ? kMenuShiftModifier : 0 ) +
-			( modifiers & _motif_COMMAND_MASK ? 0 : kMenuNoCommandModifier ));
-	#endif
+	static MelderString title { 0 };
+	if (acc == 0) {
+		MelderString_copy (& title, _GuiWin_expandAmpersands (my name));
+	} else {
+		static const char32 *keyStrings [256] = {
+			0, U"<-", U"->", U"Up", U"Down", U"PAUSE", U"Del", U"Ins", U"Backspace", U"Tab", U"LineFeed", U"Home", U"End", U"Enter", U"PageUp", U"PageDown",
+			U"Esc", U"F1", U"F2", U"F3", U"F4", U"F5", U"F6", U"F7", U"F8", U"F9", U"F10", U"F11", U"F12", 0, 0, 0,
+			U"Space", U"!", U"\"", U"#", U"$", U"%", U"&", U"\'", U"(", U")", U"*", U"+", U",", U"-", U".", U"/",
+			U"0", U"1", U"2", U"3", U"4", U"5", U"6", U"7", U"8", U"9", U":", U";", U"<", U"=", U">", U"?",
+			U"@", U"A", U"B", U"C", U"D", U"E", U"F", U"G", U"H", U"I", U"J", U"K", U"L", U"M", U"N", U"O",
+			U"P", U"Q", U"R", U"S", U"T", U"U", U"V", U"W", U"X", U"Y", U"Z", U"[", U"\\", U"]", U"^", U"_",
+			U"`", U"a", U"b", U"c", U"d", U"e", U"f", U"g", U"h", U"i", U"j", U"k", U"l", U"m", U"n", U"o",
+			U"p", U"q", U"r", U"s", U"t", U"u", U"v", U"w", U"x", U"y", U"z", U"{", U"|", U"}", U"~", U"Del",
+			0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+			0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+			0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+			0, 0, 0, 0, 0, 0, 0, 0, 0, 0, U"[", U"]", U",", U"?", U".", U"\\",
+			U";", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+			0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, U"-", U"`", U"=", U"\'", 0,
+			0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+			0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
+		const char32 *keyString = keyStrings [acc] ? keyStrings [acc] : U"???";
+		MelderString_copy (& title, _GuiWin_expandAmpersands (my name), U"\t",
+			modifiers & _motif_COMMAND_MASK ? U"Ctrl-" : nullptr,
+			modifiers & _motif_OPTION_MASK ? U"Alt-" : nullptr,
+			modifiers & _motif_SHIFT_MASK ? U"Shift-" : nullptr, keyString);
+	}
+	ModifyMenu (my nat.entry.handle, my nat.entry.id, MF_BYCOMMAND | MF_STRING, my nat.entry.id, Melder_peek32toW (title.string));
 }
 #endif
 
@@ -106,10 +80,10 @@ static void NativeMenuItem_setText (GuiObject me) {
 		iam (GuiMenuItem);
 		if (my d_callbackBlocked) return;
 		if (G_OBJECT_TYPE (widget) == GTK_TYPE_RADIO_MENU_ITEM && ! gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) return;
-		struct structGuiMenuItemEvent event = { me, 0 };
-		if (my d_commandCallback) {
+		struct structGuiMenuItemEvent event { me, false, false, false, false };
+		if (my d_callback) {
 			try {
-				my d_commandCallback (my d_boss, & event);
+				my d_callback (my d_boss, & event);
 			} catch (MelderError) {
 				Melder_flushError (U"Your choice of menu item \"", Melder_peek8to32 (GTK_WIDGET (widget) -> name), U"\" was not completely handled.");
 			}
@@ -120,25 +94,25 @@ static void NativeMenuItem_setText (GuiObject me) {
 		GuiMenuItem d_userData;
 	}
 	- (void) dealloc {   // override
-		GuiMenuItem me = self -> d_userData;
+		GuiMenuItem me = d_userData;
 		forget (me);
 		trace (U"deleting a menu item");
 		[super dealloc];
 	}
-	- (GuiThing) userData {
-		return self -> d_userData;
+	- (GuiThing) getUserData {
+		return d_userData;
 	}
 	- (void) setUserData: (GuiThing) userData {
 		Melder_assert (userData == nullptr || Thing_isa (userData, classGuiMenuItem));
-		self -> d_userData = static_cast <GuiMenuItem> (userData);
+		d_userData = static_cast <GuiMenuItem> (userData);
 	}
 	- (void) _guiCocoaMenuItem_activateCallback: (id) widget {
 		Melder_assert (self == widget);   // sender (widget) and receiver (self) happen to be the same object
-		GuiMenuItem me = self -> d_userData;
-		if (my d_commandCallback) {
-			struct structGuiMenuItemEvent event = { me, 0 };
+		GuiMenuItem me = d_userData;
+		if (my d_callback) {
+			struct structGuiMenuItemEvent event { me, false, false, false, false };
 			try {
-				my d_commandCallback (my d_boss, & event);
+				my d_callback (my d_boss, & event);
 			} catch (MelderError) {
 				Melder_flushError (U"Your choice of menu item \"", U"xx", U"\" was not completely handled.");
 			}
@@ -153,10 +127,10 @@ static void NativeMenuItem_setText (GuiObject me) {
 	}
 	static void _guiMotifMenuItem_activateCallback (GuiObject widget, XtPointer void_me, XtPointer call) {
 		iam (GuiMenuItem);
-		if (my d_commandCallback) {
-			struct structGuiMenuItemEvent event = { me, 0 };
+		if (my d_callback) {
+			struct structGuiMenuItemEvent event { me, false, false, false, false };
 			try {
-				my d_commandCallback (my d_boss, & event);
+				my d_callback (my d_boss, & event);
 			} catch (MelderError) {
 				Melder_flushError (U"Your choice of menu item \"", widget -> name, U"\" was not completely handled.");
 			}
@@ -165,9 +139,9 @@ static void NativeMenuItem_setText (GuiObject me) {
 #endif
 
 GuiMenuItem GuiMenu_addItem (GuiMenu menu, const char32 *title, uint32 flags,
-	void (*commandCallback) (void *boss, GuiMenuItemEvent event), void *boss)
+	GuiMenuItemCallback commandCallback, Thing boss)
 {
-	GuiMenuItem me = Thing_new (GuiMenuItem);
+	autoGuiMenuItem me = Thing_new (GuiMenuItem);
 	my d_shell = menu -> d_shell;
 	my d_parent = menu;
 	my d_menu = menu;
@@ -192,7 +166,7 @@ GuiMenuItem GuiMenu_addItem (GuiMenu menu, const char32 *title, uint32 flags,
 		}
 		Melder_assert (menu -> d_widget);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu -> d_widget), GTK_WIDGET (my d_widget));
-		_GuiObject_setUserData (my d_widget, me);
+		_GuiObject_setUserData (my d_widget, me.get());
 	#elif cocoa
 		(void) toggle;   // no difference between toggling and normal menu items on Cocoa
 		NSString *string = (NSString *) Melder_peek32toCfstring (title);
@@ -217,17 +191,17 @@ GuiMenuItem GuiMenu_addItem (GuiMenu menu, const char32 *title, uint32 flags,
 		trace (U"release the item");
 		[menuItem release];   // ... so we can release the item already
 		trace (U"set user data");
-		[menuItem setUserData: me];
+		[menuItem setUserData: me.get()];
 	#elif motif
 		my d_widget = XtVaCreateManagedWidget (Melder_peek32to8 (title),
 			toggle ? xmToggleButtonGadgetClass : xmPushButtonGadgetClass, menu -> d_widget, nullptr);
-		_GuiObject_setUserData (my d_widget, me);
+		_GuiObject_setUserData (my d_widget, me.get());
 	#endif
 	Melder_assert (my d_widget);
 
 	trace (U"set sensitivity");
 	if (flags & GuiMenu_INSENSITIVE)
-		GuiThing_setSensitive (me, false);
+		GuiThing_setSensitive (me.get(), false);
 
 	trace (U"understand toggle menu items");
 	if (flags & GuiMenu_TOGGLE_ON)
@@ -331,15 +305,9 @@ GuiMenuItem GuiMenu_addItem (GuiMenu menu, const char32 *title, uint32 flags,
 		#endif
 		trace (U"added accelerator ", accelerator);
 	}
-	#if mac && useCarbon
-		if (flags & GuiMenu_ATTRACTIVE) {
-			trace (U"attractive!");
-			SetItemStyle (my d_widget -> nat.entry.handle, my d_widget -> nat.entry.item, bold);
-		}
-	#endif
 
 	trace (U"install the command callback");
-	my d_commandCallback = commandCallback;
+	my d_callback = commandCallback;
 	my d_boss = boss;
 	#if gtk
 		if (commandCallback) {
@@ -347,16 +315,16 @@ GuiMenuItem GuiMenu_addItem (GuiMenu menu, const char32 *title, uint32 flags,
 				GtkWidget *shell = gtk_widget_get_toplevel (gtk_menu_get_attach_widget (GTK_MENU (menu -> d_widget)));
 				trace (U"tab set in GTK window ", Melder_pointer (shell));
 				g_object_set_data (G_OBJECT (shell), "tabCallback", (gpointer) _guiGtkMenuItem_activateCallback);
-				g_object_set_data (G_OBJECT (shell), "tabClosure", (gpointer) me);
+				g_object_set_data (G_OBJECT (shell), "tabClosure", (gpointer) me.get());
 			} else if (flags == (GuiMenu_TAB | GuiMenu_SHIFT)) {
 				GtkWidget *shell = gtk_widget_get_toplevel (gtk_menu_get_attach_widget (GTK_MENU (menu -> d_widget)));
 				trace (U"shift-tab set in GTK window ", Melder_pointer (shell));
 				g_object_set_data (G_OBJECT (shell), "shiftTabCallback", (gpointer) _guiGtkMenuItem_activateCallback);
-				g_object_set_data (G_OBJECT (shell), "shiftTabClosure", (gpointer) me);
+				g_object_set_data (G_OBJECT (shell), "shiftTabClosure", (gpointer) me.get());
 			} else {
 				g_signal_connect (G_OBJECT (my d_widget),
 					toggle ? "toggled" : "activate",
-					G_CALLBACK (_guiGtkMenuItem_activateCallback), (gpointer) me);
+					G_CALLBACK (_guiGtkMenuItem_activateCallback), (gpointer) me.get());
 			}
 		} else {
 			gtk_widget_set_sensitive (GTK_WIDGET (my d_widget), false);
@@ -368,22 +336,22 @@ GuiMenuItem GuiMenu_addItem (GuiMenu menu, const char32 *title, uint32 flags,
 	#elif motif
 		XtAddCallback (my d_widget,
 			toggle ? XmNvalueChangedCallback : XmNactivateCallback,
-			_guiMotifMenuItem_activateCallback, (XtPointer) me);
+			_guiMotifMenuItem_activateCallback, (XtPointer) me.get());
 	#endif
 
 	trace (U"make sure that I will be destroyed when my widget is destroyed");
 	#if gtk
-		g_signal_connect (G_OBJECT (my d_widget), "destroy", G_CALLBACK (_guiGtkMenuItem_destroyCallback), me);
+		g_signal_connect (G_OBJECT (my d_widget), "destroy", G_CALLBACK (_guiGtkMenuItem_destroyCallback), me.get());
 	#elif cocoa
 	#elif motif
-		XtAddCallback (my d_widget, XmNdestroyCallback, _guiMotifMenuItem_destroyCallback, me);
+		XtAddCallback (my d_widget, XmNdestroyCallback, _guiMotifMenuItem_destroyCallback, me.get());
 	#endif
 
-	return me;
+	return me.releaseToAmbiguousOwner();
 }
 
 GuiMenuItem GuiMenu_addSeparator (GuiMenu menu) {
-	GuiMenuItem me = Thing_new (GuiMenuItem);
+	autoGuiMenuItem me = Thing_new (GuiMenuItem);
 	my d_shell = menu -> d_shell;
 	my d_parent = menu;
 	my d_menu = menu;
@@ -408,19 +376,19 @@ GuiMenuItem GuiMenu_addSeparator (GuiMenu menu) {
 		trace (U"release the item");
 		//[(NSMenuItem *) my d_widget release];   // ... so we can release the item already
 		trace (U"set user data");
-		[(GuiCocoaMenuItem *) my d_widget setUserData: me];
+		[(GuiCocoaMenuItem *) my d_widget   setUserData: me.get()];
 	#elif motif
 		my d_widget = XtVaCreateManagedWidget ("menuSeparator", xmSeparatorGadgetClass, menu -> d_widget, nullptr);
 	#endif
 
 	trace (U"make sure that I will be destroyed when my widget is destroyed");
 	#if gtk
-		g_signal_connect (G_OBJECT (my d_widget), "destroy", G_CALLBACK (_guiGtkMenuItem_destroyCallback), me);
+		g_signal_connect (G_OBJECT (my d_widget), "destroy", G_CALLBACK (_guiGtkMenuItem_destroyCallback), me.get());
 	#elif cocoa
 	#elif motif
-		XtAddCallback (my d_widget, XmNdestroyCallback, _guiMotifMenuItem_destroyCallback, me);
+		XtAddCallback (my d_widget, XmNdestroyCallback, _guiMotifMenuItem_destroyCallback, me.get());
 	#endif
-	return me;
+	return me.releaseToAmbiguousOwner();
 }
 
 void GuiMenuItem_check (GuiMenuItem me, bool check) {
