@@ -1,20 +1,19 @@
 /* HyperPage.cpp
  *
- * Copyright (C) 1996-2011,2012,2013,2014,2015 Paul Boersma
+ * Copyright (C) 1996-2011,2012,2013,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <ctype.h>
@@ -47,11 +46,11 @@ static double resolution;
 
 Thing_implement (HyperLink, Daata, 0);
 
-HyperLink HyperLink_create (const char32 *name, double x1DC, double x2DC, double y1DC, double y2DC) {
+autoHyperLink HyperLink_create (const char32 *name, double x1DC, double x2DC, double y1DC, double y2DC) {
 	autoHyperLink me = Thing_new (HyperLink);
-	Thing_setName (me.peek(), name);
+	Thing_setName (me.get(), name);
 	my x1DC = x1DC, my x2DC = x2DC, my y1DC = y1DC, my y2DC = y2DC;
-	return me.transfer();
+	return me;
 }
 
 static void saveHistory (HyperPage me, const char32 *title) {
@@ -98,8 +97,7 @@ static void initScreen (HyperPage me) {
 	my d_y = PAGE_HEIGHT + my top / 5.0;
 	my d_x = 0;
 	my previousBottomSpacing = 0.0;
-	forget (my links);
-	my links = Collection_create (classHyperLink, 100);
+	my links. removeAllItems ();
 }
 
 void HyperPage_initSheetOfPaper (HyperPage me) {
@@ -170,29 +168,29 @@ if (! my printing) {
 	if (/* my d_y > PAGE_HEIGHT + 2.0 + heightGuess || */ my d_y < PAGE_HEIGHT - SCREEN_HEIGHT) {
 		my d_y -= heightGuess;
 	} else {
-		Graphics_setFont (my g, font);
-		Graphics_setFontSize (my g, size);
-		Graphics_setWrapWidth (my g, my rightMargin - x - 0.1);
-		Graphics_setSecondIndent (my g, secondIndent);
-		Graphics_setFontStyle (my g, style);
-		Graphics_text (my g, my d_x, my d_y, text);
+		Graphics_setFont (my graphics.get(), font);
+		Graphics_setFontSize (my graphics.get(), size);
+		Graphics_setWrapWidth (my graphics.get(), my rightMargin - x - 0.1);
+		Graphics_setSecondIndent (my graphics.get(), secondIndent);
+		Graphics_setFontStyle (my graphics.get(), style);
+		Graphics_text (my graphics.get(), my d_x, my d_y, text);
 		numberOfParagraphLinks = Graphics_getLinks (& paragraphLinks);
-		if (my links) for (ilink = 1; ilink <= numberOfParagraphLinks; ilink ++) {
-			HyperLink link = HyperLink_create (paragraphLinks [ilink]. name,
+		for (ilink = 1; ilink <= numberOfParagraphLinks; ilink ++) {
+			autoHyperLink link = HyperLink_create (paragraphLinks [ilink]. name,
 				paragraphLinks [ilink]. x1, paragraphLinks [ilink]. x2,
 				paragraphLinks [ilink]. y1, paragraphLinks [ilink]. y2);
-			Collection_addItem (my links, link);
+			my links. addItem_move (link.move());
 		}
 		if (method & HyperPage_ADD_BORDER) {
-			Graphics_setLineWidth (my g, 2);
-			Graphics_line (my g, 0.0, my d_y, my rightMargin, my d_y);
-			Graphics_setLineWidth (my g, 1);
+			Graphics_setLineWidth (my graphics.get(), 2.0);
+			Graphics_line (my graphics.get(), 0.0, my d_y, my rightMargin, my d_y);
+			Graphics_setLineWidth (my graphics.get(), 1.0);
 		}
 		/*
 		 * The text may have wrapped.
 		 * Ask the Graphics manager by how much, and update our text position accordingly.
 		 */
-		my d_y = Graphics_inqTextY (my g);
+		my d_y = Graphics_inqTextY (my graphics.get());
 	}
 } else {
 	Graphics_setFont (my ps, font);
@@ -303,13 +301,13 @@ if (! my printing) {
 	my d_y -= size * (1.2/72);
 	if (my d_y > PAGE_HEIGHT + 2.0 || my d_y < PAGE_HEIGHT - SCREEN_HEIGHT) {
 	} else {
-		Graphics_setFont (my g, font);
-		Graphics_setFontStyle (my g, 0);
-		Graphics_setFontSize (my g, size);
-		Graphics_setWrapWidth (my g, 0);
-		Graphics_setTextAlignment (my g, Graphics_CENTRE, Graphics_BOTTOM);
-		Graphics_text (my g, my rightMargin / 2, my d_y, formula);
-		Graphics_setTextAlignment (my g, Graphics_LEFT, Graphics_BOTTOM);
+		Graphics_setFont (my graphics.get(), font);
+		Graphics_setFontStyle (my graphics.get(), 0);
+		Graphics_setFontSize (my graphics.get(), size);
+		Graphics_setWrapWidth (my graphics.get(), 0.0);
+		Graphics_setTextAlignment (my graphics.get(), Graphics_CENTRE, Graphics_BOTTOM);
+		Graphics_text (my graphics.get(), 0.5 * my rightMargin, my d_y, formula);
+		Graphics_setTextAlignment (my graphics.get(), Graphics_LEFT, Graphics_BOTTOM);
 	}
 } else {
 	Graphics_setFont (my ps, font);
@@ -346,16 +344,16 @@ if (! my printing) {
 		my d_y -= height_inches;
 	} else {
 		my d_y -= height_inches;
-		Graphics_setFont (my g, font);
-		Graphics_setFontStyle (my g, 0);
-		Graphics_setFontSize (my g, size);
-		my d_x = width_inches > my rightMargin ? 0 : 0.5 * (my rightMargin - width_inches);
-		Graphics_setWrapWidth (my g, 0);
-		Graphics_setViewport (my g, my d_x, my d_x + width_inches, my d_y, my d_y + height_inches);
-		draw (my g);
-		Graphics_setViewport (my g, 0, 1, 0, 1);
-		Graphics_setWindow (my g, 0, 1, 0, 1);
-		Graphics_setTextAlignment (my g, Graphics_LEFT, Graphics_BOTTOM);
+		Graphics_setFont (my graphics.get(), font);
+		Graphics_setFontStyle (my graphics.get(), 0);
+		Graphics_setFontSize (my graphics.get(), size);
+		my d_x = width_inches > my rightMargin ? 0.0 : 0.5 * (my rightMargin - width_inches);
+		Graphics_setWrapWidth (my graphics.get(), 0.0);
+		Graphics_setViewport (my graphics.get(), my d_x, my d_x + width_inches, my d_y, my d_y + height_inches);
+		draw (my graphics.get());
+		Graphics_setViewport (my graphics.get(), 0.0, 1.0, 0.0, 1.0);
+		Graphics_setWindow (my graphics.get(), 0.0, 1.0, 0.0, 1.0);
+		Graphics_setTextAlignment (my graphics.get(), Graphics_LEFT, Graphics_BOTTOM);
 	}
 } else {
 	Graphics_setFont (my ps, font);
@@ -386,7 +384,7 @@ if (! my printing) {
 
 int HyperPage_script (HyperPage me, double width_inches, double height_inches, const char32 *script) {
 	char32 *text = Melder_dup (script);
-	Interpreter interpreter = Interpreter_createFromEnvironment (nullptr);
+	autoInterpreter interpreter = Interpreter_createFromEnvironment (nullptr);
 	double topSpacing = 0.1, bottomSpacing = 0.1, minFooterDistance = 0.0;
 	kGraphics_font font = my p_font;
 	int size = my p_fontSize;
@@ -398,15 +396,15 @@ if (! my printing) {
 		my d_y -= true_height_inches;
 	} else {
 		my d_y -= true_height_inches;
-		Graphics_setFont (my g, font);
-		Graphics_setFontStyle (my g, 0);
-		Graphics_setFontSize (my g, size);
-		my d_x = true_width_inches > my rightMargin ? 0 : 0.5 * (my rightMargin - true_width_inches);
-		Graphics_setWrapWidth (my g, 0);
+		Graphics_setFont (my graphics.get(), font);
+		Graphics_setFontStyle (my graphics.get(), 0);
+		Graphics_setFontSize (my graphics.get(), size);
+		my d_x = true_width_inches > my rightMargin ? 0.0 : 0.5 * (my rightMargin - true_width_inches);
+		Graphics_setWrapWidth (my graphics.get(), 0.0);
 		long x1DCold, x2DCold, y1DCold, y2DCold;
-		Graphics_inqWsViewport (my g, & x1DCold, & x2DCold, & y1DCold, & y2DCold);
+		Graphics_inqWsViewport (my graphics.get(), & x1DCold, & x2DCold, & y1DCold, & y2DCold);
 		double x1NDCold, x2NDCold, y1NDCold, y2NDCold;
-		Graphics_inqWsWindow (my g, & x1NDCold, & x2NDCold, & y1NDCold, & y2NDCold);
+		Graphics_inqWsWindow (my graphics.get(), & x1NDCold, & x2NDCold, & y1NDCold, & y2NDCold);
 		{
 			if (! my praatApplication) my praatApplication = Melder_calloc_f (structPraatApplication, 1);
 			if (! my praatObjects) my praatObjects = Melder_calloc_f (structPraatObjects, 1);
@@ -416,7 +414,7 @@ if (! my printing) {
 			theCurrentPraatApplication -> topShell = theForegroundPraatApplication. topShell;   // needed for UiForm_create () in dialogs
 			theCurrentPraatObjects = (PraatObjects) my praatObjects;
 			theCurrentPraatPicture = (PraatPicture) my praatPicture;
-			theCurrentPraatPicture -> graphics = my g;   // has to draw into HyperPage rather than Picture window
+			theCurrentPraatPicture -> graphics = my graphics.get();   // has to draw into HyperPage rather than Picture window
 			theCurrentPraatPicture -> font = font;
 			theCurrentPraatPicture -> fontSize = size;
 			theCurrentPraatPicture -> lineType = Graphics_DRAWN;
@@ -429,18 +427,18 @@ if (! my printing) {
 			theCurrentPraatPicture -> y1NDC = my d_y;
 			theCurrentPraatPicture -> y2NDC = my d_y + true_height_inches;
 
-			Graphics_setViewport (my g, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
-			Graphics_setWindow (my g, 0.0, 1.0, 0.0, 1.0);
+			Graphics_setViewport (my graphics.get(), theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
+			Graphics_setWindow (my graphics.get(), 0.0, 1.0, 0.0, 1.0);
 			long x1DC, y1DC, x2DC, y2DC;
-			Graphics_WCtoDC (my g, 0.0, 0.0, & x1DC, & y2DC);
-			Graphics_WCtoDC (my g, 1.0, 1.0, & x2DC, & y1DC);
-			Graphics_resetWsViewport (my g, x1DC, x2DC, y1DC, y2DC);
-			Graphics_setWsWindow (my g, 0, width_inches, 0, height_inches);
-			theCurrentPraatPicture -> x1NDC = 0;
+			Graphics_WCtoDC (my graphics.get(), 0.0, 0.0, & x1DC, & y2DC);
+			Graphics_WCtoDC (my graphics.get(), 1.0, 1.0, & x2DC, & y1DC);
+			Graphics_resetWsViewport (my graphics.get(), x1DC, x2DC, y1DC, y2DC);
+			Graphics_setWsWindow (my graphics.get(), 0, width_inches, 0, height_inches);
+			theCurrentPraatPicture -> x1NDC = 0.0;
 			theCurrentPraatPicture -> x2NDC = width_inches;
-			theCurrentPraatPicture -> y1NDC = 0;
+			theCurrentPraatPicture -> y1NDC = 0.0;
 			theCurrentPraatPicture -> y2NDC = height_inches;
-			Graphics_setViewport (my g, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);			
+			Graphics_setViewport (my graphics.get(), theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
 
 			{// scope
 				autoMelderProgressOff progress;
@@ -450,7 +448,7 @@ if (! my printing) {
 					Melder_setDefaultDir (& my rootDirectory);
 				}
 				try {
-					Interpreter_run (interpreter, text);
+					Interpreter_run (interpreter.get(), text);
 				} catch (MelderError) {
 					if (my scriptErrorHasBeenNotified) {
 						Melder_clearError ();
@@ -460,28 +458,28 @@ if (! my printing) {
 					}
 				}
 			}
-			Graphics_setLineType (my g, Graphics_DRAWN);
-			Graphics_setLineWidth (my g, 1.0);
-			Graphics_setArrowSize (my g, 1.0);
-			Graphics_setSpeckleSize (my g, 1.0);
-			Graphics_setColour (my g, Graphics_BLACK);
+			Graphics_setLineType (my graphics.get(), Graphics_DRAWN);
+			Graphics_setLineWidth (my graphics.get(), 1.0);
+			Graphics_setArrowSize (my graphics.get(), 1.0);
+			Graphics_setSpeckleSize (my graphics.get(), 1.0);
+			Graphics_setColour (my graphics.get(), Graphics_BLACK);
 			/*Graphics_Link *paragraphLinks;
 			long numberOfParagraphLinks = Graphics_getLinks (& paragraphLinks);
 			if (my links) for (long ilink = 1; ilink <= numberOfParagraphLinks; ilink ++) {
-				HyperLink link = HyperLink_create (paragraphLinks [ilink]. name,
+				autoHyperLink link = HyperLink_create (paragraphLinks [ilink]. name,
 					paragraphLinks [ilink]. x1, paragraphLinks [ilink]. x2,
 					paragraphLinks [ilink]. y1, paragraphLinks [ilink]. y2);
-				Collection_addItem (my links, link);
+				Collection_addItem_move (my links, link.move());
 			}*/
 			theCurrentPraatApplication = & theForegroundPraatApplication;
 			theCurrentPraatObjects = & theForegroundPraatObjects;
 			theCurrentPraatPicture = & theForegroundPraatPicture;
 		}
-		Graphics_resetWsViewport (my g, x1DCold, x2DCold, y1DCold, y2DCold);
-		Graphics_setWsWindow (my g, x1NDCold, x2NDCold, y1NDCold, y2NDCold);
-		Graphics_setViewport (my g, 0, 1, 0, 1);
-		Graphics_setWindow (my g, 0, 1, 0, 1);
-		Graphics_setTextAlignment (my g, Graphics_LEFT, Graphics_BOTTOM);
+		Graphics_resetWsViewport (my graphics.get(), x1DCold, x2DCold, y1DCold, y2DCold);
+		Graphics_setWsWindow (my graphics.get(), x1NDCold, x2NDCold, y1NDCold, y2NDCold);
+		Graphics_setViewport (my graphics.get(), 0.0, 1.0, 0.0, 1.0);
+		Graphics_setWindow (my graphics.get(), 0.0, 1.0, 0.0, 1.0);
+		Graphics_setTextAlignment (my graphics.get(), Graphics_LEFT, Graphics_BOTTOM);
 	}
 } else {
 	Graphics_setFont (my ps, font);
@@ -551,7 +549,7 @@ if (! my printing) {
 				Melder_setDefaultDir (& my rootDirectory);
 			}
 			try {
-				Interpreter_run (interpreter, text);
+				Interpreter_run (interpreter.get(), text);
 			} catch (MelderError) {
 				Melder_clearError ();
 			}
@@ -572,12 +570,11 @@ if (! my printing) {
 	Graphics_setTextAlignment (my ps, Graphics_LEFT, Graphics_BOTTOM);
 }
 	my previousBottomSpacing = bottomSpacing;
-	forget (interpreter);
 	Melder_free (text);
 	return 1;
 }
 
-static void print (I, Graphics graphics) {
+static void print (void *void_me, Graphics graphics) {
 	iam (HyperPage);
 	my ps = graphics;
 	Graphics_setDollarSignIsCode (graphics, true);
@@ -590,10 +587,8 @@ static void print (I, Graphics graphics) {
 
 /********** class HyperPage **********/
 
-void structHyperPage :: v_destroy () {
-	forget (our links);
+void structHyperPage :: v_destroy () noexcept {
 	Melder_free (our entryHint);
-	forget (our g);
 	for (int i = 0; i < 20; i ++) Melder_free (our history [i]. page);
 	Melder_free (our currentPageTitle);
 	if (our praatApplication) {
@@ -608,11 +603,9 @@ void structHyperPage :: v_destroy () {
 	our HyperPage_Parent :: v_destroy ();
 }
 
-static void gui_drawingarea_cb_expose (I, GuiDrawingAreaExposeEvent event) {
-	iam (HyperPage);
-	(void) event;
-	if (! my g) return;   // could be the case in the very beginning
-	Graphics_clearWs (my g);
+static void gui_drawingarea_cb_expose (HyperPage me, GuiDrawingArea_ExposeEvent /* event */) {
+	if (! my graphics) return;   // could be the case in the very beginning
+	Graphics_clearWs (my graphics.get());
 	initScreen (me);
 	trace (U"going to draw");
 	my v_draw ();
@@ -620,21 +613,19 @@ static void gui_drawingarea_cb_expose (I, GuiDrawingAreaExposeEvent event) {
 		Melder_free (my entryHint);
 		my top = (int) floor (5.0 * (PAGE_HEIGHT - my entryPosition));
 		if (my top < 0) my top = 0;
-		Graphics_clearWs (my g);
+		Graphics_clearWs (my graphics.get());
 		initScreen (me);
 		my v_draw ();
 		updateVerticalScrollBar (me);
 	}
 }
 
-static void gui_drawingarea_cb_click (I, GuiDrawingAreaClickEvent event) {
-	iam (HyperPage);
-	if (! my g) return;   // could be the case in the very beginning
-	if (! my links) return;
-	for (long ilink = 1; ilink <= my links -> size; ilink ++) {
-		HyperLink link = (HyperLink) my links -> item [ilink];		
+static void gui_drawingarea_cb_click (HyperPage me, GuiDrawingArea_ClickEvent event) {
+	if (! my graphics) return;   // could be the case in the very beginning
+	for (long ilink = 1; ilink <= my links.size; ilink ++) {
+		HyperLink link = my links.at [ilink];
 		if (! link)
-			Melder_fatal (U"gui_drawingarea_cb_click: empty link ", ilink, U"/", my links -> size, U".");
+			Melder_fatal (U"gui_drawingarea_cb_click: empty link ", ilink, U"/", my links.size, U".");
 		if (event -> y > link -> y2DC && event -> y < link -> y1DC && event -> x > link -> x1DC && event -> x < link -> x2DC) {
 			saveHistory (me, my currentPageTitle);
 			try {
@@ -647,21 +638,18 @@ static void gui_drawingarea_cb_click (I, GuiDrawingAreaClickEvent event) {
 	}
 }
 
-static void menu_cb_postScriptSettings (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
+static void menu_cb_postScriptSettings (HyperPage me, EDITOR_ARGS_DIRECT) {
 	Printer_postScriptSettings ();
 }
 
 #ifdef macintosh
-static void menu_cb_pageSetup (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
+static void menu_cb_pageSetup (HyperPage me, EDITOR_ARGS_DIRECT) {
 	Printer_pageSetup ();
 }
 #endif
 
-static void menu_cb_print (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
-	EDITOR_FORM (U"Print", 0)
+static void menu_cb_print (HyperPage me, EDITOR_ARGS_FORM) {
+	EDITOR_FORM (U"Print", nullptr)
 		SENTENCE (U"Left or inside header", U"")
 		SENTENCE (U"Middle header", U"")
 		LABEL (U"", U"Right or outside header:")
@@ -687,9 +675,8 @@ static void menu_cb_print (EDITOR_ARGS) {
 	EDITOR_END
 }
 
-static void menu_cb_font (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
-	EDITOR_FORM (U"Font", 0)
+static void menu_cb_font (HyperPage me, EDITOR_ARGS_FORM) {
+	EDITOR_FORM (U"Font", nullptr)
 		RADIO (U"Font", 1)
 			RADIOBUTTON (U"Times")
 			RADIOBUTTON (U"Helvetica")
@@ -699,7 +686,7 @@ static void menu_cb_font (EDITOR_ARGS) {
 	EDITOR_DO
 		int font = GET_INTEGER (U"Font");
 		my pref_font () = my p_font = font == 1 ? kGraphics_font_TIMES : kGraphics_font_HELVETICA;
-		if (my g) Graphics_updateWs (my g);
+		if (my graphics) Graphics_updateWs (my graphics.get());
 	EDITOR_END
 }
 
@@ -712,18 +699,17 @@ static void updateSizeMenu (HyperPage me) {
 }
 static void setFontSize (HyperPage me, int fontSize) {
 	my pref_fontSize () = my p_fontSize = fontSize;
-	if (my g) Graphics_updateWs (my g);
+	if (my graphics) Graphics_updateWs (my graphics.get());
 	updateSizeMenu (me);
 }
 
-static void menu_cb_10 (EDITOR_ARGS) { EDITOR_IAM (HyperPage); setFontSize (me, 10); }
-static void menu_cb_12 (EDITOR_ARGS) { EDITOR_IAM (HyperPage); setFontSize (me, 12); }
-static void menu_cb_14 (EDITOR_ARGS) { EDITOR_IAM (HyperPage); setFontSize (me, 14); }
-static void menu_cb_18 (EDITOR_ARGS) { EDITOR_IAM (HyperPage); setFontSize (me, 18); }
-static void menu_cb_24 (EDITOR_ARGS) { EDITOR_IAM (HyperPage); setFontSize (me, 24); }
+static void menu_cb_10 (HyperPage me, EDITOR_ARGS_DIRECT) { setFontSize (me, 10); }
+static void menu_cb_12 (HyperPage me, EDITOR_ARGS_DIRECT) { setFontSize (me, 12); }
+static void menu_cb_14 (HyperPage me, EDITOR_ARGS_DIRECT) { setFontSize (me, 14); }
+static void menu_cb_18 (HyperPage me, EDITOR_ARGS_DIRECT) { setFontSize (me, 18); }
+static void menu_cb_24 (HyperPage me, EDITOR_ARGS_DIRECT) { setFontSize (me, 24); }
 
-static void menu_cb_fontSize (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
+static void menu_cb_fontSize (HyperPage me, EDITOR_ARGS_FORM) {
 	EDITOR_FORM (U"Font size", 0)
 		NATURAL (U"Font size (points)", my default_fontSize ())
 	EDITOR_OK
@@ -733,8 +719,7 @@ static void menu_cb_fontSize (EDITOR_ARGS) {
 	EDITOR_END
 }
 
-static void menu_cb_searchForPage (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
+static void menu_cb_searchForPage (HyperPage me, EDITOR_ARGS_FORM) {
 	EDITOR_FORM (U"Search for page", 0)
 		TEXTFIELD (U"Page", U"a")
 	EDITOR_OK
@@ -757,17 +742,16 @@ static void menu_cb_searchForPage (EDITOR_ARGS) {
  * The 'pageIncrement' is sliderSize - 1.
  */
 
-static void gui_cb_verticalScroll (I, GuiScrollBarEvent	event) {
-	iam (HyperPage);
+static void gui_cb_verticalScroll (HyperPage me, GuiScrollBarEvent	event) {
 	double value = GuiScrollBar_getValue (event -> scrollBar);
 	if (value != my top) {
 		trace (U"scroll from ", my top, U" to ", value);
 		my top = (int) floor (value);
 		#if cocoa || gtk || win
-			Graphics_updateWs (my g);   // wait for expose event
+			Graphics_updateWs (my graphics.get());   // wait for expose event
 		#else
 			initScreen (me);
-			Graphics_clearWs (my g);
+			Graphics_clearWs (my graphics.get());
 			my v_draw ();   // do not wait for expose event
 		#endif
 		updateVerticalScrollBar (me);
@@ -792,28 +776,26 @@ static void updateVerticalScrollBar (HyperPage me)
 	my history [my historyPointer]. top = 0/*my top*/;
 }
 
-static void menu_cb_pageUp (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
+static void menu_cb_pageUp (HyperPage me, EDITOR_ARGS_DIRECT) {
 	if (! my verticalScrollBar) return;
 	int value = GuiScrollBar_getValue (my verticalScrollBar) - 24;
 	if (value < 0) value = 0;
 	if (value != my top) {
 		my top = value;
-		Graphics_clearWs (my g);
+		Graphics_clearWs (my graphics.get());
 		initScreen (me);
 		my v_draw ();   // do not wait for expose event
 		updateVerticalScrollBar (me);
 	}
 }
 
-static void menu_cb_pageDown (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
+static void menu_cb_pageDown (HyperPage me, EDITOR_ARGS_DIRECT) {
 	if (! my verticalScrollBar) return;
 	int value = GuiScrollBar_getValue (my verticalScrollBar) + 24;
 	if (value > (int) (PAGE_HEIGHT * 5) - 25) value = (int) (PAGE_HEIGHT * 5) - 25;
 	if (value != my top) {
 		my top = value;
-		Graphics_clearWs (my g);
+		Graphics_clearWs (my graphics.get());
 		initScreen (me);
 		my v_draw ();   // do not wait for expose event
 		updateVerticalScrollBar (me);
@@ -833,14 +815,11 @@ static void do_back (HyperPage me) {
 	}
 }
 
-static void menu_cb_back (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
+static void menu_cb_back (HyperPage me, EDITOR_ARGS_DIRECT) {
 	do_back (me);
 }
 
-static void gui_button_cb_back (I, GuiButtonEvent event) {
-	(void) event;
-	iam (HyperPage);
+static void gui_button_cb_back (HyperPage me, GuiButtonEvent /* event */) {
 	do_back (me);
 }
 
@@ -855,14 +834,11 @@ static void do_forth (HyperPage me) {
 	}
 }
 
-static void menu_cb_forth (EDITOR_ARGS) {
-	EDITOR_IAM (HyperPage);
+static void menu_cb_forth (HyperPage me, EDITOR_ARGS_DIRECT) {
 	do_forth (me);
 }
 
-static void gui_button_cb_forth (I, GuiButtonEvent event) {
-	(void) event;
-	iam (HyperPage);
+static void gui_button_cb_forth (HyperPage me, GuiButtonEvent /* event */) {
 	do_forth (me);
 }
 
@@ -899,26 +875,21 @@ void structHyperPage :: v_createMenus () {
 
 /********** **********/
 
-static void gui_drawingarea_cb_resize (I, GuiDrawingAreaResizeEvent event) {
-	iam (HyperPage);
-	if (! my g) return;
-	Graphics_setWsViewport (my g, 0, event -> width, 0, event -> height);
-	Graphics_setWsWindow (my g, 0.0, my rightMargin = event -> width / resolution,
+static void gui_drawingarea_cb_resize (HyperPage me, GuiDrawingArea_ResizeEvent event) {
+	if (! my graphics) return;
+	Graphics_setWsViewport (my graphics.get(), 0.0, event -> width, 0.0, event -> height);
+	Graphics_setWsWindow (my graphics.get(), 0.0, my rightMargin = event -> width / resolution,
 		PAGE_HEIGHT - event -> height / resolution, PAGE_HEIGHT);
-	Graphics_updateWs (my g);
+	Graphics_updateWs (my graphics.get());
 	updateVerticalScrollBar (me);
 }
 
-static void gui_button_cb_previousPage (I, GuiButtonEvent event) {
-	(void) event;
-	iam (HyperPage);
+static void gui_button_cb_previousPage (HyperPage me, GuiButtonEvent /* event */) {
 	HyperPage_goToPage_i (me, my v_getCurrentPageNumber () > 1 ?
 		my v_getCurrentPageNumber () - 1 : my v_getNumberOfPages ());
 }
 
-static void gui_button_cb_nextPage (I, GuiButtonEvent event) {
-	(void) event;
-	iam (HyperPage);
+static void gui_button_cb_nextPage (HyperPage me, GuiButtonEvent /* event */) {
 	long currentPageNumber = my v_getCurrentPageNumber ();
 	HyperPage_goToPage_i (me, currentPageNumber < my v_getNumberOfPages () ? currentPageNumber + 1 : 1);
 }
@@ -961,15 +932,15 @@ void HyperPage_init (HyperPage me, const char32 *title, Daata data) {
 	#if motif
 		Melder_assert (XtWindow (my drawingArea -> d_widget));
 	#endif
-	my g = Graphics_create_xmdrawingarea (my drawingArea);
-	Graphics_setAtSignIsLink (my g, true);
-	Graphics_setDollarSignIsCode (my g, true);
-	Graphics_setFont (my g, kGraphics_font_TIMES);
+	my graphics = Graphics_create_xmdrawingarea (my drawingArea);
+	Graphics_setAtSignIsLink (my graphics.get(), true);
+	Graphics_setDollarSignIsCode (my graphics.get(), true);
+	Graphics_setFont (my graphics.get(), kGraphics_font_TIMES);
 	if (my p_font != kGraphics_font_TIMES && my p_font != kGraphics_font_HELVETICA)
 		my pref_font () = my p_font = kGraphics_font_TIMES;   // ensure Unicode compatibility
 	setFontSize (me, my p_fontSize);
 
-struct structGuiDrawingAreaResizeEvent event = { my drawingArea, 0 };
+struct structGuiDrawingArea_ResizeEvent event { my drawingArea, 0 };
 event. width  = GuiControl_getWidth  (my drawingArea);
 event. height = GuiControl_getHeight (my drawingArea);
 gui_drawingarea_cb_resize (me, & event);
@@ -978,8 +949,8 @@ gui_drawingarea_cb_resize (me, & event);
 }
 
 void HyperPage_clear (HyperPage me) {
-	Graphics_updateWs (my g);
-	forget (my links);
+	Graphics_updateWs (my graphics.get());
+	my links. removeAllItems();
 }
 
 void structHyperPage :: v_dataChanged () {
