@@ -1,57 +1,19 @@
 /* Interpreter.cpp
  *
- * Copyright (C) 1993-2011,2013,2014,2015 Paul Boersma
+ * Copyright (C) 1993-2011,2013,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-/*
- * pb 2002/03/07 GPL
- * pb 2002/03/25 option menus
- * pb 2002/06/04 include the script compiler
- * pb 2002/09/26 removed bug: crashed if a line in a form contained only the word "comment"
- * pb 2002/11/25 Melder_double
- * pb 2002/12/10 include files
- * pb 2002/12/14 more informative error messages
- * pb 2003/05/19 Melder_atof
- * pb 2003/07/15 assert
- * pb 2003/07/19 if undefined fails
- * pb 2004/10/16 C++ compatible structs
- * pb 2004/12/06 made Interpreter_getArgumentsFromDialog resistant to changes in the script while the dialog is up
- * pb 2005/01/01 there can be spaces before the "form" statement
- * pb 2005/11/26 allow mixing of "option" and "button", as in Ui.c
- * pb 2006/01/11 local variables
- * pb 2007/02/05 preferencesDirectory$, homeDirectory$, temporaryDirectory$
- * pb 2007/04/02 allow comments (with '#' or ';' or empty lines) in forms
- * pb 2007/04/19 allow comments with '!' in forms
- * pb 2007/05/24 some wchar
- * pb 2007/06/09 wchar
- * pb 2007/08/12 more wchar
- * pb 2007/11/30 removed bug: allowed long arguments to the "call" statement (thanks to Ingmar Steiner)
- * pb 2007/12/10 predefined numeric variables macintosh/windows/unix
- * pb 2008/04/30 new Formula API
- * pb 2008/05/01 arrays
- * pb 2008/05/15 praatVersion, praatVersion$
- * pb 2009/01/04 Interpreter_voidExpression
- * pb 2009/01/17 arguments to UiForm callbacks
- * pb 2009/01/20 pause forms
- * pb 2009/03/17 split up structPraat
- * pb 2009/12/22 invokingButtonTitle
- * pb 2010/04/30 guard against leading nonbreaking spaces
- * pb 2011/05/14 C++
- * pb 2015/05/30 char32
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <ctype.h>
@@ -79,14 +41,15 @@ extern structMelderDir praatDir;
 
 Thing_implement (InterpreterVariable, SimpleString, 0);
 
-void structInterpreterVariable :: v_destroy () {
-	Melder_free (string);
-	Melder_free (stringValue);
-	NUMmatrix_free (numericArrayValue. data, 1, 1);
+void structInterpreterVariable :: v_destroy () noexcept {
+	Melder_free (our string);
+	Melder_free (our stringValue);
+	NUMvector_free (our numericVectorValue. data, 1);
+	NUMmatrix_free (our numericMatrixValue. data, 1, 1);
 	InterpreterVariable_Parent :: v_destroy ();
 }
 
-static InterpreterVariable InterpreterVariable_create (const char32 *key) {
+static autoInterpreterVariable InterpreterVariable_create (const char32 *key) {
 	try {
 		if (key [0] == U'e' && key [1] == U'\0')
 			Melder_throw (U"You cannot use 'e' as the name of a variable (e is the constant 2.71...).");
@@ -97,7 +60,7 @@ static InterpreterVariable InterpreterVariable_create (const char32 *key) {
 			Melder_throw (U"You cannot use 'undefined' as the name of a variable.");
 		autoInterpreterVariable me = Thing_new (InterpreterVariable);
 		my string = Melder_dup (key);
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Interpreter variable not created.");
 	}
@@ -105,42 +68,34 @@ static InterpreterVariable InterpreterVariable_create (const char32 *key) {
 
 Thing_implement (Interpreter, Thing, 0);
 
-void structInterpreter :: v_destroy () {
+void structInterpreter :: v_destroy () noexcept {
 	Melder_free (our environmentName);
 	for (int ipar = 1; ipar <= Interpreter_MAXNUM_PARAMETERS; ipar ++)
 		Melder_free (our arguments [ipar]);
-	#if USE_HASH
-	if (our variablesMap) {
-		for (auto it = our variablesMap -> begin(); it != our variablesMap -> end(); it ++) {
+	//if (our variablesMap) {
+		for (auto it = our variablesMap. begin(); it != our variablesMap. end(); it ++) {
 			InterpreterVariable var = it -> second;
 			forget (var);
 		}
-		delete (our variablesMap);
-	}
-	#else
-	forget (our variables);
-	#endif
+	//	delete (our variablesMap);
+	//}
 	Interpreter_Parent :: v_destroy ();
 }
 
-Interpreter Interpreter_create (char32 *environmentName, ClassInfo editorClass) {
+autoInterpreter Interpreter_create (char32 *environmentName, ClassInfo editorClass) {
 	try {
 		autoInterpreter me = Thing_new (Interpreter);
-		#if USE_HASH
-		my variablesMap = new std::unordered_map <std::u32string, InterpreterVariable>;
-		my variablesMap -> max_load_factor (0.65f);
-		#else
-		my variables = SortedSetOfString_create ();
-		#endif
+		//my variablesMap = new std::unordered_map <std::u32string, InterpreterVariable>;
+		my variablesMap. max_load_factor (0.65f);
 		my environmentName = Melder_dup (environmentName);
 		my editorClass = editorClass;
-		return me.transfer();
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Interpreter not created.");
 	}
 }
 
-Interpreter Interpreter_createFromEnvironment (Editor editor) {
+autoInterpreter Interpreter_createFromEnvironment (Editor editor) {
 	if (! editor) return Interpreter_create (nullptr, nullptr);
 	return Interpreter_create (editor -> name, editor -> classInfo);
 }
@@ -212,6 +167,10 @@ void Melder_includeIncludeFiles (char32 **text) {
 	}
 }
 
+inline static bool Melder_isblank (char32 kar) {
+	return kar == U' ' || kar == U'\t';
+}
+
 long Interpreter_readParameters (Interpreter me, char32 *text) {
 	char32 *formLocation = nullptr;
 	long npar = 0;
@@ -222,7 +181,7 @@ long Interpreter_readParameters (Interpreter me, char32 *text) {
 	{// scope
 		char32 *p = text;
 		for (;;) {
-			while (*p == ' ' || *p == '\t') p ++;
+			while (Melder_isblank (*p)) p ++;
 			if (str32nequ (p, U"form ", 5)) {
 				formLocation = p;
 				break;
@@ -246,13 +205,13 @@ long Interpreter_readParameters (Interpreter me, char32 *text) {
 		while (newLine) {
 			char32 *line = newLine + 1, *p;
 			int type = 0;
-			while (*line == U' ' || *line == U'\t') line ++;
+			while (Melder_isblank (*line)) line ++;
 			while (*line == U'#' || *line == U';' || *line == U'!' || *line == U'\n') {
 				newLine = str32chr (line, U'\n');
 				if (! newLine)
 					Melder_throw (U"Unfinished form.");
 				line = newLine + 1;
-				while (*line == U' ' || *line == U'\t') line ++;
+				while (Melder_isblank (*line)) line ++;
 			}
 			if (str32nequ (line, U"endform", 7)) break;
 			if (str32nequ (line, U"word ", 5)) { type = Interpreter_WORD; p = line + 5; }
@@ -297,7 +256,7 @@ long Interpreter_readParameters (Interpreter me, char32 *text) {
 				my arguments [5] := "Blue"
 			*/
 			if (type <= Interpreter_OPTIONMENU) {
-				while (*p == U' ' || *p == U'\t') p ++;
+				while (Melder_isblank (*p)) p ++;
 				if (*p == U'\n' || *p == U'\0')
 					Melder_throw (U"Missing parameter:\n\"", line, U"\".");
 				char32 *q = my parameters [++ my numberOfParameters];
@@ -307,7 +266,7 @@ long Interpreter_readParameters (Interpreter me, char32 *text) {
 			} else {
 				my parameters [++ my numberOfParameters] [0] = U'\0';
 			}
-			while (*p == U' ' || *p == U'\t') p ++;
+			while (Melder_isblank (*p)) p ++;
 			newLine = str32chr (p, U'\n');
 			if (newLine) *newLine = U'\0';
 			Melder_free (my arguments [my numberOfParameters]);
@@ -328,7 +287,7 @@ UiForm Interpreter_createForm (Interpreter me, GuiWindow parent, const char32 *p
 	UiForm form = UiForm_create (parent,
 		Melder_cat (selectionOnly ? U"Run script (selection only): " : U"Run script: ", my dialogTitle),
 		okCallback, okClosure, nullptr, nullptr);
-	Any radio = nullptr;
+	UiField radio = nullptr;
 	if (path) UiForm_addText (form, U"$file", path);
 	for (int ipar = 1; ipar <= my numberOfParameters; ipar ++) {
 		/*
@@ -504,7 +463,7 @@ void Interpreter_getArgumentsFromString (Interpreter me, const char32 *arguments
 	 * Leading spaces are skipped, but trailing spaces are included.
 	 */
 	if (size > 0) {
-		while (*arguments == U' ' || *arguments == U'\t') arguments ++;
+		while (Melder_isblank (*arguments)) arguments ++;
 		Melder_free (my arguments [size]);
 		my arguments [size] = Melder_dup_f (arguments);
 	}
@@ -645,71 +604,45 @@ void Interpreter_getArgumentsFromArgs (Interpreter me, int narg, Stackel args) {
 }
 
 static void Interpreter_addNumericVariable (Interpreter me, const char32 *key, double value) {
-	#if USE_HASH
-	InterpreterVariable variable = InterpreterVariable_create (key);
-	variable -> numericValue = value;
-	(*my variablesMap) [key] = variable;
-	#else
 	autoInterpreterVariable variable = InterpreterVariable_create (key);
 	variable -> numericValue = value;
-	Collection_addItem (my variables, variable.transfer());
-	#endif
+	my variablesMap [key] = variable.get();   // YUCK
+	variable.releaseToAmbiguousOwner();
 }
 
 static void Interpreter_addStringVariable (Interpreter me, const char32 *key, const char32 *value) {
-	#if USE_HASH
-	InterpreterVariable variable = InterpreterVariable_create (key);
-	variable -> stringValue = Melder_dup (value);
-	(*my variablesMap) [key] = variable;
-	#else
 	autoInterpreterVariable variable = InterpreterVariable_create (key);
 	variable -> stringValue = Melder_dup (value);
-	Collection_addItem (my variables, variable.transfer());
-	#endif
+	my variablesMap [key] = variable.get();   // YUCK
+	variable.releaseToAmbiguousOwner();
 }
 
 InterpreterVariable Interpreter_hasVariable (Interpreter me, const char32 *key) {
 	Melder_assert (key);
-	#if USE_HASH
-	auto it = my variablesMap -> find (key [0] == U'.' ? Melder_cat (my procedureNames [my callDepth], key) : key);
-	if (it != my variablesMap -> end()) {
+	auto it = my variablesMap. find (key [0] == U'.' ? Melder_cat (my procedureNames [my callDepth], key) : key);
+	if (it != my variablesMap. end()) {
 		return it -> second;
 	} else {
 		return nullptr;
 	}
-	#else
-	long variableNumber = SortedSetOfString_lookUp (my variables,
-		key [0] == U'.' ? Melder_cat (my procedureNames [my callDepth], key) : key);
-	return variableNumber ? (InterpreterVariable) my variables -> item [variableNumber] : nullptr;
-	#endif
 }
 
 InterpreterVariable Interpreter_lookUpVariable (Interpreter me, const char32 *key) {
 	Melder_assert (key);
 	const char32 *variableNameIncludingProcedureName =
 		key [0] == U'.' ? Melder_cat (my procedureNames [my callDepth], key) : key;
-	#if USE_HASH
-	auto it = my variablesMap -> find (variableNameIncludingProcedureName);
-	if (it != my variablesMap -> end()) {
+	auto it = my variablesMap. find (variableNameIncludingProcedureName);
+	if (it != my variablesMap. end()) {
 		return it -> second;
 	}
-	/*
-	 * The variable doesn't yet exist: create a new one.
-	 */
-	InterpreterVariable variable = InterpreterVariable_create (variableNameIncludingProcedureName);
-	(*my variablesMap) [variableNameIncludingProcedureName] = variable;
-	return variable;
-	#else
-	long variableNumber = SortedSetOfString_lookUp (my variables, variableNameIncludingProcedureName);
-	if (variableNumber) return (InterpreterVariable) my variables -> item [variableNumber];   // already exists
 	/*
 	 * The variable doesn't yet exist: create a new one.
 	 */
 	autoInterpreterVariable variable = InterpreterVariable_create (variableNameIncludingProcedureName);
-	InterpreterVariable variable_ref = variable.peek();
-	Collection_addItem (my variables, variable.transfer());
+	InterpreterVariable variable_ref = variable.get();
+	variable.releaseToAmbiguousOwner();   // YUCK
+	my variablesMap [variableNameIncludingProcedureName] = variable_ref;
 	return variable_ref;
-	#endif
 }
 
 static long lookupLabel (Interpreter me, const char32 *labelName) {
@@ -800,7 +733,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 		lines.reset (1, numberOfLines);
 		for (lineNumber = 1, command = text; lineNumber <= numberOfLines; lineNumber ++, command += str32len (command) + 1 + chopped) {
 			int length;
-			while (*command == U' ' || *command == U'\t' || *command == UNICODE_NO_BREAK_SPACE) command ++;   // nbsp can occur for scripts copied from the manual
+			while (Melder_isblank (*command) || *command == UNICODE_NO_BREAK_SPACE) command ++;   // nbsp can occur for scripts copied from the manual
 			length = str32len (command);
 			/*
 			 * Chop trailing spaces?
@@ -837,16 +770,11 @@ void Interpreter_run (Interpreter me, char32 *text) {
 		/*
 		 * Copy the parameter names and argument values into the array of variables.
 		 */
-		#if USE_HASH
-		for (auto it = my variablesMap -> begin(); it != my variablesMap -> end(); it ++) {
+		for (auto it = my variablesMap. begin(); it != my variablesMap. end(); it ++) {
 			InterpreterVariable var = it -> second;
 			forget (var);
 		}
-		my variablesMap -> clear ();
-		#else
-		forget (my variables);
-		my variables = SortedSetOfString_create ();
-		#endif
+		my variablesMap. clear ();
 		for (ipar = 1; ipar <= my numberOfParameters; ipar ++) {
 			char32 parameter [200];
 			/*
@@ -865,7 +793,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 		Interpreter_addStringVariable (me, U"newline$", U"\n");
 		Interpreter_addStringVariable (me, U"tab$", U"\t");
 		Interpreter_addStringVariable (me, U"shellDirectory$", Melder_getShellDirectory ());
-		structMelderDir dir = { { 0 } }; Melder_getDefaultDir (& dir);
+		structMelderDir dir { { 0 } }; Melder_getDefaultDir (& dir);
 		Interpreter_addStringVariable (me, U"defaultDirectory$", Melder_dirToPath (& dir));
 		Interpreter_addStringVariable (me, U"preferencesDirectory$", Melder_dirToPath (& praatDir));
 		Melder_getHomeDir (& dir);
@@ -938,7 +866,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 					 * Found a right quote. Get potential variable name.
 					 */
 					for (r = p + 1, s = varName; q - r > 0; r ++, s ++) *s = *r;
-					*s = U'\0';   /* Trailing null byte. */
+					*s = U'\0';   // trailing null byte
 					colon = str32chr (varName, U':');
 					if (colon) {
 						precision = a32tol (colon + 1);
@@ -982,7 +910,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 						 * Look for a function name.
 						 */
 						char32 *p = command2.string + 1;
-						while (*p == U' ' || *p == U'\t') p ++;   // skip whitespace
+						while (Melder_isblank (*p)) p ++;   // skip whitespace
 						char32 *callName = p;
 						while (*p != U'\0' && *p != U' ' && *p != U'\t' && *p != U'(' && *p != U':') p ++;
 						if (p == callName) Melder_throw (U"Missing procedure name after \"@\".");
@@ -992,7 +920,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 							*p = U'\0';   // close procedure name
 							if (! parenthesisOrColonFound) {
 								p ++;   // step over first white space
-								while (*p != U'\0' && (*p == U' ' || *p == U'\t')) p ++;   // skip more whitespace
+								while (Melder_isblank (*p)) p ++;   // skip more whitespace
 								hasArguments = ( *p != U'\0' );
 								parenthesisOrColonFound = ( *p == U'(' || *p == U':' );
 								if (hasArguments && ! parenthesisOrColonFound)
@@ -1008,9 +936,9 @@ void Interpreter_run (Interpreter me, char32 *text) {
 								linei [4] != U'e' || linei [5] != U'd' || linei [6] != U'u' || linei [7] != U'r' ||
 								linei [8] != U'e' || linei [9] != U' ') continue;
 							q = lines [iline] + 10;
-							while (*q == U' ' || *q == U'\t') q ++;   // skip whitespace before procedure name
+							while (Melder_isblank (*q)) q ++;   // skip whitespace before procedure name
 							char32 *procName = q;
-							while (*q != U'\0' && *q != U' ' && *q != U'\t' && *q != U'(' && *q != U':') q ++;
+							while (*q != U'\0' && ! Melder_isblank (*q) && *q != U'(' && *q != U':') q ++;
 							if (q == procName) Melder_throw (U"Missing procedure name after 'procedure'.");
 							if (q - procName == callLength && str32nequ (procName, callName, callLength)) {
 								/*
@@ -1022,16 +950,16 @@ void Interpreter_run (Interpreter me, char32 *text) {
 								bool parenthesisOrColonFound = ( *q == U'(' || *q == U':' );
 								if (*q) q ++;   // step over parenthesis or colon or first white space
 								if (! parenthesisOrColonFound) {
-									while (*q == U' ' || *q == U'\t') q ++;   // skip more whitespace
+									while (Melder_isblank (*q)) q ++;   // skip more whitespace
 									if (*q == U'(' || *q == U':') q ++;   // step over parenthesis or colon
 								}
 								while (*q && *q != U')') {
 									static MelderString argument { 0 };
 									MelderString_empty (& argument);
-									while (*p == U' ' || *p == U'\t') p ++;
-									while (*q == U' ' || *q == U'\t') q ++;
+									while (Melder_isblank (*p)) p ++;
+									while (Melder_isblank (*q)) q ++;
 									char32 *parameterName = q;
-									while (*q != U'\0' && *q != U' ' && *q != U'\t' && *q != U',' && *q != U')') q ++;   // collect parameter name
+									while (*q != U'\0' && ! Melder_isblank (*q) && *q != U',' && *q != U')') q ++;   // collect parameter name
 									int expressionDepth = 0;
 									for (; *p; p ++) {
 										if (*p == U',') {
@@ -1124,7 +1052,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 							long iline;
 							bool hasArguments;
 							int64 callLength;
-							while (*p == U' ' || *p == U'\t') p ++;   // skip whitespace
+							while (Melder_isblank (*p)) p ++;   // skip whitespace
 							callName = p;
 							while (*p != U'\0' && *p != U' ' && *p != U'\t' && *p != U'(' && *p != U':') p ++;
 							if (p == callName) Melder_throw (U"Missing procedure name after 'call'.");
@@ -1138,7 +1066,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 									linei [4] != U'e' || linei [5] != U'd' || linei [6] != U'u' || linei [7] != U'r' ||
 									linei [8] != U'e' || linei [9] != U' ') continue;
 								q = lines [iline] + 10;
-								while (*q == U' ' || *q == U'\t') q ++;
+								while (Melder_isblank (*q)) q ++;
 								procName = q;
 								while (*q != U'\0' && *q != U' ' && *q != U'\t' && *q != U'(' && *q != U':') q ++;
 								if (q == procName) Melder_throw (U"Missing procedure name after 'procedure'.");
@@ -1155,7 +1083,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 										bool parenthesisOrColonFound = ( *q == U'(' || *q == U':' );
 										q ++;   // step over parenthesis or colon or first white space
 										if (! parenthesisOrColonFound) {
-											while (*q == U' ' || *q == U'\t') q ++;   // skip more whitespace
+											while (Melder_isblank (*q)) q ++;   // skip more whitespace
 											if (*q == U'(' || *q == U':') q ++;   // step over parenthesis or colon
 										}
 										++ p;   // first argument
@@ -1163,7 +1091,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 											char32 *par, save;
 											static MelderString arg { 0 };
 											MelderString_empty (& arg);
-											while (*p == U' ' || *p == U'\t') p ++;
+											while (Melder_isblank (*p)) p ++;
 											while (*q == U' ' || *q == U'\t' || *q == U',' || *q == U')') q ++;
 											par = q;
 											while (*q != U'\0' && *q != U' ' && *q != U'\t' && *q != U',' && *q != U')') q ++;   // collect parameter name
@@ -1540,7 +1468,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 						char32 *endOfVariable = ++ p;
 						char32 *variableName = command2.string;
 						int withFile;
-						while (*p == U' ' || *p == U'\t') p ++;   // go to first token after variable name
+						while (Melder_isblank (*p)) p ++;   // go to first token after variable name
 						if (*p == U'[') {
 							/*
 							 * This must be an assignment to an indexed string variable.
@@ -1553,17 +1481,28 @@ void Interpreter_run (Interpreter me, char32 *text) {
 								static MelderString index { 0 };
 								MelderString_empty (& index);
 								int depth = 0;
-								while ((depth > 0 || (*p != U',' && *p != U']')) && *p != U'\n' && *p != U'\0') {
+								bool inString = false;
+								while ((depth > 0 || (*p != U',' && *p != U']') || inString) && *p != U'\n' && *p != U'\0') {
 									MelderString_appendCharacter (& index, *p);
-									if (*p == U'[') depth ++;
-									else if (*p == U']') depth --;
+									if (*p == U'[') {
+										if (! inString) depth ++;
+									} else if (*p == U']') {
+										if (! inString) depth --;
+									}
+									if (*p == U'"') inString = ! inString;
 									p ++;
 								}
 								if (*p == U'\n' || *p == U'\0')
 									Melder_throw (U"Missing closing bracket (]) in indexed variable.");
-								double numericIndexValue;
-								Interpreter_numericExpression (me, index.string, & numericIndexValue);
-								MelderString_append (& indexedVariableName, numericIndexValue);
+								struct Formula_Result result;
+								Interpreter_anyExpression (me, index.string, & result);
+								if (result.expressionType == kFormula_EXPRESSION_TYPE_NUMERIC) {
+									double numericIndexValue = result.result.numericResult;
+									MelderString_append (& indexedVariableName, numericIndexValue);
+								} else if (result.expressionType == kFormula_EXPRESSION_TYPE_STRING) {
+									MelderString_append (& indexedVariableName, U"\"", result.result.stringResult, U"\"");
+									Melder_free (result.result.stringResult);
+								}
 								MelderString_appendCharacter (& indexedVariableName, *p);
 								if (*p == U']') {
 									break;
@@ -1572,7 +1511,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 							variableName = indexedVariableName.string;
 							p ++;   // skip closing bracket
 						}
-						while (*p == U' ' || *p == U'\t') p ++;   // go to first token after (perhaps indexed) variable name
+						while (Melder_isblank (*p)) p ++;   // go to first token after (perhaps indexed) variable name
 						if (*p == U'=') {
 							withFile = 0;   // assignment
 						} else if (*p == U'<') {
@@ -1581,11 +1520,11 @@ void Interpreter_run (Interpreter me, char32 *text) {
 							if (p [1] == U'>')
 								withFile = 2, p ++;   // append to file
 							else
-								withFile = 3;   /* Save to file. */
+								withFile = 3;   // save to file
 						} else Melder_throw (U"Missing '=', '<', or '>' after variable ", variableName, U".");
 						*endOfVariable = U'\0';
 						p ++;
-						while (*p == U' ' || *p == U'\t') p ++;   // go to first token after assignment or I/O symbol
+						while (Melder_isblank (*p)) p ++;   // go to first token after assignment or I/O symbol
 						if (*p == U'\0') {
 							if (withFile != 0)
 								Melder_throw (U"Missing file name after variable ", variableName, U".");
@@ -1639,25 +1578,191 @@ void Interpreter_run (Interpreter me, char32 *text) {
 							var -> stringValue = stringValue;   // var becomes owner
 						}
 					} else if (*p == U'#') {
-						/*
-						 * Assign to a numeric array variable.
-						 */
-						char32 *endOfVariable = ++ p;
-						while (*p == U' ' || *p == U'\t') p ++;   // go to first token after variable name
-						if (*p == U'=') {
-							;
-						} else Melder_throw (U"Missing '=' after variable ", command2.string, U".");
-						*endOfVariable = U'\0';
-						p ++;
-						while (*p == U' ' || *p == U'\t') p ++;   // go to first token after assignment or I/O symbol
-						if (*p == U'\0') {
-							Melder_throw (U"Missing expression after variable ", command2.string, U".");
+						if (p [1] == U'#') {
+							/*
+								Assign to a numeric matrix variable or to a matrix element.
+							*/
+							static MelderString matrixName { 0 };
+							p ++;   // go to second '#'
+							*p = U'\0';   // erase the last number sign temporarily
+							MelderString_copy (& matrixName, command2.string, U'#');
+							*p = U'#';   // put the number sign back
+							p ++;   // step over last number sign
+							while (Melder_isblank (*p)) p ++;   // go to first token after matrix name
+							if (*p == U'=') {
+								/*
+									This must be an assignment to a matrix variable.
+								*/
+								p ++;   // step over equals sign
+								while (Melder_isblank (*p)) p ++;   // go to first token after assignment
+								if (*p == U'\0')
+									Melder_throw (U"Missing right-hand expression in assignment to matrix ", matrixName.string, U".");
+								struct Formula_NumericMatrix value;
+								Interpreter_numericMatrixExpression (me, p, & value);
+								InterpreterVariable var = Interpreter_lookUpVariable (me, matrixName.string);
+								NUMmatrix_free (var -> numericMatrixValue. data, 1, 1);
+								var -> numericMatrixValue = value;
+							} else if (*p == U'[') {
+								/*
+								 * This must be an assignment to an element of the matrix variable.
+								 */
+								long rowNumber = 0, columnNumber = 0;
+								p ++;   // step over opening bracket
+								/*
+									Get the row number.
+								*/
+								static MelderString rowFormula { 0 };
+								MelderString_empty (& rowFormula);
+								int depth = 0;
+								bool inString = false;
+								while ((depth > 0 || *p != U',' || inString) && *p != U'\n' && *p != U'\0') {
+									MelderString_appendCharacter (& rowFormula, *p);
+									if (*p == U'[' || *p == U'(') {
+										if (! inString) depth ++;
+									} else if (*p == U']' || *p == U')') {
+										if (! inString) depth --;
+									}
+									if (*p == U'"') inString = ! inString;
+									p ++;
+								}
+								if (*p == U'\n' || *p == U'\0')
+									Melder_throw (U"Missing comma in matrix indexing.");
+								struct Formula_Result result;
+								Interpreter_anyExpression (me, rowFormula.string, & result);
+								if (result.expressionType == kFormula_EXPRESSION_TYPE_NUMERIC) {
+									rowNumber = lround (result.result.numericResult);
+								} else {
+									Melder_throw (U"Row number should be numeric.");
+								}
+
+								p ++;   // step over comma
+								/*
+									Get the column number.
+								*/
+								static MelderString columnFormula { 0 };
+								MelderString_empty (& columnFormula);
+								depth = 0;
+								inString = false;
+								while ((depth > 0 || *p != U']' || inString) && *p != U'\n' && *p != U'\0') {
+									MelderString_appendCharacter (& columnFormula, *p);
+									if (*p == U'[') {
+										if (! inString) depth ++;
+									} else if (*p == U']') {
+										if (! inString) depth --;
+									}
+									if (*p == U'"') inString = ! inString;
+									p ++;
+								}
+								if (*p == U'\n' || *p == U'\0')
+									Melder_throw (U"Missing closing bracket (]) in matrix indexing.");
+								Interpreter_anyExpression (me, columnFormula.string, & result);
+								if (result.expressionType == kFormula_EXPRESSION_TYPE_NUMERIC) {
+									columnNumber = lround (result.result.numericResult);
+								} else {
+									Melder_throw (U"Column number should be numeric.");
+								}
+								p ++;   // step over closing bracket
+								while (Melder_isblank (*p)) p ++;
+								if (*p != U'=')
+									Melder_throw (U"Missing '=' after matrix element ", matrixName.string, U" [",
+										rowFormula.string, U",", columnFormula.string, U"].");
+								p ++;   // step over equals sign
+								while (Melder_isblank (*p)) p ++;   // go to first token after assignment
+								if (*p == U'\0') {
+									Melder_throw (U"Missing expression after matrix element ", matrixName.string, U" [",
+										rowFormula.string, U",", columnFormula.string, U"].");
+								}
+								double value;
+								Interpreter_numericExpression (me, p, & value);
+								InterpreterVariable var = Interpreter_hasVariable (me, matrixName.string);
+								if (! var)
+									Melder_throw (U"Matrix ", matrixName.string, U" does not exist.");
+								if (rowNumber < 1)
+									Melder_throw (U"A row number cannot be less than 1 (the row number you supplied is ", rowNumber, U").");
+								if (rowNumber > var -> numericMatrixValue. numberOfRows)
+									Melder_throw (U"A row number cannot be greater than the number of rows (here ",
+										var -> numericMatrixValue. numberOfRows, U"). The row number you supplied is ", rowNumber, U".");
+								if (columnNumber < 1)
+									Melder_throw (U"A column number cannot be less than 1 (the column number you supplied is ", columnNumber, U").");
+								if (columnNumber > var -> numericMatrixValue. numberOfColumns)
+									Melder_throw (U"A column number cannot be greater than the number of columns (here ",
+										var -> numericMatrixValue. numberOfColumns, U"). The column number you supplied is ", columnNumber, U".");
+								var -> numericMatrixValue. data [rowNumber] [columnNumber] = value;
+							} else Melder_throw (U"Missing '=' after matrix variable ", matrixName.string, U".");
+						} else {
+							/*
+								Assign to a numeric vector variable or to a vector element.
+							*/
+							static MelderString vectorName { 0 };
+							*p = U'\0';   // erase the number sign temporarily
+							MelderString_copy (& vectorName, command2.string, U"#");
+							*p = U'#';   // put the number sign back
+							p ++;   // step over number sign
+							while (Melder_isblank (*p)) p ++;   // go to first token after array name
+							if (*p == U'=') {
+								/*
+									This must be an assignment to a vector variable.
+								*/
+								p ++;   // step over equals sign
+								while (Melder_isblank (*p)) p ++;   // go to first token after assignment
+								if (*p == U'\0')
+									Melder_throw (U"Missing right-hand expression in assignment to vector ", vectorName.string, U".");
+								struct Formula_NumericVector value;
+								Interpreter_numericVectorExpression (me, p, & value);
+								InterpreterVariable var = Interpreter_lookUpVariable (me, vectorName.string);
+								NUMvector_free (var -> numericVectorValue. data, 1);
+								var -> numericVectorValue = value;
+							} else if (*p == U'[') {
+								/*
+								 * This must be an assignment to an element of the vector variable.
+								 */
+								long indexValue = 0;
+								p ++;   // step over opening bracket
+								static MelderString index { 0 };
+								MelderString_empty (& index);
+								int depth = 0;
+								bool inString = false;
+								while ((depth > 0 || *p != U']' || inString) && *p != U'\n' && *p != U'\0') {
+									MelderString_appendCharacter (& index, *p);
+									if (*p == U'[') {
+										if (! inString) depth ++;
+									} else if (*p == U']') {
+										if (! inString) depth --;
+									}
+									if (*p == U'"') inString = ! inString;
+									p ++;
+								}
+								if (*p == U'\n' || *p == U'\0')
+									Melder_throw (U"Missing closing bracket (]) in array element.");
+								struct Formula_Result result;
+								Interpreter_anyExpression (me, index.string, & result);
+								if (result.expressionType == kFormula_EXPRESSION_TYPE_NUMERIC) {
+									indexValue = lround (result.result.numericResult);
+								} else {
+									Melder_throw (U"Element index should be numeric.");
+								}
+								p ++;   // step over closing bracket
+								while (Melder_isblank (*p)) p ++;
+								if (*p != U'=')
+									Melder_throw (U"Missing '=' after vector element ", vectorName.string, U" [", index.string, U"].");
+								p ++;   // step over equals sign
+								while (Melder_isblank (*p)) p ++;   // go to first token after assignment
+								if (*p == U'\0') {
+									Melder_throw (U"Missing expression after vector element ", vectorName.string, U" [", index.string, U"].");
+								}
+								double value;
+								Interpreter_numericExpression (me, p, & value);
+								InterpreterVariable var = Interpreter_hasVariable (me, vectorName.string);
+								if (! var)
+									Melder_throw (U"Vector ", vectorName.string, U" does not exist.");
+								if (indexValue < 1)
+									Melder_throw (U"A vector index cannot be less than 1 (the index you supplied is ", indexValue, U").");
+								if (indexValue > var -> numericVectorValue. numberOfElements)
+									Melder_throw (U"A vector index cannot be greater than the number of elements (here ",
+										var -> numericVectorValue. numberOfElements, U"). The index you supplied is ", indexValue, U".");
+								var -> numericVectorValue. data [indexValue] = value;
+							} else Melder_throw (U"Missing '=' after vector variable ", vectorName.string, U".");
 						}
-						struct Formula_NumericArray value;
-						Interpreter_numericArrayExpression (me, p, & value);
-						InterpreterVariable var = Interpreter_lookUpVariable (me, command2.string);
-						NUMmatrix_free (var -> numericArrayValue. data, 1, 1);
-						var -> numericArrayValue = value;
 					} else {
 						/*
 						 * Try to assign to a numeric variable.
@@ -1673,7 +1778,7 @@ void Interpreter_run (Interpreter me, char32 *text) {
 							continue;   // next line
 						}
 						char32 *endOfVariable = p;
-						while (*p == U' ' || *p == U'\t') p ++;
+						while (Melder_isblank (*p)) p ++;
 						if (*p == U'=' || ((*p == U'+' || *p == U'-' || *p == U'*' || *p == U'/') && p [1] == U'=')) {
 							/*
 							 * This must be an assignment (though: "echo = ..." ???)
@@ -1692,24 +1797,36 @@ void Interpreter_run (Interpreter me, char32 *text) {
 								static MelderString index { 0 };
 								MelderString_empty (& index);
 								int depth = 0;
-								while ((depth > 0 || (*p != U',' && *p != U']')) && *p != U'\n' && *p != U'\0') {
+								bool inString = false;
+								while ((depth > 0 || (*p != U',' && *p != U']') || inString) && *p != U'\n' && *p != U'\0') {
 									MelderString_appendCharacter (& index, *p);
-									if (*p == U'[') depth ++;
-									else if (*p == U']') depth --;
+									if (*p == U'[') {
+										if (! inString) depth ++;
+									} else if (*p == U']') {
+										if (! inString) depth --;
+									}
+									if (*p == U'"') inString = ! inString;
 									p ++;
 								}
 								if (*p == U'\n' || *p == U'\0')
 									Melder_throw (U"Missing closing bracket (]) in indexed variable.");
-								Interpreter_numericExpression (me, index.string, & value);
-								MelderString_append (& indexedVariableName, value);
+								struct Formula_Result result;
+								Interpreter_anyExpression (me, index.string, & result);
+								if (result.expressionType == kFormula_EXPRESSION_TYPE_NUMERIC) {
+									double numericIndexValue = result.result.numericResult;
+									MelderString_append (& indexedVariableName, numericIndexValue);
+								} else if (result.expressionType == kFormula_EXPRESSION_TYPE_STRING) {
+									MelderString_append (& indexedVariableName, U"\"", result.result.stringResult, U"\"");
+									Melder_free (result.result.stringResult);
+								}
 								MelderString_appendCharacter (& indexedVariableName, *p);
-								if (*p == ']') {
+								if (*p == U']') {
 									break;
 								}
 							}
 							variableName = indexedVariableName.string;
 							p ++;   // skip closing bracket
-							while (*p == U' ' || *p == U'\t') p ++;
+							while (Melder_isblank (*p)) p ++;
 							if (*p == U'=' || ((*p == U'+' || *p == U'-' || *p == U'*' || *p == U'/') && p [1] == U'=')) {
 								typeOfAssignment = *p == U'+' ? 1 : *p == U'-' ? 2 : *p == U'*' ? 3 : *p == U'/' ? 4 : 0;
 							}
@@ -1872,6 +1989,20 @@ void Interpreter_numericExpression (Interpreter me, const char32 *expression, do
 	}
 }
 
+void Interpreter_numericVectorExpression (Interpreter me, const char32 *expression, struct Formula_NumericVector *value) {
+	Formula_compile (me, nullptr, expression, kFormula_EXPRESSION_TYPE_NUMERIC_VECTOR, false);
+	struct Formula_Result result;
+	Formula_run (0, 0, & result);
+	*value = result. result.numericVectorResult;
+}
+
+void Interpreter_numericMatrixExpression (Interpreter me, const char32 *expression, struct Formula_NumericMatrix *value) {
+	Formula_compile (me, nullptr, expression, kFormula_EXPRESSION_TYPE_NUMERIC_MATRIX, false);
+	struct Formula_Result result;
+	Formula_run (0, 0, & result);
+	*value = result. result.numericMatrixResult;
+}
+
 void Interpreter_stringExpression (Interpreter me, const char32 *expression, char32 **value) {
 	Formula_compile (me, nullptr, expression, kFormula_EXPRESSION_TYPE_STRING, false);
 	struct Formula_Result result;
@@ -1879,13 +2010,6 @@ void Interpreter_stringExpression (Interpreter me, const char32 *expression, cha
 	*value = result. result.stringResult;
 }
 
-void Interpreter_numericArrayExpression (Interpreter me, const char32 *expression, struct Formula_NumericArray *value) {
-	Formula_compile (me, nullptr, expression, kFormula_EXPRESSION_TYPE_NUMERIC_ARRAY, false);
-	struct Formula_Result result;
-	Formula_run (0, 0, & result);
-	*value = result. result.numericArrayResult;
-}
-
 void Interpreter_anyExpression (Interpreter me, const char32 *expression, struct Formula_Result *result) {
 	Formula_compile (me, nullptr, expression, kFormula_EXPRESSION_TYPE_UNKNOWN, false);
 	Formula_run (0, 0, result);
