@@ -1,20 +1,19 @@
 /* Picture.cpp
  *
- * Copyright (C) 1992-2011,2012,2013,2014,2015 Paul Boersma, 2008 Stefan de Konink, 2010 Franz Brauße
+ * Copyright (C) 1992-2011,2012,2013,2014,2015,2016 Paul Boersma, 2008 Stefan de Konink, 2010 Franz Brauße
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "melder.h"
@@ -26,15 +25,7 @@
 	#include "GraphicsP.h"
 #endif
 
-struct structPicture {
-	GuiDrawingArea drawingArea;
-	Graphics graphics, selectionGraphics;
-	bool sensitive;
-	double selx1, selx2, sely1, sely2;   // selection in NDC co-ordinates
-	void (*selectionChangedCallback) (struct structPicture *, void *, double, double, double, double);
-	void *selectionChangedClosure;
-	bool backgrounding, mouseSelectsInnerViewport;
-};
+Thing_implement (Picture, Thing, 0);
 
 static void drawMarkers (Picture me)
 /*
@@ -50,85 +41,82 @@ static void drawMarkers (Picture me)
  */
 #define YELLOW_GRID 3
 {
-	int i;
-
 	/* Fill the entire canvas with GC's background. */
 
-	Graphics_setColour (my selectionGraphics, Graphics_WHITE);
-	Graphics_fillRectangle (my selectionGraphics, 0, SIDE, 0, SIDE);
+	Graphics_setColour (my selectionGraphics.get(), Graphics_WHITE);
+	Graphics_fillRectangle (my selectionGraphics.get(), 0, SIDE, 0, SIDE);
 
 	/* Draw yellow grid lines for coarse navigation. */
 
-	Graphics_setColour (my selectionGraphics, Graphics_YELLOW);
-	for (i = YELLOW_GRID; i < SIDE; i += YELLOW_GRID) {
-		Graphics_line (my selectionGraphics, 0, i, SIDE, i);
-		Graphics_line (my selectionGraphics, i, 0, i, SIDE);
+	Graphics_setColour (my selectionGraphics.get(), Graphics_YELLOW);
+	for (int i = YELLOW_GRID; i < SIDE; i += YELLOW_GRID) {
+		Graphics_line (my selectionGraphics.get(), 0, i, SIDE, i);
+		Graphics_line (my selectionGraphics.get(), i, 0, i, SIDE);
 	}
 
 	/* Draw red ticks and numbers for feedback on viewport measurement. */
 
-	Graphics_setColour (my selectionGraphics, Graphics_RED);
-	for (i = 1; i < SIDE; i ++) {
+	Graphics_setColour (my selectionGraphics.get(), Graphics_RED);
+	for (int i = 1; i < SIDE; i ++) {
 		double x = i;
-		Graphics_setTextAlignment (my selectionGraphics, Graphics_CENTRE, Graphics_TOP);
-		Graphics_text (my selectionGraphics, x, SIDE, i);
-		Graphics_setTextAlignment (my selectionGraphics, Graphics_CENTRE, Graphics_BOTTOM);
-		Graphics_text (my selectionGraphics, x, 0, i);
+		Graphics_setTextAlignment (my selectionGraphics.get(), Graphics_CENTRE, Graphics_TOP);
+		Graphics_text (my selectionGraphics.get(), x, SIDE, i);
+		Graphics_setTextAlignment (my selectionGraphics.get(), Graphics_CENTRE, Graphics_BOTTOM);
+		Graphics_text (my selectionGraphics.get(), x, 0, i);
 	}
-	for (i = 1; i < SQUARES ; i ++) {   /* Vertical ticks. */
+	for (int i = 1; i < SQUARES ; i ++) {   // vertical ticks
 		double x = 0.5 * i;
-		Graphics_line (my selectionGraphics, x, SIDE - 0.04, x, SIDE);
-		Graphics_line (my selectionGraphics, x, 0, x, 0.04);
+		Graphics_line (my selectionGraphics.get(), x, SIDE - 0.04, x, SIDE);
+		Graphics_line (my selectionGraphics.get(), x, 0, x, 0.04);
 	}
-	for (i = 1; i < SIDE; i ++) {
+	for (int i = 1; i < SIDE; i ++) {
 		double y = SIDE - i;
-		Graphics_setTextAlignment (my selectionGraphics, Graphics_LEFT, Graphics_HALF);
-		Graphics_text (my selectionGraphics, 0.04, y, i);
-		Graphics_setTextAlignment (my selectionGraphics, Graphics_RIGHT, Graphics_HALF);
-		Graphics_text (my selectionGraphics, SIDE - 0.03, y, i);
+		Graphics_setTextAlignment (my selectionGraphics.get(), Graphics_LEFT, Graphics_HALF);
+		Graphics_text (my selectionGraphics.get(), 0.04, y, i);
+		Graphics_setTextAlignment (my selectionGraphics.get(), Graphics_RIGHT, Graphics_HALF);
+		Graphics_text (my selectionGraphics.get(), SIDE - 0.03, y, i);
 	}
-	for (i = 1; i < SQUARES; i ++) {   /* Horizontal ticks. */
+	for (int i = 1; i < SQUARES; i ++) {   // horizontal ticks
 		double y = SIDE - 0.5 * i;
-		Graphics_line (my selectionGraphics, SIDE - 0.04, y, SIDE, y);
-		Graphics_line (my selectionGraphics, 0, y, 0.04, y);
+		Graphics_line (my selectionGraphics.get(), SIDE - 0.04, y, SIDE, y);
+		Graphics_line (my selectionGraphics.get(), 0, y, 0.04, y);
 	}
 
-	Graphics_setColour (my selectionGraphics, Graphics_BLACK);
+	Graphics_setColour (my selectionGraphics.get(), Graphics_BLACK);
 }
 
 static void drawSelection (Picture me, int high) {
-	double dx, dy;
 	if (my backgrounding) return;
-	dy = 2.8 * Graphics_inqFontSize (my graphics) / 72.0;
-	dx = 1.5 * dy;
+	double dy = 2.8 * Graphics_inqFontSize (my graphics.get()) / 72.0;
+	double dx = 1.5 * dy;
 	if (dy > 0.4 * (my sely2 - my sely1)) dy = 0.4 * (my sely2 - my sely1);
 	if (dx > 0.4 * (my selx2 - my selx1)) dx = 0.4 * (my selx2 - my selx1);
 	if (high) {
-		Graphics_highlight2 (my selectionGraphics, my selx1, my selx2, my sely1, my sely2,
+		Graphics_highlight2 (my selectionGraphics.get(), my selx1, my selx2, my sely1, my sely2,
 			my selx1 + dx, my selx2 - dx, my sely1 + dy, my sely2 - dy);
 	} else {
-		Graphics_unhighlight2 (my selectionGraphics, my selx1, my selx2, my sely1, my sely2,
+		Graphics_unhighlight2 (my selectionGraphics.get(), my selx1, my selx2, my sely1, my sely2,
 			my selx1 + dx, my selx2 - dx, my sely1 + dy, my sely2 - dy);
 	}
 }
 
 //static double test = 0.0;
 
-static void gui_drawingarea_cb_expose (I, GuiDrawingAreaExposeEvent event) {
-	iam (Picture);
-	(void) event;
+static void gui_drawingarea_cb_expose (Picture me, GuiDrawingArea_ExposeEvent event) {
 	#if gtk
 		/*
 		 * The size of the viewable part of the drawing area may have changed.
 		 */
 		Melder_assert (event -> widget);
 		#if ALLOW_GDK_DRAWING
-			gdk_cairo_reset_clip ((cairo_t *) Graphics_x_getCR (my graphics),          GDK_DRAWABLE (GTK_WIDGET (event -> widget -> d_widget) -> window));
-			gdk_cairo_reset_clip ((cairo_t *) Graphics_x_getCR (my selectionGraphics), GDK_DRAWABLE (GTK_WIDGET (event -> widget -> d_widget) -> window));
+			gdk_cairo_reset_clip ((cairo_t *) Graphics_x_getCR (my graphics.get()),          GDK_DRAWABLE (GTK_WIDGET (event -> widget -> d_widget) -> window));
+			gdk_cairo_reset_clip ((cairo_t *) Graphics_x_getCR (my selectionGraphics.get()), GDK_DRAWABLE (GTK_WIDGET (event -> widget -> d_widget) -> window));
 		#endif
+	#else
+		(void) event;
 	#endif
 	drawMarkers (me);
-	Graphics_play ((Graphics) my graphics, (Graphics) my graphics);
+	Graphics_play (my graphics.get(), my graphics.get());
 	drawSelection (me, 1);
 }
 
@@ -144,14 +132,13 @@ static void gui_drawingarea_cb_expose (I, GuiDrawingAreaExposeEvent event) {
 // (Paul:) No, running this through the normal event loop with mouse-down-drag-up events and generating exposes
 // redrew the entire picture window on every change of the selection during dragging. Much too slow!
 
-static void gui_drawingarea_cb_click (I, GuiDrawingAreaClickEvent event) {
-	iam (Picture);
+static void gui_drawingarea_cb_click (Picture me, GuiDrawingArea_ClickEvent event) {
 	int xstart = event -> x;
 	int ystart = event -> y;
 	double xWC, yWC;
 	int ixstart, iystart, ix, iy, oldix = 0, oldiy = 0;
 
-	Graphics_DCtoWC (my selectionGraphics, xstart, ystart, & xWC, & yWC);
+	Graphics_DCtoWC (my selectionGraphics.get(), xstart, ystart, & xWC, & yWC);
 	ix = ixstart = 1 + floor (xWC * SQUARES / SIDE);
 	iy = iystart = SQUARES - floor (yWC * SQUARES / SIDE);
 	if (ixstart < 1 || ixstart > SQUARES || iystart < 1 || iystart > SQUARES) return;
@@ -165,7 +152,7 @@ static void gui_drawingarea_cb_click (I, GuiDrawingAreaClickEvent event) {
 	}
 	//while (Graphics_mouseStillDown (my selectionGraphics)) {
 	do {
-		Graphics_getMouseLocation (my selectionGraphics, & xWC, & yWC);
+		Graphics_getMouseLocation (my selectionGraphics.get(), & xWC, & yWC);
 		ix = 1 + floor (xWC * SQUARES / SIDE);
 		iy = SQUARES - floor (yWC * SQUARES / SIDE);
 		if (ix >= 1 && ix <= SQUARES && iy >= 1 && iy <= SQUARES && (ix != oldix || iy != oldiy)) {
@@ -175,7 +162,7 @@ static void gui_drawingarea_cb_click (I, GuiDrawingAreaClickEvent event) {
 			if (iy < iystart) { iy1 = iy; iy2 = iystart; }
 			else              { iy1 = iystart; iy2 = iy; }
 			if (my mouseSelectsInnerViewport) {
-				int fontSize = Graphics_inqFontSize (my graphics);
+				int fontSize = Graphics_inqFontSize (my graphics.get());
 				double xmargin = fontSize * 4.2 / 72.0, ymargin = fontSize * 2.8 / 72.0;
 				if (xmargin > ix2 - ix1 + 1) xmargin = ix2 - ix1 + 1;
 				if (ymargin > iy2 - iy1 + 1) ymargin = iy2 - iy1 + 1;
@@ -187,10 +174,10 @@ static void gui_drawingarea_cb_click (I, GuiDrawingAreaClickEvent event) {
 			}
 			oldix = ix; oldiy = iy;
 		}
-	} while (Graphics_mouseStillDown (my selectionGraphics));
+	} while (Graphics_mouseStillDown (my selectionGraphics.get()));
 	// }
 	#if cocoa
-		Graphics_updateWs (my selectionGraphics);   // to change the dark red back into black
+		Graphics_updateWs (my selectionGraphics.get());   // to change the dark red back into black
 	#endif
 	if (my selectionChangedCallback) {
 		//Melder_casual (U"selectionChangedCallback from gui_drawingarea_cb_click");
@@ -199,10 +186,9 @@ static void gui_drawingarea_cb_click (I, GuiDrawingAreaClickEvent event) {
 	}
 }
 
-Picture Picture_create (GuiDrawingArea drawingArea, bool sensitive) {
-	Picture me = nullptr;
+autoPicture Picture_create (GuiDrawingArea drawingArea, bool sensitive) {
 	try {
-		me = Melder_calloc (struct structPicture, 1);
+		autoPicture me = Thing_new (Picture);
 		my drawingArea = drawingArea;
 		/*
 		 * The initial viewport is a rectangle 6 inches wide and 4 inches high.
@@ -215,24 +201,23 @@ Picture Picture_create (GuiDrawingArea drawingArea, bool sensitive) {
 		if (drawingArea) {
 			/* The drawing area must have been realized; see manual at XtWindow. */
 			my graphics = Graphics_create_xmdrawingarea (my drawingArea);
-			GuiDrawingArea_setExposeCallback (my drawingArea, gui_drawingarea_cb_expose, me);
+			GuiDrawingArea_setExposeCallback (my drawingArea, gui_drawingarea_cb_expose, me.get());
 		} else {
 			/*
 			 * Create a dummy Graphics.
 			 */
 			my graphics = Graphics_create (600);
 		}
-		Graphics_setWsWindow (my graphics, 0.0, 12.0, 0.0, 12.0);
-		Graphics_setViewport (my graphics, my selx1, my selx2, my sely1, my sely2);
+		Graphics_setWsWindow (my graphics.get(), 0.0, 12.0, 0.0, 12.0);
+		Graphics_setViewport (my graphics.get(), my selx1, my selx2, my sely1, my sely2);
 		if (my sensitive) {
 			my selectionGraphics = Graphics_create_xmdrawingarea (my drawingArea);
-			Graphics_setWindow (my selectionGraphics, 0, 12, 0, 12);
-			GuiDrawingArea_setClickCallback (my drawingArea, gui_drawingarea_cb_click, me);
+			Graphics_setWindow (my selectionGraphics.get(), 0, 12, 0, 12);
+			GuiDrawingArea_setClickCallback (my drawingArea, gui_drawingarea_cb_click, me.get());
 		}
-		Graphics_startRecording (my graphics);
+		Graphics_startRecording (my graphics.get());
 		return me;
 	} catch (MelderError) {
-		if (me) Melder_free (me);
 		Melder_throw (U"Picture not created.");
 	}
 }
@@ -249,17 +234,12 @@ void Picture_setMouseSelectsInnerViewport (Picture me, int mouseSelectsInnerView
 	my mouseSelectsInnerViewport = mouseSelectsInnerViewport;
 }
 
-void Picture_remove (Picture *pme) {
-	Picture me = *pme;
-	if (! me) return;
-	Picture_erase (me);
-	forget (my graphics);
-	if (my sensitive) forget (my selectionGraphics);
-	Melder_free (me);
-	*pme = nullptr;
+void structPicture :: v_destroy () noexcept {
+	Picture_erase (this);
+	Picture_Parent :: v_destroy ();
 }
 
-Graphics Picture_getGraphics (Picture me) { return my graphics; }
+Graphics Picture_peekGraphics (Picture me) { return my graphics.get(); }
 
 void Picture_unhighlight (Picture me) {
 	if (my drawingArea) drawSelection (me, 0);   // unselect
@@ -270,8 +250,8 @@ void Picture_highlight (Picture me) {
 }
 
 void Picture_erase (Picture me) {
-	Graphics_clearRecording (my graphics);
-	Graphics_clearWs (my graphics);
+	Graphics_clearRecording (my graphics.get());
+	Graphics_clearWs (my graphics.get());
 	if (my drawingArea) {
 		drawMarkers (me);
 		drawSelection (me, 1);
@@ -282,7 +262,7 @@ void Picture_writeToPraatPictureFile (Picture me, MelderFile file) {
 	try {
 		autofile f = Melder_fopen (file, "wb");
 		if (fprintf (f, "PraatPictureFile") < 0) Melder_throw (U"Write error.");
-		Graphics_writeRecordings (my graphics, f);
+		Graphics_writeRecordings (my graphics.get(), f);
 		f.close (file);
 	} catch (MelderError) {
 		Melder_throw (U"Cannot write Praat picture file ", file, U".");
@@ -301,8 +281,8 @@ void Picture_readFromPraatPictureFile (Picture me, MelderFile file) {
 		*end = '\0';
 		rewind (f);
 		fread (line, 1, end - line + strlen (tag), f);
-		Graphics_readRecordings (my graphics, f);
-		Graphics_updateWs (my graphics);
+		Graphics_readRecordings (my graphics.get(), f);
+		Graphics_updateWs (my graphics.get());
 		f.close (file);
 	} catch (MelderError) {
 		Melder_throw (U"Praat picture not read from file ", file);
@@ -331,9 +311,10 @@ void Picture_copyToClipboard (Picture me) {
 	CGRect rect = CGRectMake (0, 0, (my selx2 - my selx1) * resolution, (my sely1 - my sely2) * resolution);
 	CGContextRef context = CGPDFContextCreate (consumer, & rect, nullptr);
 	//my selx1 * RES, (12 - my sely2) * RES, my selx2 * RES, (12 - my sely1) * RES)
-	Graphics graphics = Graphics_create_pdf (context, resolution, my selx1, my selx2, my sely1, my sely2);
-	Graphics_play ((Graphics) my graphics, graphics);
-	forget (graphics);
+	{// scope
+		autoGraphics graphics = Graphics_create_pdf (context, resolution, my selx1, my selx2, my sely1, my sely2);
+		Graphics_play (my graphics.get(), graphics.get());
+	}
 	PasteboardPutItemFlavor (clipboard, (PasteboardItemID) 1, kUTTypePDF, data, kPasteboardFlavorNoFlags);
 	CFRelease (data);
 	/*
@@ -393,16 +374,16 @@ static HENHMETAFILE copyToMetafile (Picture me) {
 		MelderInfo_close ();
 	}
 	autoGraphics pictGraphics = Graphics_create_screen ((void *) dc, nullptr, resolution);
-	Graphics_setWsViewport (pictGraphics.peek(), 0, WIN_WIDTH * resolution, 0, WIN_HEIGHT * resolution);
-	Graphics_setWsWindow (pictGraphics.peek(), 0.0, WIN_WIDTH, 12.0 - WIN_HEIGHT, 12.0);
-	Graphics_play ((Graphics) my graphics, pictGraphics.peek());
+	Graphics_setWsViewport (pictGraphics.get(), 0, WIN_WIDTH * resolution, 0, WIN_HEIGHT * resolution);
+	Graphics_setWsWindow (pictGraphics.get(), 0.0, WIN_WIDTH, 12.0 - WIN_HEIGHT, 12.0);
+	Graphics_play (my graphics.get(), pictGraphics.get());
 	HENHMETAFILE metafile = CloseEnhMetaFile (dc);
 	return metafile;
 }
 void Picture_copyToClipboard (Picture me) {
 	try {
 		HENHMETAFILE metafile = copyToMetafile (me);
-		OpenClipboard (((GraphicsScreen) my graphics) -> d_winWindow);
+		OpenClipboard (((GraphicsScreen) my graphics.get()) -> d_winWindow);
 		EmptyClipboard ();
 		SetClipboardData (CF_ENHMETAFILE, metafile);
 		CloseClipboard ();
@@ -434,7 +415,7 @@ void Picture_writeToEpsFile (Picture me, MelderFile file, bool includeFonts, boo
 		{// scope
 			autoGraphics ps = Graphics_create_epsfile (file, 600, thePrinter. spots,
 				my selx1, my selx2, my sely1, my sely2, includeFonts, useSilipaPS);
-			Graphics_play ((Graphics) my graphics, ps.peek());
+			Graphics_play (my graphics.get(), ps.get());
 		}
 	} catch (MelderError) {
 		Melder_throw (U"Picture not written to EPS file ", file);
@@ -444,7 +425,7 @@ void Picture_writeToEpsFile (Picture me, MelderFile file, bool includeFonts, boo
 void Picture_writeToPdfFile (Picture me, MelderFile file) {
 	try {
 		autoGraphics graphics = Graphics_create_pdffile (file, 300, my selx1, my selx2, my sely1, my sely2);
-		Graphics_play ((Graphics) my graphics, graphics.peek());
+		Graphics_play (my graphics.get(), graphics.get());
 	} catch (MelderError) {
 		Melder_throw (U"Picture not written to PDF file ", file, U".");
 	}
@@ -453,7 +434,7 @@ void Picture_writeToPdfFile (Picture me, MelderFile file) {
 void Picture_writeToPngFile_300 (Picture me, MelderFile file) {
 	try {
 		autoGraphics graphics = Graphics_create_pngfile (file, 300, my selx1, my selx2, my sely1, my sely2);
-		Graphics_play ((Graphics) my graphics, graphics.peek());
+		Graphics_play (my graphics.get(), graphics.get());
 	} catch (MelderError) {
 		Melder_throw (U"Picture not written to PNG file ", file, U".");
 	}
@@ -462,15 +443,15 @@ void Picture_writeToPngFile_300 (Picture me, MelderFile file) {
 void Picture_writeToPngFile_600 (Picture me, MelderFile file) {
 	try {
 		autoGraphics graphics = Graphics_create_pngfile (file, 600, my selx1, my selx2, my sely1, my sely2);
-		Graphics_play ((Graphics) my graphics, graphics.peek());
+		Graphics_play (my graphics.get(), graphics.get());
 	} catch (MelderError) {
 		Melder_throw (U"Picture not written to PNG file ", file, U".");
 	}
 }
 
-static void print (I, Graphics printer) {
+static void print (void *void_me, Graphics printer) {
 	iam (Picture);
-	Graphics_play ((Graphics) my graphics, printer);
+	Graphics_play (my graphics.get(), printer);
 }
 
 void Picture_print (Picture me) {
