@@ -2,36 +2,18 @@
  *
  * Copyright (C) 1998-2011,2012,2013,2014,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-/*
- * pb 2003/02/05 distinct treatment of NT and non-NT
- * pb 2004/05/25 font choice strategy
- * pb 2004/09/25 use /tmp as temporary directory
- * pb 2005/05/19 preference to switch screen preview off
- * pb 2005/07/21 removed bug in previous change for Linux
- * pb 2006/10/28 erased MacOS 9 stuff
- * pb 2006/12/28 theCurrentPraat
- * pb 2007/04/28 Mac: error messages for failing PostScript passthrough
- * pb 2007/08/12 wchar
- * pb 2007/10/05 less char
- * pb 2007/12/09 enums
- * pb 2009/01/18 arguments to UiForm callbacks
- * pb 2011/05/15 C++
- * pb 2011/07/11 C++
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <unistd.h> // close
@@ -61,8 +43,7 @@
 	kGraphicsPostscript_spots_DEFAULT, kGraphicsPostscript_paperSize_DEFAULT, kGraphicsPostscript_orientation_DEFAULT, false,
 	true, kGraphicsPostscript_fontChoiceStrategy_DEFAULT,
 	600, 5100, 6600,
-	1.0,
-	NULL
+	1.0
 };
 
 void Printer_prefs () {
@@ -74,54 +55,29 @@ void Printer_prefs () {
 
 #if cocoa
 	static NSView *theMacView;
-#elif defined (macintosh)
-	static PMPrintSession theMacPrintSession;
-	static PMPageFormat theMacPageFormat;
-	static PMPrintSettings theMacPrintSettings;
-	static GrafPtr theMacPort;
-	static PMRect paperSize;
 #endif
 #ifdef _WIN32
 	static PRINTDLG theWinPrint;
 	static HDC theWinDC;
 #endif
 
-#if defined (_WIN32) || defined (macintosh)
+#if defined (_WIN32)
 	int Printer_postScript_printf (void *stream, const char *format, ... ) {
-		#if defined (_WIN32)
-			static union { char chars [3002]; short shorts [1501]; } theLine;
-		#elif cocoa
-		#elif defined (macintosh)
-			static Handle theLine;
-		#endif
+		static union { char chars [3002]; short shorts [1501]; } theLine;
 		int length;
 		va_list args;
 		va_start (args, format);
 		(void) stream;
-		#if cocoa
-		#elif defined (_WIN32)
-			vsprintf (theLine.chars + 2, format, args);
-			length = strlen (theLine.chars + 2);
-			theLine.shorts [0] = length;
-			if (length > 0 && theLine.chars [length + 1] == '\n') {
-				theLine.chars [length + 1] = '\r';
-				theLine.chars [length + 2] = '\n';
-				theLine.chars [length + 3] = '\0';
-				length ++;
-			}
-			Escape (theWinDC, POSTSCRIPT_PASSTHROUGH, length + 2, theLine.chars, NULL);
-		#elif defined (macintosh)
-			if (! theLine) {
-				theLine = NewHandle (3000);
-				HLock (theLine);
-			}
-			vsprintf (*theLine, format, args);
-			length = strlen (*theLine);
-			if (length > 0 && (*theLine) [length - 1] == '\n')
-				(*theLine) [length - 1] = '\r';
-			SetPort (theMacPort);
-			PMSessionPostScriptData (theMacPrintSession, *theLine, strlen (*theLine));
-		#endif
+		vsprintf (theLine.chars + 2, format, args);
+		length = strlen (theLine.chars + 2);
+		theLine.shorts [0] = length;
+		if (length > 0 && theLine.chars [length + 1] == '\n') {
+			theLine.chars [length + 1] = '\r';
+			theLine.chars [length + 2] = '\n';
+			theLine.chars [length + 3] = '\0';
+			length ++;
+		}
+		Escape (theWinDC, POSTSCRIPT_PASSTHROUGH, length + 2, theLine.chars, nullptr);
 		va_end (args);
 		return 1;
 	}
@@ -132,7 +88,7 @@ void Printer_prefs () {
 		/*
 		 * Save the driver's state.
 		 */
-		Printer_postScript_printf (NULL, "/PraatPictureSaveObject save def\n");
+		Printer_postScript_printf (nullptr, "/PraatPictureSaveObject save def\n");
 		/*
 		 * The LaserWriter driver puts the coordinates upside down.
 		 * According to the PostScript Reference Manual,
@@ -144,13 +100,13 @@ void Printer_prefs () {
 		 or whatever it is.
 		 */
 		#if 1
-		Printer_postScript_printf (NULL, "initmatrix initclip\n");
+		Printer_postScript_printf (nullptr, "initmatrix initclip\n");
 		#else
-Printer_postScript_printf (NULL, "8 8 scale initclip\n");
+Printer_postScript_printf (nullptr, "8 8 scale initclip\n");
 		#endif
 	}
 	static void exitPostScriptPage () {
-		Printer_postScript_printf (NULL, "PraatPictureSaveObject restore\n");
+		Printer_postScript_printf (nullptr, "PraatPictureSaveObject restore\n");
 	}
 #endif
 
@@ -158,28 +114,6 @@ Printer_postScript_printf (NULL, "8 8 scale initclip\n");
 #elif defined (_WIN32)
 	static void initPrinter () {
 	}
-#elif defined (macintosh)
-	static void initPrinter () {
-		Boolean result;
-		PMResolution res300 = { 300, 300 }, res600 = { 600, 600 };
-		if (theMacPrintSettings == NULL) {   /* Once. */
-			PMCreateSession (& theMacPrintSession);   /* Initialize the Printing Manager. */
-			PMCreatePageFormat (& theMacPageFormat);
-			PMCreatePrintSettings (& theMacPrintSettings);
-			PMSessionDefaultPageFormat (theMacPrintSession, theMacPageFormat);
-			PMSessionDefaultPrintSettings (theMacPrintSession, theMacPrintSettings);
-		}
-		PMSessionValidatePageFormat (theMacPrintSession, theMacPageFormat, & result);
-		PMSessionValidatePrintSettings (theMacPrintSession, theMacPrintSettings, & result);
-		/*
-		 * BUG.
-		 * If we now ask for the available printer resolutions,
-		 * we may get the answer that there's only 300 dpi (perhaps PostScript drivers say so?).
-		 * So we don't rely on that and have a buggy assumption instead.
-		 */
-		PMSetResolution (theMacPageFormat, & res300);   /* Perhaps all printers have this... */
-		PMSetResolution (theMacPageFormat, & res600);   /* ... but this is preferred. */
-	}
 #endif
 
 void Printer_nextPage () {
@@ -201,12 +135,6 @@ void Printer_nextPage () {
 			SetBkMode (theWinDC, TRANSPARENT);
 			SetTextAlign (theWinDC, TA_LEFT | TA_BASELINE | TA_NOUPDATECP);
 		}
-	#elif defined (macintosh)
-		PMSessionEndPage (theMacPrintSession);
-		PMSessionBeginPage (theMacPrintSession, theMacPageFormat, NULL);
-		PMSessionGetGraphicsContext (theMacPrintSession, kPMGraphicsContextQuickdraw, (void **) & theMacPort);
-		SetPort (theMacPort);
-		SetOrigin (- paperSize. left, - paperSize. top);
 	#endif
 }
 
@@ -215,10 +143,6 @@ int Printer_pageSetup () {
 		NSPageLayout *cocoaPageSetupDialog = [NSPageLayout pageLayout];
 		[cocoaPageSetupDialog runModal];
 	#elif defined (_WIN32)
-	#elif defined (macintosh)
-		Boolean accepted;
-		initPrinter ();
-		PMSessionPageSetupDialog (theMacPrintSession, theMacPageFormat, & accepted);
 	#endif
 	return 1;
 }
@@ -252,9 +176,9 @@ static void DO_Printer_postScriptSettings (UiForm dia, int /* narg */, Stackel /
 
 int Printer_postScriptSettings () {
 	static UiForm dia;
-	if (dia == NULL) {
-		Any radio;
-		dia = UiForm_create (theCurrentPraatApplication -> topShell, U"PostScript settings", DO_Printer_postScriptSettings, NULL, U"PostScript settings...", U"PostScript settings...");
+	if (! dia) {
+		UiField radio;
+		dia = UiForm_create (theCurrentPraatApplication -> topShell, U"PostScript settings", DO_Printer_postScriptSettings, nullptr, U"PostScript settings...", U"PostScript settings...");
 		#if defined (_WIN32)
 			BOOLEAN (U"Allow direct PostScript", true);
 		#endif
@@ -320,9 +244,10 @@ int Printer_postScriptSettings () {
 	- (void) drawRect: (NSRect) dirtyRect {
 		trace (U"printing ", dirtyRect. origin. x, U" ", dirtyRect. origin. y, U" ", dirtyRect. size. width, U" ", dirtyRect. size. height);
 		int currentPage = [[NSPrintOperation currentOperation] currentPage];
-		thePrinter. graphics = Graphics_create_screenPrinter (NULL, self);
-		theDraw (theBoss, thePrinter. graphics);
-		forget (thePrinter. graphics);
+		{// scope
+			autoGraphics graphics = Graphics_create_screenPrinter (nullptr, self);
+			theDraw (theBoss, graphics.get());
+		}
 	}
 	- (BOOL) isFlipped {
 		return YES;
@@ -351,10 +276,11 @@ int Printer_print (void (*draw) (void *boss, Graphics g), void *boss) {
 			char tempPath_utf8 [] = "/tmp/picXXXXXX";
 			close (mkstemp (tempPath_utf8));
 			Melder_pathToFile (Melder_peek8to32 (tempPath_utf8), & tempFile);
-			thePrinter. graphics = Graphics_create_postscriptjob (& tempFile, thePrinter. resolution,
-				thePrinter. spots, thePrinter. paperSize, thePrinter. orientation, thePrinter. magnification);
-			draw (boss, thePrinter. graphics);
-			forget (thePrinter. graphics);
+			{// scope
+				autoGraphics graphics = Graphics_create_postscriptjob (& tempFile, thePrinter. resolution,
+					thePrinter. spots, thePrinter. paperSize, thePrinter. orientation, thePrinter. magnification);
+				draw (boss, graphics.get());
+			}
 			char command [500];
 			sprintf (command, Melder_peek32to8 (Site_getPrintCommand ()), tempPath_utf8);
 			system (command);
@@ -393,12 +319,12 @@ int Printer_print (void (*draw) (void *boss, Graphics g), void *boss) {
 				 */
 				if (op) {
 					[op setCanSpawnSeparateThread: NO];
-					NSView *pictureView = ((GraphicsScreen) Picture_getGraphics ((Picture) boss)) -> d_macView;
+					NSView *pictureView = ((GraphicsScreen) Picture_peekGraphics ((Picture) boss)) -> d_macView;
 					[op
 						runOperationModalForWindow: [pictureView window]
 						delegate: cocoaPrintingArea
 						didRunSelector: @selector(printOperationDidRun:success:contextInfo:)
-						contextInfo: NULL
+						contextInfo: nil
 					];
 				}
 			#endif
@@ -415,7 +341,7 @@ int Printer_print (void (*draw) (void *boss, Graphics g), void *boss) {
 			}
 			if (Melder_backgrounding) {
 				theWinPrint. Flags = PD_RETURNDEFAULT | PD_RETURNDC;
-				if (! PrintDlg (& theWinPrint) || theWinPrint. hDC == NULL) {
+				if (! PrintDlg (& theWinPrint) || ! theWinPrint. hDC) {
 					Melder_throw (U"Cannot print from a script on this computer.");
 				}
 			} else {
@@ -425,7 +351,7 @@ int Printer_print (void (*draw) (void *boss, Graphics g), void *boss) {
 			}
 			theWinDC = theWinPrint. hDC;
 			thePrinter. postScript = thePrinter. allowDirectPostScript &&
-				Escape (theWinDC, QUERYESCSUPPORT, sizeof (int), (LPSTR) & postScriptCode, NULL);
+				Escape (theWinDC, QUERYESCSUPPORT, sizeof (int), (LPSTR) & postScriptCode, nullptr);
 			/*
 			 * The HP colour inkjet printer returns in dmFields:
 			 * 0, 1, 8, 9, 10, 11, 12, 13, 14, 15, 23, 24, 25, 26 = DM_ORIENTATION |
@@ -465,23 +391,25 @@ int Printer_print (void (*draw) (void *boss, Graphics g), void *boss) {
 			memset (& docInfo, 0, sizeof (DOCINFO));
 			docInfo. cbSize = sizeof (DOCINFO);
 			docInfo. lpszDocName = L"Praatjes";
-			docInfo. lpszOutput = NULL;
+			docInfo. lpszOutput = nullptr;
 			if (thePrinter. postScript) {
 				StartDoc (theWinDC, & docInfo);
 				StartPage (theWinDC);
 				initPostScriptPage ();
-				thePrinter. graphics = Graphics_create_postscriptprinter ();
-				draw (boss, thePrinter. graphics);
-				forget (thePrinter. graphics);
+				{// scope
+					autoGraphics graphics = Graphics_create_postscriptprinter ();
+					draw (boss, graphics.get());
+				}
 				exitPostScriptPage ();
 				EndPage (theWinDC);
 				EndDoc (theWinDC);
 			} else {
 				StartDoc (theWinDC, & docInfo);
 				StartPage (theWinDC);
-				thePrinter. graphics = Graphics_create_screenPrinter (NULL, theWinDC);
-				draw (boss, thePrinter. graphics);
-				forget (thePrinter. graphics);
+				{// scope
+					autoGraphics graphics = Graphics_create_screenPrinter (nullptr, theWinDC);
+					draw (boss, graphics.get());
+				}
 				if (EndPage (theWinDC) < 0) {
 					Melder_throw (U"Cannot print page.");
 				} else {
@@ -489,66 +417,10 @@ int Printer_print (void (*draw) (void *boss, Graphics g), void *boss) {
 				}
 			}
 			EnableWindow ((HWND) XtWindow (theCurrentPraatApplication -> topShell -> d_xmShell), true);
-			DeleteDC (theWinDC), theWinDC = NULL;
-		#elif defined (macintosh)
-			Boolean result;
-			initPrinter ();
-			if (Melder_backgrounding) {
-				PMSessionValidatePageFormat (theMacPrintSession, theMacPageFormat, & result);
-				PMSessionValidatePrintSettings (theMacPrintSession, theMacPrintSettings, & result);
-			} else {
-				Boolean accepted;
-				PMSessionPrintDialog (theMacPrintSession, theMacPrintSettings, theMacPageFormat, & accepted);
-				if (! accepted) return 1;   // normal cancelled return
-			}
-			PMSessionValidatePageFormat (theMacPrintSession, theMacPageFormat, & result);
-			PMSessionValidatePrintSettings (theMacPrintSession, theMacPrintSettings, & result);
-			PMResolution res;
-			PMGetResolution (theMacPageFormat, & res);
-			thePrinter. resolution = res. hRes;
-			PMGetAdjustedPaperRect (theMacPageFormat, & paperSize);
-			thePrinter. paperWidth = paperSize. right - paperSize. left;
-			thePrinter. paperHeight = paperSize. bottom - paperSize. top;
-			thePrinter. postScript = false;
-			PMOrientation orientation;
-			PMGetOrientation (theMacPageFormat, & orientation);
-			thePrinter. orientation = orientation == kPMLandscape ||
-				orientation == kPMReverseLandscape ? kGraphicsPostscript_orientation_LANDSCAPE : kGraphicsPostscript_orientation_PORTRAIT;
-			PMSessionBeginDocument (theMacPrintSession, theMacPrintSettings, theMacPageFormat);
-			PMSessionBeginPage (theMacPrintSession, theMacPageFormat, NULL);
-			PMSessionGetGraphicsContext (theMacPrintSession, kPMGraphicsContextQuickdraw, (void **) & theMacPort);
-			/*
-			 * On PostScript, the point (0, 0) is the bottom left corner of the paper, which is fine.
-			 * On the screen, however, the point (0, 0) is the top left corner of the writable page.
-			 * Since we want paper-related margins, not writable-page-related margins,
-			 * we require that this point gets the coordinates (250, 258) or so,
-			 * so that the top left corner of the paper gets coordinates (0, 0).
-			 * The "left" and "top" attributes of rPaper are negative values (e.g. -250 and -258),
-			 * so multiply them by -1.
-			 *
-			 * Under Carbon, the port has to be set inside the page.
-			 */
-			SetPort (theMacPort);
-			SetOrigin (- paperSize. left, - paperSize. top);
-			thePrinter. graphics = Graphics_create_screenPrinter (NULL, theMacPort);
-			draw (boss, thePrinter. graphics);
-			forget (thePrinter. graphics);
-			if (theMacPort) {
-				PMSessionEndPage (theMacPrintSession);
-				PMSessionEndDocument (theMacPrintSession);
-				theMacPort = NULL;
-			}
+			DeleteDC (theWinDC), theWinDC = nullptr;
 		#endif
 		return 1;
 	} catch (MelderError) {
-		#if cocoa
-		#elif defined (macintosh)
-			if (theMacPort) {
-				PMSessionEndPage (theMacPrintSession);
-				PMSessionEndDocument (theMacPrintSession);
-				theMacPort = NULL;
-			}
-		#endif
 		Melder_throw (U"Not printed.");
 	}
 }
