@@ -4,33 +4,30 @@
  *
  * Copyright (C) 1992-2012,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "Data.h"
 
 #include "Simple_def.h"
-oo_CLASS_CREATE (SimpleInt, Daata);
-oo_CLASS_CREATE (SimpleLong, Daata);
-oo_CLASS_CREATE (SimpleDouble, Daata);
-oo_CLASS_CREATE (SimpleString, Daata);
 
-SimpleInt SimpleInt_create (int number);
-SimpleLong SimpleLong_create (long number);
-SimpleDouble SimpleDouble_create (double number);
-SimpleString SimpleString_create (const char32 *string);
+autoSimpleInt SimpleInt_create (int number);
+autoSimpleLong SimpleLong_create (long number);
+autoSimpleDouble SimpleDouble_create (double number);
+autoSimpleString SimpleString_create (const char32 *string);
+
+int SimpleString_compare (SimpleString me, SimpleString thee) noexcept;
 
 /* End of file Simple.h */
 #endif
