@@ -1,20 +1,19 @@
 /* StringsEditor.cpp
  *
- * Copyright (C) 2007-2011,2015 Paul Boersma
+ * Copyright (C) 2007-2011,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "StringsEditor.h"
@@ -23,13 +22,11 @@
 
 Thing_implement (StringsEditor, Editor, 0);
 
-void structStringsEditor :: v_destroy () {
+void structStringsEditor :: v_destroy () noexcept {
 	StringsEditor_Parent :: v_destroy ();
 }
 
-static void menu_cb_help (EDITOR_ARGS) {
-	EDITOR_IAM (StringsEditor);
-	(void) me;
+static void menu_cb_help (StringsEditor /* me */, EDITOR_ARGS_DIRECT) {
 	Melder_help (U"StringsEditor");
 }
 
@@ -45,15 +42,13 @@ static void updateList (StringsEditor me) {
 		GuiList_insertItem (my list, strings -> strings [i], 0);
 }
 
-static void gui_button_cb_insert (I, GuiButtonEvent event) {
-	(void) event;
-	iam (StringsEditor);
+static void gui_button_cb_insert (StringsEditor me, GuiButtonEvent /* event */) {
 	Strings strings = (Strings) my data;
 	/*
 	 * Find the first selected item.
 	 */
 	long numberOfSelected, *selected = GuiList_getSelectedPositions (my list, & numberOfSelected);
-	long position = selected == NULL ? strings -> numberOfStrings + 1 : selected [1];
+	long position = selected ? selected [1] : strings -> numberOfStrings + 1;
 	NUMvector_free (selected, 1);
 	char32 *text = GuiText_getString (my text);
 	/*
@@ -73,9 +68,7 @@ static void gui_button_cb_insert (I, GuiButtonEvent event) {
 	Editor_broadcastDataChanged (me);
 }
 
-static void gui_button_cb_append (I, GuiButtonEvent event) {
-	(void) event;
-	iam (StringsEditor);
+static void gui_button_cb_append (StringsEditor me, GuiButtonEvent /* event */) {
 	Strings strings = (Strings) my data;
 	char32 *text = GuiText_getString (my text);
 	/*
@@ -95,9 +88,7 @@ static void gui_button_cb_append (I, GuiButtonEvent event) {
 	Editor_broadcastDataChanged (me);
 }
 
-static void gui_button_cb_remove (I, GuiButtonEvent event) {
-	(void) event;
-	iam (StringsEditor);
+static void gui_button_cb_remove (StringsEditor me, GuiButtonEvent /* event */) {
 	long numberOfSelected, *selected = GuiList_getSelectedPositions (my list, & numberOfSelected);
 	for (long iselected = numberOfSelected; iselected >= 1; iselected --) {
 		Strings_remove ((Strings) my data, selected [iselected]);
@@ -107,9 +98,7 @@ static void gui_button_cb_remove (I, GuiButtonEvent event) {
 	Editor_broadcastDataChanged (me);
 }
 
-static void gui_button_cb_replace (I, GuiButtonEvent event) {
-	(void) event;
-	iam (StringsEditor);
+static void gui_button_cb_replace (StringsEditor me, GuiButtonEvent /* event */) {
 	Strings strings = (Strings) my data;
 	long numberOfSelected, *selected = GuiList_getSelectedPositions (my list, & numberOfSelected);
 	char32 *text = GuiText_getString (my text);
@@ -121,17 +110,15 @@ static void gui_button_cb_replace (I, GuiButtonEvent event) {
 	Editor_broadcastDataChanged (me);
 }
 
-static void gui_list_cb_doubleClick (GuiObject widget, void *void_me, long item) {
-	(void) widget;
-	iam (StringsEditor);
+static void gui_list_cb_doubleClick (StringsEditor me, GuiList_DoubleClickEvent /* event */) {
 	Strings strings = (Strings) my data;
-	if (item <= strings -> numberOfStrings)
-		GuiText_setString (my text, strings -> strings [item]);
+	//if (event -> position <= strings -> numberOfStrings)   // FIXME
+	//	GuiText_setString (my text, strings -> strings [event -> position]);
 }
 
 void structStringsEditor :: v_createChildren () {
-	list = GuiList_create (d_windowForm, 1, 0, Machine_getMenuBarHeight (), -70, true, NULL);
-	//GuiList_setDoubleClickCallback (list, gui_list_cb_doubleClick, this);
+	list = GuiList_create (d_windowForm, 1, 0, Machine_getMenuBarHeight (), -70, true, nullptr);
+	GuiList_setDoubleClickCallback (list, gui_list_cb_doubleClick, this);
 	GuiThing_show (list);
 
 	text = GuiText_createShown (d_windowForm, 0, 0, -40 - Gui_TEXTFIELD_HEIGHT, -40, 0);
@@ -145,12 +132,12 @@ void structStringsEditor :: v_dataChanged () {
 	updateList (this);
 }
 
-StringsEditor StringsEditor_create (const char32 *title, Strings data) {
+autoStringsEditor StringsEditor_create (const char32 *title, Strings data) {
 	try {
 		autoStringsEditor me = Thing_new (StringsEditor);
-		Editor_init (me.peek(), 20, 40, 600, 600, title, data);
-		updateList (me.peek());
-		return me.transfer();
+		Editor_init (me.get(), 20, 40, 600, 600, title, data);
+		updateList (me.get());
+		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Strings window not created.");
 	}
