@@ -1,6 +1,6 @@
 /* melder.cpp
  *
- * Copyright (C) 1992-2012,2013,2014,2015,2016 Paul Boersma, 2008 Stefan de Konink, 2010 Franz Brausse, 2013 Tom Naughton
+ * Copyright (C) 1992-2012,2013,2014,2015,2016 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,29 +16,21 @@
  * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <time.h>
-#include <ctype.h>
-#include <assert.h>
+//#include <ctype.h>
+//#include <assert.h>
 #include "melder.h"
-#include "longchar.h"
 #include "regularExp.h"
 #ifdef _WIN32
 	#include <windows.h>
 #endif
-#if defined (macintosh)
-	#include "macport_on.h"
-	//#include <Sound.h>
-	#include "macport_off.h"
-#endif
 
-#include "Graphics.h"
-#include "machine.h"
+//#include "Graphics.h"
+//#include "machine.h"
 #ifdef macintosh
 	#include "macport_on.h"
 	#include <AudioToolbox/AudioToolbox.h>
 	#include "macport_off.h"
 #endif
-#include "Gui.h"
 
 #include "MelderThread.h"
 
@@ -54,8 +46,6 @@ bool Melder_backgrounding;   // are we running a script?- Set and unset dynamica
 bool Melder_asynchronous;
 int32 Melder_systemVersion;
 
-GuiWindow Melder_topShell;
-
 static void defaultHelp (const char32 *query) {
 	Melder_flushError (U"Don't know how to find help on \"", query, U"\".");
 }
@@ -64,6 +54,13 @@ static void defaultSearch () {
 	Melder_flushError (U"Do not know how to search.");
 }
 
+static void defaultProgress (double progress, const char32 *message) {
+}
+
+static void * defaultMonitor (double progress, const char32 *message) {
+	return NULL;
+}
+
 static void defaultWarning (const char32 *message) {
 	Melder_writeToConsole (U"Warning: ", true);
 	Melder_writeToConsole (message, true);
@@ -99,6 +96,8 @@ static int defaultPublishPlayed () {
 static struct {
 	void (*help) (const char32 *query);
 	void (*search) ();
+	void (*progress) (double progress, const char32 *message);
+	void * (*monitor) (double progress, const char32 *message);
 	void (*warning) (const char32 *message);
 	void (*fatal) (const char32 *message);
 	int (*record) (double duration);
@@ -109,6 +108,7 @@ static struct {
 }
 	theMelder = {
 		defaultHelp, defaultSearch,
+		defaultProgress, defaultMonitor,
 		defaultWarning, defaultFatal,
 		defaultRecord, defaultRecordFromFile, defaultPlay, defaultPlayReverse, defaultPublishPlayed
 	};
@@ -116,169 +116,12 @@ static struct {
 /********** PROGRESS **********/
 
 static int theProgressDepth = 0;
-static bool theProgressCancelled = false;
 void Melder_progressOff () { theProgressDepth --; }
 void Melder_progressOn () { theProgressDepth ++; }
 
-static bool waitWhileProgress (double progress, const char32 *message, GuiDialog dia, GuiProgressBar scale, GuiLabel label1, GuiLabel label2, GuiButton cancelButton) {
-	#if gtk
-		// Wait for all pending events to be processed. If anybody knows how to inspect GTK's
-		// event queue for specific events, dump the code here, please.
-		// Until then, the button click attaches a g_object data key named "pressed" to the cancelButton
-		// which this function reads out in order to tell whether interruption has occurred
-		while (gtk_events_pending ()) {
-			trace (U"event pending");
-			gtk_main_iteration ();
-		}
-	#elif defined (macintosh)
-		NSEvent *nsEvent = [NSApp
-			nextEventMatchingMask: NSAnyEventMask
-			untilDate: [NSDate distantPast]
-			inMode: NSDefaultRunLoopMode
-			dequeue: YES
-			];
-		if (nsEvent) {
-			NSUInteger nsEventType = [nsEvent type];
-			if (nsEventType == NSKeyDown) NSBeep ();
-			[[nsEvent window]  sendEvent: nsEvent];
-		}
-	#elif defined (_WIN32)
-		XEvent event;
-		while (PeekMessage (& event, 0, 0, 0, PM_REMOVE)) {
-			if (event. message == WM_KEYDOWN) {
-				/*
-				 * Ignore all key-down messages, except Escape.
-				 */
-				if (LOWORD (event. wParam) == VK_ESCAPE) {
-					XtUnmanageChild (dia -> d_widget);
-					return false;   // don't continue
-				}
-			} else if (event. message == WM_LBUTTONDOWN) {
-				/*
-				 * Ignore all mouse-down messages, except click in Interrupt button.
-				 */
-				GuiObject me = (GuiObject) GetWindowLongPtr (event. hwnd, GWLP_USERDATA);
-				if (me == cancelButton -> d_widget) {
-					XtUnmanageChild (dia -> d_widget);
-					return false;   // don't continue
-				}
-			} else if (event. message != WM_SYSKEYDOWN) {
-				/*
-				 * Process paint messages etc.
-				 */
-				DispatchMessage (& event);
-			}
-		}
-	#endif
-	if (progress >= 1.0) {
-		GuiThing_hide (dia);
-	} else {
-		if (progress <= 0.0) progress = 0.0;
-		GuiThing_show (dia);   // TODO: prevent raising to the front
-		const char32 *newline = str32chr (message, U'\n');
-		if (newline) {
-			static MelderString buffer { 0 };
-			MelderString_copy (& buffer, message);
-			buffer.string [newline - message] = U'\0';
-			GuiLabel_setText (label1, buffer.string);
-			buffer.string [newline - message] = U'\n';
-			GuiLabel_setText (label2, buffer.string + (newline - message) + 1);
-		} else {
-			GuiLabel_setText (label1, message);
-			GuiLabel_setText (label2, U"");
-		}
-		#if gtk
-			trace (U"update the progress bar");
-			GuiProgressBar_setValue (scale, progress);
-			while (gtk_events_pending ()) {
-				trace (U"event pending");
-				gtk_main_iteration ();
-			}
-			trace (U"check whether the cancel button has the \"pressed\" key set");
-			if (g_object_steal_data (G_OBJECT (cancelButton -> d_widget), "pressed")) {
-				trace (U"the cancel button has been pressed");
-				return false;   // don't continue
-			}
-		#elif cocoa
-			GuiProgressBar_setValue (scale, progress);
-			//[scale -> d_cocoaProgressBar   displayIfNeeded];
-			if (theProgressCancelled) {
-				theProgressCancelled = false;
-				return false;
-			}
-		#elif motif
-			GuiProgressBar_setValue (scale, progress);
-			GdiFlush ();
-		#endif
-	}
-	trace (U"continue");
-	return true;
-}
-
-static GuiButton theProgressCancelButton = nullptr;
-
-#if gtk || macintosh
-static void progress_dia_close (Thing /* boss */) {
-	theProgressCancelled = true;
-	#if gtk
-		g_object_set_data (G_OBJECT (theProgressCancelButton -> d_widget), "pressed", (gpointer) 1);
-	#endif
-}
-static void progress_cancel_btn_press (Thing /* boss */, GuiButtonEvent /* event */) {
-	theProgressCancelled = true;
-	#if gtk
-		g_object_set_data (G_OBJECT (theProgressCancelButton -> d_widget), "pressed", (gpointer) 1);
-	#endif
-}
-#endif
-
-static void _Melder_dia_init (GuiDialog *dia, GuiProgressBar *scale, GuiLabel *label1, GuiLabel *label2, GuiButton *cancelButton, bool hasMonitor) {
-	trace (U"creating the dialog");
-	*dia = GuiDialog_create (Melder_topShell, 200, 100, 400, hasMonitor ? 430 : 200, U"Work in progress",
-		#if gtk || macintosh
-			progress_dia_close, nullptr,
-		#else
-			nullptr, nullptr,
-		#endif
-		0);
-
-	trace (U"creating the labels");
-	*label1 = GuiLabel_createShown (*dia, 3, 403, 0, Gui_LABEL_HEIGHT, U"label1", 0);
-	*label2 = GuiLabel_createShown (*dia, 3, 403, 30, 30 + Gui_LABEL_HEIGHT, U"label2", 0);
-
-	trace (U"creating the scale");
-	*scale = GuiProgressBar_createShown (*dia, 3, -3, 70, 110, 0);
-
-	trace (U"creating the cancel button");
-	*cancelButton = GuiButton_createShown (*dia, 0, 400, 170, 170 + Gui_PUSHBUTTON_HEIGHT,
-		U"Interrupt",
-		#if gtk
-			progress_cancel_btn_press, nullptr,
-		#elif macintosh
-			progress_cancel_btn_press, nullptr,
-		#else
-			nullptr, nullptr,
-		#endif
-		0);
-	trace (U"end");
-}
-
 static void _Melder_progress (double progress, const char32 *message) {
 	if (! Melder_batch && theProgressDepth >= 0 && Melder_debug != 14) {
-		static clock_t lastTime;
-		static GuiDialog dia = nullptr;
-		static GuiProgressBar scale = nullptr;
-		static GuiLabel label1 = nullptr, label2 = nullptr;
-		clock_t now = clock ();
-		if (progress <= 0.0 || progress >= 1.0 ||
-			now - lastTime > CLOCKS_PER_SEC / 4)   // this time step must be much longer than the null-event waiting time
-		{
-			if (! dia)
-				_Melder_dia_init (& dia, & scale, & label1, & label2, & theProgressCancelButton, false);
-			if (! waitWhileProgress (progress, message, dia, scale, label1, label2, theProgressCancelButton))
-				Melder_throw (U"Interrupted!");
-			lastTime = now;
-		}
+		theMelder. progress (progress, message);
 	}
 }
 
@@ -344,41 +187,12 @@ void Melder_progress (double progress, Melder_19_ARGS) {
 	_Melder_progress (progress, theProgressBuffer.string);
 }
 
-static autoGraphics graphics;
-
-static void gui_drawingarea_cb_expose (Thing /* boss */, GuiDrawingArea_ExposeEvent /* event */) {
-	if (! graphics) return;
-	Graphics_play (graphics.get(), graphics.get());
-}
-
-static Graphics _Melder_monitor (double progress, const char32 *message) {
+static void * _Melder_monitor (double progress, const char32 *message) {
 	if (! Melder_batch && theProgressDepth >= 0) {
-		static clock_t lastTime;
-		static GuiDialog dia = nullptr;
-		static GuiProgressBar scale = nullptr;
-		static GuiDrawingArea drawingArea = nullptr;
-		static GuiButton cancelButton = nullptr;
-		static GuiLabel label1 = nullptr, label2 = nullptr;
-		clock_t now = clock ();
-		if (progress <= 0.0 || progress >= 1.0 ||
-			now - lastTime > CLOCKS_PER_SEC / 4)   // this time step must be much longer than the null-event waiting time
-		{
-			if (! dia) {
-				_Melder_dia_init (& dia, & scale, & label1, & label2, & cancelButton, true);
-				drawingArea = GuiDrawingArea_createShown (dia, 0, 400, 230, 430, gui_drawingarea_cb_expose, nullptr, nullptr, nullptr, nullptr, 0);
-				GuiThing_show (dia);
-				graphics = Graphics_create_xmdrawingarea (drawingArea);
-			}
-			if (graphics)
-				Graphics_flushWs (graphics.get());
-			if (! waitWhileProgress (progress, message, dia, scale, label1, label2, cancelButton))
-				Melder_throw (U"Interrupted!");
-			lastTime = now;
-			if (progress == 0.0)
-				return graphics.get();
-		}
+		void *result = theMelder. monitor (progress, message);
+		if (result) return result;
 	}
-	return progress <= 0.0 ? nullptr /* no Graphics */ : (Graphics) -1 /* any non-null pointer */;
+	return progress <= 0.0 ? nullptr /* no Graphics */ : (void *) -1 /* any non-null pointer */;
 }
 
 void * Melder_monitor (double progress) {
@@ -975,149 +789,6 @@ void Melder_assert_ (const char *fileName, int lineNumber, const char *condition
 	abort ();
 }
 
-#if defined (macintosh)
-static void mac_message (NSAlertStyle macAlertType, const char32 *message32) {
-	static unichar messageU [4000];
-	int messageLength = str32len (message32);
-	int j = 0;
-	for (int i = 0; i < messageLength && j <= 4000 - 3; i ++) {
-		char32 kar = message32 [i];
-		if (kar <= 0x00FFFF) {
-			messageU [j ++] = kar;
-		} else if (kar <= 0x10FFFF) {
-			kar -= 0x010000;
-			messageU [j ++] = 0x00D800 | (kar >> 10);
-			messageU [j ++] = 0x00DC00 | (kar & 0x0003FF);
-		}
-	}
-	messageU [j] = '\0';   // append null byte because we are going to search this string
-
-	/*
-	 * Split up the message between header (will appear in bold) and rest.
-	 * The split is done at the first line break, except if the first line ends in a colon,
-	 * in which case the split is done at the second line break.
-	 */
-	UniChar *lineBreak = & messageU [0];
-	for (; *lineBreak != '\0'; lineBreak ++) {
-		if (*lineBreak == '\n') {
-			break;
-		}
-	}
-	if (*lineBreak == '\n' && lineBreak - messageU > 0 && lineBreak [-1] == ':') {
-		for (lineBreak ++; *lineBreak != '\0'; lineBreak ++) {
-			if (*lineBreak == '\n') {
-				break;
-			}
-		}
-	}
-	/*
-	 * Create an alert dialog with an icon that is appropriate for the level.
-	 */
-	NSAlert *alert = [[NSAlert alloc] init];
-	[alert setAlertStyle: macAlertType];
-	/*
-	 * Add the header in bold.
-	 */
-	NSString *header = [[NSString alloc] initWithCharacters: messageU   length: lineBreak - messageU];   // note: init can change the object pointer!
-	if (header) {   // make this very safe, because we can be at error time or at fatal time
-		[alert setMessageText: header];
-		[header release];
-	}
-	/*
-	 * Add the rest of the message in small type.
-	 */
-	if (lineBreak - messageU < j) {
-		NSString *rest = [[NSString alloc] initWithCharacters: lineBreak + 1   length: j - 1 - (lineBreak - messageU)];
-		if (rest) {   // make this very safe, because we can be at error time or at fatal time
-			[alert setInformativeText: rest];
-			[rest release];
-		}
-	}
-	/*
-	 * Display the alert dialog and synchronously wait for the user to click OK.
-	 */
-	[alert runModal];
-	[alert release];
-}
-#endif
-
-#define theMessageFund_SIZE  100000
-static char * theMessageFund = nullptr;
-
-static void gui_fatal (const char32 *message) {
-	free (theMessageFund);
-	#if gtk
-		GuiObject dialog = gtk_message_dialog_new (GTK_WINDOW (Melder_topShell -> d_gtkWindow), GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", Melder_peek32to8 (message));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-	#elif defined (macintosh)
-		mac_message (NSCriticalAlertStyle, message);
-		SysError (11);
-	#elif defined (_WIN32)
-		MessageBox (nullptr, Melder_peek32toW (message), L"Fatal error", MB_OK | MB_TOPMOST | MB_ICONSTOP);
-	#endif
-}
-
-static void gui_error (const char32 *message) {
-	bool memoryIsLow = str32str (message, U"Out of memory");
-	if (memoryIsLow) {
-		free (theMessageFund);
-	}
-	#if gtk
-		trace (U"create dialog");
-		GuiObject dialog = gtk_message_dialog_new (GTK_WINDOW (Melder_topShell -> d_gtkWindow), GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, "%s", Melder_peek32to8 (message));
-		trace (U"run dialog");
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		trace (U"destroy dialog");
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-	#elif defined (macintosh)
-		mac_message (NSWarningAlertStyle, message);
-	#elif defined (_WIN32)
-		MessageBox (nullptr, Melder_peek32toW (message), L"Message", MB_OK | MB_TOPMOST | MB_ICONWARNING);   // or (HWND) XtWindow ((GuiObject) Melder_topShell)
-	#endif
-	if (memoryIsLow) {
-		theMessageFund = (char *) malloc (theMessageFund_SIZE);
-		if (! theMessageFund) {
-			#if gtk
-				GuiObject dialog = gtk_message_dialog_new (GTK_WINDOW (Melder_topShell -> d_gtkWindow), GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "Praat is very low on memory.\nSave your work and quit Praat.\nIf you don't do that, Praat may crash.");
-				gtk_dialog_run (GTK_DIALOG (dialog));
-				gtk_widget_destroy (GTK_WIDGET (dialog));
-			#elif defined (macintosh)
-				mac_message (NSCriticalAlertStyle, U"Praat is very low on memory.\nSave your work and quit Praat.\nIf you don't do that, Praat may crash.");
-			#elif defined (_WIN32)
-				MessageBox (nullptr, L"Praat is very low on memory.\nSave your work and quit Praat.\nIf you don't do that, Praat may crash.", L"Message", MB_OK);
-			#endif
-		}
-	}
-}
-
-static void gui_warning (const char32 *message) {
-	#if gtk
-		GuiObject dialog = gtk_message_dialog_new (GTK_WINDOW (Melder_topShell -> d_gtkWindow), GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_MESSAGE_INFO, GTK_BUTTONS_OK, "%s", Melder_peek32to8 (message));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-	#elif defined (macintosh)
-		mac_message (NSInformationalAlertStyle, message);
-	#elif defined (_WIN32)
-		MessageBox (nullptr, Melder_peek32toW (message), L"Warning", MB_OK | MB_TOPMOST | MB_ICONINFORMATION);
-	#endif
-}
-
-void gui_information (const char32 *);   // BUG: no prototype
-void MelderGui_create (void *parent) {
-	theMessageFund = (char *) malloc (theMessageFund_SIZE);
-	assert (theMessageFund);
-	Melder_topShell = (GuiWindow) parent;
-	Melder_setInformationProc (gui_information);
-	Melder_setFatalProc (gui_fatal);
-	Melder_setErrorProc (gui_error);
-	Melder_setWarningProc (gui_warning);
-}
-
 int Melder_record (double duration) {
 	return theMelder. record (duration);
 }
@@ -1149,6 +820,12 @@ void Melder_setSearchProc (void (*search) (void))
 void Melder_setWarningProc (void (*warning) (const char32 *))
 	{ theMelder. warning = warning ? warning : defaultWarning; }
 
+void Melder_setProgressProc (void (*progress) (double, const char32 *))
+	{ theMelder. progress = progress ? progress : defaultProgress; }
+
+void Melder_setMonitorProc (void * (*monitor) (double, const char32 *))
+	{ theMelder. monitor = monitor ? monitor : defaultMonitor; }
+
 void Melder_setFatalProc (void (*fatal) (const char32 *))
 	{ theMelder. fatal = fatal ? fatal : defaultFatal; }
 
