@@ -1,6 +1,6 @@
 /* melder_debug.cpp
  *
- * Copyright (C) 2000-2012,2014,2015 Paul Boersma
+ * Copyright (C) 2000-2012,2014,2015,2016 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -78,7 +78,7 @@ the behaviour of that program changes in the following way:
 46: trace GTK parent sizes in _GuiObject_position ()
 47: force resampling in OTGrammar RIP
 900: use DG Meta Serif Science instead of Palatino
-1264: Mac: Sound_recordFixedTime uses microphone "FW Solo (1264)"
+1264: Mac: Sound_record_fixedTime uses microphone "FW Solo (1264)"
 
 (negative values are for David)
 
@@ -605,7 +605,7 @@ void Melder_trace (const char *fileName, int lineNumber, const char *functionNam
 	Melder_trace_close (f);
 }
 
-#ifdef linux
+#if defined (linux) && ! defined (NO_GRAPHICS)
 static void theGtkLogHandler (const gchar *log_domain, GLogLevelFlags log_level, const gchar *message, gpointer unused_data) {
 	FILE *f = Melder_trace_open (nullptr, 0, "GTK");
 	fprintf (f, "%s", message);
@@ -633,7 +633,7 @@ void Melder_setTracing (bool tracing) {
 			U" at ", Melder_peek8to32 (ctime (& today))
 		);
 	Melder_isTracing = tracing;
-	#ifdef linux
+	#if defined (linux) && ! defined (NO_GRAPHICS)
 		static guint handler_id1, handler_id2, handler_id3;
 		if (tracing) {
 			handler_id1 = g_log_set_handler ("Gtk",          (GLogLevelFlags) (G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION), theGtkLogHandler,         nullptr);
