@@ -1,20 +1,19 @@
 /* melder_files.cpp
  *
- * Copyright (C) 1992-2012,2013,2014,2015 Paul Boersma, 2013 Tom Naughton
+ * Copyright (C) 1992-2012,2013,2014,2015,2016 Paul Boersma, 2013 Tom Naughton
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -58,11 +57,7 @@ using namespace std;
 #endif
 #if defined (macintosh)
 	#include "macport_on.h"
-    #if useCarbon
-        #include <Carbon/Carbon.h>
-    #else
-        #include <CoreFoundation/CoreFoundation.h>
-    #endif
+	#include <CoreFoundation/CoreFoundation.h>
 	#include "macport_off.h"
 #endif
 #include <errno.h>
@@ -82,11 +77,11 @@ extern "C" void FLAC__stream_encoder_delete (FLAC__StreamEncoder *);
 
 static char32 theShellDirectory [kMelder_MAXPATH+1];
 void Melder_rememberShellDirectory () {
-	structMelderDir shellDir = { { 0 } };
+	structMelderDir shellDir { { 0 } };
 	Melder_getDefaultDir (& shellDir);
 	str32cpy (theShellDirectory, Melder_dirToPath (& shellDir));
 }
-char32 * Melder_getShellDirectory () {
+const char32 * Melder_getShellDirectory () {
 	return & theShellDirectory [0];
 }
 
@@ -127,7 +122,7 @@ void Melder_str32To8bitFileRepresentation_inline (const char32 *string, char *ut
 		}
 		utf8 [j] = '\0';
 	#else
-		#error Unsupported platform.
+		//#error Unsupported platform.
 	#endif
 }
 
@@ -161,15 +156,6 @@ void Melder_8bitFileRepresentationToStr32_inline (const char *path8, char32 *pat
 }
 #endif
 
-#if defined (macintosh) && useCarbon
-	void Melder_machToFile (void *void_fsref, MelderFile file) {
-		FSRef *fsref = (FSRef *) void_fsref;
-		char path [kMelder_MAXPATH+1];
-		FSRefMakePath (fsref, (unsigned char *) path, kMelder_MAXPATH);   // decomposed UTF-8
-		Melder_8bitFileRepresentationToStr32_inline (path, file -> path);
-	}
-#endif
-
 const char32 * MelderFile_name (MelderFile file) {
 	#if defined (UNIX)
 		char32 *slash = str32rchr (file -> path, U'/');
@@ -177,16 +163,20 @@ const char32 * MelderFile_name (MelderFile file) {
 	#elif defined (_WIN32)
 		char32 *backslash = str32rchr (file -> path, U'\\');
 		return backslash ? backslash + 1 : file -> path;
+	#else
+		return nullptr;
 	#endif
 }
 
-char32 * MelderDir_name (MelderDir dir) {
+const char32 * MelderDir_name (MelderDir dir) {
 	#if defined (UNIX)
 		char32 *slash = str32rchr (dir -> path, U'/');
 		return slash ? slash + 1 : dir -> path;
 	#elif defined (_WIN32)
 		char32 *backslash = str32rchr (dir -> path, U'\\');
 		return backslash ? backslash + 1 : dir -> path;
+	#else
+		return nullptr;
 	#endif
 }
 
@@ -197,7 +187,6 @@ void Melder_pathToDir (const char32 *path, MelderDir dir) {
 void Melder_pathToFile (const char32 *path, MelderFile file) {
 	/*
 	 * This handles complete path names only.
-	 * Unlike Melder_relativePathToFile, this handles Windows file names with slashes in them.
 	 *
 	 * Used if we know for sure that we have a complete path name,
 	 * i.e. if the program determined the name (fileselector, printing, prefs).
@@ -208,7 +197,7 @@ void Melder_pathToFile (const char32 *path, MelderFile file) {
 void Melder_relativePathToFile (const char32 *path, MelderFile file) {
 	/*
 	 * This handles complete and partial path names,
-	 * and translates slashes to native directory separators (unlike Melder_pathToFile).
+	 * and translates slashes to native directory separators.
 	 *
 	 * Used if we do not know for sure that we have a complete path name,
 	 * i.e. if the user determined the name (scripting).
@@ -237,7 +226,7 @@ void Melder_relativePathToFile (const char32 *path, MelderFile file) {
 		 *    LPT1:
 		 *    \\host\path
 		 */
-		structMelderDir dir = { { 0 } };
+		structMelderDir dir { { 0 } };
 		if (path [0] == U'~' && path [1] == U'/') {
 			Melder_getHomeDir (& dir);
 			Melder_sprint (file -> path,kMelder_MAXPATH+1, dir. path, & path [1]);
@@ -271,11 +260,11 @@ void Melder_relativePathToFile (const char32 *path, MelderFile file) {
 	#endif
 }
 
-char32 * Melder_dirToPath (MelderDir dir) {
+const char32 * Melder_dirToPath (MelderDir dir) {
 	return & dir -> path [0];
 }
 
-char32 * Melder_fileToPath (MelderFile file) {
+const char32 * Melder_fileToPath (MelderFile file) {
 	return & file -> path [0];
 }
 
@@ -328,7 +317,7 @@ void MelderDir_getFile (MelderDir parent, const char32 *fileName, MelderFile fil
 }
 
 void MelderDir_relativePathToFile (MelderDir dir, const char32 *path, MelderFile file) {
-	structMelderDir saveDir = { { 0 } };
+	structMelderDir saveDir { { 0 } };
 	Melder_getDefaultDir (& saveDir);
 	Melder_setDefaultDir (dir);
 	Melder_relativePathToFile (path, file);
@@ -555,7 +544,7 @@ FILE * Melder_fopen (MelderFile file, const char *type) {
 	char utf8path [kMelder_MAXPATH+1];
 	Melder_str32To8bitFileRepresentation_inline (file -> path, utf8path);
 	FILE *f;
-	file -> openForWriting = type [0] == 'w' || type [0] == 'a' || strchr (type, '+');
+	file -> openForWriting = ( type [0] == 'w' || type [0] == 'a' || strchr (type, '+') );
 	if (str32equ (file -> path, U"<stdout>") && file -> openForWriting) {
 		f = stdout;
 	#ifdef CURLPRESENT
@@ -722,7 +711,7 @@ long MelderFile_length (MelderFile file) {
 		char utf8path [kMelder_MAXPATH+1];
 		Melder_str32To8bitFileRepresentation_inline (file -> path, utf8path);
 		struct stat statistics;
-		if (stat ((char *) utf8path, & statistics)) return -1;
+		if (stat ((char *) utf8path, & statistics) != 0) return -1;
 		return statistics. st_size;
 	#else
 		try {
@@ -795,7 +784,7 @@ void MelderFile_setDefaultDir (MelderFile file) {
 
 void Melder_createDirectory (MelderDir parent, const char32 *dirName, int mode) {
 #if defined (UNIX)
-	structMelderFile file = { 0 };
+	structMelderFile file { 0 };
 	if (dirName [0] == U'/') {
 		Melder_sprint (file. path,kMelder_MAXPATH+1, dirName);   // absolute path
 	} else if (parent -> path [0] == U'/' && parent -> path [1] == U'\0') {
@@ -808,7 +797,7 @@ void Melder_createDirectory (MelderDir parent, const char32 *dirName, int mode)
 	if (mkdir (utf8path, mode) == -1 && errno != EEXIST)   // ignore if directory already exists
 		Melder_throw (U"Cannot create directory ", & file, U".");
 #elif defined (_WIN32)
-	structMelderFile file = { 0 };
+	structMelderFile file { 0 };
 	SECURITY_ATTRIBUTES sa;
 	(void) mode;
 	sa. nLength = sizeof (SECURITY_ATTRIBUTES);
@@ -822,7 +811,7 @@ void Melder_createDirectory (MelderDir parent, const char32 *dirName, int mode)
 	if (! CreateDirectoryW (Melder_peek32toW (file. path), & sa) && GetLastError () != ERROR_ALREADY_EXISTS)   // ignore if directory already exists
 		Melder_throw (U"Cannot create directory ", & file, U".");
 #else
-	#error Unsupported operating system.
+	//#error Unsupported operating system.
 #endif
 }
 
@@ -880,7 +869,7 @@ char * MelderFile_readLine (MelderFile me) {
 
 MelderFile MelderFile_create (MelderFile me) {
 	my filePointer = Melder_fopen (me, "wb");
-	my openForWriting = true;   // A bit superfluous (will have been set by Melder_fopen).
+	my openForWriting = true;   // a bit superfluous (will have been set by Melder_fopen)
 	return me;
 }
 
@@ -894,9 +883,9 @@ void MelderFile_seek (MelderFile me, long position, int direction) {
 }
 
 long MelderFile_tell (MelderFile me) {
-	long result = 0;
 	if (! my filePointer) return 0;
-	if ((result = ftell (my filePointer)) == -1) {
+	long result = ftell (my filePointer);
+	if (result == -1) {
 		fclose (my filePointer);
 		my filePointer = nullptr;
 		Melder_throw (U"Cannot tell in file ", me, U".");
