@@ -1,6 +1,6 @@
 /* melder_info.cpp
  *
- * Copyright (C) 1992-2012,2014,2015 Paul Boersma
+ * Copyright (C) 1992-2012,2014,2015,2016 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -439,7 +439,7 @@ void MelderInfo_close () {
 			When writing to a diverted string, we must *not* add a newline symbol,
 			because scripts expect returned strings without appended newlines!
 		*/
-		if (theInfos -> length == 0 || theInfos -> string [theInfos -> length - 1] != U'\n') {   // Only if no newline there yet.
+		if (theInfos -> length == 0 || theInfos -> string [theInfos -> length - 1] != U'\n') {   // only if no newline there yet
 			MelderString_appendCharacter (theInfos, U'\n');
 			if (theInformation == defaultInformation) {
 				Melder_writeToConsole (U"\n", false);
@@ -461,12 +461,11 @@ void MelderInfo_drain () {
 
 void Melder_informationReal (double value, const char32 *units) {
 	MelderInfo_open ();
-	if (value == NUMundefined)
-		MelderInfo_write (U"--undefined--");
-	else if (! units)
+	if (! units) {
 		MelderInfo_write (value);
-	else
+	} else {
 		MelderInfo_write (value, U" ", units);
+	}
 	MelderInfo_close ();
 }
 
