@@ -169,16 +169,26 @@ static char32 * _MelderFile_readText (MelderFile file, char **string8) {
 				type = 1;   // big-endian 16-bit
 			} else if (firstByte == 0xFF && secondByte == 0xFE) {
 				type = 2;   // little-endian 16-bit
+			} else if (firstByte == 0xEF && secondByte == 0xBB && length >= 3) {
+				int thirdByte = fgetc (f);
+				if (thirdByte == 0xBF) {
+					type = -1;   // UTF-8 with BOM
+				}
 			}
 		}
-		if (type == 0) {
-			rewind (f);   // length and type already set correctly.
+		if (type <= 0) {
+			if (type == -1) {
+				length -= 3;
+				fseeko (f, 3, SEEK_SET);
+			} else {
+				rewind (f);   // length and type already set correctly.
+			}
 			autostring8 text8bit = Melder_malloc (char, length + 1);
 			Melder_assert (text8bit.peek());
 			size_t numberOfBytesRead = fread_multi (text8bit.peek(), (size_t) length, f);
 			if ((int64) numberOfBytesRead < length)
-				Melder_throw (U"The file contains ", length, U" bytes, but we could read only ",
-					numberOfBytesRead, U" of them.");
+				Melder_throw (U"The file contains ", length, U" bytes", type == -1 ? U" after the byte-order mark" : U"",
+					U", but we could read only ", numberOfBytesRead, U" of them.");
 			text8bit [length] = '\0';
 			/*
 			 * Count and repair null bytes.
