@@ -1,34 +1,19 @@
 /* melder_textencoding.cpp
  *
- * Copyright (C) 2007-2011,2014,2015 Paul Boersma
+ * Copyright (C) 2007-2011,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-/*
- * pb 2007/06/02 utf8 <-> wcs
- * pb 2007/06/14 separated from melder_strings.c and melder_alloc.c
- * pb 2007/06/16 text encoding preferences
- * pb 2007/08/12 prefs in wchar
- * pb 2007/09/04 Melder_malloc rather than malloc in Melder_wcsToAscii (had caused an error in counting memory leaks)
- * pb 2007/10/06 Melder_peekWcsToCfstring
- * pb 2007/12/09 made MelderFile_writeCharacter compatible with the ISO Latin-1 preference
- * pb 2008/11/05 split off from melder_encodings.c
- * pb 2010/03/08 support for Unicode values above 0xFFFF
- * pb 2011/04/05 C++
- * pb 2011/07/04 C++
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "melder.h"
@@ -39,11 +24,7 @@
 
 #if defined (macintosh)
 	#include "macport_on.h"
-    #if useCarbon
-        #include <Carbon/Carbon.h>
-    #else
-        #include <CoreFoundation/CoreFoundation.h>
-    #endif
+	#include <CoreFoundation/CoreFoundation.h>
 	#include "macport_off.h"
 #endif
 
@@ -207,7 +188,7 @@ size_t str32len_utf16 (const char32 *string, bool nativizeNewlines) {
 }
 
 char32 * Melder_peek8to32 (const char *textA) {
-	if (textA == NULL) return NULL;
+	if (! textA) return nullptr;
 	static MelderString buffers [19] { { 0 } };
 	static int ibuffer = 0;
 	if (++ ibuffer == 11) ibuffer = 0;
@@ -420,21 +401,21 @@ void Melder_8to32_inline (const char *string8, char32 *string32, int inputEncodi
 }
 
 char32 * Melder_8to32 (const char *string, int inputEncoding) {
-	if (string == NULL) return NULL;
+	if (! string) return nullptr;
 	autostring32 result = Melder_malloc (char32, (int64) strlen (string) + 1);
 	Melder_8to32_inline (string, result.peek(), inputEncoding);
 	return result.transfer();
 }
 
 char32 * Melder_8to32 (const char *string) {
-	if (string == NULL) return NULL;
+	if (! string) return nullptr;
 	autostring32 result = Melder_malloc (char32, (int64) strlen (string) + 1);
 	Melder_8to32_inline (string, result.peek(), kMelder_textInputEncoding_UTF8);
 	return result.transfer();
 }
 
 char32 * Melder_peek16to32 (const char16 *text) {
-	if (text == NULL) return nullptr;
+	if (! text) return nullptr;
 	static MelderString buffers [19] { { 0 } };
 	static int ibuffer = 0;
 	if (++ ibuffer == 19) ibuffer = 0;
@@ -493,16 +474,16 @@ void Melder_32to8_inline (const char32 *string, char *utf8) {
 }
 
 char * Melder_32to8 (const char32 *string) {
-	if (string == NULL) return NULL;
+	if (! string) return nullptr;
 	autostring8 result = Melder_malloc (char, (int64) str32len_utf8 (string, true) + 1);
 	Melder_32to8_inline (string, result.peek());
 	return result.transfer();
 }
 
 char * Melder_peek32to8 (const char32 *text) {
-	if (text == NULL) return NULL;
-	static char *buffer [19] = { NULL };
-	static int64 bufferSize [19] = { 0 };
+	if (! text) return nullptr;
+	static char *buffer [19] { nullptr };
+	static int64 bufferSize [19] { 0 };
 	static int ibuffer = 0;
 	if (++ ibuffer == 19) ibuffer = 0;
 	int64 sizeNeeded = str32len (text) * 4 + 1;
@@ -520,8 +501,8 @@ char * Melder_peek32to8 (const char32 *text) {
 }
 
 char16 * Melder_peek32to16 (const char32 *text, bool nativizeNewlines) {
-	if (text == NULL) return NULL;
-	static MelderString16 buffers [19] = { { 0 } };
+	if (! text) return nullptr;
+	static MelderString16 buffers [19] { { 0 } };
 	static int ibuffer = 0;
 	if (++ ibuffer == 19) ibuffer = 0;
 	MelderString16_empty (& buffers [ibuffer]);
@@ -555,12 +536,12 @@ char16 * Melder_32to16 (const char32 *text) {
 
 #if defined (macintosh)
 const void * Melder_peek32toCfstring (const char32 *text) {
-	if (text == NULL) return NULL;
+	if (! text) return nullptr;
 	static CFStringRef cfString [11];
 	static int icfString = 0;
 	if (++ icfString == 11) icfString = 0;
-	if (cfString [icfString] != NULL) CFRelease (cfString [icfString]);
-	cfString [icfString] = CFStringCreateWithCString (NULL, (const char *) Melder_peek32to8 (text), kCFStringEncodingUTF8);
+	if (cfString [icfString]) CFRelease (cfString [icfString]);
+	cfString [icfString] = CFStringCreateWithCString (nullptr, (const char *) Melder_peek32to8 (text), kCFStringEncodingUTF8);
 	return cfString [icfString];
 }
 #endif
