@@ -4,19 +4,18 @@
  *
  * Copyright (C) 1994-2012,2013,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*** Single types. ***/
@@ -212,14 +211,6 @@
 #define oo_STRUCT_VECTOR(Type,x,n)  oo_STRUCT_VECTOR_FROM (Type, x, 1, n)
 #define oo_STRUCT_MATRIX(Type,x,nrow,ncol)  oo_STRUCT_MATRIX_FROM (Type, x, 1, nrow, 1, ncol)
 
-/*** Class declaration in header file. ***/
-
-#define oo_CLASS_CREATE(klas,parent) \
-	extern struct structClassInfo theClassInfo_##klas; \
-	extern ClassInfo class##klas
-
-
-
 /********** Definitions for header files only. **********/
 /* These are undef'ed and redefined in the header files that implement methods, */
 /* like oo_DESTROY.h, oo_COPY.h, oo_EQUAL.h, oo_WRITE_TEXT.h, etc. */
@@ -248,9 +239,8 @@
 #define oo_STRUCT_VECTOR_FROM(Type,x,min,max)  Type x;
 #define oo_STRUCT_MATRIX_FROM(Type,x,row1,row2,col1,col2)  struct struct##Type **x;
 
-#define oo_OBJECT(Class,version,x)  Class x;
 #define oo_AUTO_OBJECT(Class,version,x)  auto##Class x;
-#define oo_COLLECTION(Class,x,ItemClass,version)  Class x;
+#define oo_COLLECTION_OF(Class,x,ItemClass,version)  Class<struct##ItemClass> x;
 #define oo_AUTO_COLLECTION(Class,x,ItemClass,version)  auto##Class x;
 #define oo_FILE(x)  structMelderFile x;
 #define oo_DIR(x)  structMelderDir x;
@@ -277,12 +267,14 @@
 	typedef struct struct##klas *klas; \
 	typedef _Thing_auto <struct##klas> auto##klas; \
 	typedef struct##parent klas##_Parent; \
+	extern struct structClassInfo theClassInfo_##klas; \
+	extern ClassInfo class##klas; \
 	struct struct##klas : public struct##parent {
 
 #define oo_END_CLASS(Class) \
-		void v_destroy () override; \
-		void v_copy (Any data_to) override; \
-		bool v_equal (Any otherData) override; \
+		void v_destroy () noexcept override; \
+		void v_copy (Daata data_to) override; \
+		bool v_equal (Daata otherData) override; \
 		static Data_Description s_description; \
 		Data_Description v_description () override { return s_description; } \
 		bool v_canWriteAsEncoding (int outputEncoding) override; \
