@@ -2,19 +2,18 @@
  *
  * Copyright (C) 2007-2012,2013,2014,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "oo_undef.h"
@@ -91,14 +90,13 @@
 				if (! our x [i] [j]. canWriteAsEncoding (encoding)) return false; \
 	}
 
-#define oo_OBJECT(Class,version,x)  \
-	if (our x && ! Data_canWriteAsEncoding (our x, encoding)) return false;
-
 #define oo_AUTO_OBJECT(Class,version,x)  \
 	if (our x && ! Data_canWriteAsEncoding (our x.get(), encoding)) return false;
 
-#define oo_COLLECTION(Class,x,ItemClass,version)  \
-	if (our x && ! Data_canWriteAsEncoding (our x, encoding)) return false;
+#define oo_COLLECTION_OF(Class,x,ItemClass,version)  \
+	for (long i = 1; i <= x.size; i ++) { \
+		if (our x.at [i] && ! Data_canWriteAsEncoding (our x.at [i], encoding)) return false; \
+	}
 
 #define oo_AUTO_COLLECTION(Class,x,ItemClass,version)  \
 	if (our x && ! Data_canWriteAsEncoding (our x.get(), encoding)) return false;
