@@ -2,19 +2,18 @@
  *
  * Copyright (C) 1994-2012,2013,2014,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "oo_undef.h"
@@ -92,14 +91,21 @@
 				our x [i] [j]. copy (& thy x [i] [j]); \
 	}
 
-#define oo_OBJECT(Class,version,x)  \
-	if (our x) thy x = Data_copy (our x);
-
 #define oo_AUTO_OBJECT(Class,version,x)  \
 	if (our x) thy x = Data_copy (our x.get());
 
-#define oo_COLLECTION(Class,x,ItemClass,version)  \
-	if (our x) thy x = Data_copy (our x);
+#define oo_COLLECTION_OF(Class,x,ItemClass,version)  \
+	if (our x._capacity > 0) { \
+		thy x.at._elements = Melder_calloc (ItemClass, our x._capacity); \
+		thy x.at._elements --; \
+	} \
+	thy x.size = our x.size; \
+	thy x._capacity = our x._capacity; \
+	thy x._ownItems = our x._ownItems; \
+	thy x._ownershipInitialized = our x._ownershipInitialized; \
+	for (long i = 1; i <= our x.size; i ++) { \
+		if (our x.at [i]) thy x.at [i] = Data_copy (our x.at [i]).releaseToAmbiguousOwner(); \
+	}
 
 #define oo_AUTO_COLLECTION(Class,x,ItemClass,version)  \
 	if (our x) thy x = Data_copy (our x.get());
@@ -117,8 +123,8 @@
 	}
 
 #define oo_DEFINE_CLASS(Class,Parent)  \
-	void struct##Class :: v_copy (thou) { \
-		thouart (Class); \
+	void struct##Class :: v_copy (Daata thee_Daata) { \
+		Class thee = static_cast <Class> (thee_Daata); \
 		Class##_Parent :: v_copy (thee);
 
 #define oo_END_CLASS(Class)  \
