@@ -1,20 +1,19 @@
 /* oo_DESTROY.h
  *
- * Copyright (C) 1994-2012,2013,2014,2015 Paul Boersma
+ * Copyright (C) 1994-2012,2013,2014,2015,2016 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "oo_undef.h"
@@ -85,13 +84,9 @@
 		NUMmatrix_free <struct##Type> (our x, row1, col1); \
 	}
 
-#define oo_OBJECT(Class,version,x)  \
-	forget (our x);
-
 #define oo_AUTO_OBJECT(Class,version,x)
 
-#define oo_COLLECTION(Class,x,ItemClass,version)  \
-	forget (our x);
+#define oo_COLLECTION_OF(Class,x,ItemClass,version)
 
 #define oo_AUTO_COLLECTION(Class,x,ItemClass,version)
 
@@ -106,7 +101,7 @@
 	}
 
 #define oo_DEFINE_CLASS(Class,Parent)  \
-	void struct##Class :: v_destroy () { \
+	void struct##Class :: v_destroy () noexcept { \
 
 #define oo_END_CLASS(Class)  \
 		Class##_Parent :: v_destroy (); \
