@@ -2,19 +2,18 @@
  *
  * Copyright (C) 1994-2012,2013,2014,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "oo_undef.h"
@@ -88,30 +87,23 @@
 		for (long j = col1; j <= col2; j ++) \
 			our x [i] [j]. writeBinary (f);
 
-#define oo_OBJECT(Class,version,x)  \
-	binputex ((bool) our x, f); \
-	if (our x) \
-		Data_writeBinary (our x, f);
-
 #define oo_AUTO_OBJECT(Class,version,x)  \
 	binputex ((bool) our x, f); \
 	if (our x) \
 		Data_writeBinary (our x.get(), f);
 
-#define oo_COLLECTION(Class,x,ItemClass,version)  \
-	binputi4 (our x ? our x -> size : 0, f); \
-	if (our x) { \
-		for (long i = 1; i <= our x -> size; i ++) { \
-			ItemClass data = (ItemClass) our x -> item [i]; \
-			data -> struct##ItemClass :: v_writeBinary (f); \
-		} \
+#define oo_COLLECTION_OF(Class,x,ItemClass,version)  \
+	binputi4 (our x.size, f); \
+	for (long i = 1; i <= our x.size; i ++) { \
+		ItemClass data = our x.at [i]; \
+		data -> struct##ItemClass :: v_writeBinary (f); \
 	}
 
 #define oo_AUTO_COLLECTION(Class,x,ItemClass,version)  \
-	binputi4 (our x ? our x -> size : 0, f); \
+	binputi4 (our x ? our x->size : 0, f); \
 	if (our x) { \
-		for (long i = 1; i <= our x -> size; i ++) { \
-			ItemClass data = (ItemClass) our x -> item [i]; \
+		for (long i = 1; i <= our x->size; i ++) { \
+			ItemClass data = our x->at [i]; \
 			data -> struct##ItemClass :: v_writeBinary (f); \
 		} \
 	}
