@@ -1,20 +1,19 @@
 /* praat_logo.cpp
  *
- * Copyright (C) 1996-2012,2013,2014,2015 Paul Boersma, 2008 Stefan de Konink
+ * Copyright (C) 1996-2012,2013,2014,2015,2016 Paul Boersma, 2008 Stefan de Konink
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "praatP.h"
@@ -35,7 +34,7 @@ static void logo_defaultDraw (Graphics g) {
 	Graphics_text (g, 0.5, 0.6, praatP.title);
 	Graphics_setFontStyle (g, 0);
 	Graphics_setFontSize (g, 12);
-	Graphics_text (g, 0.5, 0.25, U"\\s{Built on the} %%Praat shell%\\s{,© Paul Boersma, 1992-2015");
+	Graphics_text (g, 0.5, 0.25, U"\\s{Built on the} %%Praat shell%\\s{,© Paul Boersma, 1992-2016");
 }
 
 static struct {
@@ -44,7 +43,7 @@ static struct {
 	GuiDialog dia;
 	GuiForm form;
 	GuiDrawingArea drawingArea;
-	Graphics graphics;
+	autoGraphics graphics;
 } theLogo = { 90, 40, logo_defaultDraw };
 
 #if motif
@@ -61,42 +60,38 @@ void praat_setLogo (double width_mm, double height_mm, void (*draw) (Graphics g)
 	theLogo.draw = draw;
 }
 
-static void gui_drawingarea_cb_expose (I, GuiDrawingAreaExposeEvent event) {
-	if (theLogo.graphics == NULL)
+static void gui_drawingarea_cb_expose (Thing /* me */, GuiDrawingArea_ExposeEvent event) {
+	if (! theLogo.graphics)
 		theLogo.graphics = Graphics_create_xmdrawingarea (theLogo.drawingArea);
 	#if gtk
 		#if ALLOW_GDK_DRAWING
-			Graphics_x_setCR (theLogo.graphics, gdk_cairo_create (GDK_DRAWABLE (GTK_WIDGET (event -> widget -> d_widget) -> window)));
+			Graphics_x_setCR (theLogo.graphics.get(), gdk_cairo_create (GDK_DRAWABLE (GTK_WIDGET (event -> widget -> d_widget) -> window)));
 		#else
-			Graphics_x_setCR (theLogo.graphics, gdk_cairo_create (gtk_widget_get_window (GTK_WIDGET (event -> widget -> d_widget))));
+			Graphics_x_setCR (theLogo.graphics.get(), gdk_cairo_create (gtk_widget_get_window (GTK_WIDGET (event -> widget -> d_widget))));
 		#endif
-		cairo_rectangle ((cairo_t *) Graphics_x_getCR (theLogo.graphics), (double) event->x, (double) event->y, (double) event->width, (double) event->height);
-		cairo_clip ((cairo_t *) Graphics_x_getCR (theLogo.graphics));
-		theLogo.draw (theLogo.graphics);
-		cairo_destroy ((cairo_t *) Graphics_x_getCR (theLogo.graphics));
+		cairo_rectangle ((cairo_t *) Graphics_x_getCR (theLogo.graphics.get()), (double) event->x, (double) event->y, (double) event->width, (double) event->height);
+		cairo_clip ((cairo_t *) Graphics_x_getCR (theLogo.graphics.get()));
+		theLogo.draw (theLogo.graphics.get());
+		cairo_destroy ((cairo_t *) Graphics_x_getCR (theLogo.graphics.get()));
 	#elif motif || cocoa
-		(void) void_me;
 		(void) event;
-		if (theLogo.graphics == NULL)
+		if (! theLogo.graphics)
 			theLogo.graphics = Graphics_create_xmdrawingarea (theLogo.drawingArea);
-		theLogo.draw (theLogo.graphics);
+		theLogo.draw (theLogo.graphics.get());
 	#endif
 }
 
-static void gui_drawingarea_cb_click (I, GuiDrawingAreaClickEvent event) {
-	(void) void_me;
-	(void) event;
+static void gui_drawingarea_cb_click (Thing /* me */, GuiDrawingArea_ClickEvent /* event */) {
  	GuiThing_hide (theLogo.form);
 }
 
-static void gui_cb_goAway (I) {
-	(void) void_me;
+static void gui_cb_goAway (Thing /* boss */) {
  	GuiThing_hide (theLogo.form);
 }
 
 void praat_showLogo (bool autoPopDown) {
 	#if gtk
-		static const gchar *authors [3] = { "Paul Boersma", "David Weenink", NULL };
+		static const gchar *authors [3] = { "Paul Boersma", "David Weenink", nullptr };
 
 		GuiObject dialog = gtk_about_dialog_new ();
 		#define xstr(s) str(s)
@@ -106,26 +101,26 @@ void praat_showLogo (bool autoPopDown) {
 		gtk_about_dialog_set_license (GTK_ABOUT_DIALOG (dialog), "GPL");
 		gtk_about_dialog_set_website (GTK_ABOUT_DIALOG (dialog), "http://www.praat.org");
 		//gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG (dialog), authors);
-		g_signal_connect (GTK_DIALOG (dialog), "response", G_CALLBACK (gtk_widget_destroy), NULL);
+		g_signal_connect (GTK_DIALOG (dialog), "response", G_CALLBACK (gtk_widget_destroy), nullptr);
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
 
 	#else
 		if (theCurrentPraatApplication -> batch || ! theLogo.draw) return;
 		if (! theLogo.dia) {
-			int width  = theLogo.width_mm  / 25.4 * Gui_getResolution (NULL);
-			int height = theLogo.height_mm / 25.4 * Gui_getResolution (NULL);
+			int width  = theLogo.width_mm  / 25.4 * Gui_getResolution (nullptr);
+			int height = theLogo.height_mm / 25.4 * Gui_getResolution (nullptr);
 			theLogo.dia = GuiDialog_create (theCurrentPraatApplication -> topShell, 100, 100, width, height,
-				U"About", gui_cb_goAway, NULL, 0);
+				U"About", gui_cb_goAway, nullptr, 0);
 			theLogo.form = theLogo.dia;
 			theLogo.drawingArea = GuiDrawingArea_createShown (theLogo.form, 0, width, 0, height,
-				gui_drawingarea_cb_expose, gui_drawingarea_cb_click, NULL, NULL, NULL, 0);
+				gui_drawingarea_cb_expose, gui_drawingarea_cb_click, nullptr, nullptr, nullptr, 0);
 		}
 		GuiThing_show (theLogo.form);
 		GuiThing_show (theLogo.dia);
 		#if motif
 			if (autoPopDown)
-				GuiAddTimeOut (2000, logo_timeOut, (XtPointer) NULL);
+				GuiAddTimeOut (2000, logo_timeOut, (XtPointer) nullptr);
 		#endif
 	#endif
 }
