@@ -33,37 +33,28 @@
 
 /********** Callbacks of the fixed buttons. **********/
 
-DIRECT2 (Remove) {
+DIRECT (PRAAT_Remove) {
 	WHERE_DOWN (SELECTED)
 		praat_removeObject (IOBJECT);
 	praat_show ();
-END2 }
+END }
 
-FORM (Rename, U"Rename object", U"Rename...") {
+FORM (MODIFY_Rename, U"Rename object", U"Rename...") {
 	LABEL (U"rename object", U"New name:")
-	TEXTFIELD (U"newName", U"")
-	OK2
-int IOBJECT; WHERE (SELECTED) SET_STRING (U"newName", NAME)
+	TEXTFIELD4 (newName, U"newName", U"")
+OK
+	WHERE (SELECTED) SET_STRING (U"newName", NAME)
 DO
-	char32 *string = GET_STRING (U"newName");
 	if (theCurrentPraatObjects -> totalSelection == 0)
 		Melder_throw (U"Selection changed!\nNo object selected. Cannot rename.");
 	if (theCurrentPraatObjects -> totalSelection > 1)
 		Melder_throw (U"Selection changed!\nCannot rename more than one object at a time.");
 	WHERE (SELECTED) break;
-	praat_cleanUpName (string);   // this is allowed because "string" is local and dispensible
-	#if 0
-	std::u32string newFullName = std::u32string (Thing_className (OBJECT) + U" " + string;
-	if (newFullName != std::u32string (FULL_NAME)) {
-		Melder_free (FULL_NAME), FULL_NAME = Melder_dup_f (newFullName.c_str());
-		praat_list_renameAndSelect (IOBJECT, (std::u32string (Melder_integer (ID)) + U". " + newFullName). c_str());
-		for (int ieditor = 0; ieditor < praat_MAXNUM_EDITORS; ieditor ++)
-			if (EDITOR [ieditor]) Thing_setName (EDITOR [ieditor], newFullName.c_str());
-		Thing_setName (OBJECT, string);
-	}
-	#else
+	static MelderString string;
+	MelderString_copy (& string, newName);
+	praat_cleanUpName (string.string);
 	static MelderString fullName { 0 };
-	MelderString_copy (& fullName, Thing_className (OBJECT), U" ", string);
+	MelderString_copy (& fullName, Thing_className (OBJECT), U" ", string.string);
 	if (! str32equ (fullName.string, FULL_NAME)) {
 		Melder_free (FULL_NAME), FULL_NAME = Melder_dup_f (fullName.string);
 		autoMelderString listName;
@@ -71,36 +62,34 @@ DO
 		praat_list_renameAndSelect (IOBJECT, listName.string);
 		for (int ieditor = 0; ieditor < praat_MAXNUM_EDITORS; ieditor ++)
 			if (EDITOR [ieditor]) Thing_setName (EDITOR [ieditor], fullName.string);
-		Thing_setName (OBJECT, string);
+		Thing_setName (OBJECT, string.string);
 	}
-	#endif
-END2 }
+END }
 
-FORM (Copy, U"Copy object", U"Copy...") {
+FORM (NEW1_Copy, U"Copy object", U"Copy...") {
 	LABEL (U"copy object", U"Name of new object:")
-	TEXTFIELD (U"newName", U"")
-	OK2
-{ int IOBJECT; WHERE (SELECTED) SET_STRING (U"newName", NAME) }
+	TEXTFIELD4 (newName, U"newName", U"")
+OK
+	WHERE (SELECTED) SET_STRING (U"newName", NAME)
 DO
 	if (theCurrentPraatObjects -> totalSelection == 0)
 		Melder_throw (U"Selection changed!\nNo object selected. Cannot copy.");
 	if (theCurrentPraatObjects -> totalSelection > 1)
 		Melder_throw (U"Selection changed!\nCannot copy more than one object at a time.");
 	WHERE (SELECTED) {
-		char32 *name = GET_STRING (U"newName");
-		praat_new (Data_copy ((Daata) OBJECT), name);
+		praat_new (Data_copy ((Daata) OBJECT), newName);
 	}
-END2 }
+END }
 
-DIRECT2 (Info) {
+DIRECT (INFO_Info) {
 	if (theCurrentPraatObjects -> totalSelection == 0)
 		Melder_throw (U"Selection changed!\nNo object selected. Cannot query.");
 	if (theCurrentPraatObjects -> totalSelection > 1)
 		Melder_throw (U"Selection changed!\nCannot query more than one object at a time.");
 	WHERE (SELECTED) Thing_infoWithIdAndFile (OBJECT, ID, & theCurrentPraatObjects -> list [IOBJECT]. file);
-END2 }
+END }
 
-DIRECT2 (Inspect) {
+DIRECT (WINDOW_Inspect) {
 	if (theCurrentPraatObjects -> totalSelection == 0)
 		Melder_throw (U"Selection changed!\nNo object selected. Cannot inspect.");
 	if (theCurrentPraatApplication -> batch) {
@@ -112,7 +101,7 @@ DIRECT2 (Inspect) {
 			editor.releaseToUser();
 		}
 	}
-END2 }
+END }
 
 /********** The fixed menus. **********/
 
@@ -141,20 +130,20 @@ GuiMenu praat_objects_resolveMenu (const char32 *menu) {
 
 /********** Callbacks of the Praat menu. **********/
 
-DIRECT2 (About) {
+DIRECT (WINDOW_About) {
 	praat_showLogo (false);
-END2 }
+END }
 
-DIRECT2 (praat_newScript) {
+DIRECT (WINDOW_praat_newScript) {
 	autoScriptEditor editor = ScriptEditor_createFromText (nullptr, nullptr);
 	editor.releaseToUser();
-END2 }
+END }
 
-DIRECT2 (praat_openScript) {
+DIRECT (WINDOW_praat_openScript) {
 	autoScriptEditor editor = ScriptEditor_createFromText (nullptr, nullptr);
 	TextEditor_showOpen (editor.get());
 	editor.releaseToUser();
-END2 }
+END }
 
 static ButtonEditor theReferenceToTheOnlyButtonEditor;
 
@@ -162,7 +151,7 @@ static void cb_ButtonEditor_destruction (Editor /* editor */) {
 	theReferenceToTheOnlyButtonEditor = nullptr;
 }
 
-DIRECT2 (praat_editButtons) {
+DIRECT (WINDOW_praat_editButtons) {
 	if (theReferenceToTheOnlyButtonEditor) {
 		Editor_raise (theReferenceToTheOnlyButtonEditor);
 	} else {
@@ -171,123 +160,118 @@ DIRECT2 (praat_editButtons) {
 		theReferenceToTheOnlyButtonEditor = editor.get();
 		editor.releaseToUser();
 	}
-END2 }
+END }
 
-FORM (praat_addMenuCommand, U"Add menu command", U"Add menu command...") {
-	WORD (U"Window", U"Objects")
-	WORD (U"Menu", U"New")
-	SENTENCE (U"Command", U"Hallo...")
-	SENTENCE (U"After command", U"")
-	INTEGER (U"Depth", U"0")
+FORM (PRAAT_addMenuCommand, U"Add menu command", U"Add menu command...") {
+	WORD4 (window, U"Window", U"Objects")
+	WORD4 (menu, U"Menu", U"New")
+	SENTENCE4 (command, U"Command", U"Hallo...")
+	SENTENCE4 (afterCommand, U"After command", U"")
+	INTEGER4 (depth, U"Depth", U"0")
 	LABEL (U"", U"Script file:")
-	TEXTFIELD (U"Script", U"/u/miep/hallo.praat")
-	OK2
+	TEXTFIELD4 (script, U"script", U"/u/miep/hallo.praat")
+	OK
 DO
-	praat_addMenuCommandScript (GET_STRING (U"Window"), GET_STRING (U"Menu"),
-		GET_STRING (U"Command"), GET_STRING (U"After command"),
-		GET_INTEGER (U"Depth"), GET_STRING (U"Script"));
-END2 }
+	praat_addMenuCommandScript (window, menu, command, afterCommand, depth, script);
+END }
 
-FORM (praat_hideMenuCommand, U"Hide menu command", U"Hide menu command...") {
-	WORD (U"Window", U"Objects")
-	WORD (U"Menu", U"New")
-	SENTENCE (U"Command", U"Hallo...")
-	OK2
+FORM (PRAAT_hideMenuCommand, U"Hide menu command", U"Hide menu command...") {
+	WORD4 (window, U"Window", U"Objects")
+	WORD4 (menu, U"Menu", U"New")
+	SENTENCE4 (command, U"Command", U"Hallo...")
+	OK
 DO
-	praat_hideMenuCommand (GET_STRING (U"Window"), GET_STRING (U"Menu"), GET_STRING (U"Command"));
-END2 }
+	praat_hideMenuCommand (window, menu, command);
+END }
 
-FORM (praat_showMenuCommand, U"Show menu command", U"Show menu command...") {
-	WORD (U"Window", U"Objects")
-	WORD (U"Menu", U"New")
-	SENTENCE (U"Command", U"Hallo...")
-	OK2
+FORM (PRAAT_showMenuCommand, U"Show menu command", U"Show menu command...") {
+	WORD4 (window, U"Window", U"Objects")
+	WORD4 (menu, U"Menu", U"New")
+	SENTENCE4 (command, U"Command", U"Hallo...")
+	OK
 DO
-	praat_showMenuCommand (GET_STRING (U"Window"), GET_STRING (U"Menu"), GET_STRING (U"Command"));
-END2 }
+	praat_showMenuCommand (window, menu, command);
+END }
 
-FORM (praat_addAction, U"Add action command", U"Add action command...") {
-	WORD (U"Class 1", U"Sound")
-	INTEGER (U"Number 1", U"0")
-	WORD (U"Class 2", U"")
-	INTEGER (U"Number 2", U"0")
-	WORD (U"Class 3", U"")
-	INTEGER (U"Number 3", U"0")
-	SENTENCE (U"Command", U"Play reverse")
-	SENTENCE (U"After command", U"Play")
-	INTEGER (U"Depth", U"0")
+FORM (PRAAT_addAction, U"Add action command", U"Add action command...") {
+	WORD4 (class1, U"Class 1", U"Sound")
+	INTEGER4 (number1, U"Number 1", U"0")
+	WORD4 (class2, U"Class 2", U"")
+	INTEGER4 (number2, U"Number 2", U"0")
+	WORD4 (class3, U"Class 3", U"")
+	INTEGER4 (number3, U"Number 3", U"0")
+	SENTENCE4 (command, U"Command", U"Play reverse")
+	SENTENCE4 (afterCommand, U"After command", U"Play")
+	INTEGER4 (depth, U"Depth", U"0")
 	LABEL (U"", U"Script file:")
-	TEXTFIELD (U"Script", U"/u/miep/playReverse.praat")
-	OK2
+	TEXTFIELD4 (script, U"script", U"/u/miep/playReverse.praat")
+	OK
 DO
-	praat_addActionScript (GET_STRING (U"Class 1"), GET_INTEGER (U"Number 1"),
-		GET_STRING (U"Class 2"), GET_INTEGER (U"Number 2"), GET_STRING (U"Class 3"),
-		GET_INTEGER (U"Number 3"), GET_STRING (U"Command"), GET_STRING (U"After command"),
-		GET_INTEGER (U"Depth"), GET_STRING (U"Script"));
-END2 }
+	praat_addActionScript (class1, number1, class2, number2, class3, number3, command, afterCommand, depth, script);
+END }
 
-FORM (praat_hideAction, U"Hide action command", U"Hide action command...") {
-	WORD (U"Class 1", U"Sound")
-	WORD (U"Class 2", U"")
-	WORD (U"Class 3", U"")
-	SENTENCE (U"Command", U"Play")
-	OK2
+FORM (PRAAT_hideAction, U"Hide action command", U"Hide action command...") {
+	WORD4 (class1, U"Class 1", U"Sound")
+	WORD4 (class2, U"Class 2", U"")
+	WORD4 (class3, U"Class 3", U"")
+	SENTENCE4 (command, U"Command", U"Play")
+	OK
 DO
-	praat_hideAction_classNames (GET_STRING (U"Class 1"), GET_STRING (U"Class 2"), GET_STRING (U"Class 3"), GET_STRING (U"Command"));
-END2 }
+	praat_hideAction_classNames (class1, class2, class3, command);
+END }
 
-FORM (praat_showAction, U"Show action command", U"Show action command...") {
-	WORD (U"Class 1", U"Sound")
-	WORD (U"Class 2", U"")
-	WORD (U"Class 3", U"")
-	SENTENCE (U"Command", U"Play")
-	OK2
+FORM (PRAAT_showAction, U"Show action command", U"Show action command...") {
+	WORD4 (class1, U"Class 1", U"Sound")
+	WORD4 (class2, U"Class 2", U"")
+	WORD4 (class3, U"Class 3", U"")
+	SENTENCE4 (command, U"Command", U"Play")
+	OK
 DO
-	praat_showAction_classNames (GET_STRING (U"Class 1"), GET_STRING (U"Class 2"), GET_STRING (U"Class 3"), GET_STRING (U"Command"));
-END2 }
+	praat_showAction_classNames (class1, class2, class3, command);
+END }
 
 /********** Callbacks of the Preferences menu. **********/
 
-FORM (TextInputEncodingSettings, U"Text reading preferences", U"Unicode") {
-	RADIO_ENUM (U"Encoding of 8-bit text files", kMelder_textInputEncoding, DEFAULT)
-	OK2
-SET_ENUM (U"Encoding of 8-bit text files", kMelder_textInputEncoding, Melder_getInputEncoding ())
+FORM (PREFS_TextInputEncodingSettings, U"Text reading preferences", U"Unicode") {
+	RADIO_ENUM4 (encodingOf8BitTextFiles, U"Encoding of 8-bit text files", kMelder_textInputEncoding, DEFAULT)
+OK
+	SET_ENUM (U"Encoding of 8-bit text files", kMelder_textInputEncoding, Melder_getInputEncoding ())
 DO
-	Melder_setInputEncoding (GET_ENUM (kMelder_textInputEncoding, U"Encoding of 8-bit text files"));
-END2 }
+	Melder_setInputEncoding ((kMelder_textInputEncoding) encodingOf8BitTextFiles);
+END }
 
-FORM (TextOutputEncodingSettings, U"Text writing preferences", U"Unicode") {
-	RADIO_ENUM (U"Output encoding", kMelder_textOutputEncoding, DEFAULT)
-	OK2
-SET_ENUM (U"Output encoding", kMelder_textOutputEncoding, Melder_getOutputEncoding ())
+FORM (PREFS_TextOutputEncodingSettings, U"Text writing preferences", U"Unicode") {
+	RADIO_ENUM4 (outputEncoding, U"Output encoding", kMelder_textOutputEncoding, DEFAULT)
+OK
+	SET_ENUM (U"Output encoding", kMelder_textOutputEncoding, Melder_getOutputEncoding ())
 DO
-	Melder_setOutputEncoding (GET_ENUM (kMelder_textOutputEncoding, U"Output encoding"));
-END2 }
+	Melder_setOutputEncoding ((kMelder_textOutputEncoding) outputEncoding);
+END }
 
-FORM (GraphicsCjkFontStyleSettings, U"CJK font style preferences", nullptr) {
-	OPTIONMENU_ENUM (U"CJK font style", kGraphics_cjkFontStyle, DEFAULT)
-	OK2
-SET_ENUM (U"CJK font style", kGraphics_cjkFontStyle, theGraphicsCjkFontStyle)
+FORM (PREFS_GraphicsCjkFontStyleSettings, U"CJK font style preferences", nullptr) {
+	OPTIONMENU_ENUM4 (cjkFontStyle, U"CJK font style", kGraphics_cjkFontStyle, DEFAULT)
+OK
+	SET_ENUM (U"CJK font style", kGraphics_cjkFontStyle, theGraphicsCjkFontStyle)
 DO
-	theGraphicsCjkFontStyle = GET_ENUM (kGraphics_cjkFontStyle, U"CJK font style");
-END2 }
+	theGraphicsCjkFontStyle = (kGraphics_cjkFontStyle) cjkFontStyle;
+END }
 
 /********** Callbacks of the Goodies menu. **********/
 
-FORM (praat_calculator, U"Calculator", U"Calculator") {
+FORM (STRING_praat_calculator, U"Calculator", U"Calculator") {
 	LABEL (U"", U"Type any numeric formula or string formula:")
-	TEXTFIELD (U"expression", U"5*5")
+	TEXTFIELD4 (expression, U"expression", U"5*5")
 	LABEL (U"", U"Note that you can include many special functions in your formula,")
 	LABEL (U"", U"including statistical functions and acoustics-auditory conversions.")
 	LABEL (U"", U"For details, click Help.")
-	OK2
+	OK
 DO
 	struct Formula_Result result;
 	if (! interpreter) {
 		autoInterpreter tempInterpreter = Interpreter_create (nullptr, nullptr);
-		Interpreter_anyExpression (tempInterpreter.get(), GET_STRING (U"expression"), & result);
+		Interpreter_anyExpression (tempInterpreter.get(), expression, & result);
 	} else {
-		Interpreter_anyExpression (interpreter, GET_STRING (U"expression"), & result);
+		Interpreter_anyExpression (interpreter, expression, & result);
 	}
 	switch (result. expressionType) {
 		case kFormula_EXPRESSION_TYPE_NUMERIC: {
@@ -302,22 +286,20 @@ DO
 		case kFormula_EXPRESSION_TYPE_NUMERIC_MATRIX: {
 		}
 	}
-END2 }
+END }
 
-FORM (praat_reportDifferenceOfTwoProportions, U"Report difference of two proportions", U"Difference of two proportions") {
-	INTEGER (U"left Row 1", U"71")
-	INTEGER (U"right Row 1", U"39")
-	INTEGER (U"left Row 2", U"93")
-	INTEGER (U"right Row 2", U"27")
-	OK2
+FORM (INFO_reportDifferenceOfTwoProportions, U"Report difference of two proportions", U"Difference of two proportions") {
+	INTEGER4 (a, U"left Row 1", U"71")
+	INTEGER4 (b, U"right Row 1", U"39")
+	INTEGER4 (c, U"left Row 2", U"93")
+	INTEGER4 (d, U"right Row 2", U"27")
+	OK
 DO
-	double a = GET_INTEGER (U"left Row 1"), b = GET_INTEGER (U"right Row 1");
-	double c = GET_INTEGER (U"left Row 2"), d = GET_INTEGER (U"right Row 2");
 	double n = a + b + c + d;
 	double aexp, bexp, cexp, dexp, crossDifference, x2;
-	REQUIRE (a >= 0 && b >= 0 && c >= 0 && d >= 0, U"Numbers must not be negative.")
-	REQUIRE ((a > 0 || b > 0) && (c > 0 || d > 0), U"Row totals must be positive.")
-	REQUIRE ((a > 0 || c > 0) && (b > 0 || d > 0), U"Column totals must be positive.")
+	if (a < 0 || b < 0 || c < 0 || d < 0) Melder_throw (U"The numbers should not be negative.");
+	if (a + b <= 0 || c + d <= 0) Melder_throw (U"The row totals should be positive.");
+	if (a + c <= 0 || b + d <= 0) Melder_throw (U"The column totals should be positive.");
 	MelderInfo_open ();
 	MelderInfo_writeLine (U"Observed row 1 =    ", lround (a), U"    ", lround (b));
 	MelderInfo_writeLine (U"Observed row 2 =    ", lround (c), U"    ", lround (d));
@@ -351,11 +333,11 @@ DO
 	MelderInfo_writeLine (U"Chi-square =    ", x2);
 	MelderInfo_writeLine (U"Two-tailed p =    ", NUMchiSquareQ (x2, 1));
 	MelderInfo_close ();
-END2 }
+END }
 
 /********** Callbacks of the Technical menu. **********/
 
-FORM (praat_debug, U"Set debugging options", nullptr) {
+FORM (PRAAT_debug, U"Set debugging options", nullptr) {
 	LABEL (U"", U"If you switch Tracing on, Praat will write lots of detailed ")
 	LABEL (U"", U"information about what goes on in Praat")
 	structMelderDir dir;
@@ -367,42 +349,63 @@ FORM (praat_debug, U"Set debugging options", nullptr) {
 		MelderDir_getFile (& dir, U"Tracing.txt", & file);
 	#endif
 	LABEL (U"", Melder_cat (U"to ", Melder_fileToPath (& file), U"."))
-	BOOLEAN (U"Tracing", false)
+	BOOLEAN4 (tracing, U"Tracing", false)
 	LABEL (U"", U"Setting the following to anything other than zero")
 	LABEL (U"", U"will alter the behaviour of Praat")
 	LABEL (U"", U"in unpredictable ways.")
-	INTEGER (U"Debug option", U"0")
-	OK2
-SET_INTEGER (U"Tracing", Melder_isTracing)
-SET_INTEGER (U"Debug option", Melder_debug)
+	INTEGER4 (debugOption, U"Debug option", U"0")
+OK
+	SET_INTEGER (U"Tracing", Melder_isTracing)
+	SET_INTEGER (U"Debug option", Melder_debug)
 DO
-	Melder_setTracing (GET_INTEGER (U"Tracing"));
-	Melder_debug = GET_INTEGER (U"Debug option");
-END2 }
+	Melder_setTracing (tracing);
+	Melder_debug = debugOption;
+END }
 
-DIRECT2 (praat_listReadableTypesOfObjects) {
+DIRECT (INFO_listReadableTypesOfObjects) {
 	Thing_listReadableClasses ();
-END2 }
+END }
 
-DIRECT2 (praat_reportSystemProperties) {
+FORM (INFO_praat_library_createC, U"PraatLib: Create C header or file", nullptr) {
+	BOOLEAN4 (isInHeader, U"Is in header", true)
+	BOOLEAN4 (includeCreateAPI, U"Include \"Create\" API", true)
+	BOOLEAN4 (includeReadAPI, U"Include \"Read\" API", true)
+	BOOLEAN4 (includeSaveAPI, U"Include \"Save\" API", true)
+	BOOLEAN4 (includeQueryAPI, U"Include \"Query\" API", true)
+	BOOLEAN4 (includeModifyAPI, U"Include \"Modify\" API", true)
+	BOOLEAN4 (includeToAPI, U"Include \"To\" API", true)
+	BOOLEAN4 (includeRecordAPI, U"Include \"Record\" API", true)
+	BOOLEAN4 (includePlayAPI, U"Include \"Play\" API", true)
+	BOOLEAN4 (includeDrawAPI, U"Include \"Draw\" API", true)
+	BOOLEAN4 (includeHelpAPI, U"Include \"Help\" API", false)
+	BOOLEAN4 (includeWindowAPI, U"Include \"Window\" API", false)
+	BOOLEAN4 (includeDemoAPI, U"Include \"Demo\" API", false)
+	OK
+DO
+	praat_library_createC (isInHeader, includeCreateAPI, includeReadAPI, includeSaveAPI,
+		includeQueryAPI, includeModifyAPI, includeToAPI, includeRecordAPI, includePlayAPI,
+		includeDrawAPI, includeHelpAPI, includeWindowAPI, includeDemoAPI);
+END }
+
+DIRECT (INFO_reportSystemProperties) {
 	praat_reportSystemProperties ();
-END2 }
+END }
 
-DIRECT2 (praat_reportGraphicalProperties) {
+DIRECT (INFO_reportGraphicalProperties) {
 	praat_reportGraphicalProperties ();
-END2 }
+END }
 
-DIRECT2 (praat_reportIntegerProperties) {
+DIRECT (INFO_reportIntegerProperties) {
 	praat_reportIntegerProperties ();
-END2 }
+END }
 
-DIRECT2 (praat_reportMemoryUse) {
+DIRECT (INFO_reportMemoryUse) {
 	praat_reportMemoryUse ();
-END2 }
+END }
 
-DIRECT2 (praat_reportTextProperties) {
+DIRECT (INFO_reportTextProperties) {
 	praat_reportTextProperties ();
-END2 }
+END }
 
 /********** Callbacks of the Open menu. **********/
 
@@ -432,13 +435,13 @@ static void readFromFile (MelderFile file) {
 	praat_updateSelection ();
 }
 
-FORM_READ2 (Data_readFromFile, U"Read Object(s) from file", 0, true) {
+FORM_READ (READMANY_Data_readFromFile, U"Read Object(s) from file", 0, true) {
 	readFromFile (file);
-END2 }
+END }
 
 /********** Callbacks of the Save menu. **********/
 
-FORM_WRITE2 (Data_writeToTextFile, U"Save Object(s) as one text file", nullptr, nullptr) {
+FORM_SAVE (SAVE_Data_writeToTextFile, U"Save Object(s) as one text file", nullptr, nullptr) {
 	if (theCurrentPraatObjects -> totalSelection == 1) {
 		LOOP {
 			iam (Daata);
@@ -448,9 +451,9 @@ FORM_WRITE2 (Data_writeToTextFile, U"Save Object(s) as one text file", nullptr,
 		autoCollection set = praat_getSelectedObjects ();
 		Data_writeToTextFile (set.get(), file);
 	}
-END2 }
+END }
 
-FORM_WRITE2 (Data_writeToShortTextFile, U"Save Object(s) as one short text file", nullptr, nullptr) {
+FORM_SAVE (SAVE_Data_writeToShortTextFile, U"Save Object(s) as one short text file", nullptr, nullptr) {
 	if (theCurrentPraatObjects -> totalSelection == 1) {
 		LOOP {
 			iam (Daata);
@@ -460,9 +463,9 @@ FORM_WRITE2 (Data_writeToShortTextFile, U"Save Object(s) as one short text file"
 		autoCollection set = praat_getSelectedObjects ();
 		Data_writeToShortTextFile (set.get(), file);
 	}
-END2 }
+END }
 
-FORM_WRITE2 (Data_writeToBinaryFile, U"Save Object(s) as one binary file", nullptr, nullptr) {
+FORM_SAVE (SAVE_Data_writeToBinaryFile, U"Save Object(s) as one binary file", nullptr, nullptr) {
 	if (theCurrentPraatObjects -> totalSelection == 1) {
 		LOOP {
 			iam (Daata);
@@ -472,24 +475,23 @@ FORM_WRITE2 (Data_writeToBinaryFile, U"Save Object(s) as one binary file", nullp
 		autoCollection set = praat_getSelectedObjects ();
 		Data_writeToBinaryFile (set.get(), file);
 	}
-END2 }
+END }
 
-FORM (ManPages_saveToHtmlDirectory, U"Save all pages as HTML files", nullptr) {
+FORM (PRAAT_ManPages_saveToHtmlDirectory, U"Save all pages as HTML files", nullptr) {
 	LABEL (U"", U"Type a directory name:")
-	TEXTFIELD (U"directory", U"")
-	OK2
-structMelderDir currentDirectory { { 0 } };
-Melder_getDefaultDir (& currentDirectory);
-SET_STRING (U"directory", Melder_dirToPath (& currentDirectory))
+	TEXTFIELD4 (directory, U"directory", U"")
+OK
+	structMelderDir currentDirectory { { 0 } };
+	Melder_getDefaultDir (& currentDirectory);
+	SET_STRING (U"directory", Melder_dirToPath (& currentDirectory))
 DO
-	char32 *directory = GET_STRING (U"directory");
 	LOOP {
 		iam (ManPages);
 		ManPages_writeAllToHtmlDir (me, directory);
 	}
-END2 }
+END }
 
-DIRECT2 (ManPages_view) {
+DIRECT (WINDOW_ManPages_view) {
 	LOOP {
 		iam (ManPages);
 		ManPage firstPage = my pages.at [1];
@@ -500,46 +502,45 @@ DIRECT2 (ManPages_view) {
 		praat_installEditor (manual.get(), IOBJECT);
 		manual.releaseToUser();
 	}
-END2 }
+END }
 
 /********** Callbacks of the Help menu. **********/
 
-FORM (SearchManual, U"Search manual", U"Manual") {
+FORM (HELP_SearchManual, U"Search manual", U"Manual") {
 	LABEL (U"", U"Search for strings (separate with spaces):")
-	TEXTFIELD (U"query", U"")
-	OK2
+	TEXTFIELD4 (query, U"query", U"")
+	OK
 DO
 	if (theCurrentPraatApplication -> batch)
 		Melder_throw (U"Cannot view a manual from batch.");
 	autoManual manual = Manual_create (U"Intro", theCurrentPraatApplication -> manPages, false);
-	Manual_search (manual.get(), GET_STRING (U"query"));
+	Manual_search (manual.get(), query);
 	manual.releaseToUser();
-END2 }
+END }
 
-FORM (GoToManualPage, U"Go to manual page", nullptr) {
-	{long numberOfPages;
-	const char32 **pages = ManPages_getTitles (theCurrentPraatApplication -> manPages, & numberOfPages);
-	LIST (U"Page", numberOfPages, pages, 1)}
-	OK2
+FORM (HELP_GoToManualPage, U"Go to manual page", nullptr) {
+	static long numberOfPages;
+	static const char32 **pages = ManPages_getTitles (theCurrentPraatApplication -> manPages, & numberOfPages);
+	LIST (U"Page", numberOfPages, pages, 1)
+	OK
 DO
 	if (theCurrentPraatApplication -> batch)
 		Melder_throw (U"Cannot view a manual from batch.");
 	autoManual manual = Manual_create (U"Intro", theCurrentPraatApplication -> manPages, false);
 	HyperPage_goToPage_i (manual.get(), GET_INTEGER (U"Page"));
 	manual.releaseToUser();
-END2 }
+END }
 
-FORM (WriteManualToHtmlDirectory, U"Save all pages as HTML files", nullptr) {
+FORM (HELP_WriteManualToHtmlDirectory, U"Save all pages as HTML files", nullptr) {
 	LABEL (U"", U"Type a directory name:")
-	TEXTFIELD (U"directory", U"")
-	OK2
-structMelderDir currentDirectory { { 0 } };
-Melder_getDefaultDir (& currentDirectory);
-SET_STRING (U"directory", Melder_dirToPath (& currentDirectory))
+	TEXTFIELD4 (directory, U"directory", U"")
+OK
+	structMelderDir currentDirectory { { 0 } };
+	Melder_getDefaultDir (& currentDirectory);
+	SET_STRING (U"directory", Melder_dirToPath (& currentDirectory))
 DO
-	char32 *directory = GET_STRING (U"directory");
 	ManPages_writeAllToHtmlDir (theCurrentPraatApplication -> manPages, directory);
-END2 }
+END }
 
 /********** Menu descriptions. **********/
 
@@ -560,15 +561,15 @@ void praat_show () {
 /********** Menu descriptions. **********/
 
 void praat_addFixedButtons (GuiWindow window) {
-	praat_addFixedButtonCommand (window, U"Rename...", DO_Rename, 8, 70);
-	praat_addFixedButtonCommand (window, U"Copy...", DO_Copy, 98, 70);
-	praat_addFixedButtonCommand (window, U"Inspect", DO_Inspect, 8, 40);
-	praat_addFixedButtonCommand (window, U"Info", DO_Info, 98, 40);
-	praat_addFixedButtonCommand (window, U"Remove", DO_Remove, 8, 10);
+	praat_addFixedButtonCommand (window, U"Rename...", MODIFY_Rename, 8, 70);
+	praat_addFixedButtonCommand (window, U"Copy...", NEW1_Copy, 98, 70);
+	praat_addFixedButtonCommand (window, U"Inspect", WINDOW_Inspect, 8, 40);
+	praat_addFixedButtonCommand (window, U"Info", INFO_Info, 98, 40);
+	praat_addFixedButtonCommand (window, U"Remove", PRAAT_Remove, 8, 10);
 }
 
 static void searchProc () {
-	DO_SearchManual (nullptr, 0, nullptr, nullptr, nullptr, nullptr, false, nullptr);
+	HELP_SearchManual (nullptr, 0, nullptr, nullptr, nullptr, nullptr, false, nullptr);
 }
 
 static MelderString itemTitle_about { 0 };
@@ -593,24 +594,24 @@ static void cb_openDocument (MelderFile file) {
 }
 
 #if cocoa
-DIRECT2 (praat_cut) {
+DIRECT (PRAAT_cut) {
 	[[[NSApp keyWindow] fieldEditor: YES forObject: nil] cut: nil];
-END2 }
-DIRECT2 (praat_copy) {
+END }
+DIRECT (PRAAT_copy) {
 	[[[NSApp keyWindow] fieldEditor: YES forObject: nil] copy: nil];
-END2 }
-DIRECT2 (praat_paste) {
+END }
+DIRECT (PRAAT_paste) {
 	[[[NSApp keyWindow] fieldEditor: YES forObject: nil] pasteAsPlainText: nil];
-END2 }
-DIRECT2 (praat_minimize) {
+END }
+DIRECT (PRAAT_minimize) {
 	[[NSApp keyWindow] performMiniaturize: nil];
-END2 }
-DIRECT2 (praat_zoom) {
+END }
+DIRECT (PRAAT_zoom) {
 	[[NSApp keyWindow] performZoom: nil];
-END2 }
-DIRECT2 (praat_close) {
+END }
+DIRECT (PRAAT_close) {
 	[[NSApp keyWindow] performClose: nil];
-END2 }
+END }
 #endif
 
 void praat_addMenus (GuiWindow window) {
@@ -642,81 +643,83 @@ void praat_addMenus (GuiWindow window) {
 	
 	MelderString_append (& itemTitle_about, U"About ", praatP.title, U"...");
 	#ifdef macintosh
-		praat_addMenuCommand (U"Objects", U"Praat", itemTitle_about.string, nullptr, praat_UNHIDABLE, DO_About);
+		praat_addMenuCommand (U"Objects", U"Praat", itemTitle_about.string, nullptr, praat_UNHIDABLE, WINDOW_About);
 		#if cocoa
 			/*
 			 * HACK: give the following command weird names,
 			 * because otherwise they may be called from a script.
 			 * (we add three alt-spaces)
 			 */
-			praat_addMenuCommand (U"Objects", U"Edit", U"Cut   ", nullptr, praat_UNHIDABLE + 'X', DO_praat_cut);
-			praat_addMenuCommand (U"Objects", U"Edit", U"Copy   ", nullptr, praat_UNHIDABLE + 'C', DO_praat_copy);
-			praat_addMenuCommand (U"Objects", U"Edit", U"Paste   ", nullptr, praat_UNHIDABLE + 'V', DO_praat_paste);
-			praat_addMenuCommand (U"Objects", U"Window", U"Minimize   ", nullptr, praat_UNHIDABLE, DO_praat_minimize);
-			praat_addMenuCommand (U"Objects", U"Window", U"Zoom   ", nullptr, praat_UNHIDABLE, DO_praat_zoom);
-			praat_addMenuCommand (U"Objects", U"Window", U"Close   ", nullptr, 'W', DO_praat_close);
+			praat_addMenuCommand (U"Objects", U"Edit", U"Cut   ", nullptr, praat_UNHIDABLE | 'X' | praat_NO_API, PRAAT_cut);
+			praat_addMenuCommand (U"Objects", U"Edit", U"Copy   ", nullptr, praat_UNHIDABLE | 'C' | praat_NO_API, PRAAT_copy);
+			praat_addMenuCommand (U"Objects", U"Edit", U"Paste   ", nullptr, praat_UNHIDABLE | 'V' | praat_NO_API, PRAAT_paste);
+			praat_addMenuCommand (U"Objects", U"Window", U"Minimize   ", nullptr, praat_UNHIDABLE | praat_NO_API, PRAAT_minimize);
+			praat_addMenuCommand (U"Objects", U"Window", U"Zoom   ", nullptr, praat_UNHIDABLE | praat_NO_API, PRAAT_zoom);
+			praat_addMenuCommand (U"Objects", U"Window", U"Close   ", nullptr, 'W' | praat_NO_API, PRAAT_close);
 		#endif
 	#endif
 	#ifdef UNIX
-		praat_addMenuCommand (U"Objects", U"Praat", itemTitle_about.string, nullptr, praat_UNHIDABLE, DO_About);
+		praat_addMenuCommand (U"Objects", U"Praat", itemTitle_about.string, nullptr, praat_UNHIDABLE, WINDOW_About);
 	#endif
 	praat_addMenuCommand (U"Objects", U"Praat", U"-- script --", nullptr, 0, nullptr);
-	praat_addMenuCommand (U"Objects", U"Praat", U"New Praat script", nullptr, 0, DO_praat_newScript);
-	praat_addMenuCommand (U"Objects", U"Praat", U"Open Praat script...", nullptr, 0, DO_praat_openScript);
+	praat_addMenuCommand (U"Objects", U"Praat", U"New Praat script", nullptr, praat_NO_API, WINDOW_praat_newScript);
+	praat_addMenuCommand (U"Objects", U"Praat", U"Open Praat script...", nullptr, praat_NO_API, WINDOW_praat_openScript);
 	praat_addMenuCommand (U"Objects", U"Praat", U"-- buttons --", nullptr, 0, nullptr);
-	praat_addMenuCommand (U"Objects", U"Praat", U"Add menu command...", nullptr, praat_HIDDEN, DO_praat_addMenuCommand);
-	praat_addMenuCommand (U"Objects", U"Praat", U"Hide menu command...", nullptr, praat_HIDDEN, DO_praat_hideMenuCommand);
-	praat_addMenuCommand (U"Objects", U"Praat", U"Show menu command...", nullptr, praat_HIDDEN, DO_praat_showMenuCommand);
-	praat_addMenuCommand (U"Objects", U"Praat", U"Add action command...", nullptr, praat_HIDDEN, DO_praat_addAction);
-	praat_addMenuCommand (U"Objects", U"Praat", U"Hide action command...", nullptr, praat_HIDDEN, DO_praat_hideAction);
-	praat_addMenuCommand (U"Objects", U"Praat", U"Show action command...", nullptr, praat_HIDDEN, DO_praat_showAction);
+	praat_addMenuCommand (U"Objects", U"Praat", U"Add menu command...", nullptr, praat_HIDDEN | praat_NO_API, PRAAT_addMenuCommand);
+	praat_addMenuCommand (U"Objects", U"Praat", U"Hide menu command...", nullptr, praat_HIDDEN | praat_NO_API, PRAAT_hideMenuCommand);
+	praat_addMenuCommand (U"Objects", U"Praat", U"Show menu command...", nullptr, praat_HIDDEN | praat_NO_API, PRAAT_showMenuCommand);
+	praat_addMenuCommand (U"Objects", U"Praat", U"Add action command...", nullptr, praat_HIDDEN | praat_NO_API, PRAAT_addAction);
+	praat_addMenuCommand (U"Objects", U"Praat", U"Hide action command...", nullptr, praat_HIDDEN | praat_NO_API, PRAAT_hideAction);
+	praat_addMenuCommand (U"Objects", U"Praat", U"Show action command...", nullptr, praat_HIDDEN | praat_NO_API, PRAAT_showAction);
 
 	GuiMenuItem menuItem = praat_addMenuCommand (U"Objects", U"Praat", U"Goodies", nullptr, praat_UNHIDABLE, nullptr);
 	goodiesMenu = menuItem ? menuItem -> d_menu : nullptr;
-	praat_addMenuCommand (U"Objects", U"Goodies", U"Calculator...", nullptr, 'U', DO_praat_calculator);
-	praat_addMenuCommand (U"Objects", U"Goodies", U"Report difference of two proportions...", nullptr, 0, DO_praat_reportDifferenceOfTwoProportions);
+	praat_addMenuCommand (U"Objects", U"Goodies", U"Calculator...", nullptr, 'U', STRING_praat_calculator);
+	praat_addMenuCommand (U"Objects", U"Goodies", U"Report difference of two proportions...", nullptr, 0, INFO_reportDifferenceOfTwoProportions);
 
 	menuItem = praat_addMenuCommand (U"Objects", U"Praat", U"Preferences", nullptr, praat_UNHIDABLE, nullptr);
 	preferencesMenu = menuItem ? menuItem -> d_menu : nullptr;
-	praat_addMenuCommand (U"Objects", U"Preferences", U"Buttons...", nullptr, praat_UNHIDABLE, DO_praat_editButtons);   /* Cannot be hidden. */
+	praat_addMenuCommand (U"Objects", U"Preferences", U"Buttons...", nullptr, praat_UNHIDABLE, WINDOW_praat_editButtons);
 	praat_addMenuCommand (U"Objects", U"Preferences", U"-- encoding prefs --", nullptr, 0, nullptr);
-	praat_addMenuCommand (U"Objects", U"Preferences", U"Text reading preferences...", nullptr, 0, DO_TextInputEncodingSettings);
-	praat_addMenuCommand (U"Objects", U"Preferences", U"Text writing preferences...", nullptr, 0, DO_TextOutputEncodingSettings);
-	praat_addMenuCommand (U"Objects", U"Preferences", U"CJK font style preferences...", nullptr, 0, DO_GraphicsCjkFontStyleSettings);
+	praat_addMenuCommand (U"Objects", U"Preferences", U"Text reading preferences...", nullptr, 0, PREFS_TextInputEncodingSettings);
+	praat_addMenuCommand (U"Objects", U"Preferences", U"Text writing preferences...", nullptr, 0, PREFS_TextOutputEncodingSettings);
+	praat_addMenuCommand (U"Objects", U"Preferences", U"CJK font style preferences...", nullptr, 0, PREFS_GraphicsCjkFontStyleSettings);
 
 	menuItem = praat_addMenuCommand (U"Objects", U"Praat", U"Technical", nullptr, praat_UNHIDABLE, nullptr);
 	technicalMenu = menuItem ? menuItem -> d_menu : nullptr;
-	praat_addMenuCommand (U"Objects", U"Technical", U"List readable types of objects", nullptr, 0, DO_praat_listReadableTypesOfObjects);
-	praat_addMenuCommand (U"Objects", U"Technical", U"Report memory use", nullptr, 0, DO_praat_reportMemoryUse);
-	praat_addMenuCommand (U"Objects", U"Technical", U"Report integer properties", nullptr, 0, DO_praat_reportIntegerProperties);
-	praat_addMenuCommand (U"Objects", U"Technical", U"Report text properties", nullptr, 0, DO_praat_reportTextProperties);
-	praat_addMenuCommand (U"Objects", U"Technical", U"Report system properties", nullptr, 0, DO_praat_reportSystemProperties);
-	praat_addMenuCommand (U"Objects", U"Technical", U"Report graphical properties", nullptr, 0, DO_praat_reportGraphicalProperties);
-	praat_addMenuCommand (U"Objects", U"Technical", U"Debug...", nullptr, 0, DO_praat_debug);
+	praat_addMenuCommand (U"Objects", U"Technical", U"Report memory use", nullptr, 0, INFO_reportMemoryUse);
+	praat_addMenuCommand (U"Objects", U"Technical", U"Report integer properties", nullptr, 0, INFO_reportIntegerProperties);
+	praat_addMenuCommand (U"Objects", U"Technical", U"Report text properties", nullptr, 0, INFO_reportTextProperties);
+	praat_addMenuCommand (U"Objects", U"Technical", U"Report system properties", nullptr, 0, INFO_reportSystemProperties);
+	praat_addMenuCommand (U"Objects", U"Technical", U"Report graphical properties", nullptr, 0, INFO_reportGraphicalProperties);
+	praat_addMenuCommand (U"Objects", U"Technical", U"Debug...", nullptr, 0, PRAAT_debug);
+	praat_addMenuCommand (U"Objects", U"Technical", U"-- api --", nullptr, 0, nullptr);
+	praat_addMenuCommand (U"Objects", U"Technical", U"List readable types of objects", nullptr, 0, INFO_listReadableTypesOfObjects);
+	praat_addMenuCommand (U"Objects", U"Technical", U"Create C interface...", nullptr, 0, INFO_praat_library_createC);
 
-	praat_addMenuCommand (U"Objects", U"Open", U"Read from file...", nullptr, praat_ATTRACTIVE + 'O', DO_Data_readFromFile);
+	praat_addMenuCommand (U"Objects", U"Open", U"Read from file...", nullptr, praat_ATTRACTIVE | 'O', READMANY_Data_readFromFile);
 
-	praat_addAction1 (classDaata, 0, U"Save as text file...", nullptr, 0, DO_Data_writeToTextFile);
-	praat_addAction1 (classDaata, 0, U"Write to text file...", nullptr, praat_HIDDEN, DO_Data_writeToTextFile);
-	praat_addAction1 (classDaata, 0, U"Save as short text file...", nullptr, 0, DO_Data_writeToShortTextFile);
-	praat_addAction1 (classDaata, 0, U"Write to short text file...", nullptr, praat_HIDDEN, DO_Data_writeToShortTextFile);
-	praat_addAction1 (classDaata, 0, U"Save as binary file...", nullptr, 0, DO_Data_writeToBinaryFile);
-	praat_addAction1 (classDaata, 0, U"Write to binary file...", nullptr, praat_HIDDEN, DO_Data_writeToBinaryFile);
+	praat_addAction1 (classDaata, 0, U"Save as text file...", nullptr, 0, SAVE_Data_writeToTextFile);
+	praat_addAction1 (classDaata, 0,   U"Write to text file...", nullptr, praat_DEPRECATED_2011, SAVE_Data_writeToTextFile);
+	praat_addAction1 (classDaata, 0, U"Save as short text file...", nullptr, 0, SAVE_Data_writeToShortTextFile);
+	praat_addAction1 (classDaata, 0,   U"Write to short text file...", nullptr, praat_DEPRECATED_2011, SAVE_Data_writeToShortTextFile);
+	praat_addAction1 (classDaata, 0, U"Save as binary file...", nullptr, 0, SAVE_Data_writeToBinaryFile);
+	praat_addAction1 (classDaata, 0,   U"Write to binary file...", nullptr, praat_DEPRECATED_2011, SAVE_Data_writeToBinaryFile);
 
-	praat_addAction1 (classManPages, 1, U"Save to HTML directory...", nullptr, 0, DO_ManPages_saveToHtmlDirectory);
-	praat_addAction1 (classManPages, 1, U"View", nullptr, 0, DO_ManPages_view);
+	praat_addAction1 (classManPages, 1, U"Save to HTML directory...", nullptr, 0, PRAAT_ManPages_saveToHtmlDirectory);
+	praat_addAction1 (classManPages, 1, U"View", nullptr, 0, WINDOW_ManPages_view);
 }
 
 void praat_addMenus2 () {
 	praat_addMenuCommand (U"Objects", U"ApplicationHelp", U"-- manual --", nullptr, 0, nullptr);
-	praat_addMenuCommand (U"Objects", U"ApplicationHelp", U"Go to manual page...", nullptr, 0, DO_GoToManualPage);
-	praat_addMenuCommand (U"Objects", U"ApplicationHelp", U"Write manual to HTML directory...", nullptr, praat_HIDDEN, DO_WriteManualToHtmlDirectory);
+	praat_addMenuCommand (U"Objects", U"ApplicationHelp", U"Go to manual page...", nullptr, 0, HELP_GoToManualPage);
+	praat_addMenuCommand (U"Objects", U"ApplicationHelp", U"Write manual to HTML directory...", nullptr, praat_HIDDEN, HELP_WriteManualToHtmlDirectory);
 	praat_addMenuCommand (U"Objects", U"ApplicationHelp",
 		Melder_cat (U"Search ", praatP.title, U" manual..."),
-		nullptr, 'M', DO_SearchManual);
+		nullptr, 'M' | praat_NO_API, HELP_SearchManual);
 	#ifdef _WIN32
 		praat_addMenuCommand (U"Objects", U"Help", U"-- about --", nullptr, 0, nullptr);
-		praat_addMenuCommand (U"Objects", U"Help", itemTitle_about.string, nullptr, praat_UNHIDABLE, DO_About);
+		praat_addMenuCommand (U"Objects", U"Help", itemTitle_about.string, nullptr, praat_UNHIDABLE, WINDOW_About);
 	#endif
 
 	#if defined (macintosh) || defined (_WIN32)
